@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,14 +35,12 @@
 
 #include <memory>
 
-#include "base/android_jni_proxy.h"
-#include "base/android_util.h"
-#include "base/file_util.h"
 #include "base/logging.h"
-#include "base/scheduler.h"
 #include "base/singleton.h"
+#include "base/status.h"
+#include "base/statusor.h"
 #include "base/system_util.h"
-#include "base/version.h"
+#include "base/util.h"
 #include "data_manager/data_manager.h"
 #include "engine/engine.h"
 #include "engine/engine_builder.h"
@@ -50,52 +48,18 @@
 #include "protocol/commands.pb.h"
 #include "session/session_handler.h"
 #include "session/session_usage_observer.h"
-#include "usage_stats/usage_stats_uploader.h"
-
-#if !defined(MOZC_USE_CUSTOM_DATA_MANAGER)
-// Use plain DataManager, which needs to be manually initialized.
-using TargetDataManager = ::mozc::DataManager;
-constexpr bool kEmbeddedData = false;
-
-
-#else
-// Use OssDataManager, which is embedding data by default.
-#include "data_manager/oss/oss_data_manager.h"
-using TargetDataManager = ::mozc::oss::OssDataManager;
-constexpr bool kEmbeddedData = true;
-
-#endif
+#include "absl/strings/str_cat.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace jni {
 namespace {
 
-// Returns a job setting for usage stats job.
-const Scheduler::JobSetting GetJobSetting() {
-  return Scheduler::JobSetting(
-      "UsageStatsTimer",
-      usage_stats::UsageStatsUploader::kDefaultScheduleInterval,
-      usage_stats::UsageStatsUploader::kDefaultScheduleMaxInterval,
-      usage_stats::UsageStatsUploader::kDefaultSchedulerDelay,
-      usage_stats::UsageStatsUploader::kDefaultSchedulerRandomDelay,
-      &usage_stats::UsageStatsUploader::Send,
-      NULL);
-}
-
-// Gets the Java VM from JNIEnv.
-JavaVM *GetJavaVm(JNIEnv *env) {
-  DCHECK(env);
-  JavaVM *vm = nullptr;
-  env->GetJavaVM(&vm);
-  return vm;
-}
-
 // The global instance of Mozc system to be initialized in onPostLoad().
 std::unique_ptr<SessionHandlerInterface> g_session_handler;
 
 // Concrete implementation for MozcJni.evalCommand
-jbyteArray JNICALL evalCommand(JNIEnv *env,
-                               jclass clazz,
+jbyteArray JNICALL evalCommand(JNIEnv *env, jclass clazz,
                                jbyteArray in_bytes_array) {
   jbyte *in_bytes = env->GetByteArrayElements(in_bytes_array, nullptr);
   const jsize in_size = env->GetArrayLength(in_bytes_array);
@@ -110,7 +74,7 @@ jbyteArray JNICALL evalCommand(JNIEnv *env,
   // Use JNI_ABORT because in_bytes is read only.
   env->ReleaseByteArrayElements(in_bytes_array, in_bytes, JNI_ABORT);
 
-  const int out_size = command.ByteSize();
+  const int out_size = command.ByteSizeLong();
   jbyteArray out_bytes_array = env->NewByteArray(out_size);
   jbyte *out_bytes = env->GetByteArrayElements(out_bytes_array, nullptr);
   command.SerializeToArray(out_bytes, out_size);
@@ -128,46 +92,56 @@ string JstringToCcString(JNIEnv *env, jstring j_string) {
   return cc_string;
 }
 
-std::unique_ptr<DataManager> CreateDataManager(JNIEnv *env,
-                                               jstring j_data_file_path) {
-  if (kEmbeddedData) {
-    // If the data manager uses embedded data like OSS version,
-    // j_data_file_path is validly nullptr.
-    std::unique_ptr<DataManager> data_manager(new TargetDataManager());
-    return data_manager;
-  }
-
-  if (j_data_file_path == nullptr) {
-    return nullptr;
-  }
-  const string &data_file_path = JstringToCcString(env, j_data_file_path);
-  std::unique_ptr<DataManager> data_manager(new TargetDataManager());
+mozc::StatusOr<std::unique_ptr<DataManager>> CreateDataManager(
+    const std::string &data_file_path) {
+  auto data_manager = absl::make_unique<DataManager>();
   const auto status = data_manager->InitFromFile(data_file_path);
   if (status != DataManager::Status::OK) {
-    LOG(INFO) << "Failed to load data file from " << data_file_path << "("
-              << DataManager::StatusCodeToString(status) << "). "
-              << "Fall back to the embedded data.";
-    data_manager.reset();
+    return mozc::FailedPreconditionError(
+        DataManager::StatusCodeToString(status));
   }
   return data_manager;
 }
 
+std::unique_ptr<EngineInterface> CreateMobileEngine(
+    const std::string &data_file_path) {
+  auto data_manager = CreateDataManager(data_file_path);
+  if (!data_manager.ok()) {
+    LOG(ERROR) << "Failed to create a data manager from " << data_file_path
+               << ": " << data_manager.status()
+               << ": Fallback to minimal engine";
+    return absl::make_unique<MinimalEngine>();
+  }
+  const absl::string_view data_version = (*data_manager)->GetDataVersion();
+  auto engine = Engine::CreateMobileEngine(*std::move(data_manager));
+  if (!engine.ok()) {
+    LOG(ERROR) << "Failed to create a mobile engine: file " << data_file_path
+               << ", data version: " << data_version << ": " << engine.status()
+               << ": Fallback to minimal engine";
+    return absl::make_unique<MinimalEngine>();
+  }
+  LOG(INFO) << "Successfully created a mobile engine from " << data_file_path
+            << ", data version=" << data_version;
+  return *std::move(engine);
+}
+
 std::unique_ptr<SessionHandlerInterface> CreateSessionHandler(
-    JNIEnv *env, jstring data_file_path) {
+    JNIEnv *env, jstring j_data_file_path) {
   if (env == nullptr) {
     LOG(DFATAL) << "JNIEnv is null";
     return nullptr;
   }
-  std::unique_ptr<DataManager> data_manager =
-      CreateDataManager(env, data_file_path);
   std::unique_ptr<EngineInterface> engine;
-  if (data_manager) {
-    engine = Engine::CreateMobileEngine(std::move(data_manager));
+  if (j_data_file_path == nullptr) {
+    LOG(ERROR) << "j_data_file_path is null.  Fallback to minimal engine.";
+    engine = absl::make_unique<MinimalEngine>();
   } else {
-    engine.reset(new MinimalEngine());
+    const string &data_file_path = JstringToCcString(env, j_data_file_path);
+    engine = CreateMobileEngine(data_file_path);
   }
-  std::unique_ptr<SessionHandlerInterface> result(new SessionHandler(
-      std::move(engine), std::unique_ptr<EngineBuilder>(new EngineBuilder())));
+  DCHECK(engine);
+  auto result = absl::make_unique<SessionHandler>(
+      std::move(engine), absl::make_unique<EngineBuilder>());
   result->AddObserver(Singleton<session::SessionUsageObserver>::get());
   return result;
 }
@@ -175,10 +149,9 @@ std::unique_ptr<SessionHandlerInterface> CreateSessionHandler(
 // Does post-load tasks.
 // Returns true if the task succeeded
 // or SessionHandler has already been initializaed.
-jboolean JNICALL onPostLoad(JNIEnv *env,
-                        jclass clazz,
-                        jstring user_profile_directory_path,
-                        jstring data_file_path) {
+jboolean JNICALL onPostLoad(JNIEnv *env, jclass clazz,
+                            jstring user_profile_directory_path,
+                            jstring data_file_path) {
   if (g_session_handler) {
     return true;
   }
@@ -188,91 +161,54 @@ jboolean JNICALL onPostLoad(JNIEnv *env,
   SystemUtil::SetUserProfileDirectory(
       JstringToCcString(env, user_profile_directory_path));
 
-  // Initializes Java native callback proxy.
-  JavaHttpClientProxy::SetJavaVM(GetJavaVm(env));
-
   // Initializes the global Mozc system.
   g_session_handler = CreateSessionHandler(env, data_file_path);
   if (!g_session_handler) {
-    JavaHttpClientProxy::SetJavaVM(nullptr);
     SystemUtil::SetUserProfileDirectory(original_dir);
     LOG(DFATAL) << "Failed to create Mozc session handler";
     return false;
   }
 
-  // Starts usage stats timer.
-  Scheduler::AddJob(GetJobSetting());
   return true;
 }
 
-jstring JNICALL getVersion(JNIEnv *env) {
-  return env->NewStringUTF(Version::GetMozcVersion().c_str());
-}
-
 jstring JNICALL getDataVersion(JNIEnv *env) {
   string version = "";
   if (g_session_handler) {
-    g_session_handler->GetDataVersion().CopyToString(&version);
+    const absl::string_view version_sp = g_session_handler->GetDataVersion();
+    version.assign(version_sp.begin(), version_sp.end());
   }
   return env->NewStringUTF(version.c_str());
 }
 
-void JNICALL suppressSendingStats(JNIEnv *env,
-                                  jobject clazz,
-                                  jboolean suppress) {
-  const Scheduler::JobSetting &jobSetting = GetJobSetting();
-  const string &name = jobSetting.name();
-  const bool hasJob = mozc::Scheduler::HasJob(name);
-  if (suppress && hasJob) {
-    mozc::Scheduler::RemoveJob(name);
-  } else if (!suppress && !hasJob) {
-    mozc::Scheduler::AddJob(jobSetting);
-  }
-}
-
 }  // namespace
 }  // namespace jni
 }  // namespace mozc
 
 extern "C" {
 
-JNIEXPORT jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved) {
-  JNIEnv *env = mozc::AndroidUtil::GetEnv(vm);
+JNIEXPORT jboolean JNICALL
+Java_com_google_android_inputmethod_japanese_session_MozcJNI_initialize(
+    JNIEnv *env, jclass clazz) {
   if (!env) {
     // Fatal error. No way to recover.
-     return JNI_EVERSION;
+    return false;
   }
   const JNINativeMethod methods[] = {
-      {"evalCommand",
-       "([B)[B",
-       reinterpret_cast<void*>(&mozc::jni::evalCommand)},
-      {"onPostLoad",
-       "(Ljava/lang/String;Ljava/lang/String;)Z",
-       reinterpret_cast<void*>(&mozc::jni::onPostLoad)},
-      {"getVersion",
-       "()Ljava/lang/String;",
-       reinterpret_cast<void*>(&mozc::jni::getVersion)},
-      {"getDataVersion",
-       "()Ljava/lang/String;",
-       reinterpret_cast<void*>(&mozc::jni::getDataVersion)},
-      {"suppressSendingStats",
-       "(Z)V",
-       reinterpret_cast<void*>(&mozc::jni::suppressSendingStats)},
+      {"evalCommand", "([B)[B",
+       reinterpret_cast<void *>(&mozc::jni::evalCommand)},
+      {"onPostLoad", "(Ljava/lang/String;Ljava/lang/String;)Z",
+       reinterpret_cast<void *>(&mozc::jni::onPostLoad)},
+      {"getDataVersion", "()Ljava/lang/String;",
+       reinterpret_cast<void *>(&mozc::jni::getDataVersion)},
   };
-  jclass clazz = env->FindClass(
-      "org/mozc/android/inputmethod/japanese/session/MozcJNI");
   if (env->RegisterNatives(clazz, methods, arraysize(methods))) {
     // Fatal error. No way to recover.
-    return JNI_EVERSION;
+    return false;
   }
 
-  mozc::Logging::InitLogStream("");  // Andorid doesn't stream log to a file.
-  return JNI_VERSION_1_6;
-}
-
-JNIEXPORT void JNICALL JNI_OnUnload(JavaVM *vm, void *reserved) {
-  mozc::jni::g_session_handler.reset();
-  mozc::jni::JavaHttpClientProxy::SetJavaVM(nullptr);
+  mozc::Logging::InitLogStream("");  // Android doesn't stream log to a file.
+  return true;
 }
 
 }  // extern "C"
