@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -65,8 +65,7 @@ TEST(BitArray, BitArraySizeTest) {
 }
 
 TEST(BitArray, BitArrayTest) {
-  const size_t kBitArraySize[] =
-      { 1, 2, 10, 32, 64, 100, 1000, 1024, 10000 };
+  const size_t kBitArraySize[] = {1, 2, 10, 32, 64, 100, 1000, 1024, 10000};
 
   for (size_t i = 0; i < arraysize(kBitArraySize); ++i) {
     const size_t size = kBitArraySize[i];
