@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -40,16 +40,20 @@ namespace mozc {
 class ClockMock : public ClockInterface {
  public:
   ClockMock(uint64 sec, uint32 usec);
-  virtual ~ClockMock();
 
-  virtual void GetTimeOfDay(uint64 *sec, uint32 *usec);
-  virtual uint64 GetTime();
-  virtual bool GetTmWithOffsetSecond(time_t offset_sec, tm *output);
-  virtual uint64 GetFrequency();
-  virtual uint64 GetTicks();
-#ifdef OS_NACL
-  virtual void SetTimezoneOffset(int32 timezone_offset_sec);
-#endif  // OS_NACL
+  ClockMock(const ClockMock &) = delete;
+  ClockMock &operator=(const ClockMock &) = delete;
+
+  ~ClockMock() override;
+
+  void GetTimeOfDay(uint64 *sec, uint32 *usec) override;
+  uint64 GetTime() override;
+  absl::Time GetAbslTime() override;
+  uint64 GetFrequency() override;
+  uint64 GetTicks() override;
+
+  const absl::TimeZone& GetTimeZone() override;
+  void SetTimeZoneOffset(int32 timezone_offset_sec) override;
 
   // Puts this clock forward.
   // It has no impact on ticks.
@@ -72,15 +76,31 @@ class ClockMock : public ClockInterface {
   uint32 micro_seconds_;
   uint64 frequency_;
   uint64 ticks_;
-#ifdef OS_NACL
+  absl::TimeZone timezone_;
   int32 timezone_offset_sec_;
-#endif  // OS_NACL
   // Everytime user requests time clock, following time is added to the
   // internal clock.
   uint64 delta_seconds_;
   uint32 delta_micro_seconds_;
+};
 
-  DISALLOW_COPY_AND_ASSIGN(ClockMock);
+// Changes the global clock with a mock during the life time of this object.
+class ScopedClockMock {
+ public:
+  ScopedClockMock(uint64 sec, uint32 usec) : mock_(sec, usec) {
+    Clock::SetClockForUnitTest(&mock_);
+  }
+
+  ScopedClockMock(const ScopedClockMock &) = delete;
+  ScopedClockMock &operator=(const ScopedClockMock &) = delete;
+
+  ~ScopedClockMock() { Clock::SetClockForUnitTest(nullptr); }
+
+  ClockMock *operator->() { return &mock_; }
+  const ClockMock *operator->() const { return &mock_; }
+
+ private:
+  ClockMock mock_;
 };
 
 }  // namespace mozc
