@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,13 +33,13 @@
 #include <windows.h>
 #endif  // OS_WIN
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
+#include <mach/host_info.h>
 #include <mach/mach_host.h>
 #include <mach/mach_init.h>
-#include <mach/host_info.h>
 #include <mach/task.h>
 #include <sys/time.h>
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 
 #include "base/logging.h"
 #include "base/port.h"
@@ -49,30 +49,29 @@ namespace {
 
 #ifdef OS_WIN
 uint64 FileTimeToInt64(const FILETIME &file_time) {
-  return (static_cast<uint64>(file_time.dwHighDateTime) << 32)
-      | (static_cast<uint64>(file_time.dwLowDateTime));
+  return (static_cast<uint64>(file_time.dwHighDateTime) << 32) |
+         (static_cast<uint64>(file_time.dwLowDateTime));
 }
 #endif  // OS_WIN
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
 uint64 TimeValueTToInt64(const time_value_t &time_value) {
   return 1000000ULL * time_value.seconds + time_value.microseconds;
 }
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 
-float UpdateCPULoad(uint64 current_total_times,
-                    uint64 current_cpu_times,
-                    uint64 *prev_total_times,
-                    uint64 *prev_cpu_times) {
+float UpdateCPULoad(uint64 current_total_times, uint64 current_cpu_times,
+                    uint64 *prev_total_times, uint64 *prev_cpu_times) {
   float result = 0.0;
   if (current_total_times < *prev_total_times ||
       current_cpu_times < *prev_cpu_times) {
-    LOG(ERROR) << "Inconsitent time values are passed. ignored";
+    LOG(ERROR) << "Inconsistent time values are passed. ignored";
   } else {
     const uint64 total_diff = current_total_times - *prev_total_times;
     const uint64 cpu_diff = current_cpu_times - *prev_cpu_times;
-    result = (total_diff == 0ULL ? 0.0 :
-              static_cast<float>(1.0 * cpu_diff / total_diff));
+    result =
+        (total_diff == 0ULL ? 0.0
+                            : static_cast<float>(1.0 * cpu_diff / total_diff));
   }
 
   *prev_total_times = current_total_times;
@@ -101,12 +100,12 @@ float CPUStats::GetSystemCPULoad() {
 
   // kernel_time includes Kernel idle time, so no need to
   // include cpu_time as total_times
-  const uint64 total_times = FileTimeToInt64(kernel_time) +
-      FileTimeToInt64(user_time);
+  const uint64 total_times =
+      FileTimeToInt64(kernel_time) + FileTimeToInt64(user_time);
   const uint64 cpu_times = total_times - FileTimeToInt64(idle_time);
 #endif  // OS_WIN
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
   host_cpu_load_info_data_t cpu_info;
   mach_msg_type_number_t info_count = HOST_CPU_LOAD_INFO_COUNT;
   if (KERN_SUCCESS != host_statistics(mach_host_self(), HOST_CPU_LOAD_INFO,
@@ -117,13 +116,14 @@ float CPUStats::GetSystemCPULoad() {
   }
 
   const uint64 cpu_times = cpu_info.cpu_ticks[CPU_STATE_NICE] +
-      cpu_info.cpu_ticks[CPU_STATE_SYSTEM] +
-      cpu_info.cpu_ticks[CPU_STATE_USER];
+                           cpu_info.cpu_ticks[CPU_STATE_SYSTEM] +
+                           cpu_info.cpu_ticks[CPU_STATE_USER];
   const uint64 total_times = cpu_times + cpu_info.cpu_ticks[CPU_STATE_IDLE];
 
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 
-#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL)
+#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
+  defined(OS_WASM)
   // NOT IMPLEMENTED
   // TODO(taku): implement Linux version
   // can take the info from /proc/stats
@@ -131,9 +131,7 @@ float CPUStats::GetSystemCPULoad() {
   const uint64 cpu_times = 0;
 #endif  // OS_LINUX || OS_ANDROID || OS_NACL
 
-  return UpdateCPULoad(total_times,
-                       cpu_times,
-                       &prev_system_total_times_,
+  return UpdateCPULoad(total_times, cpu_times, &prev_system_total_times_,
                        &prev_system_cpu_times_);
 }
 
@@ -143,8 +141,8 @@ float CPUStats::GetCurrentProcessCPULoad() {
   ::GetSystemTimeAsFileTime(&current_file_time);
 
   FILETIME create_time, exit_time, kernel_time, user_time;
-  if (!::GetProcessTimes(::GetCurrentProcess(),
-                         &create_time, &exit_time, &kernel_time, &user_time)) {
+  if (!::GetProcessTimes(::GetCurrentProcess(), &create_time, &exit_time,
+                         &kernel_time, &user_time)) {
     LOG(ERROR) << "::GetProcessTimes() failed: " << ::GetLastError();
     return 0.0;
   }
@@ -155,7 +153,7 @@ float CPUStats::GetCurrentProcessCPULoad() {
       FileTimeToInt64(kernel_time) + FileTimeToInt64(user_time);
 #endif  // OS_WIN
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
   task_thread_times_info task_times_info;
   mach_msg_type_number_t info_count = TASK_THREAD_TIMES_INFO_COUNT;
 
@@ -169,23 +167,23 @@ float CPUStats::GetCurrentProcessCPULoad() {
   // OSX has no host_get_time(), use gettimeofday instead.
   // http://www.gnu.org/software/hurd/gnumach-doc/Host-Time.html
   // OSX's basic_info_t has no filed |creation_time|, we cannot use it.
-  // The intial value might be diffrent from the real CPU load.
+  // The initial value might be different from the real CPU load.
   struct timeval tv;
-  gettimeofday(&tv, NULL);
+  gettimeofday(&tv, nullptr);
 
   const uint64 total_times = 1000000ULL * tv.tv_sec + tv.tv_usec;
   const uint64 cpu_times = TimeValueTToInt64(task_times_info.user_time) +
-      TimeValueTToInt64(task_times_info.system_time);
-#endif  // OS_MACOSX
+                           TimeValueTToInt64(task_times_info.system_time);
+#endif  // __APPLE__
 
-#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL)
+#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
+  defined(OS_WASM)
   // not implemented
   const uint64 total_times = 0;
   const uint64 cpu_times = 0;
 #endif  // OS_LINUX || OS_ANDROID || OS_NACL
 
-  return UpdateCPULoad(total_times,
-                       cpu_times,
+  return UpdateCPULoad(total_times, cpu_times,
                        &prev_current_process_total_times_,
                        &prev_current_process_cpu_times_);
 }
@@ -197,7 +195,7 @@ size_t CPUStats::GetNumberOfProcessors() const {
   return static_cast<size_t>(info.dwNumberOfProcessors);
 #endif  // OS_WIN
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
   host_basic_info basic_info;
   mach_msg_type_number_t info_count = HOST_BASIC_INFO_COUNT;
   if (KERN_SUCCESS != host_info(mach_host_self(), HOST_BASIC_INFO,
@@ -208,9 +206,10 @@ size_t CPUStats::GetNumberOfProcessors() const {
   }
 
   return static_cast<size_t>(basic_info.avail_cpus);
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 
-#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL)
+#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
+  defined(OS_WASM)
   // Not implemented
   return 1;
 #endif  // OS_LINUX
