@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ namespace {
 class DummyThread : public mozc::Thread {
  public:
   DummyThread() {}
-  void Run() {
+  void Run() override {
     volatile uint64 n = 0;
     while (true) {
       ++n;
@@ -60,7 +60,7 @@ class DummyThread : public mozc::Thread {
 }  // namespace
 
 int main(int argc, char **argv) {
-  mozc::InitMozc(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv);
 
   std::unique_ptr<DummyThread[]> threads;
 
