@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
 
 #import "base/crash_report_handler.h"
 
@@ -78,4 +78,4 @@ bool CrashReportHandler::Uninitialize() {
 
 }  // namespace mozc
 
-#endif  // OS_MACOSX
+#endif  // __APPLE__
