@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,6 +39,7 @@
 #include "base/file_stream.h"
 #include "base/logging.h"
 #include "base/util.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
 // Ad-hoc workadound against macro problem on Windows.
@@ -56,16 +57,12 @@
 #undef CopyFile
 #endif  // CopyFile
 
-DECLARE_string(test_srcdir);
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 
-class FileUtilTest : public testing::Test {
-};
+class FileUtilTest : public testing::Test {};
 
 namespace {
-void CreateTestFile(const string &filename, const string &data) {
+void CreateTestFile(const std::string &filename, const std::string &data) {
   OutputFileStream ofs(filename.c_str(), std::ios::binary | std::ios::trunc);
   ofs << data;
   EXPECT_TRUE(ofs.good());
@@ -75,7 +72,7 @@ void CreateTestFile(const string &filename, const string &data) {
 TEST_F(FileUtilTest, CreateDirectory) {
   EXPECT_TRUE(FileUtil::DirectoryExists(FLAGS_test_tmpdir));
   // dirpath = FLAGS_test_tmpdir/testdir
-  const string dirpath = FileUtil::JoinPath(FLAGS_test_tmpdir, "testdir");
+  const std::string dirpath = FileUtil::JoinPath(FLAGS_test_tmpdir, "testdir");
 
   // Delete dirpath, if it exists.
   if (FileUtil::FileExists(dirpath)) {
@@ -94,7 +91,8 @@ TEST_F(FileUtilTest, CreateDirectory) {
 
 TEST_F(FileUtilTest, DirectoryExists) {
   EXPECT_TRUE(FileUtil::DirectoryExists(FLAGS_test_tmpdir));
-  const string filepath = FileUtil::JoinPath(FLAGS_test_tmpdir, "testfile");
+  const std::string filepath =
+      FileUtil::JoinPath(FLAGS_test_tmpdir, "testfile");
 
   // Delete filepath, if it exists.
   if (FileUtil::FileExists(filepath)) {
@@ -113,7 +111,8 @@ TEST_F(FileUtilTest, DirectoryExists) {
 }
 
 TEST_F(FileUtilTest, Unlink) {
-  const string filepath = FileUtil::JoinPath(FLAGS_test_tmpdir, "testfile");
+  const std::string filepath =
+      FileUtil::JoinPath(FLAGS_test_tmpdir, "testfile");
   FileUtil::Unlink(filepath);
   EXPECT_FALSE(FileUtil::FileExists(filepath));
 
@@ -124,14 +123,10 @@ TEST_F(FileUtilTest, Unlink) {
 
 #ifdef OS_WIN
   const DWORD kTestAttributeList[] = {
-    FILE_ATTRIBUTE_ARCHIVE,
-    FILE_ATTRIBUTE_HIDDEN,
-    FILE_ATTRIBUTE_NORMAL,
-    FILE_ATTRIBUTE_NOT_CONTENT_INDEXED,
-    FILE_ATTRIBUTE_OFFLINE,
-    FILE_ATTRIBUTE_READONLY,
-    FILE_ATTRIBUTE_SYSTEM,
-    FILE_ATTRIBUTE_TEMPORARY,
+      FILE_ATTRIBUTE_ARCHIVE, FILE_ATTRIBUTE_HIDDEN,
+      FILE_ATTRIBUTE_NORMAL,  FILE_ATTRIBUTE_NOT_CONTENT_INDEXED,
+      FILE_ATTRIBUTE_OFFLINE, FILE_ATTRIBUTE_READONLY,
+      FILE_ATTRIBUTE_SYSTEM,  FILE_ATTRIBUTE_TEMPORARY,
   };
 
   std::wstring wfilepath;
@@ -167,14 +162,14 @@ TEST_F(FileUtilTest, HideFile) {
             ::SetFileAttributesW(wfilename.c_str(), FILE_ATTRIBUTE_NORMAL));
   EXPECT_TRUE(FileUtil::HideFile(filename));
   EXPECT_EQ(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM |
-            FILE_ATTRIBUTE_NOT_CONTENT_INDEXED,
+                FILE_ATTRIBUTE_NOT_CONTENT_INDEXED,
             ::GetFileAttributesW(wfilename.c_str()));
 
   EXPECT_NE(FALSE,
             ::SetFileAttributesW(wfilename.c_str(), FILE_ATTRIBUTE_ARCHIVE));
   EXPECT_TRUE(FileUtil::HideFile(filename));
   EXPECT_EQ(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM |
-            FILE_ATTRIBUTE_NOT_CONTENT_INDEXED | FILE_ATTRIBUTE_ARCHIVE,
+                FILE_ATTRIBUTE_NOT_CONTENT_INDEXED | FILE_ATTRIBUTE_ARCHIVE,
             ::GetFileAttributesW(wfilename.c_str()));
 
   EXPECT_NE(FALSE,
@@ -182,7 +177,7 @@ TEST_F(FileUtilTest, HideFile) {
   EXPECT_TRUE(FileUtil::HideFileWithExtraAttributes(filename,
                                                     FILE_ATTRIBUTE_TEMPORARY));
   EXPECT_EQ(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM |
-            FILE_ATTRIBUTE_NOT_CONTENT_INDEXED | FILE_ATTRIBUTE_TEMPORARY,
+                FILE_ATTRIBUTE_NOT_CONTENT_INDEXED | FILE_ATTRIBUTE_TEMPORARY,
             ::GetFileAttributesW(wfilename.c_str()));
 
   EXPECT_NE(FALSE,
@@ -190,8 +185,8 @@ TEST_F(FileUtilTest, HideFile) {
   EXPECT_TRUE(FileUtil::HideFileWithExtraAttributes(filename,
                                                     FILE_ATTRIBUTE_TEMPORARY));
   EXPECT_EQ(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM |
-            FILE_ATTRIBUTE_NOT_CONTENT_INDEXED | FILE_ATTRIBUTE_ARCHIVE |
-            FILE_ATTRIBUTE_TEMPORARY,
+                FILE_ATTRIBUTE_NOT_CONTENT_INDEXED | FILE_ATTRIBUTE_ARCHIVE |
+                FILE_ATTRIBUTE_TEMPORARY,
             ::GetFileAttributesW(wfilename.c_str()));
 
   FileUtil::Unlink(filename);
@@ -199,8 +194,8 @@ TEST_F(FileUtilTest, HideFile) {
 #endif  // OS_WIN
 
 TEST_F(FileUtilTest, IsEqualFile) {
-  const string filename1 = FileUtil::JoinPath(FLAGS_test_tmpdir, "test1");
-  const string filename2 = FileUtil::JoinPath(FLAGS_test_tmpdir, "test2");
+  const std::string filename1 = FileUtil::JoinPath(FLAGS_test_tmpdir, "test1");
+  const std::string filename2 = FileUtil::JoinPath(FLAGS_test_tmpdir, "test2");
   FileUtil::Unlink(filename1);
   FileUtil::Unlink(filename2);
   EXPECT_FALSE(FileUtil::IsEqualFile(filename1, filename2));
@@ -223,8 +218,8 @@ TEST_F(FileUtilTest, IsEqualFile) {
 
 TEST_F(FileUtilTest, CopyFile) {
   // just test rename operation works as intended
-  const string from = FileUtil::JoinPath(FLAGS_test_tmpdir, "copy_from");
-  const string to = FileUtil::JoinPath(FLAGS_test_tmpdir, "copy_to");
+  const std::string from = FileUtil::JoinPath(FLAGS_test_tmpdir, "copy_from");
+  const std::string to = FileUtil::JoinPath(FLAGS_test_tmpdir, "copy_to");
   FileUtil::Unlink(from);
   FileUtil::Unlink(to);
 
@@ -238,26 +233,25 @@ TEST_F(FileUtilTest, CopyFile) {
 
 #ifdef OS_WIN
   struct TestData {
-    TestData(DWORD from, DWORD to)
-        : from_attributes(from), to_attributes(to) {}
+    TestData(DWORD from, DWORD to) : from_attributes(from), to_attributes(to) {}
     const DWORD from_attributes;
     const DWORD to_attributes;
   };
   const TestData kTestDataList[] = {
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_ARCHIVE),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_HIDDEN),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NORMAL),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NOT_CONTENT_INDEXED),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_OFFLINE),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_READONLY),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_SYSTEM),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_TEMPORARY),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_ARCHIVE),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_HIDDEN),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NORMAL),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NOT_CONTENT_INDEXED),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_OFFLINE),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_READONLY),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_SYSTEM),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_TEMPORARY),
 
-    TestData(FILE_ATTRIBUTE_READONLY, FILE_ATTRIBUTE_NORMAL),
-    TestData(FILE_ATTRIBUTE_NORMAL,
-             FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_READONLY),
-    TestData(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM,
-             FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM),
+      TestData(FILE_ATTRIBUTE_READONLY, FILE_ATTRIBUTE_NORMAL),
+      TestData(FILE_ATTRIBUTE_NORMAL,
+               FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_READONLY),
+      TestData(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM,
+               FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM),
   };
 
   for (size_t i = 0; i < arraysize(kTestDataList); ++i) {
@@ -291,10 +285,10 @@ TEST_F(FileUtilTest, CopyFile) {
 
 TEST_F(FileUtilTest, AtomicRename) {
   // just test rename operation works as intended
-  const string from = FileUtil::JoinPath(FLAGS_test_tmpdir,
-                                         "atomic_rename_test_from");
-  const string to = FileUtil::JoinPath(FLAGS_test_tmpdir,
-                                       "atomic_rename_test_to");
+  const std::string from =
+      FileUtil::JoinPath(FLAGS_test_tmpdir, "atomic_rename_test_from");
+  const std::string to =
+      FileUtil::JoinPath(FLAGS_test_tmpdir, "atomic_rename_test_to");
   FileUtil::Unlink(from);
   FileUtil::Unlink(to);
 
@@ -310,8 +304,8 @@ TEST_F(FileUtilTest, AtomicRename) {
   {
     InputFileStream ifs(to.c_str());
     EXPECT_TRUE(ifs.good());
-    string line;
-    getline(ifs, line);
+    std::string line;
+    std::getline(ifs, line);
     EXPECT_EQ("test", line);
   }
 
@@ -327,26 +321,25 @@ TEST_F(FileUtilTest, AtomicRename) {
 
 #ifdef OS_WIN
   struct TestData {
-    TestData(DWORD from, DWORD to)
-        : from_attributes(from), to_attributes(to) {}
+    TestData(DWORD from, DWORD to) : from_attributes(from), to_attributes(to) {}
     const DWORD from_attributes;
     const DWORD to_attributes;
   };
   const TestData kTestDataList[] = {
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_ARCHIVE),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_HIDDEN),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NORMAL),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NOT_CONTENT_INDEXED),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_OFFLINE),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_READONLY),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_SYSTEM),
-    TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_TEMPORARY),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_ARCHIVE),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_HIDDEN),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NORMAL),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_NOT_CONTENT_INDEXED),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_OFFLINE),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_READONLY),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_SYSTEM),
+      TestData(FILE_ATTRIBUTE_NORMAL, FILE_ATTRIBUTE_TEMPORARY),
 
-    TestData(FILE_ATTRIBUTE_READONLY, FILE_ATTRIBUTE_NORMAL),
-    TestData(FILE_ATTRIBUTE_NORMAL,
-             FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_READONLY),
-    TestData(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM,
-             FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM),
+      TestData(FILE_ATTRIBUTE_READONLY, FILE_ATTRIBUTE_NORMAL),
+      TestData(FILE_ATTRIBUTE_NORMAL,
+               FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_READONLY),
+      TestData(FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM,
+               FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM),
   };
 
   for (size_t i = 0; i < arraysize(kTestDataList); ++i) {
@@ -454,7 +447,7 @@ TEST_F(FileUtilTest, GetModificationTime) {
   FileTimeStamp time_stamp = 0;
   EXPECT_FALSE(FileUtil::GetModificationTime("not_existent_file", &time_stamp));
 
-  const string &path = FileUtil::JoinPath(FLAGS_test_tmpdir, "testfile");
+  const std::string &path = FileUtil::JoinPath(FLAGS_test_tmpdir, "testfile");
   CreateTestFile(path, "content");
   EXPECT_TRUE(FileUtil::GetModificationTime(path, &time_stamp));
   EXPECT_NE(0, time_stamp);
