@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,7 +33,7 @@
 namespace mozc {
 
 // Initializes all the modules, such as flags and logging.
-void InitMozc(const char *arg0, int *argc, char ***argv, bool remove_flags);
+void InitMozc(const char *arg0, int *argc, char ***argv);
 
 }  // namespace mozc
 
