@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,6 @@
 #include <cstdio>
 #include <cstring>
 #include <limits>
-#include <sstream>
 #include <string>
 #include <vector>
 
@@ -44,57 +43,42 @@
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/util.h"
+#include "absl/strings/numbers.h"
+#include "absl/strings/str_format.h"
 
 namespace mozc {
 namespace {
 
 // Table of number character of Kansuji
-const char *const kNumKanjiDigits[] = {
-    "〇", "一", "二", "三", "四", "五", "六", "七", "八", "九", nullptr
-};
-const char *const kNumKanjiOldDigits[] = {
-    nullptr, "壱", "弐", "参", "四", "五", "六", "七", "八", "九"
-};
-const char *const kNumFullWidthDigits[] = {
-    "０", "１", "２", "３", "４", "５", "６", "７", "８", "９", nullptr
-};
-const char *const kNumHalfWidthDigits[] = {
-    "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", nullptr
-};
+const char *const kNumKanjiDigits[] = {"〇", "一", "二", "三", "四",   "五",
+                                       "六", "七", "八", "九", nullptr};
+const char *const kNumKanjiOldDigits[] = {nullptr, "壱", "弐", "参", "四",
+                                          "五",    "六", "七", "八", "九"};
+const char *const kNumFullWidthDigits[] = {"０", "１", "２", "３", "４",   "５",
+                                           "６", "７", "８", "９", nullptr};
+const char *const kNumHalfWidthDigits[] = {"0", "1", "2", "3", "4",    "5",
+                                           "6", "7", "8", "9", nullptr};
 
 // Table of Kanji number ranks
-const char *const kNumKanjiRanks[] = {
-    nullptr, "", "十", "百", "千"
-};
-const char *const kNumKanjiBiggerRanks[] = {
-    "", "万", "億", "兆", "京"
-};
-const char *const kNumKanjiOldRanks[] = {
-    nullptr, "", "拾", "百", "阡"
-};
-const char *const kNumKanjiBiggerOldRanks[] = {
-    "", "萬", "億", "兆", "京"
-};
+const char *const kNumKanjiRanks[] = {nullptr, "", "十", "百", "千"};
+const char *const kNumKanjiBiggerRanks[] = {"", "万", "億", "兆", "京"};
+const char *const kNumKanjiOldRanks[] = {nullptr, "", "拾", "百", "阡"};
+const char *const kNumKanjiBiggerOldRanks[] = {"", "萬", "億", "兆", "京"};
 
-const char *const kRomanNumbersCapital[] = {
-    nullptr, "Ⅰ", "Ⅱ", "Ⅲ", "Ⅳ", "Ⅴ", "Ⅵ", "Ⅶ", "Ⅷ", "Ⅸ", "Ⅹ",
-    "Ⅺ", "Ⅻ", nullptr
-};
+const char *const kRomanNumbersCapital[] = {nullptr, "Ⅰ", "Ⅱ", "Ⅲ",    "Ⅳ",
+                                            "Ⅴ",     "Ⅵ", "Ⅶ", "Ⅷ",    "Ⅸ",
+                                            "Ⅹ",     "Ⅺ", "Ⅻ", nullptr};
 
-const char *const kRomanNumbersSmall[] = {
-    nullptr, "ⅰ", "ⅱ", "ⅲ", "ⅳ", "ⅴ", "ⅵ", "ⅶ", "ⅷ", "ⅸ", "ⅹ",
-    "ⅺ", "ⅻ", nullptr
-};
+const char *const kRomanNumbersSmall[] = {nullptr, "ⅰ", "ⅱ", "ⅲ",    "ⅳ",
+                                          "ⅴ",     "ⅵ", "ⅶ", "ⅷ",    "ⅸ",
+                                          "ⅹ",     "ⅺ", "ⅻ", nullptr};
 
 const char *const kCircledNumbers[] = {
-    nullptr,
-    "①", "②", "③", "④", "⑤", "⑥", "⑦", "⑧", "⑨", "⑩",
-    "⑪", "⑫", "⑬", "⑭", "⑮", "⑯", "⑰", "⑱", "⑲", "⑳",
-    "㉑", "㉒", "㉓", "㉔", "㉕", "㉖", "㉗", "㉘", "㉙", "㉚",
-    "㉛", "㉜", "㉝", "㉞", "㉟", "㊱", "㊲", "㊳", "㊴", "㊵",
-    "㊶", "㊷", "㊸", "㊹", "㊺", "㊻", "㊼", "㊽", "㊾", "㊿",
-    nullptr
-};
+    nullptr, "①",  "②",  "③",  "④",  "⑤",  "⑥",  "⑦",    "⑧",  "⑨",  "⑩",
+    "⑪",     "⑫",  "⑬",  "⑭",  "⑮",  "⑯",  "⑰",  "⑱",    "⑲",  "⑳",  "㉑",
+    "㉒",    "㉓", "㉔", "㉕", "㉖", "㉗", "㉘", "㉙",   "㉚", "㉛", "㉜",
+    "㉝",    "㉞", "㉟", "㊱", "㊲", "㊳", "㊴", "㊵",   "㊶", "㊷", "㊸",
+    "㊹",    "㊺", "㊻", "㊼", "㊽", "㊾", "㊿", nullptr};
 
 // Structure to store character set variations.
 struct NumberStringVariation {
@@ -108,7 +92,7 @@ struct NumberStringVariation {
 
 // Judges given string is a decimal number (including integer) or not.
 // It accepts strings whose last point is a decimal point like "123456."
-bool IsDecimalNumber(StringPiece str) {
+bool IsDecimalNumber(absl::string_view str) {
   int num_point = 0;
   for (size_t i = 0; i < str.size(); ++i) {
     if (str[i] == '.') {
@@ -131,12 +115,12 @@ const char kAsciiNine = '9';
 
 }  // namespace
 
-int NumberUtil::SimpleAtoi(StringPiece str) {
-  std::stringstream ss;
-  ss << str;
-  int i = 0;
-  ss >> i;
-  return i;
+int NumberUtil::SimpleAtoi(absl::string_view str) {
+  int integer;
+  if (absl::SimpleAtoi(str, &integer)) {
+    return integer;
+  }
+  return 0;
 }
 
 namespace {
@@ -158,7 +142,7 @@ inline bool IsArabicDecimalChar32(char32 ucs4) {
 
 }  // namespace
 
-bool NumberUtil::IsArabicNumber(StringPiece input_string) {
+bool NumberUtil::IsArabicNumber(absl::string_view input_string) {
   if (input_string.empty()) {
     return false;
   }
@@ -173,7 +157,7 @@ bool NumberUtil::IsArabicNumber(StringPiece input_string) {
   return true;
 }
 
-bool NumberUtil::IsDecimalInteger(StringPiece str) {
+bool NumberUtil::IsDecimalInteger(absl::string_view str) {
   if (str.empty()) {
     return false;
   }
@@ -206,7 +190,7 @@ const char kOldTwenty[] = "廿";
 
 }  // namespace
 
-bool NumberUtil::ArabicToKanji(StringPiece input_num,
+bool NumberUtil::ArabicToKanji(absl::string_view input_num,
                                std::vector<NumberString> *output) {
   DCHECK(output);
   const char *const kNumZero = "零";
@@ -218,8 +202,9 @@ bool NumberUtil::ArabicToKanji(StringPiece input_num,
 
   {
     // We don't convert a number starting with '0', other than 0 itself.
-    StringPiece::size_type i;
-    for (i = 0; i < input_num.size() && input_num[i] == kAsciiZero; ++i) {}
+    absl::string_view::size_type i;
+    for (i = 0; i < input_num.size() && input_num[i] == kAsciiZero; ++i) {
+    }
     if (i == input_num.size()) {
       output->push_back(
           NumberString(kNumZero, "大字", NumberString::NUMBER_OLD_KANJI));
@@ -235,13 +220,14 @@ bool NumberUtil::ArabicToKanji(StringPiece input_num,
 
   // Fill '0' in the beginning of input_num to make its length
   // (N * kDigitsInBigRank).
-  const int filled_zero_num = (kDigitsInBigRank -
-      (input_num.size() % kDigitsInBigRank)) % kDigitsInBigRank;
-  string input(filled_zero_num, kAsciiZero);
+  const int filled_zero_num =
+      (kDigitsInBigRank - (input_num.size() % kDigitsInBigRank)) %
+      kDigitsInBigRank;
+  std::string input(filled_zero_num, kAsciiZero);
   input.append(input_num.data(), input_num.size());
 
   // Segment into kDigitsInBigRank-digits pieces
-  std::vector<string> ranked_numbers;
+  std::vector<std::string> ranked_numbers;
   for (int i = static_cast<int>(input.size()) - kDigitsInBigRank; i >= 0;
        i -= kDigitsInBigRank) {
     ranked_numbers.push_back(input.substr(i, kDigitsInBigRank));
@@ -271,12 +257,12 @@ bool NumberUtil::ArabicToKanji(StringPiece input_num,
     }
 
     // TODO(peria): Bring |result| out if it improves the performance.
-    string result;
+    std::string result;
 
     // Converts each segment, and merges them with rank Kanjis.
     for (int rank = rank_size - 1; rank >= 0; --rank) {
-      const string &segment = ranked_numbers[rank];
-      string segment_result;
+      const std::string &segment = ranked_numbers[rank];
+      std::string segment_result;
       bool leading = true;
       for (size_t i = 0; i < segment.size(); ++i) {
         if (leading && segment[i] == kAsciiZero) {
@@ -311,12 +297,12 @@ bool NumberUtil::ArabicToKanji(StringPiece input_num,
     // Add specialized style numbers.
     if (style == NumberString::NUMBER_OLD_KANJI) {
       size_t index = result.find(kOldTwoTen);
-      if (index != string::npos) {
-        string result2(result);
+      if (index != std::string::npos) {
+        std::string result2(result);
         do {
           result2.replace(index, kOldTwoTenLength, kOldTwenty);
           index = result2.find(kOldTwoTen, index);
-        } while (index != string::npos);
+        } while (index != std::string::npos);
         output->push_back(NumberString(result2, description, style));
       }
 
@@ -344,8 +330,8 @@ const NumberStringVariation kNumDigitsVariations[] = {
 
 }  // namespace
 
-bool NumberUtil::ArabicToSeparatedArabic(
-    StringPiece input_num, std::vector<NumberString> *output) {
+bool NumberUtil::ArabicToSeparatedArabic(absl::string_view input_num,
+                                         std::vector<NumberString> *output) {
   DCHECK(output);
 
   if (!IsDecimalNumber(input_num)) {
@@ -353,13 +339,13 @@ bool NumberUtil::ArabicToSeparatedArabic(
   }
 
   // Separate a number into an integral part and a fractional part.
-  StringPiece::size_type point_pos = input_num.find('.');
-  if (point_pos == StringPiece::npos) {
+  absl::string_view::size_type point_pos = input_num.find('.');
+  if (point_pos == absl::string_view::npos) {
     point_pos = input_num.size();
   }
-  const StringPiece integer = input_num.substr(0, point_pos);
+  const absl::string_view integer = input_num.substr(0, point_pos);
   // |fraction| has the decimal point with digits in fractional part.
-  const StringPiece fraction =
+  const absl::string_view fraction =
       input_num.substr(point_pos, input_num.size() - point_pos);
 
   // We don't add separator to number whose integral part starts with '0'
@@ -371,10 +357,10 @@ bool NumberUtil::ArabicToSeparatedArabic(
     const NumberStringVariation &variation = kNumDigitsVariations[i];
     const char *const *const digits = variation.digits;
     // TODO(peria): Bring |result| out if it improves the performance.
-    string result;
+    std::string result;
 
     // integral part
-    for (StringPiece::size_type j = 0; j < integer.size(); ++j) {
+    for (absl::string_view::size_type j = 0; j < integer.size(); ++j) {
       // We don't add separater first
       if (j != 0 && (integer.size() - j) % 3 == 0) {
         result.append(variation.separator);
@@ -389,7 +375,7 @@ bool NumberUtil::ArabicToSeparatedArabic(
     if (!fraction.empty()) {
       DCHECK_EQ(fraction[0], '.');
       result.append(variation.point);
-      for (StringPiece::size_type j = 1; j < fraction.size(); ++j) {
+      for (absl::string_view::size_type j = 1; j < fraction.size(); ++j) {
         result.append(digits[static_cast<int>(fraction[j] - kAsciiZero)]);
       }
     }
@@ -413,8 +399,8 @@ const NumberStringVariation kSingleDigitsVariations[] = {
 
 }  // namespace
 
-bool NumberUtil::ArabicToWideArabic(
-    StringPiece input_num, std::vector<NumberString> *output) {
+bool NumberUtil::ArabicToWideArabic(absl::string_view input_num,
+                                    std::vector<NumberString> *output) {
   DCHECK(output);
 
   if (!IsDecimalInteger(input_num)) {
@@ -424,8 +410,8 @@ bool NumberUtil::ArabicToWideArabic(
   for (size_t i = 0; i < arraysize(kSingleDigitsVariations); ++i) {
     const NumberStringVariation &variation = kSingleDigitsVariations[i];
     // TODO(peria): Bring |result| out if it improves the performance.
-    string result;
-    for (StringPiece::size_type j = 0; j < input_num.size(); ++j) {
+    std::string result;
+    for (absl::string_view::size_type j = 0; j < input_num.size(); ++j) {
       result.append(
           variation.digits[static_cast<int>(input_num[j] - kAsciiZero)]);
     }
@@ -451,8 +437,8 @@ const NumberStringVariation kSpecialNumericVariations[] = {
 
 }  // namespace
 
-bool NumberUtil::ArabicToOtherForms(
-    StringPiece input_num, std::vector<NumberString> *output) {
+bool NumberUtil::ArabicToOtherForms(absl::string_view input_num,
+                                    std::vector<NumberString> *output) {
   DCHECK(output);
 
   if (!IsDecimalInteger(input_num)) {
@@ -485,9 +471,8 @@ bool NumberUtil::ArabicToOtherForms(
   for (size_t i = 0; i < arraysize(kSpecialNumericVariations); ++i) {
     const NumberStringVariation &variation = kSpecialNumericVariations[i];
     if (n < variation.numbers_size && variation.digits[n]) {
-      output->push_back(
-          NumberString(variation.digits[n], variation.description,
-                       variation.style));
+      output->push_back(NumberString(variation.digits[n], variation.description,
+                                     variation.style));
       converted = true;
     }
   }
@@ -495,16 +480,8 @@ bool NumberUtil::ArabicToOtherForms(
   return converted;
 }
 
-namespace {
-
-// Enough size to store MAX_INT64 in octal digits with prefix.
-// Must be larger than or equal to Ceil(64 / 3) + 1 ("0") + 1 ('\0') = 24
-const int kMaxInt64Size = 24;
-
-}  // namespace
-
-bool NumberUtil::ArabicToOtherRadixes(
-    StringPiece input_num, std::vector<NumberString> *output) {
+bool NumberUtil::ArabicToOtherRadixes(absl::string_view input_num,
+                                      std::vector<NumberString> *output) {
   DCHECK(output);
 
   if (!IsDecimalInteger(input_num)) {
@@ -518,22 +495,19 @@ bool NumberUtil::ArabicToOtherRadixes(
 
   // Hexadecimal
   if (n > 9) {
-    // Keep
-    char hex[kMaxInt64Size];
-    snprintf(hex, kMaxInt64Size, "0x%" MOZC_PRIx64, n);
+    const std::string hex = absl::StrFormat("0x%x", static_cast<uint64>(n));
     output->push_back(NumberString(hex, "16進数", NumberString::NUMBER_HEX));
   }
 
   // Octal
   if (n > 7) {
-    char oct[kMaxInt64Size];
-    snprintf(oct, kMaxInt64Size, "0%" MOZC_PRIo64, n);
+    const std::string oct = absl::StrFormat("0%o", static_cast<uint64>(n));
     output->push_back(NumberString(oct, "8進数", NumberString::NUMBER_OCT));
   }
 
   // Binary
   if (n > 1) {
-    string binary;
+    std::string binary;
     for (uint64 num = n; num; num >>= 1) {
       binary.push_back(kAsciiZero + static_cast<char>(num & 0x1));
     }
@@ -548,9 +522,10 @@ bool NumberUtil::ArabicToOtherRadixes(
 
 namespace {
 
-const StringPiece SkipWhiteSpace(StringPiece str) {
-  StringPiece::size_type i;
-  for (i = 0; i < str.size() && isspace(str[i]); ++i) {}
+const absl::string_view SkipWhiteSpace(absl::string_view str) {
+  absl::string_view::size_type i;
+  for (i = 0; i < str.size() && isspace(str[i]); ++i) {
+  }
   DCHECK(i == str.size() || !isspace(str[i]));
   return str.substr(i);
 }
@@ -563,7 +538,7 @@ const StringPiece SkipWhiteSpace(StringPiece str) {
 // return false when an integer overflow happens.
 bool AddAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
   *output = arg1 + arg2;
-  if (arg2 > (kuint64max - arg1)) {
+  if (arg2 > (std::numeric_limits<uint64>::max() - arg1)) {
     // overflow happens
     return false;
   }
@@ -574,7 +549,7 @@ bool AddAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
 // return false when an integer overflow happens.
 bool MultiplyAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
   *output = arg1 * arg2;
-  if (arg1 != 0 && arg2 > (kuint64max / arg1)) {
+  if (arg1 != 0 && arg2 > (std::numeric_limits<uint64>::max() / arg1)) {
     // overflow happens
     return false;
   }
@@ -582,10 +557,10 @@ bool MultiplyAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
 }
 
 // A simple wrapper of strtoull function. |c_str| must be terminated by '\0'.
-inline uint64 StrToUint64(const char* c_str, char** end_ptr, int base) {
+inline uint64 StrToUint64(const char *c_str, char **end_ptr, int base) {
 #ifdef OS_WIN
   return _strtoui64(c_str, end_ptr, base);
-#else  // OS_WIN
+#else   // OS_WIN
   return strtoull(c_str, end_ptr, base);
 #endif  // OS_WIN
 }
@@ -593,7 +568,7 @@ inline uint64 StrToUint64(const char* c_str, char** end_ptr, int base) {
 // Converts a string which describes a number into an uint64 value in |base|
 // radix.  Does not convert octal or hexadecimal strings with "0" or "0x"
 // suffixes.
-bool SafeStrToUInt64WithBase(StringPiece str, int base, uint64 *value) {
+bool SafeStrToUInt64WithBase(absl::string_view str, int base, uint64 *value) {
   DCHECK(value);
 
   // Maximum possible length of number string, including terminating '\0'. Note
@@ -602,7 +577,7 @@ bool SafeStrToUInt64WithBase(StringPiece str, int base, uint64 *value) {
   const size_t kMaxPossibleLength = 65;
 
   // Leading white spaces are allowed.
-  const StringPiece stripped_str = SkipWhiteSpace(str);
+  const absl::string_view stripped_str = SkipWhiteSpace(str);
   if (stripped_str.empty() || stripped_str.size() >= kMaxPossibleLength) {
     return false;
   }
@@ -612,7 +587,8 @@ bool SafeStrToUInt64WithBase(StringPiece str, int base, uint64 *value) {
     return false;
   }
 
-  // Since StringPiece doesn't end with '\0', we make a c-string on stack here.
+  // Since absl::string_view doesn't end with '\0', we make a c-string on stack
+  // here.
   char buf[kMaxPossibleLength];
   memcpy(buf, str.data(), str.size());
   buf[str.size()] = '\0';
@@ -624,14 +600,14 @@ bool SafeStrToUInt64WithBase(StringPiece str, int base, uint64 *value) {
     return false;
   }
   // Trailing white spaces are allowed.
-  const StringPiece trailing_str(end_ptr, buf + str.size() - end_ptr);
+  const absl::string_view trailing_str(end_ptr, buf + str.size() - end_ptr);
   return SkipWhiteSpace(trailing_str).empty();
 }
 
 template <typename T1, typename T2>
 struct GenericFalseTypeArity2 {
   // TODO(yukawa): Use std::false_type once C++11 is enabled everywhere.
-  static const bool value = false;
+  static constexpr bool value = false;
 };
 
 template <typename SrcType, typename DestType>
@@ -643,8 +619,8 @@ bool SafeCast(SrcType src, DestType *dest) {
 
 template <>
 bool SafeCast(int64 src, int16 *dest) {
-  if (src < static_cast<int64>(kint16min) ||
-      static_cast<int64>(kint16max) < src) {
+  if (src < static_cast<int64>(std::numeric_limits<int16>::min()) ||
+      static_cast<int64>(std::numeric_limits<int16>::max()) < src) {
     return false;
   }
   *dest = static_cast<int16>(src);
@@ -653,8 +629,8 @@ bool SafeCast(int64 src, int16 *dest) {
 
 template <>
 bool SafeCast(int64 src, int32 *dest) {
-  if (src < static_cast<int64>(kint32min) ||
-      static_cast<int64>(kint32max) < src) {
+  if (src < static_cast<int64>(std::numeric_limits<int32>::min()) ||
+      static_cast<int64>(std::numeric_limits<int32>::max()) < src) {
     return false;
   }
   *dest = static_cast<int32>(src);
@@ -663,7 +639,7 @@ bool SafeCast(int64 src, int32 *dest) {
 
 template <>
 bool SafeCast(uint64 src, int64 *dest) {
-  if (src > static_cast<uint64>(kint64max)) {
+  if (src > static_cast<uint64>(std::numeric_limits<int64>::max())) {
     return false;
   }
   *dest = static_cast<int64>(src);
@@ -672,7 +648,7 @@ bool SafeCast(uint64 src, int64 *dest) {
 
 template <>
 bool SafeCast(uint64 src, uint16 *dest) {
-  if (src > static_cast<uint64>(kuint16max)) {
+  if (src > static_cast<uint64>(std::numeric_limits<uint16>::max())) {
     return false;
   }
   *dest = static_cast<uint16>(src);
@@ -681,7 +657,7 @@ bool SafeCast(uint64 src, uint16 *dest) {
 
 template <>
 bool SafeCast(uint64 src, uint32 *dest) {
-  if (src > static_cast<uint64>(kuint32max)) {
+  if (src > static_cast<uint64>(std::numeric_limits<uint32>::max())) {
     return false;
   }
   *dest = static_cast<uint32>(src);
@@ -702,7 +678,7 @@ bool SafeUnaryNegation(uint64 src, int64 *dest) {
     if (src == 0x8000000000000000ul) {
       // This is an exceptional case. |src| isn't in the range of int64,
       // but |-src| is in the range.
-      *dest = kint64min;
+      *dest = std::numeric_limits<int64>::min();
       return true;
     }
     return false;
@@ -713,7 +689,7 @@ bool SafeUnaryNegation(uint64 src, int64 *dest) {
 
 }  // namespace
 
-bool NumberUtil::SafeStrToInt16(StringPiece str, int16 *value) {
+bool NumberUtil::SafeStrToInt16(absl::string_view str, int16 *value) {
   int64 tmp;
   if (!SafeStrToInt64(str, &tmp)) {
     return false;
@@ -721,7 +697,7 @@ bool NumberUtil::SafeStrToInt16(StringPiece str, int16 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToInt32(StringPiece str, int32 *value) {
+bool NumberUtil::SafeStrToInt32(absl::string_view str, int32 *value) {
   int64 tmp;
   if (!SafeStrToInt64(str, &tmp)) {
     return false;
@@ -729,14 +705,15 @@ bool NumberUtil::SafeStrToInt32(StringPiece str, int32 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToInt64(StringPiece str, int64 *value) {
-  const StringPiece stripped_str = SkipWhiteSpace(str);
+bool NumberUtil::SafeStrToInt64(absl::string_view str, int64 *value) {
+  const absl::string_view stripped_str = SkipWhiteSpace(str);
   if (stripped_str.empty()) {
     return false;
   }
   uint64 tmp;
   if (stripped_str[0] == '-') {
-    StringPiece opposite_str = stripped_str.substr(1, stripped_str.size() - 1);
+    absl::string_view opposite_str =
+        stripped_str.substr(1, stripped_str.size() - 1);
     if (!SafeStrToUInt64WithBase(opposite_str, 10, &tmp)) {
       return false;
     }
@@ -748,7 +725,7 @@ bool NumberUtil::SafeStrToInt64(StringPiece str, int64 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToUInt16(StringPiece str, uint16 *value) {
+bool NumberUtil::SafeStrToUInt16(absl::string_view str, uint16 *value) {
   uint64 tmp;
   if (!SafeStrToUInt64WithBase(str, 10, &tmp)) {
     return false;
@@ -756,7 +733,7 @@ bool NumberUtil::SafeStrToUInt16(StringPiece str, uint16 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToUInt32(StringPiece str, uint32 *value) {
+bool NumberUtil::SafeStrToUInt32(absl::string_view str, uint32 *value) {
   uint64 tmp;
   if (!SafeStrToUInt64WithBase(str, 10, &tmp)) {
     return false;
@@ -764,7 +741,7 @@ bool NumberUtil::SafeStrToUInt32(StringPiece str, uint32 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeHexStrToUInt32(StringPiece str, uint32 *value) {
+bool NumberUtil::SafeHexStrToUInt32(absl::string_view str, uint32 *value) {
   uint64 tmp;
   if (!SafeStrToUInt64WithBase(str, 16, &tmp)) {
     return false;
@@ -772,7 +749,7 @@ bool NumberUtil::SafeHexStrToUInt32(StringPiece str, uint32 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeOctStrToUInt32(StringPiece str, uint32 *value) {
+bool NumberUtil::SafeOctStrToUInt32(absl::string_view str, uint32 *value) {
   uint64 tmp;
   if (!SafeStrToUInt64WithBase(str, 8, &tmp)) {
     return false;
@@ -780,18 +757,18 @@ bool NumberUtil::SafeOctStrToUInt32(StringPiece str, uint32 *value) {
   return SafeCast(tmp, value);
 }
 
-bool NumberUtil::SafeStrToUInt64(StringPiece str, uint64 *value) {
+bool NumberUtil::SafeStrToUInt64(absl::string_view str, uint64 *value) {
   return SafeStrToUInt64WithBase(str, 10, value);
 }
 
-bool NumberUtil::SafeStrToDouble(StringPiece str, double *value) {
+bool NumberUtil::SafeStrToDouble(absl::string_view str, double *value) {
   DCHECK(value);
-  // Note that StringPiece isn't terminated by '\0'.  However, since strtod
-  // requires null-terminated string, we make a string here. If we have a good
-  // estimate of the maximum possible length of the input string, we may be able
-  // to use char buffer instead.  Note: const reference ensures the life of this
-  // temporary string until the end!
-  const string &s = str.as_string();
+  // Note that absl::string_view isn't terminated by '\0'.  However, since
+  // strtod requires null-terminated string, we make a string here. If we have a
+  // good estimate of the maximum possible length of the input string, we may be
+  // able to use char buffer instead.  Note: const reference ensures the life of
+  // this temporary string until the end!
+  const std::string &s = std::string(str);
   const char *ptr = s.c_str();
 
   char *end_ptr;
@@ -801,15 +778,13 @@ bool NumberUtil::SafeStrToDouble(StringPiece str, double *value) {
   // Note that strtod accepts white spaces at the beginning of the parameter.
   *value = std::strtod(ptr, &end_ptr);
 
-  if (errno != 0 ||
-      ptr == end_ptr ||
-      std::isnan(*value) ||
-      *value ==  std::numeric_limits<double>::infinity() ||
+  if (errno != 0 || ptr == end_ptr || std::isnan(*value) ||
+      *value == std::numeric_limits<double>::infinity() ||
       *value == -std::numeric_limits<double>::infinity()) {
     return false;
   }
   // Trailing white spaces are allowed.
-  const StringPiece trailing_str(end_ptr, ptr + s.size() - end_ptr);
+  const absl::string_view trailing_str(end_ptr, ptr + s.size() - end_ptr);
   return SkipWhiteSpace(trailing_str).empty();
 }
 
@@ -820,8 +795,7 @@ namespace {
 // Returns false when overflow happened.
 bool ReduceLeadingNumbersAsBase10System(
     std::vector<uint64>::const_iterator *begin,
-    const std::vector<uint64>::const_iterator &end,
-    uint64 *output) {
+    const std::vector<uint64>::const_iterator &end, uint64 *output) {
   *output = 0;
   for (; *begin < end; ++*begin) {
     if (**begin >= 10) {
@@ -882,8 +856,7 @@ bool ReduceOnesDigit(std::vector<uint64>::const_iterator *begin,
 //     [1, 2, 3, 4, ...] => 1234
 bool ReduceDigitsHelper(std::vector<uint64>::const_iterator *begin,
                         const std::vector<uint64>::const_iterator &end,
-                        uint64 *num,
-                        const uint64 expected_base) {
+                        uint64 *num, const uint64 expected_base) {
   // Skip leading zero(s).
   while (*begin != end && **begin == 0) {
     ++*begin;
@@ -906,8 +879,7 @@ bool ReduceDigitsHelper(std::vector<uint64>::const_iterator *begin,
     // 10 * expected_base.
     if (next_number < 10) {
       if (!ReduceLeadingNumbersAsBase10System(begin, end, num) ||
-          *num >= expected_base * 10 ||
-          (*begin != end && **begin < 10000)) {
+          *num >= expected_base * 10 || (*begin != end && **begin < 10000)) {
         *begin = end;  // Force to ignore the rest of the sequence.
         return false;
       }
@@ -994,7 +966,7 @@ bool ReduceNumberLessThan10000(std::vector<uint64>::const_iterator *begin,
 //   "一十二百" = [1, 10, 2, 100] => error
 bool InterpretNumbersInJapaneseWay(const std::vector<uint64> &numbers,
                                    uint64 *output) {
-  uint64 last_base = kuint64max;
+  uint64 last_base = std::numeric_limits<uint64>::max();
   auto begin = numbers.begin();
   *output = 0;
   do {
@@ -1038,12 +1010,9 @@ bool NormalizeNumbersHelper(const std::vector<uint64> &numbers,
 }
 
 // TODO(peria): Do refactoring this method.
-bool NormalizeNumbersInternal(StringPiece input,
-                              bool trim_leading_zeros,
-                              bool allow_suffix,
-                              string *kanji_output,
-                              string *arabic_output,
-                              string *suffix) {
+bool NormalizeNumbersInternal(absl::string_view input, bool trim_leading_zeros,
+                              bool allow_suffix, std::string *kanji_output,
+                              std::string *arabic_output, std::string *suffix) {
   DCHECK(kanji_output);
   DCHECK(arabic_output);
   const char *begin = input.data();
@@ -1055,14 +1024,14 @@ bool NormalizeNumbersInternal(StringPiece input,
   // Simultaneously, constructs a Kanji number string.
   kanji_output->clear();
   arabic_output->clear();
-  string kanji_char;
+  std::string kanji_char;
 
   while (begin < end) {
     size_t mblen = 0;
     const char32 wchar = Util::UTF8ToUCS4(begin, end, &mblen);
     kanji_char.assign(begin, mblen);
 
-    string tmp;
+    std::string tmp;
     NumberUtil::KanjiNumberToArabicNumber(kanji_char, &tmp);
 
     uint64 n = 0;
@@ -1112,9 +1081,7 @@ bool NormalizeNumbersInternal(StringPiece input,
     arabic_output->append(num_zeros, kAsciiZero);
   }
 
-  char buf[kMaxInt64Size];
-  snprintf(buf, sizeof(buf), "%" MOZC_PRIu64, n);
-  *arabic_output += buf;
+  arabic_output->append(absl::StrFormat("%u", static_cast<uint64>(n)));
   return true;
 }
 
@@ -1122,38 +1089,30 @@ bool NormalizeNumbersInternal(StringPiece input,
 
 // Convert Kanji numbers into Arabic numbers:
 // e.g. "百二十万" -> 1200000
-bool NumberUtil::NormalizeNumbers(StringPiece input,
+bool NumberUtil::NormalizeNumbers(absl::string_view input,
                                   bool trim_leading_zeros,
-                                  string *kanji_output,
-                                  string *arabic_output) {
-  return NormalizeNumbersInternal(input,
-                                  trim_leading_zeros,
+                                  std::string *kanji_output,
+                                  std::string *arabic_output) {
+  return NormalizeNumbersInternal(input, trim_leading_zeros,
                                   false,  // allow_suffix
-                                  kanji_output,
-                                  arabic_output,
-                                  nullptr);
+                                  kanji_output, arabic_output, nullptr);
 }
 
-bool NumberUtil::NormalizeNumbersWithSuffix(StringPiece input,
+bool NumberUtil::NormalizeNumbersWithSuffix(absl::string_view input,
                                             bool trim_leading_zeros,
-                                            string *kanji_output,
-                                            string *arabic_output,
-                                            string *suffix) {
-  return NormalizeNumbersInternal(input,
-                                  trim_leading_zeros,
+                                            std::string *kanji_output,
+                                            std::string *arabic_output,
+                                            std::string *suffix) {
+  return NormalizeNumbersInternal(input, trim_leading_zeros,
                                   true,  // allow_suffix
-                                  kanji_output,
-                                  arabic_output,
-                                  suffix);
+                                  kanji_output, arabic_output, suffix);
 }
 
-void NumberUtil::KanjiNumberToArabicNumber(StringPiece input,
-                                           string *output) {
+void NumberUtil::KanjiNumberToArabicNumber(absl::string_view input,
+                                           std::string *output) {
   Util::ConvertUsingDoubleArray(
       japanese_util_rule::kanjinumber_to_arabicnumber_da,
-      japanese_util_rule::kanjinumber_to_arabicnumber_table,
-      input,
-      output);
+      japanese_util_rule::kanjinumber_to_arabicnumber_table, input, output);
 }
 
 }  // namespace mozc
