@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,15 +33,15 @@
 #include "base/password_manager.h"
 #include "base/util.h"
 
-int main(int argc,char **argv) {
-  mozc::InitMozc(argv[0], &argc, &argv, false);
-  string password;
+int main(int argc, char **argv) {
+  mozc::InitMozc(argv[0], &argc, &argv);
+  std::string password;
   if (!mozc::PasswordManager::GetPassword(&password)) {
     LOG(INFO) << "GetPassword failed";
     return -1;
   }
 
-  string escaped;
+  std::string escaped;
   mozc::Util::Escape(password, &escaped);
   LOG(INFO) << "Escaped password is: " << escaped;
   return 0;
