@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,7 @@
 
 #ifndef OS_WIN
 #include <unistd.h>
+
 #include <cstdlib>
 #endif  // OS_WIN
 
@@ -38,22 +39,21 @@
 #include "base/logging.h"
 #include "base/system_util.h"
 #include "base/util.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 namespace {
 static const char kName[] = "process_mutex_test";
 
 class ProcessMutexTest : public testing::Test {
  protected:
-  virtual void SetUp() {
+  void SetUp() override {
     original_user_profile_dir_ = SystemUtil::GetUserProfileDirectory();
     SystemUtil::SetUserProfileDirectory(FLAGS_test_tmpdir);
   }
 
-  virtual void TearDown() {
+  void TearDown() override {
     ProcessMutex mutex(kName);
     if (FileUtil::FileExists(mutex.lock_filename())) {
       LOG(FATAL) << "Lock file unexpectedly remains: " << mutex.lock_filename();
@@ -63,7 +63,7 @@ class ProcessMutexTest : public testing::Test {
   }
 
  private:
-  string original_user_profile_dir_;
+  std::string original_user_profile_dir_;
 };
 
 #if !defined(OS_WIN) && !defined(OS_NACL)
