@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -45,25 +45,23 @@ bool SchedulerStub::AddJob(const Scheduler::JobSetting &job_setting) {
     return false;
   }
 
-  jobs_.insert(std::pair<string, JobForStub>(
-      job_setting.name(), JobForStub(job_setting)));
+  jobs_.insert(std::pair<std::string, JobForStub>(job_setting.name(),
+                                                  JobForStub(job_setting)));
   return true;
 }
 
-bool SchedulerStub::RemoveJob(const string &name) {
+bool SchedulerStub::RemoveJob(const std::string &name) {
   return (jobs_.erase(name) != 0);
 }
 
-void SchedulerStub::RemoveAllJobs() {
-  jobs_.clear();
-}
+void SchedulerStub::RemoveAllJobs() { jobs_.clear(); }
 
-bool SchedulerStub::HasJob(const string &name) const {
+bool SchedulerStub::HasJob(const std::string &name) const {
   return (jobs_.find(name) != jobs_.end());
 }
 
 void SchedulerStub::PutClockForward(uint64 delta_usec) {
-  for (std::map<string, JobForStub>::iterator itr = jobs_.begin();
+  for (std::map<std::string, JobForStub>::iterator itr = jobs_.begin();
        itr != jobs_.end(); ++itr) {
     JobForStub *job_for_stub = &itr->second;
     uint64 time_usec = delta_usec;
@@ -74,21 +72,21 @@ void SchedulerStub::PutClockForward(uint64 delta_usec) {
       }
 
       time_usec -= job_for_stub->remaining_usec;
-      const bool result = job_for_stub->job.callback()(
-          job_for_stub->job.data());
+      const bool result =
+          job_for_stub->job.callback()(job_for_stub->job.data());
       if (result) {
         job_for_stub->backoff_count = 0;
         job_for_stub->remaining_usec = job_for_stub->job.default_interval();
       } else {
-        const int new_backoff_count = (job_for_stub->backoff_count == 0) ?
-            1 : job_for_stub->backoff_count * 2;
-        if ((new_backoff_count + 1) * job_for_stub->job.default_interval()
-            < job_for_stub->job.max_interval()) {
+        const int new_backoff_count = (job_for_stub->backoff_count == 0)
+                                          ? 1
+                                          : job_for_stub->backoff_count * 2;
+        if ((new_backoff_count + 1) * job_for_stub->job.default_interval() <
+            job_for_stub->job.max_interval()) {
           job_for_stub->backoff_count = new_backoff_count;
         }
-        job_for_stub->remaining_usec =
-            (job_for_stub->job.default_interval() *
-             (job_for_stub->backoff_count + 1));
+        job_for_stub->remaining_usec = (job_for_stub->job.default_interval() *
+                                        (job_for_stub->backoff_count + 1));
       }
     }
   }
