@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,21 +35,21 @@
 #include <string>
 
 #include "base/port.h"
-#include "base/string_piece.h"
 #include "testing/base/public/gunit.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
 
 class SerializedStringArrayTest : public ::testing::Test {
  protected:
-  StringPiece AlignString(const char *s, size_t len) {
+  absl::string_view AlignString(const char *s, size_t len) {
     return AlignString(string(s, len));
   }
 
-  StringPiece AlignString(const string &s) {
+  absl::string_view AlignString(const string &s) {
     buf_.reset(new uint32[(s.size() + 3) / 4]);
-    return StringPiece(
+    return absl::string_view(
         static_cast<const char *>(memcpy(buf_.get(), s.data(), s.size())),
         s.size());
   }
@@ -65,7 +65,7 @@ TEST_F(SerializedStringArrayTest, DefaultConstructor) {
 }
 
 TEST_F(SerializedStringArrayTest, EmptyArray) {
-  const StringPiece data = AlignString("\x00\x00\x00\x00", 4);
+  const absl::string_view data = AlignString("\x00\x00\x00\x00", 4);
   ASSERT_TRUE(SerializedStringArray::VerifyData(data));
 
   SerializedStringArray a;
@@ -85,14 +85,14 @@ const char kTestData[] =
 
 TEST_F(SerializedStringArrayTest, SerializeToBuffer) {
   std::unique_ptr<uint32[]> buf;
-  const StringPiece actual = SerializedStringArray::SerializeToBuffer(
+  const absl::string_view actual = SerializedStringArray::SerializeToBuffer(
       {"Hello", "Mozc", "google"}, &buf);
-  const StringPiece expected(kTestData, arraysize(kTestData) - 1);
+  const absl::string_view expected(kTestData, arraysize(kTestData) - 1);
   EXPECT_EQ(expected, actual);
 }
 
 TEST_F(SerializedStringArrayTest, Basic) {
-  const StringPiece data =
+  const absl::string_view data =
       AlignString(string(kTestData, arraysize(kTestData) - 1));
 
   ASSERT_TRUE(SerializedStringArray::VerifyData(data));
@@ -117,7 +117,7 @@ TEST_F(SerializedStringArrayTest, Basic) {
 }
 
 TEST_F(SerializedStringArrayTest, Iterator) {
-  const StringPiece data =
+  const absl::string_view data =
       AlignString(string(kTestData, arraysize(kTestData) - 1));
 
   ASSERT_TRUE(SerializedStringArray::VerifyData(data));
