@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,47 +30,53 @@
 #include "base/system_util.h"
 
 #ifdef OS_WIN
+// clang-format off
 #include <Windows.h>
 #include <LMCons.h>
 #include <Sddl.h>
 #include <ShlObj.h>
 #include <VersionHelpers.h>
+// clang-format on
 #else  // OS_WIN
 #include <pwd.h>
 #include <sys/mman.h>
 #include <unistd.h>
-#ifdef OS_MACOSX
-#include <sys/stat.h>
-#include <sys/sysctl.h>
-#endif  // OS_MACOSX
 #endif  // OS_WIN
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
+#include <sys/stat.h>
+#include <sys/sysctl.h>
 #include <cerrno>
-#endif  // OS_MACOSX
+#endif  // __APPLE__
+
 #include <cstdlib>
 #include <cstring>
+
 #ifdef OS_WIN
 #include <memory>
 #endif  // OS_WIN
+
 #include <sstream>
 #include <string>
 
-#include "base/const.h"
-#include "base/file_util.h"
-#include "base/logging.h"
-#include "base/mac_util.h"
-#include "base/number_util.h"
-#include "base/singleton.h"
-#include "base/util.h"
-#include "base/win_util.h"
-
 #ifdef OS_ANDROID
 #include "base/android_util.h"
 #endif  // OS_ANDROID
 
+#include "base/const.h"
+#include "base/environ.h"
+#include "base/file_util.h"
+#include "base/logging.h"
+
+#ifdef __APPLE__
+#include "base/mac_util.h"
+#endif  // __APPLE__
+
+#include "base/singleton.h"
+#include "base/util.h"
+
 #ifdef OS_WIN
-using std::unique_ptr;
+#include "base/win_util.h"
 #endif  // OS_WIN
 
 namespace mozc {
@@ -78,13 +84,35 @@ namespace mozc {
 namespace {
 class UserProfileDirectoryImpl {
  public:
-  UserProfileDirectoryImpl();
-  string get() { return dir_; }
-  void set(const string &dir) { dir_ = dir; }
+  UserProfileDirectoryImpl() = default;
+  virtual ~UserProfileDirectoryImpl() = default;
+
+  std::string GetDir();
+  void SetDir(const std::string &dir);
+
  private:
-  string dir_;
+  std::string GetUserProfileDirectory() const;
+  std::string dir_;
 };
 
+std::string UserProfileDirectoryImpl::GetDir() {
+  if (!dir_.empty()) {
+    return dir_;
+  }
+  const std::string dir = GetUserProfileDirectory();
+  FileUtil::CreateDirectory(dir);
+  if (!FileUtil::DirectoryExists(dir)) {
+    LOG(ERROR) << "Failed to create directory: " << dir;
+  }
+
+  dir_ = dir;
+  return dir_;
+}
+
+void UserProfileDirectoryImpl::SetDir(const std::string &dir) {
+  dir_ = dir;
+}
+
 #ifdef OS_WIN
 // TODO(yukawa): Use API wrapper so that unit test can emulate any case.
 class LocalAppDataDirectoryCache {
@@ -92,15 +120,9 @@ class LocalAppDataDirectoryCache {
   LocalAppDataDirectoryCache() : result_(E_FAIL) {
     result_ = SafeTryGetLocalAppData(&path_);
   }
-  HRESULT result() const {
-    return result_;
-  }
-  const bool succeeded() const {
-    return SUCCEEDED(result_);
-  }
-  const string &path() const {
-    return path_;
-  }
+  HRESULT result() const { return result_; }
+  const bool succeeded() const { return SUCCEEDED(result_); }
+  const string &path() const { return path_; }
 
  private:
   // b/5707813 implies that TryGetLocalAppData causes an exception and makes
@@ -116,7 +138,7 @@ class LocalAppDataDirectoryCache {
   static HRESULT __declspec(nothrow) SafeTryGetLocalAppData(string *dir) {
     __try {
       return TryGetLocalAppData(dir);
-    } __except(EXCEPTION_EXECUTE_HANDLER) {
+    } __except (EXCEPTION_EXECUTE_HANDLER) {
       return E_UNEXPECTED;
     }
   }
@@ -152,9 +174,9 @@ class LocalAppDataDirectoryCache {
     if (FAILED(result)) {
       return result;
     }
-    wstring path = config;
-    const wstring::size_type local_pos = path.find(L"\\Packages\\");
-    if (local_pos == wstring::npos) {
+    std::wstring path = config;
+    const std::wstring::size_type local_pos = path.find(L"\\Packages\\");
+    if (local_pos == std::wstring::npos) {
       return E_FAIL;
     }
     path.erase(local_pos);
@@ -172,8 +194,8 @@ class LocalAppDataDirectoryCache {
     dir->clear();
 
     wchar_t *task_mem_buffer = nullptr;
-    const HRESULT result = ::SHGetKnownFolderPath(
-        FOLDERID_LocalAppDataLow, 0, nullptr, &task_mem_buffer);
+    const HRESULT result = ::SHGetKnownFolderPath(FOLDERID_LocalAppDataLow, 0,
+                                                  nullptr, &task_mem_buffer);
     if (FAILED(result)) {
       if (task_mem_buffer != nullptr) {
         ::CoTaskMemFree(task_mem_buffer);
@@ -185,7 +207,7 @@ class LocalAppDataDirectoryCache {
       return E_UNEXPECTED;
     }
 
-    wstring wpath = task_mem_buffer;
+    std::wstring wpath = task_mem_buffer;
     ::CoTaskMemFree(task_mem_buffer);
 
     string path;
@@ -202,80 +224,102 @@ class LocalAppDataDirectoryCache {
 };
 #endif  // OS_WIN
 
-UserProfileDirectoryImpl::UserProfileDirectoryImpl() {
-#ifdef MOZC_USE_PEPPER_FILE_IO
-  // In NaCl, we can't call FileUtil::CreateDirectory() nor
-  // FileUtil::DirectoryExists(). So we just set dir_ here.
-  dir_ = "/";
-  return;
-#else  // MOZC_USE_PEPPER_FILE_IO
-  string dir;
+std::string UserProfileDirectoryImpl::GetUserProfileDirectory() const {
+#if defined(OS_CHROMEOS)
+  // TODO(toka): Must use passed in user profile dir which passed in. If mojo
+  // platform the user profile is determined on runtime.
+  // It's hack, the user profile dir should be passed in. Although the value in
+  // NaCL platform is correct.
+  return "/mutable";
 
-#ifdef OS_WIN
-  DCHECK(SUCCEEDED(Singleton<LocalAppDataDirectoryCache>::get()->result()));
-  dir = Singleton<LocalAppDataDirectoryCache>::get()->path();
-#ifdef GOOGLE_JAPANESE_INPUT_BUILD
-  dir = FileUtil::JoinPath(dir, kCompanyNameInEnglish);
-  FileUtil::CreateDirectory(dir);
-#endif  // GOOGLE_JAPANESE_INPUT_BUILD
-  dir = FileUtil::JoinPath(dir, kProductNameInEnglish);
-
-#elif defined(OS_MACOSX)
-  dir = MacUtil::GetApplicationSupportDirectory();
-#ifdef GOOGLE_JAPANESE_INPUT_BUILD
-  dir = FileUtil::JoinPath(dir, "Google");
-  // The permission of ~/Library/Application Support/Google seems to be 0755.
-  // TODO(komatsu): nice to make a wrapper function.
-  ::mkdir(dir.c_str(), 0755);
-  dir = FileUtil::JoinPath(dir, "JapaneseInput");
-#else  //  GOOGLE_JAPANESE_INPUT_BUILD
-  dir = FileUtil::JoinPath(dir, "Mozc");
-#endif  //  GOOGLE_JAPANESE_INPUT_BUILD
+#elif defined(OS_WASM)
+  // Do nothing for WebAssembly.
+  return "";
 
 #elif defined(OS_ANDROID)
   // For android, we do nothing here because user profile directory,
   // of which the path depends on active user,
   // is injected from Java layer.
+  return "";
 
-#else  // !OS_WIN && !OS_MACOSX && !OS_ANDROID
-  char buf[1024];
-  struct passwd pw, *ppw;
-  const uid_t uid = geteuid();
-  CHECK_EQ(0, getpwuid_r(uid, &pw, buf, sizeof(buf), &ppw))
-      << "Can't get passwd entry for uid " << uid << ".";
-  CHECK_LT(0, strlen(pw.pw_dir))
-      << "Home directory for uid " << uid << " is not set.";
-  dir = FileUtil::JoinPath(pw.pw_dir, ".mozc");
-#endif  // !OS_WIN && !OS_MACOSX && !OS_ANDROID
+#elif defined(OS_IOS)
+  // OS_IOS block must be placed before __APPLE__ because both macros are
+  // currently defined on iOS.
+  //
+  // On iOS, use Caches directory instead of Application Spport directory
+  // because the support directory doesn't exist by default.  Also, it is backed
+  // up by iTunes and iCloud.
+  return FileUtil::JoinPath({MacUtil::GetCachesDirectory(), kProductPrefix});
 
+#elif defined(OS_WIN)
+  DCHECK(SUCCEEDED(Singleton<LocalAppDataDirectoryCache>::get()->result()));
+  std::string dir = Singleton<LocalAppDataDirectoryCache>::get()->path();
+
+# ifdef GOOGLE_JAPANESE_INPUT_BUILD
+  dir = FileUtil::JoinPath(dir, kCompanyNameInEnglish);
   FileUtil::CreateDirectory(dir);
-  if (!FileUtil::DirectoryExists(dir)) {
-    LOG(ERROR) << "Failed to create directory: " << dir;
+# endif  // GOOGLE_JAPANESE_INPUT_BUILD
+  return FileUtil::JoinPath(dir, kProductNameInEnglish);
+
+
+#elif defined(__APPLE__)
+  std::string dir = MacUtil::GetApplicationSupportDirectory();
+# ifdef GOOGLE_JAPANESE_INPUT_BUILD
+  dir = FileUtil::JoinPath(dir, "Google");
+  // The permission of ~/Library/Application Support/Google seems to be 0755.
+  // TODO(komatsu): nice to make a wrapper function.
+  ::mkdir(dir.c_str(), 0755);
+  return FileUtil::JoinPath(dir, "JapaneseInput");
+# else   //  GOOGLE_JAPANESE_INPUT_BUILD
+  return FileUtil::JoinPath(dir, "Mozc");
+# endif  //  GOOGLE_JAPANESE_INPUT_BUILD
+
+
+#elif defined(OS_LINUX)
+  // 1. If "$HOME/.mozc" already exists,
+  //    use "$HOME/.mozc" for backward compatibility.
+  // 2. If $XDG_CONFIG_HOME is defined
+  //    use "$XDG_CONFIG_HOME/mozc".
+  // 3. Otherwise
+  //    use "$HOME/.config/mozc" as the default value of $XDG_CONFIG_HOME
+  // https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
+  const char *home = Environ::GetEnv("HOME");
+  CHECK(home) << "$HOME was not defined.";
+  const std::string old_dir = FileUtil::JoinPath(home, ".mozc");
+  if (FileUtil::DirectoryExists(old_dir)) {
+    return old_dir;
   }
 
-  // set User profile directory
-  dir_ = dir;
-#endif  // MOZC_USE_PEPPER_FILE_IO
+  const char *xdg_config_home = Environ::GetEnv("XDG_CONFIG_HOME");
+  if (xdg_config_home) {
+    return FileUtil::JoinPath(xdg_config_home, "mozc");
+  }
+  return FileUtil::JoinPath(home, ".config/mozc");
+
+#else
+#error Undefined target platform.
+
+#endif
 }
 
 }  // namespace
 
-string SystemUtil::GetUserProfileDirectory() {
-  return Singleton<UserProfileDirectoryImpl>::get()->get();
+std::string SystemUtil::GetUserProfileDirectory() {
+  return Singleton<UserProfileDirectoryImpl>::get()->GetDir();
 }
 
-string SystemUtil::GetLoggingDirectory() {
-#ifdef OS_MACOSX
+std::string SystemUtil::GetLoggingDirectory() {
+#ifdef __APPLE__
   string dir = MacUtil::GetLoggingDirectory();
   FileUtil::CreateDirectory(dir);
   return dir;
-#else  // OS_MACOSX
+#else   // __APPLE__
   return GetUserProfileDirectory();
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 }
 
-void SystemUtil::SetUserProfileDirectory(const string &path) {
-  Singleton<UserProfileDirectoryImpl>::get()->set(path);
+void SystemUtil::SetUserProfileDirectory(const std::string &path) {
+  Singleton<UserProfileDirectoryImpl>::get()->SetDir(path);
 }
 
 #ifdef OS_WIN
@@ -286,15 +330,9 @@ class ProgramFilesX86Cache {
   ProgramFilesX86Cache() : result_(E_FAIL) {
     result_ = SafeTryProgramFilesPath(&path_);
   }
-  const bool succeeded() const {
-    return SUCCEEDED(result_);
-  }
-  const HRESULT result() const {
-    return result_;
-  }
-  const string &path() const {
-    return path_;
-  }
+  const bool succeeded() const { return SUCCEEDED(result_); }
+  const HRESULT result() const { return result_; }
+  const string &path() const { return path_; }
 
  private:
   // b/5707813 implies that the Shell API causes an exception in some cases.
@@ -309,7 +347,7 @@ class ProgramFilesX86Cache {
   static HRESULT __declspec(nothrow) SafeTryProgramFilesPath(string *path) {
     __try {
       return TryProgramFilesPath(path);
-    } __except(EXCEPTION_EXECUTE_HANDLER) {
+    } __except (EXCEPTION_EXECUTE_HANDLER) {
       return E_UNEXPECTED;
     }
   }
@@ -326,16 +364,16 @@ class ProgramFilesX86Cache {
     // CSIDL_PROGRAM_FILES points 64-bit Program Files directory. In this case,
     // we should use CSIDL_PROGRAM_FILESX86 to find server, renderer, and other
     // binaries' path.
-    const HRESULT result = ::SHGetFolderPathW(
-        nullptr, CSIDL_PROGRAM_FILESX86, nullptr,
-        SHGFP_TYPE_CURRENT, program_files_path_buffer);
+    const HRESULT result =
+        ::SHGetFolderPathW(nullptr, CSIDL_PROGRAM_FILESX86, nullptr,
+                           SHGFP_TYPE_CURRENT, program_files_path_buffer);
 #elif defined(_M_IX86)
     // In 32-bit processes (such as server, renderer, and other binaries),
     // CSIDL_PROGRAM_FILES always points 32-bit Program Files directory
     // even if they are running in 64-bit Windows.
-    const HRESULT result = ::SHGetFolderPathW(
-        nullptr, CSIDL_PROGRAM_FILES, nullptr,
-        SHGFP_TYPE_CURRENT, program_files_path_buffer);
+    const HRESULT result =
+        ::SHGetFolderPathW(nullptr, CSIDL_PROGRAM_FILES, nullptr,
+                           SHGFP_TYPE_CURRENT, program_files_path_buffer);
 #else  // !_M_X64 && !_M_IX86
 #error "Unsupported CPU architecture"
 #endif  // _M_X64, _M_IX86, and others
@@ -356,34 +394,39 @@ class ProgramFilesX86Cache {
 }  // namespace
 #endif  // OS_WIN
 
-string SystemUtil::GetServerDirectory() {
+std::string SystemUtil::GetServerDirectory() {
 #ifdef OS_WIN
   DCHECK(SUCCEEDED(Singleton<ProgramFilesX86Cache>::get()->result()));
-#if defined(GOOGLE_JAPANESE_INPUT_BUILD)
+# if defined(GOOGLE_JAPANESE_INPUT_BUILD)
   return FileUtil::JoinPath(
       FileUtil::JoinPath(Singleton<ProgramFilesX86Cache>::get()->path(),
                          kCompanyNameInEnglish),
       kProductNameInEnglish);
-#else  // GOOGLE_JAPANESE_INPUT_BUILD
+# else   // GOOGLE_JAPANESE_INPUT_BUILD
   return FileUtil::JoinPath(Singleton<ProgramFilesX86Cache>::get()->path(),
                             kProductNameInEnglish);
-#endif  // GOOGLE_JAPANESE_INPUT_BUILD
+# endif  // GOOGLE_JAPANESE_INPUT_BUILD
+#endif  // OS_WIN
 
-#elif defined(OS_MACOSX)
+#if defined(__APPLE__)
   return MacUtil::GetServerDirectory();
+#endif  // __APPLE__
 
-#elif defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL)
-#if defined(MOZC_SERVER_DIRECTORY)
+#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
+    defined(OS_WASM)
+# if defined(MOZC_SERVER_DIRECTORY)
   return MOZC_SERVER_DIRECTORY;
-#else
+# else
   return "/usr/lib/mozc";
-#endif  // MOZC_SERVER_DIRECTORY
+# endif  // MOZC_SERVER_DIRECTORY
+#endif  // OS_LINUX || OS_ANDROID || OS_NACL || OS_WASM
 
-#endif  // OS_WIN, OS_MACOSX, OS_LINUX, ...
+  // If none of the above platforms is specified, the compiler raises an error
+  // because of no return value.
 }
 
-string SystemUtil::GetServerPath() {
-  const string server_path = GetServerDirectory();
+std::string SystemUtil::GetServerPath() {
+  const std::string server_path = GetServerDirectory();
   // if server path is empty, return empty path
   if (server_path.empty()) {
     return "";
@@ -391,8 +434,8 @@ string SystemUtil::GetServerPath() {
   return FileUtil::JoinPath(server_path, kMozcServerName);
 }
 
-string SystemUtil::GetRendererPath() {
-  const string server_path = GetServerDirectory();
+std::string SystemUtil::GetRendererPath() {
+  const std::string server_path = GetServerDirectory();
   // if server path is empty, return empty path
   if (server_path.empty()) {
     return "";
@@ -400,8 +443,8 @@ string SystemUtil::GetRendererPath() {
   return FileUtil::JoinPath(server_path, kMozcRenderer);
 }
 
-string SystemUtil::GetToolPath() {
-  const string server_path = GetServerDirectory();
+std::string SystemUtil::GetToolPath() {
+  const std::string server_path = GetServerDirectory();
   // if server path is empty, return empty path
   if (server_path.empty()) {
     return "";
@@ -409,28 +452,24 @@ string SystemUtil::GetToolPath() {
   return FileUtil::JoinPath(server_path, kMozcTool);
 }
 
-string SystemUtil::GetDocumentDirectory() {
-#if defined(OS_MACOSX)
+std::string SystemUtil::GetDocumentDirectory() {
+#if defined(__APPLE__)
   return GetServerDirectory();
 #elif defined(MOZC_DOCUMENT_DIRECTORY)
   return MOZC_DOCUMENT_DIRECTORY;
 #else
   return FileUtil::JoinPath(GetServerDirectory(), "documents");
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 }
 
-string SystemUtil::GetCrashReportDirectory() {
+std::string SystemUtil::GetCrashReportDirectory() {
   const char kCrashReportDirectory[] = "CrashReports";
   return FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(),
                             kCrashReportDirectory);
 }
 
-string SystemUtil::GetUserNameAsString() {
-#ifdef MOZC_USE_PEPPER_FILE_IO
-  LOG(ERROR) << "SystemUtil::GetUserNameAsString() is not implemented in NaCl.";
-  return "username";
-
-#elif defined(OS_WIN)  // MOZC_USE_PEPPER_FILE_IO
+std::string SystemUtil::GetUserNameAsString() {
+#if defined(OS_WIN)
   wchar_t wusername[UNLEN + 1];
   DWORD name_size = UNLEN + 1;
   // Call the same name Windows API.  (include Advapi32.lib).
@@ -442,20 +481,24 @@ string SystemUtil::GetUserNameAsString() {
   string username;
   Util::WideToUTF8(&wusername[0], &username);
   return username;
+#endif  // OS_WIN
 
-#elif defined(OS_ANDROID)  // OS_WIN
+#if defined(OS_ANDROID)
   // Android doesn't seem to support getpwuid_r.
   struct passwd *ppw = getpwuid(geteuid());
-  CHECK(ppw != NULL);
+  CHECK(ppw != nullptr);
   return ppw->pw_name;
+#endif  // OS_ANDROID
 
-#else  // OS_ANDROID
-  // OS_MACOSX, OS_LINUX or OS_NACL
+#if defined(__APPLE__) || defined(OS_LINUX) || defined(OS_WASM)
   struct passwd pw, *ppw;
   char buf[1024];
   CHECK_EQ(0, getpwuid_r(geteuid(), &pw, buf, sizeof(buf), &ppw));
   return pw.pw_name;
-#endif  // !MOZC_USE_PEPPER_FILE_IO && !OS_WIN && !OS_ANDROID
+#endif  // __APPLE__ || OS_LINUX || OS_WASM
+
+  // If none of the above platforms is specified, the compiler raises an error
+  // because of no return value.
 }
 
 #ifdef OS_WIN
@@ -465,6 +508,7 @@ class UserSidImpl {
  public:
   UserSidImpl();
   const string &get() { return sid_; }
+
  private:
   string sid_;
 };
@@ -479,7 +523,7 @@ UserSidImpl::UserSidImpl() {
 
   DWORD length = 0;
   ::GetTokenInformation(htoken, TokenUser, nullptr, 0, &length);
-  unique_ptr<char[]> buf(new char[length]);
+  std::unique_ptr<char[]> buf(new char[length]);
   PTOKEN_USER p_user = reinterpret_cast<PTOKEN_USER>(buf.get());
 
   if (length == 0 ||
@@ -507,10 +551,10 @@ UserSidImpl::UserSidImpl() {
 }  // namespace
 #endif  // OS_WIN
 
-string SystemUtil::GetUserSidAsString() {
+std::string SystemUtil::GetUserSidAsString() {
 #ifdef OS_WIN
   return Singleton<UserSidImpl>::get()->get();
-#else  // OS_WIN
+#else   // OS_WIN
   return GetUserNameAsString();
 #endif  // OS_WIN
 }
@@ -527,8 +571,7 @@ string GetObjectNameAsString(HANDLE handle) {
   DWORD size = 0;
   if (::GetUserObjectInformationA(handle, UOI_NAME, nullptr, 0, &size) ||
       ERROR_INSUFFICIENT_BUFFER != ::GetLastError()) {
-    LOG(ERROR) << "GetUserObjectInformationA() failed: "
-               << ::GetLastError();
+    LOG(ERROR) << "GetUserObjectInformationA() failed: " << ::GetLastError();
     return "";
   }
 
@@ -537,12 +580,11 @@ string GetObjectNameAsString(HANDLE handle) {
     return "";
   }
 
-  unique_ptr<char[]> buf(new char[size]);
+  std::unique_ptr<char[]> buf(new char[size]);
   DWORD return_size = 0;
-  if (!::GetUserObjectInformationA(handle, UOI_NAME, buf.get(),
-                                   size, &return_size)) {
-    LOG(ERROR) << "::GetUserObjectInformationA() failed: "
-               << ::GetLastError();
+  if (!::GetUserObjectInformationA(handle, UOI_NAME, buf.get(), size,
+                                   &return_size)) {
+    LOG(ERROR) << "::GetUserObjectInformationA() failed: " << ::GetLastError();
     return "";
   }
 
@@ -552,7 +594,7 @@ string GetObjectNameAsString(HANDLE handle) {
   }
 
   char *result = buf.get();
-  result[return_size - 1] = '\0';  // just make sure NULL terminated
+  result[return_size - 1] = '\0';  // just make sure nullptr terminated
 
   return result;
 }
@@ -575,7 +617,8 @@ bool GetCurrentSessionId(uint32 *session_id) {
 // current thread. One reason behind this is that some applications such as
 // Adobe Reader XI use multiple desktops in a process. Basically the input
 // desktop is most appropriate and important desktop for our use case.
-// See http://blogs.adobe.com/asset/2012/10/new-security-capabilities-in-adobe-reader-and-acrobat-xi-now-available.html
+// See
+// http://blogs.adobe.com/asset/2012/10/new-security-capabilities-in-adobe-reader-and-acrobat-xi-now-available.html
 string GetInputDesktopName() {
   const HDESK desktop_handle =
       ::OpenInputDesktop(0, FALSE, DESKTOP_READOBJECTS);
@@ -603,24 +646,27 @@ string GetSessionIdString() {
   if (!GetCurrentSessionId(&session_id)) {
     return "";
   }
-  return NumberUtil::SimpleItoa(session_id);
+  return std::to_string(session_id);
 }
 
 }  // namespace
 #endif  // OS_WIN
 
-string SystemUtil::GetDesktopNameAsString() {
-#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL)
-  const char *display = getenv("DISPLAY");
-  if (display == NULL) {
+std::string SystemUtil::GetDesktopNameAsString() {
+#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
+    defined(OS_WASM)
+  const char *display = Environ::GetEnv("DISPLAY");
+  if (display == nullptr) {
     return "";
   }
   return display;
+#endif  // OS_LINUX || OS_ANDROID || OS_NACL || OS_WASM
 
-#elif defined(OS_MACOSX)
+#if defined(__APPLE__)
   return "";
+#endif  // __APPLE__
 
-#elif defined(OS_WIN)
+#if defined(OS_WIN)
   const string &session_id = GetSessionIdString();
   if (session_id.empty()) {
     DLOG(ERROR) << "Failed to retrieve session id";
@@ -640,7 +686,7 @@ string SystemUtil::GetDesktopNameAsString() {
   }
 
   return (session_id + "." + window_station_name + "." + desktop_name);
-#endif  // OS_LINUX, OS_MACOSX, OS_WIN, ...
+#endif  // OS_WIN
 }
 
 #ifdef OS_WIN
@@ -659,12 +705,9 @@ class SystemDirectoryCache {
     DCHECK_EQ(L'\0', path_buffer_[copied_len_wo_null_if_success]);
     system_dir_ = path_buffer_;
   }
-  const bool succeeded() const {
-    return system_dir_ != nullptr;
-  }
-  const wchar_t *system_dir() const {
-    return system_dir_;
-  }
+  const bool succeeded() const { return system_dir_ != nullptr; }
+  const wchar_t *system_dir() const { return system_dir_; }
+
  private:
   wchar_t path_buffer_[MAX_PATH];
   wchar_t *system_dir_;
@@ -740,8 +783,7 @@ bool SystemUtil::IsWindowsX64() {
   SYSTEM_INFO system_info = {};
   // This function never fails.
   ::GetNativeSystemInfo(&system_info);
-  return (system_info.wProcessorArchitecture ==
-          PROCESSOR_ARCHITECTURE_AMD64);
+  return (system_info.wProcessorArchitecture == PROCESSOR_ARCHITECTURE_AMD64);
 #else
   return false;
 #endif  // OS_WIN
@@ -789,33 +831,33 @@ string SystemUtil::GetMSCTFAsmCacheReadyEventName() {
 
 // TODO(toshiyuki): move this to the initialization module and calculate
 // version only when initializing.
-string SystemUtil::GetOSVersionString() {
+std::string SystemUtil::GetOSVersionString() {
 #ifdef OS_WIN
   string ret = "Windows";
-  OSVERSIONINFOEX osvi = { 0 };
+  OSVERSIONINFOEX osvi = {0};
   osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
   if (GetVersionEx(reinterpret_cast<OSVERSIONINFO *>(&osvi))) {
     ret += ".";
-    ret += NumberUtil::SimpleItoa(static_cast<uint32>(osvi.dwMajorVersion));
+    ret += std::to_string(static_cast<uint32>(osvi.dwMajorVersion));
     ret += ".";
-    ret += NumberUtil::SimpleItoa(static_cast<uint32>(osvi.dwMinorVersion));
-    ret += "." + NumberUtil::SimpleItoa(osvi.wServicePackMajor);
-    ret += "." + NumberUtil::SimpleItoa(osvi.wServicePackMinor);
+    ret += std::to_string(static_cast<uint32>(osvi.dwMinorVersion));
+    ret += "." + std::to_string(osvi.wServicePackMajor);
+    ret += "." + std::to_string(osvi.wServicePackMinor);
   } else {
     LOG(WARNING) << "GetVersionEx failed";
   }
   return ret;
-#elif defined(OS_MACOSX)
+#elif defined(__APPLE__)
   const string ret = "MacOSX " + MacUtil::GetOSVersionString();
   // TODO(toshiyuki): get more specific info
   return ret;
 #elif defined(OS_LINUX) || defined(OS_NACL)
-  const string ret = "Linux";
+  const std::string ret = "Linux";
   return ret;
-#else  // !OS_WIN && !OS_MACOSX && !OS_LINUX
+#else   // !OS_WIN && !__APPLE__ && !OS_LINUX
   const string ret = "Unknown";
   return ret;
-#endif  // OS_WIN, OS_MACOSX, OS_LINUX
+#endif  // OS_WIN, __APPLE__, OS_LINUX
 }
 
 void SystemUtil::DisableIME() {
@@ -829,17 +871,19 @@ void SystemUtil::DisableIME() {
 
 uint64 SystemUtil::GetTotalPhysicalMemory() {
 #if defined(OS_WIN)
-  MEMORYSTATUSEX memory_status = { sizeof(MEMORYSTATUSEX) };
+  MEMORYSTATUSEX memory_status = {sizeof(MEMORYSTATUSEX)};
   if (!::GlobalMemoryStatusEx(&memory_status)) {
     return 0;
   }
   return memory_status.ullTotalPhys;
-#elif defined(OS_MACOSX)
-  int mib[] = { CTL_HW, HW_MEMSIZE };
+#endif  // OS_WIN
+
+#if defined(__APPLE__)
+  int mib[] = {CTL_HW, HW_MEMSIZE};
   uint64 total_memory = 0;
   size_t size = sizeof(total_memory);
   const int error =
-      sysctl(mib, arraysize(mib), &total_memory, &size, NULL, 0);
+      sysctl(mib, arraysize(mib), &total_memory, &size, nullptr, 0);
   if (error == -1) {
     const int error = errno;
     LOG(ERROR) << "sysctl with hw.memsize failed. "
@@ -847,22 +891,26 @@ uint64 SystemUtil::GetTotalPhysicalMemory() {
     return 0;
   }
   return total_memory;
-#elif defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL)
-#if defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
-  const long page_size = sysconf(_SC_PAGESIZE);
-  const long number_of_phyisical_pages = sysconf(_SC_PHYS_PAGES);
+#endif  // __APPLE__
+
+#if defined(OS_LINUX) || defined(OS_ANDROID) || defined(OS_NACL) || \
+    defined(OS_WASM)
+# if defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
+  const int32 page_size = sysconf(_SC_PAGESIZE);
+  const int32 number_of_phyisical_pages = sysconf(_SC_PHYS_PAGES);
   if (number_of_phyisical_pages < 0) {
     // likely to be overflowed.
     LOG(FATAL) << number_of_phyisical_pages << ", " << page_size;
     return 0;
   }
   return static_cast<uint64>(number_of_phyisical_pages) * page_size;
-#else  // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
+# else   // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
   return 0;
-#endif  // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
-#else  // !(defined(OS_WIN) || defined(OS_MACOSX) || defined(OS_LINUX))
-#error "unknown platform"
-#endif  // OS_WIN, OS_MACOSX, OS_LINUX
+# endif  // defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
+#endif  // OS_LINUX || OS_ANDROID || OS_NACL || OS_WASM
+
+  // If none of the above platforms is specified, the compiler raises an error
+  // because of no return value.
 }
 
 }  // namespace mozc
