@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -51,11 +51,11 @@ namespace {
 // the number of characters to be normalized.
 inline char32 NormalizeCharForWindows(char32 c) {
   switch (c) {
-    case 0x301C:  // WAVE DASH
-      return 0xFF5E;   // FULLWIDTH TILDE
+    case 0x301C:      // WAVE DASH
+      return 0xFF5E;  // FULLWIDTH TILDE
       break;
-    case 0x2212:  // MINUS SIGN
-      return 0xFF0D;   // FULLWIDTH HYPHEN MINUS
+    case 0x2212:      // MINUS SIGN
+      return 0xFF0D;  // FULLWIDTH HYPHEN MINUS
       break;
     default:
       return c;
@@ -66,7 +66,8 @@ inline char32 NormalizeCharForWindows(char32 c) {
 
 }  // namespace
 
-void TextNormalizer::NormalizeText(StringPiece input, string *output) {
+void TextNormalizer::NormalizeText(absl::string_view input,
+                                   std::string *output) {
 #ifdef OS_WIN
   output->clear();
   for (ConstChar32Iterator iter(input); !iter.Done(); iter.Next()) {
