@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@
 namespace mozc {
 
 TEST(TextNormalizerTest, NormalizeText) {
-  string output;
+  std::string output;
   TextNormalizer::NormalizeText("めかぶ", &output);
   EXPECT_EQ("めかぶ", output);
 
