@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -43,44 +43,42 @@ namespace internal {
 // TODO(team): Consider to remove this class and stop doing obfuscation.
 class UnverifiedAES256 {
  public:
-  static const size_t kKeyBytes = 32;    // 256 bit
-  static const size_t kBlockBytes = 16;  // 128 bit
-  static const size_t kKeyScheduleBytes = 240;
+  static constexpr size_t kKeyBytes = 32;    // 256 bit
+  static constexpr size_t kBlockBytes = 16;  // 128 bit
+  static constexpr size_t kKeyScheduleBytes = 240;
 
   // Does AES256 CBC transformation.
   // CAVEATS: See the above comment.
   static void TransformCBC(const uint8 (&key)[kKeyBytes],
-                           const uint8 (&iv)[kBlockBytes],
-                           uint8 *buffer,
+                           const uint8 (&iv)[kBlockBytes], uint8 *block,
                            size_t block_count);
 
   // Does AES256 CBC inverse transformation.
   // CAVEATS: See the above comment.
   static void InverseTransformCBC(const uint8 (&key)[kKeyBytes],
-                                  const uint8 (&iv)[kBlockBytes],
-                                  uint8 *buffer,
+                                  const uint8 (&iv)[kBlockBytes], uint8 *block,
                                   size_t block_count);
 
  protected:
   // Does AES256 ECB transformation.
   // CAVEATS: See the above comment.
   static void TransformECB(const uint8 (&w)[kKeyScheduleBytes],
-                           uint8 buffer[kBlockBytes]);
+                           uint8 block[kBlockBytes]);
 
   // Does AES256 ECB inverse transformation.
   // CAVEATS: See the above comment.
   static void InverseTransformECB(const uint8 (&w)[kKeyScheduleBytes],
-                                  uint8 buffer[kBlockBytes]);
+                                  uint8 block[kBlockBytes]);
 
   // Declared as protected for unit test.
   static void MakeKeySchedule(const uint8 (&key)[kKeyBytes],
                               uint8 w[kKeyScheduleBytes]);
-  static void SubBytes(uint8 buf[kBlockBytes]);
-  static void InvSubBytes(uint8 buf[kBlockBytes]);
-  static void MixColumns(uint8 buf[kBlockBytes]);
-  static void InvMixColumns(uint8 buf[kBlockBytes]);
-  static void ShiftRows(uint8 buf[kBlockBytes]);
-  static void InvShiftRows(uint8 buf[kBlockBytes]);
+  static void SubBytes(uint8 block[kBlockBytes]);
+  static void InvSubBytes(uint8 block[kBlockBytes]);
+  static void MixColumns(uint8 block[kBlockBytes]);
+  static void InvMixColumns(uint8 block[kBlockBytes]);
+  static void ShiftRows(uint8 block[kBlockBytes]);
+  static void InvShiftRows(uint8 block[kBlockBytes]);
 
  private:
   DISALLOW_IMPLICIT_CONSTRUCTORS(UnverifiedAES256);
