@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,8 @@ class URL {
   // Composes a URL for an uninstallation survey.  Note that we should set
   // version because, in Mac OS, we can not get mozc version from uninstaller
   // binary.
-  static bool GetUninstallationSurveyURL(const string &version, string *url);
+  static bool GetUninstallationSurveyURL(const std::string &version,
+                                         std::string *url);
 
   // should never be allocated.
  private:
