@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,16 +36,14 @@ namespace mozc {
 namespace {
 
 const DWORD kFakeWindowsVersion = 0x12345678;
-DWORD WINAPI GetVersionHook() {
-  return kFakeWindowsVersion;
-}
+DWORD WINAPI GetVersionHook() { return kFakeWindowsVersion; }
 
 TEST(WinAPITestHelperTest, BasicTest) {
   std::vector<WinAPITestHelper::HookRequest> requests;
   requests.push_back(DEFINE_HOOK("kernel32.dll", GetVersion, GetVersionHook));
 
-  auto restore_info = WinAPITestHelper::DoHook(
-      ::GetModuleHandle(nullptr), requests);
+  auto restore_info =
+      WinAPITestHelper::DoHook(::GetModuleHandle(nullptr), requests);
   EXPECT_EQ(GetVersion(), kFakeWindowsVersion);
 
   WinAPITestHelper::RestoreHook(restore_info);
