@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -59,7 +59,7 @@ void VerifySidContained(const std::vector<Sid> sids,
 }
 
 TEST(WinSandboxTest, GetSidsToDisable) {
-  HANDLE process_token_ret = NULL;
+  HANDLE process_token_ret = nullptr;
   ::OpenProcessToken(::GetCurrentProcess(), TOKEN_ALL_ACCESS,
                      &process_token_ret);
   ScopedHandle process_token(process_token_ret);
@@ -92,7 +92,7 @@ TEST(WinSandboxTest, GetSidsToDisable) {
 }
 
 TEST(WinSandboxTest, GetPrivilegesToDisable) {
-  HANDLE process_token_ret = NULL;
+  HANDLE process_token_ret = nullptr;
   ::OpenProcessToken(::GetCurrentProcess(), TOKEN_ALL_ACCESS,
                      &process_token_ret);
   ScopedHandle process_token(process_token_ret);
@@ -118,7 +118,7 @@ TEST(WinSandboxTest, GetPrivilegesToDisable) {
 }
 
 TEST(WinSandboxTest, GetSidsToRestrict) {
-  HANDLE process_token_ret = NULL;
+  HANDLE process_token_ret = nullptr;
   ::OpenProcessToken(::GetCurrentProcess(), TOKEN_ALL_ACCESS,
                      &process_token_ret);
   ScopedHandle process_token(process_token_ret);
@@ -134,7 +134,7 @@ TEST(WinSandboxTest, GetSidsToRestrict) {
   const std::vector<Sid> non_admin = WinSandbox::GetSidsToRestrict(
       process_token.get(), WinSandbox::USER_NON_ADMIN);
   const std::vector<Sid> restricted_same_access = WinSandbox::GetSidsToRestrict(
-          process_token.get(), WinSandbox::USER_RESTRICTED_SAME_ACCESS);
+      process_token.get(), WinSandbox::USER_RESTRICTED_SAME_ACCESS);
   const std::vector<Sid> unprotect = WinSandbox::GetSidsToRestrict(
       process_token.get(), WinSandbox::USER_UNPROTECTED);
 
@@ -150,13 +150,12 @@ const wchar_t kDummyUserSID[] = L"S-8";
 const wchar_t kDummyGroupSID[] = L"S-9";
 
 std::wstring GetSDDLForVista(WinSandbox::ObjectSecurityType type) {
-  return TestableWinSandbox::GetSDDL(
-      type, kDummyUserSID, kDummyGroupSID, false);
+  return TestableWinSandbox::GetSDDL(type, kDummyUserSID, kDummyGroupSID,
+                                     false);
 }
 
 std::wstring GetSDDLForWin8(WinSandbox::ObjectSecurityType type) {
-  return TestableWinSandbox::GetSDDL(
-      type, kDummyUserSID, kDummyGroupSID, true);
+  return TestableWinSandbox::GetSDDL(type, kDummyUserSID, kDummyGroupSID, true);
 }
 
 TEST(WinSandboxTest, GetSDDLForSharablePipe) {
