@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2010-2018, Google Inc.
+# Copyright 2010-2020, Google Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -30,10 +30,14 @@
 
 """Utilities to generate source codes."""
 
-__author__ = "hidehiko"
+from __future__ import absolute_import
 
 import struct
-import types
+import six
+
+from six.moves import range  # pylint: disable=redefined-builtin
+
+__author__ = "hidehiko"
 
 
 def ToCppStringLiteral(s):
@@ -41,19 +45,31 @@ def ToCppStringLiteral(s):
   if s is None:
     return 'NULL'
 
-  if all(0x20 <= ord(c) <= 0x7E for c in s):
-    # All characters are in ascii code.
-    return '"%s"' % s.replace('\\', r'\\').replace('"', r'\"')
+  if six.PY3:
+    # Python3
+    if all(0x20 <= ord(c) <= 0x7E for c in s):
+      # All characters are in ascii code.
+      return '"%s"' % s.replace('\\', r'\\').replace('"', r'\"')
+    else:
+      # One or more characters are non-ascii.
+      return '"%s"' % ''.join(r'\x%02X' % c for c in s.encode('utf-8'))
+
   else:
-    # One or more characters are non-ascii.
-    return '"%s"' % ''.join(r'\x%02X' % ord(c) for c in s)
+    # Python2
+    s = six.ensure_str(s)
+    if all(0x20 <= ord(c) <= 0x7E for c in s):
+      # All characters are in ascii code.
+      return '"%s"' % s.replace('\\', r'\\').replace('"', r'\"')
+    else:
+      # One or more characters are non-ascii.
+      return '"%s"' % ''.join(r'\x%02X' % ord(c) for c in s)
 
 
 def FormatWithCppEscape(format_text, *args):
   """Returns a string filling format with args."""
   literal_list = []
   for arg in args:
-    if isinstance(arg, (types.StringType, types.NoneType)):
+    if isinstance(arg, (str, type(None))):
       arg = ToCppStringLiteral(arg)
     literal_list.append(arg)
 
@@ -61,7 +77,7 @@ def FormatWithCppEscape(format_text, *args):
 
 
 def WriteCppDataArray(data, variable_name, target_compiler, stream):
-  """Format data into C++ style array.
+  r"""Format data into C++ style array.
 
   Visual C++ does not support string literals longer than 65535 characters
   so integer arrays (e.g. arrays of uint64) are used to represent byte arrays
@@ -91,14 +107,14 @@ def WriteCppDataArray(data, variable_name, target_compiler, stream):
     stream: output stream.
   """
 
-  # To accept "target_compiler = None", check taget_compiler itself first.
+  # To accept "target_compiler = None", check target_compiler itself first.
   if target_compiler and target_compiler.startswith('msvs'):
     stream.write('const uint64 k%s_data_wordtype[] = {\n' % variable_name)
 
-    for word_index in xrange(0, len(data), 8):
+    for word_index in range(0, len(data), 8):
       word_chunk = data[word_index:word_index + 8].ljust(8, '\x00')
-      stream.write('0x%016X, ' % struct.unpack('<Q', word_chunk))
-      if (word_index / 8) % 4 == 3:
+      stream.write('0x%016X, ' % struct.unpack('<Q', six.b(word_chunk)))
+      if (word_index // 8) % 4 == 3:
         # Line feed for every 4 elements.
         stream.write('\n')
 
@@ -111,7 +127,7 @@ def WriteCppDataArray(data, variable_name, target_compiler, stream):
     stream.write('const char k%s_data[] =\n' % variable_name)
     # Output 16bytes per line.
     chunk_size = 16
-    for index in xrange(0, len(data), chunk_size):
+    for index in range(0, len(data), chunk_size):
       chunk = data[index:index + chunk_size]
       stream.write('"')
       stream.writelines(r'\x%02X' % ord(c) for c in chunk)
@@ -123,19 +139,19 @@ def WriteCppDataArray(data, variable_name, target_compiler, stream):
 
 def ToJavaStringLiteral(codepoint_list):
   """Returns string literal with surrogate pair and emoji support."""
-  if type(codepoint_list) is int:
+  if isinstance(codepoint_list, int):
     codepoint_list = (codepoint_list,)
-  if codepoint_list is None or len(codepoint_list) == 0:
+  if not codepoint_list:
     return 'null'
   result = r'"'
   for codepoint in codepoint_list:
-    utf16_string = unichr(codepoint).encode('utf-16be')
-    if len(utf16_string) == 2:
-      (u0, l0) = utf16_string
-      result += r'\u%02X%02X' % (ord(u0), ord(l0))
+    utf16_array = bytearray(six.unichr(codepoint).encode('utf-16be'))
+    if len(utf16_array) == 2:
+      (u0, l0) = utf16_array
+      result += r'\u%02X%02X' % (u0, l0)
     else:
-      (u0, l0, u1, l1) = utf16_string
-      result += r'\u%02X%02X\u%02X%02X' % (ord(u0), ord(l0), ord(u1), ord(l1))
+      (u0, l0, u1, l1) = utf16_array
+      result += r'\u%02X%02X\u%02X%02X' % (u0, l0, u1, l1)
   result += r'"'
   return result
 
@@ -172,5 +188,5 @@ def SplitChunk(iterable, n):
   grouper extends the last chunk to make it an n-element chunk by adding
   appropriate value, but this returns truncated chunk.
   """
-  for index in xrange(0, len(iterable), n):
+  for index in range(0, len(iterable), n):
     yield iterable[index:index + n]
