@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -58,22 +58,22 @@
 #include "base/win_util.h"
 #endif  // OS_WIN
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
 #include "base/mac_process.h"
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 
 namespace mozc {
 namespace client {
 
 namespace {
-const char kServerAddress[]    = "session";  // name for the IPC connection.
-const int    kResultBufferSize = 8192 * 32;   // size of IPC buffer
-const size_t kMaxPlayBackSize  = 512;   // size of maximum history
+const char kServerAddress[] = "session";  // name for the IPC connection.
+const int kResultBufferSize = 8192 * 32;  // size of IPC buffer
+const size_t kMaxPlayBackSize = 512;      // size of maximum history
 
 #ifdef DEBUG
-const int kDefaultTimeout = 100000;   // 100 sec for dbg
+const int kDefaultTimeout = 100000;  // 100 sec for dbg
 #else
-const int kDefaultTimeout = 30000;    // 30 sec for opt
+const int kDefaultTimeout = 30000;  // 30 sec for opt
 #endif  // DEBUG
 
 // Delete Session is called inside the Destructor of Client class.
@@ -106,8 +106,7 @@ void Client::SetIPCClientFactory(IPCClientFactoryInterface *client_factory) {
   client_factory_ = client_factory;
 }
 
-void Client::SetServerLauncher(
-    ServerLauncherInterface *server_launcher) {
+void Client::SetServerLauncher(ServerLauncherInterface *server_launcher) {
   server_launcher_.reset(server_launcher);
 }
 
@@ -193,9 +192,9 @@ void Client::DumpQueryOfDeath() {
   ResetHistory();
 }
 
-void Client::DumpHistorySnapshot(const string &filename,
-                                 const string &label) const {
-  const string snapshot_file =
+void Client::DumpHistorySnapshot(const std::string &filename,
+                                 const std::string &label) const {
+  const std::string snapshot_file =
       FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(), filename);
   // open with append mode
   OutputFileStream output(snapshot_file.c_str(), std::ios::app);
@@ -228,7 +227,7 @@ void Client::PlaybackHistory() {
 }
 
 void Client::PushHistory(const commands::Input &input,
-                          const commands::Output &output) {
+                         const commands::Output &output) {
   if (!output.has_consumed() || !output.consumed()) {
     // Do not remember unconsumed input.
     return;
@@ -248,8 +247,7 @@ void Client::PushHistory(const commands::Input &input,
   // found context boundary.
   // don't regard the empty output (output without preedit) as the context
   // boundary, as the IMEOn command make the empty output.
-  if (input.type() == commands::Input::SEND_KEY &&
-      output.has_result()) {
+  if (input.type() == commands::Input::SEND_KEY && output.has_result()) {
     ResetHistory();
   }
 }
@@ -257,7 +255,7 @@ void Client::PushHistory(const commands::Input &input,
 // Clear the history and push IMEOn command for initialize session.
 void Client::ResetHistory() {
   history_inputs_.clear();
-#if defined(OS_MACOSX)
+#if defined(__APPLE__)
   // On Mac, we should send ON key at the first of each input session
   // excepting the very first session, because when the session is restored,
   // its state is direct. On the first session, users should send ON key
@@ -339,7 +337,7 @@ bool Client::CheckVersionOrRestartServer() {
 }
 
 bool Client::EnsureCallCommand(commands::Input *input,
-                                commands::Output *output) {
+                               commands::Output *output) {
   if (!EnsureSession()) {
     LOG(ERROR) << "EnsureSession failed";
     return false;
@@ -350,7 +348,7 @@ bool Client::EnsureCallCommand(commands::Input *input,
 
   if (!CallAndCheckVersion(*input, output)) {  // server is not running
     LOG(ERROR) << "Call command failed";
-  } else if (output->id() != input->id()) {   // invalid ID
+  } else if (output->id() != input->id()) {  // invalid ID
     LOG(ERROR) << "Session id is void. re-issue session id";
     server_status_ = SERVER_INVALID_SESSION;
   }
@@ -395,21 +393,19 @@ bool Client::EnsureCallCommand(commands::Input *input,
 }
 
 void Client::EnableCascadingWindow(const bool enable) {
-  if (preferences_.get() == NULL) {
+  if (preferences_ == nullptr) {
     preferences_.reset(new config::Config);
   }
   preferences_->set_use_cascading_window(enable);
 }
 
-void Client::set_timeout(int timeout) {
-  timeout_ = timeout;
-}
+void Client::set_timeout(int timeout) { timeout_ = timeout; }
 
 void Client::set_restricted(bool restricted) {
   server_launcher_->set_restricted(restricted);
 }
 
-void Client::set_server_program(const string &program_path) {
+void Client::set_server_program(const std::string &program_path) {
   server_launcher_->set_server_program(program_path);
 }
 
@@ -528,17 +524,11 @@ bool Client::Shutdown() {
   return true;
 }
 
-bool Client::SyncData() {
-  return CallCommand(commands::Input::SYNC_DATA);
-}
+bool Client::SyncData() { return CallCommand(commands::Input::SYNC_DATA); }
 
-bool Client::Reload() {
-  return CallCommand(commands::Input::RELOAD);
-}
+bool Client::Reload() { return CallCommand(commands::Input::RELOAD); }
 
-bool Client::Cleanup() {
-  return CallCommand(commands::Input::CLEANUP);
-}
+bool Client::Cleanup() { return CallCommand(commands::Input::CLEANUP); }
 
 bool Client::NoOperation() {
   return CallCommand(commands::Input::NO_OPERATION);
@@ -546,7 +536,7 @@ bool Client::NoOperation() {
 
 // PingServer ignores all server status
 bool Client::PingServer() const {
-  if (client_factory_ == NULL) {
+  if (client_factory_ == nullptr) {
     return false;
   }
 
@@ -557,11 +547,10 @@ bool Client::PingServer() const {
   input.set_type(commands::Input::NO_OPERATION);
 
   // Call IPC
-  std::unique_ptr<IPCClientInterface> client(
-      client_factory_->NewClient(kServerAddress,
-                                 server_launcher_->server_program()));
+  std::unique_ptr<IPCClientInterface> client(client_factory_->NewClient(
+      kServerAddress, server_launcher_->server_program()));
 
-  if (client.get() == NULL) {
+  if (client == nullptr) {
     LOG(ERROR) << "Cannot make client object";
     return false;
   }
@@ -572,12 +561,12 @@ bool Client::PingServer() const {
   }
 
   // Serialize
-  string request;
+  std::string request;
   input.SerializeToString(&request);
 
   size_t size = kResultBufferSize;
-  if (!client->Call(request.data(), request.size(),
-                    result_.get(), &size, timeout_)) {
+  if (!client->Call(request.data(), request.size(), result_.get(), &size,
+                    timeout_)) {
     LOG(ERROR) << "IPCClient::Call failed: " << client->GetLastIPCError();
     return false;
   }
@@ -594,11 +583,10 @@ bool Client::CallCommand(commands::Input::CommandType type) {
 }
 
 bool Client::CallAndCheckVersion(const commands::Input &input,
-                                  commands::Output *output) {
+                                 commands::Output *output) {
   if (!Call(input, output)) {
     if (server_protocol_version_ != IPC_PROTOCOL_VERSION) {
-      LOG(ERROR) << "version mismatch: "
-                 << server_protocol_version_ << " "
+      LOG(ERROR) << "version mismatch: " << server_protocol_version_ << " "
                  << static_cast<int>(IPC_PROTOCOL_VERSION);
       server_status_ = SERVER_VERSION_MISMATCH;
     }
@@ -608,10 +596,8 @@ bool Client::CallAndCheckVersion(const commands::Input &input,
   return true;
 }
 
-bool Client::Call(const commands::Input &input,
-                  commands::Output *output) {
-  VLOG(2) << "commands::Input: " << std::endl
-          << input.DebugString();
+bool Client::Call(const commands::Input &input, commands::Output *output) {
+  VLOG(2) << "commands::Input: " << std::endl << input.DebugString();
 
   // don't repeat Call() if the status is either
   // SERVER_FATAL, SERVER_TIMEOUT, or SERVER_BROKEN_MESSAGE
@@ -620,18 +606,17 @@ bool Client::Call(const commands::Input &input,
     return false;
   }
 
-  if (client_factory_ == NULL) {
+  if (client_factory_ == nullptr) {
     return false;
   }
 
   // Serialize
-  string request;
+  std::string request;
   input.SerializeToString(&request);
 
   // Call IPC
-  std::unique_ptr<IPCClientInterface> client(
-      client_factory_->NewClient(kServerAddress,
-                                 server_launcher_->server_program()));
+  std::unique_ptr<IPCClientInterface> client(client_factory_->NewClient(
+      kServerAddress, server_launcher_->server_program()));
 
   // set client protocol version.
   // When an error occurs inside Connected() function,
@@ -644,7 +629,7 @@ bool Client::Call(const commands::Input &input,
   server_product_version_ = Version::GetMozcVersion();
   server_process_id_ = 0;
 
-  if (client.get() == NULL) {
+  if (client == nullptr) {
     LOG(ERROR) << "Cannot make client object";
     server_status_ = SERVER_FATAL;
     return false;
@@ -673,8 +658,8 @@ bool Client::Call(const commands::Input &input,
   // http://b/2126375
   // TODO(taku): Investigate the error in detail.
   size_t size = kResultBufferSize;
-  if (!client->Call(request.data(), request.size(),
-                    result_.get(), &size, timeout_)) {
+  if (!client->Call(request.data(), request.size(), result_.get(), &size,
+                    timeout_)) {
     LOG(ERROR) << "Call failure";
     //               << input.DebugString();
     if (client->GetLastIPCError() == IPC_TIMEOUT_ERROR) {
@@ -697,37 +682,35 @@ bool Client::Call(const commands::Input &input,
          server_status_ == SERVER_INVALID_SESSION ||
          server_status_ == SERVER_SHUTDOWN ||
          server_status_ == SERVER_UNKNOWN /* during StartServer() */)
-             << " " << server_status_;
+      << " " << server_status_;
 
-  VLOG(2) << "commands::Output: " << std::endl
-          << output->DebugString();
+  VLOG(2) << "commands::Output: " << std::endl << output->DebugString();
 
   return true;
 }
 
 bool Client::StartServer() {
-  if (server_launcher_.get() != NULL) {
+  if (server_launcher_ != nullptr) {
     return server_launcher_->StartServer(this);
   }
   return true;
 }
 
-
 void Client::OnFatal(ServerLauncherInterface::ServerErrorType type) {
-  if (server_launcher_.get() != NULL) {
+  if (server_launcher_ != nullptr) {
     server_launcher_->OnFatal(type);
   }
 }
 
 void Client::InitInput(commands::Input *input) const {
   input->set_id(id_);
-  if (preferences_.get() != NULL) {
+  if (preferences_ != nullptr) {
     input->mutable_config()->CopyFrom(*preferences_);
   }
 }
 
-bool Client::CheckVersionOrRestartServerInternal(
-    const commands::Input &input, commands::Output *output) {
+bool Client::CheckVersionOrRestartServerInternal(const commands::Input &input,
+                                                 commands::Output *output) {
   for (int trial = 0; trial < 2; ++trial) {
     const bool call_result = Call(input, output);
 
@@ -737,9 +720,8 @@ bool Client::CheckVersionOrRestartServerInternal(
       return false;
     }
 
-    const bool version_upgraded =
-        Version::CompareVersion(server_product_version_,
-                                Version::GetMozcVersion());
+    const bool version_upgraded = Version::CompareVersion(
+        server_product_version_, Version::GetMozcVersion());
 
     // if the server version is older than client version or
     // protocol version is updated, force to reboot the server.
@@ -748,13 +730,10 @@ bool Client::CheckVersionOrRestartServerInternal(
     // SERVER_FATAL state finally.
     if ((call_result && version_upgraded) ||
         (!call_result && server_protocol_version_ < IPC_PROTOCOL_VERSION)) {
-      LOG(WARNING) << "Version Mismatch: "
-                   << server_product_version_ << " "
-                   << Version::GetMozcVersion()
-                   << " "
+      LOG(WARNING) << "Version Mismatch: " << server_product_version_ << " "
+                   << Version::GetMozcVersion() << " "
                    << server_protocol_version_ << " "
-                   << static_cast<int>(IPC_PROTOCOL_VERSION)
-                   << " " << trial;
+                   << static_cast<int>(IPC_PROTOCOL_VERSION) << " " << trial;
       if (trial > 0) {
         LOG(ERROR) << "Server version mismatch even after server reboot";
         server_status_ = SERVER_BROKEN_MESSAGE;
@@ -812,8 +791,8 @@ void Client::Reset() {
 }
 
 bool Client::TranslateProtoBufToMozcToolArg(const commands::Output &output,
-                                             string *mode) {
-  if (!output.has_launch_tool_mode() || mode == NULL) {
+                                            std::string *mode) {
+  if (!output.has_launch_tool_mode() || mode == nullptr) {
     return false;
   }
 
@@ -838,7 +817,7 @@ bool Client::TranslateProtoBufToMozcToolArg(const commands::Output &output,
 }
 
 bool Client::LaunchToolWithProtoBuf(const commands::Output &output) {
-  string mode;
+  std::string mode;
   if (!TranslateProtoBufToMozcToolArg(output, &mode)) {
     return false;
   }
@@ -847,7 +826,7 @@ bool Client::LaunchToolWithProtoBuf(const commands::Output &output) {
   return LaunchTool(mode, "");
 }
 
-bool Client::LaunchTool(const string &mode, const string &extra_arg) {
+bool Client::LaunchTool(const std::string &mode, const std::string &extra_arg) {
   // Don't execute any child process if the parent process is not
   // in proper runlevel.
   if (!IsValidRunLevel()) {
@@ -877,16 +856,16 @@ bool Client::LaunchTool(const string &mode, const string &extra_arg) {
     // In Windows XP, cannot use "runas", instead, administration
     // dialog is launched with normal process with "open"
     // http://b/2415191
-    return WinUtil::ShellExecuteInSystemDir(
-        L"runas", wpath.c_str(), L"--mode=administration_dialog");
+    return WinUtil::ShellExecuteInSystemDir(L"runas", wpath.c_str(),
+                                            L"--mode=administration_dialog");
 #endif  // OS_WIN
 
     return false;
   }
 
-#if defined(OS_WIN) || defined(OS_LINUX) || defined(OS_ANDROID)\
-    || defined(OS_NACL)
-  string arg = "--mode=" + mode;
+#if defined(OS_WIN) || defined(OS_LINUX) || defined(OS_ANDROID) || \
+    defined(OS_NACL)
+  std::string arg = "--mode=" + mode;
   if (!extra_arg.empty()) {
     arg += " ";
     arg += extra_arg;
@@ -899,17 +878,17 @@ bool Client::LaunchTool(const string &mode, const string &extra_arg) {
 
   // TODO(taku): move MacProcess inside SpawnMozcProcess.
   // TODO(taku): support extra_arg.
-#ifdef OS_MACOSX
+#ifdef __APPLE__
   if (!MacProcess::LaunchMozcTool(mode)) {
     LOG(ERROR) << "Cannot execute: " << mode;
     return false;
   }
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 
   return true;
 }
 
-bool Client::OpenBrowser(const string &url) {
+bool Client::OpenBrowser(const std::string &url) {
   if (!IsValidRunLevel()) {
     return false;
   }
@@ -925,24 +904,21 @@ bool Client::OpenBrowser(const string &url) {
 namespace {
 class DefaultClientFactory : public ClientFactoryInterface {
  public:
-  virtual ClientInterface *NewClient() {
-    return new Client;
-  }
+  virtual ClientInterface *NewClient() { return new Client; }
 };
 
-ClientFactoryInterface *g_client_factory = NULL;
+ClientFactoryInterface *g_client_factory = nullptr;
 }  // namespace
 
 ClientInterface *ClientFactory::NewClient() {
-  if (g_client_factory == NULL) {
+  if (g_client_factory == nullptr) {
     return Singleton<DefaultClientFactory>::get()->NewClient();
   } else {
     return g_client_factory->NewClient();
   }
 }
 
-void ClientFactory::SetClientFactory(
-    ClientFactoryInterface *client_factory) {
+void ClientFactory::SetClientFactory(ClientFactoryInterface *client_factory) {
   g_client_factory = client_factory;
 }
 }  // namespace client
