@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -47,9 +47,9 @@ namespace {
 const int kMaxRecursion = 4;
 
 // Delete "end" from "target", if "target" ends with the "end".
-bool DeleteEnd(const string &end, string *target) {
-  const string::size_type rindex = target->rfind(end);
-  if (rindex == string::npos) {
+bool DeleteEnd(const std::string &end, std::string *target) {
+  const std::string::size_type rindex = target->rfind(end);
+  if (rindex == std::string::npos) {
     return false;
   }
   target->erase(rindex);
@@ -73,8 +73,8 @@ bool DeleteEnd(const string &end, string *target) {
 // '{*}ぃ' -> '', '{*}い'
 // '{*}い' -> '', '{*}ぃ'
 // Here, we want to get '{*}あ' <-> '{*}ぁ' loop from the input, 'あ'
-bool GetFromPending(const Table *table, const string &key,
-                    int recursion_count, std::set<string> *result) {
+bool GetFromPending(const Table *table, const std::string &key,
+                    int recursion_count, std::set<std::string> *result) {
   DCHECK(result);
   if (recursion_count == 0) {
     // Don't find the loop within the |recursion_count|.
@@ -99,8 +99,8 @@ bool GetFromPending(const Table *table, const string &key,
       // So here we stop calling recursion.
       return false;
     }
-    if (!GetFromPending(table, entries[i]->pending(),
-                        recursion_count - 1, result)) {
+    if (!GetFromPending(table, entries[i]->pending(), recursion_count - 1,
+                        result)) {
       return false;
     }
   }
@@ -112,7 +112,8 @@ CharChunk::CharChunk(Transliterators::Transliterator transliterator,
                      const Table *table)
     : transliterator_(transliterator),
       table_(table),
-      attributes_(NO_TABLE_ATTRIBUTE) {
+      attributes_(NO_TABLE_ATTRIBUTE),
+      local_length_cache_(std::string::npos) {
   DCHECK_NE(Transliterators::LOCAL, transliterator);
 }
 
@@ -121,46 +122,51 @@ void CharChunk::Clear() {
   conversion_.clear();
   pending_.clear();
   ambiguous_.clear();
+  local_length_cache_ = std::string::npos;
 }
 
 size_t CharChunk::GetLength(Transliterators::Transliterator t12r) const {
-  const string t13n = Transliterate(
-      t12r,
-      Table::DeleteSpecialKey(raw_),
-      Table::DeleteSpecialKey(conversion_ + pending_));
-  return Util::CharsLen(t13n);
+  if (t12r == Transliterators::LOCAL &&
+      local_length_cache_ != std::string::npos) {
+    return local_length_cache_;
+  }
+  const std::string t13n =
+      Transliterate(t12r, Table::DeleteSpecialKey(raw_),
+                    Table::DeleteSpecialKey(conversion_ + pending_));
+  size_t length = Util::CharsLen(t13n);
+  if (t12r == Transliterators::LOCAL) {
+    local_length_cache_ = length;
+  }
+  return length;
 }
 
 void CharChunk::AppendResult(Transliterators::Transliterator t12r,
-                             string *result) const {
-  const string t13n = Transliterate(
-      t12r,
-      Table::DeleteSpecialKey(raw_),
-      Table::DeleteSpecialKey(conversion_ + pending_));
+                             std::string *result) const {
+  const std::string t13n =
+      Transliterate(t12r, Table::DeleteSpecialKey(raw_),
+                    Table::DeleteSpecialKey(conversion_ + pending_));
   result->append(t13n);
 }
 
 void CharChunk::AppendTrimedResult(Transliterators::Transliterator t12r,
-                                   string *result) const {
+                                   std::string *result) const {
   // Only determined value (e.g. |conversion_| only) is added.
-  string converted = conversion_;
+  std::string converted = conversion_;
   if (!pending_.empty()) {
     size_t key_length = 0;
     bool fixed = false;
     const Entry *entry = table_->LookUpPrefix(pending_, &key_length, &fixed);
-    if (entry != NULL && entry->input() == entry->result()) {
+    if (entry != nullptr && entry->input() == entry->result()) {
       converted.append(entry->result());
     }
   }
-  result->append(Transliterate(
-      t12r,
-      Table::DeleteSpecialKey(raw_),
-      Table::DeleteSpecialKey(converted)));
+  result->append(Transliterate(t12r, Table::DeleteSpecialKey(raw_),
+                               Table::DeleteSpecialKey(converted)));
 }
 
 void CharChunk::AppendFixedResult(Transliterators::Transliterator t12r,
-                                  string *result) const {
-  string converted = conversion_;
+                                  std::string *result) const {
+  std::string converted = conversion_;
   if (!ambiguous_.empty()) {
     // Add the |ambiguous_| value as a fixed value.  |ambiguous_|
     // contains an undetermined result string like "ん" converted
@@ -173,10 +179,8 @@ void CharChunk::AppendFixedResult(Transliterators::Transliterator t12r,
     // appended.
     converted.append(pending_);
   }
-  result->append(Transliterate(
-      t12r,
-      Table::DeleteSpecialKey(raw_),
-      Table::DeleteSpecialKey(converted)));
+  result->append(Transliterate(t12r, Table::DeleteSpecialKey(raw_),
+                               Table::DeleteSpecialKey(converted)));
 }
 
 // If we have the rule (roman),
@@ -218,7 +222,7 @@ void CharChunk::AppendFixedResult(Transliterators::Transliterator t12r,
 //
 // What we want to append here is the 'looped rule' in |kMaxRecursion| lookup.
 // Here, '{*}ぁ' -> '{*}あ' -> '{*}ぁ' is the loop.
-void CharChunk::GetExpandedResults(std::set<string> *results) const {
+void CharChunk::GetExpandedResults(std::set<std::string> *results) const {
   DCHECK(results);
 
   if (pending_.empty()) {
@@ -237,40 +241,37 @@ void CharChunk::GetExpandedResults(std::set<string> *results) const {
     if (entries[i]->pending().empty()) {
       continue;
     }
-    std::set<string> loop_result;
-    if (!GetFromPending(table_, entries[i]->pending(),
-                        kMaxRecursion, &loop_result)) {
+    std::set<std::string> loop_result;
+    if (!GetFromPending(table_, entries[i]->pending(), kMaxRecursion,
+                        &loop_result)) {
       continue;
     }
-    for (std::set<string>::const_iterator itr = loop_result.begin();
+    for (std::set<std::string>::const_iterator itr = loop_result.begin();
          itr != loop_result.end(); ++itr) {
       results->insert(Table::DeleteSpecialKey(*itr));
     }
   }
 }
 
-bool CharChunk::IsFixed() const {
-  return pending_.empty();
-}
+bool CharChunk::IsFixed() const { return pending_.empty(); }
 
 bool CharChunk::IsAppendable(Transliterators::Transliterator t12r,
                              const Table *table) const {
   return !pending_.empty() &&
-      (t12r == Transliterators::LOCAL || t12r == transliterator_) &&
-      table == table_;
+         (t12r == Transliterators::LOCAL || t12r == transliterator_) &&
+         table == table_;
 }
 
-bool CharChunk::IsConvertible(
-    Transliterators::Transliterator t12r,
-    const Table *table,
-    const string &input) const {
+bool CharChunk::IsConvertible(Transliterators::Transliterator t12r,
+                              const Table *table,
+                              const std::string &input) const {
   if (!IsAppendable(t12r, table)) {
     return false;
   }
 
   size_t key_length = 0;
   bool fixed = false;
-  string key = pending_ + input;
+  std::string key = pending_ + input;
   const Entry *entry = table->LookUpPrefix(key, &key_length, &fixed);
 
   return entry && (key.size() == key_length) && fixed;
@@ -279,6 +280,7 @@ bool CharChunk::IsConvertible(
 void CharChunk::Combine(const CharChunk &left_chunk) {
   conversion_ = left_chunk.conversion_ + conversion_;
   raw_ = left_chunk.raw_ + raw_;
+  local_length_cache_ = std::string::npos;
   // TODO(komatsu): This is a hacky way.  We should look up the
   // conversion table with the new |raw_| value.
   if (left_chunk.ambiguous_.empty()) {
@@ -293,15 +295,16 @@ void CharChunk::Combine(const CharChunk &left_chunk) {
   pending_ = left_chunk.pending_ + pending_;
 }
 
-bool CharChunk::AddInputInternal(string *input) {
+bool CharChunk::AddInputInternal(std::string *input) {
   const bool kNoLoop = false;
 
   size_t key_length = 0;
   bool fixed = false;
-  string key = pending_ + *input;
+  std::string key = pending_ + *input;
   const Entry *entry = table_->LookUpPrefix(key, &key_length, &fixed);
+  local_length_cache_ = std::string::npos;
 
-  if (entry == NULL) {
+  if (entry == nullptr) {
     if (key_length == 0) {
       // No prefix character is not contained in the table, fallback
       // operation is performed.
@@ -324,11 +327,11 @@ bool CharChunk::AddInputInternal(string *input) {
     key_length -= pending_.size();
 
     // Conversion data had only pending.
-    const string new_pending_chars(*input, 0, key_length);
+    const std::string new_pending_chars(*input, 0, key_length);
     raw_.append(new_pending_chars);
     pending_.append(new_pending_chars);
     if (!ambiguous_.empty()) {
-      // If ambiguos_ has already a value, ambiguous_ is appended.
+      // If ambiguous_ has already a value, ambiguous_ is appended.
       // ex. "ny" makes ambiguous_ "んy", but "sh" leaves ambiguous_ empty.
       ambiguous_.append(new_pending_chars);
     }
@@ -336,12 +339,12 @@ bool CharChunk::AddInputInternal(string *input) {
     return kNoLoop;
   }
 
-  // The prefix of key reached a conversion result, thus entry is not NULL.
+  // The prefix of key reached a conversion result, thus entry is not nullptr.
 
   if (key.size() == key_length) {
-    const bool is_following_entry = (
-        !conversion_.empty() ||
-        (!raw_.empty() && !pending_.empty() && raw_ != pending_));
+    const bool is_following_entry =
+        (!conversion_.empty() ||
+         (!raw_.empty() && !pending_.empty() && raw_ != pending_));
 
     raw_.append(*input);
     input->clear();
@@ -386,20 +389,23 @@ bool CharChunk::AddInputInternal(string *input) {
   return kLoop;
 }
 
-void CharChunk::AddInput(string *input) {
-  while (AddInputInternal(input)) {}
+void CharChunk::AddInput(std::string *input) {
+  while (AddInputInternal(input)) {
+  }
 }
 
-void CharChunk::AddConvertedChar(string *input) {
+void CharChunk::AddConvertedChar(std::string *input) {
   // TODO(komatsu) Nice to make "string Util::PopOneChar(string *str);".
-  string first_char = Util::SubString(*input, 0, 1);
-  conversion_.append(first_char);
-  raw_.append(first_char);
-  *input = Util::SubString(*input, 1, string::npos);
+  const absl::string_view first_char = Util::Utf8SubString(*input, 0, 1);
+  conversion_.append(first_char.data(), first_char.size());
+  raw_.append(first_char.data(), first_char.size());
+  Util::Utf8SubString(*input, 1, std::string::npos, input);
+  local_length_cache_ = std::string::npos;
 }
 
-void CharChunk::AddInputAndConvertedChar(string *key,
-                                         string *converted_char) {
+void CharChunk::AddInputAndConvertedChar(std::string *key,
+                                         std::string *converted_char) {
+  local_length_cache_ = std::string::npos;
   // If this chunk is empty, the key and converted_char are simply
   // copied.
   if (raw_.empty() && pending_.empty() && conversion_.empty()) {
@@ -407,7 +413,7 @@ void CharChunk::AddInputAndConvertedChar(string *key,
     key->clear();
     pending_ = *converted_char;
     // TODO(komatsu): We should check if the |converted_char| is
-    // really ambigous or not, otherwise the last character of the
+    // really ambiguous or not, otherwise the last character of the
     // preedit on Kana input is always dropped.
     ambiguous_ = *converted_char;
     converted_char->clear();
@@ -415,17 +421,17 @@ void CharChunk::AddInputAndConvertedChar(string *key,
     // If this entry is the first entry, the table attributes are
     // applied to this chunk.
     const Entry *entry = table_->LookUp(pending_);
-    if (entry != NULL) {
+    if (entry != nullptr) {
       attributes_ = entry->attributes();
     }
     return;
   }
 
-  const string input = pending_ + *converted_char;
+  const std::string input = pending_ + *converted_char;
   size_t key_length = 0;
   bool fixed = false;
   const Entry *entry = table_->LookUpPrefix(input, &key_length, &fixed);
-  if (entry == NULL) {
+  if (entry == nullptr) {
     // Do not modify this char_chunk, all key and converted_char
     // values will be used by the next char_chunk.
     return;
@@ -478,12 +484,10 @@ bool CharChunk::ShouldInsertNewChunk(const CompositionInput &input) const {
   }
 
   const bool is_new_input =
-      input.is_new_input() ||
-      ((attributes_ & END_CHUNK) && pending_.empty());
+      input.is_new_input() || ((attributes_ & END_CHUNK) && pending_.empty());
 
-  if (is_new_input &&
-      (table_->HasNewChunkEntry(input.raw()) ||
-          !table_->HasSubRules(input.raw()))) {
+  if (is_new_input && (table_->HasNewChunkEntry(input.raw()) ||
+                       !table_->HasSubRules(input.raw()))) {
     // Such input which is not on the table is treated as NewChunk entry.
     return true;
   }
@@ -491,10 +495,9 @@ bool CharChunk::ShouldInsertNewChunk(const CompositionInput &input) const {
 }
 
 void CharChunk::AddCompositionInput(CompositionInput *input) {
+  local_length_cache_ = std::string::npos;
   if (input->has_conversion()) {
-    AddInputAndConvertedChar(
-                             input->mutable_raw(),
-                             input->mutable_conversion());
+    AddInputAndConvertedChar(input->mutable_raw(), input->mutable_conversion());
     return;
   }
 
@@ -511,55 +514,51 @@ void CharChunk::SetTransliterator(
     // Just ignore.
     return;
   }
+  local_length_cache_ = std::string::npos;
   transliterator_ = transliterator;
 }
 
-const string &CharChunk::raw() const {
-  return raw_;
-}
+const std::string &CharChunk::raw() const { return raw_; }
 
-void CharChunk::set_raw(const string &raw) {
+void CharChunk::set_raw(const std::string &raw) {
   raw_ = raw;
+  local_length_cache_ = std::string::npos;
 }
 
-const string &CharChunk::conversion() const {
-  return conversion_;
-}
+const std::string &CharChunk::conversion() const { return conversion_; }
 
-void CharChunk::set_conversion(const string &conversion) {
+void CharChunk::set_conversion(const std::string &conversion) {
   conversion_ = conversion;
+  local_length_cache_ = std::string::npos;
 }
 
-const string &CharChunk::pending() const {
-  return pending_;
-}
+const std::string &CharChunk::pending() const { return pending_; }
 
-void CharChunk::set_pending(const string &pending) {
+void CharChunk::set_pending(const std::string &pending) {
   pending_ = pending;
+  local_length_cache_ = std::string::npos;
 }
 
-const string &CharChunk::ambiguous() const {
-  return ambiguous_;
-}
+const std::string &CharChunk::ambiguous() const { return ambiguous_; }
 
-void CharChunk::set_ambiguous(const string &ambiguous) {
+void CharChunk::set_ambiguous(const std::string &ambiguous) {
   ambiguous_ = ambiguous;
+  local_length_cache_ = std::string::npos;
 }
 
 bool CharChunk::SplitChunk(Transliterators::Transliterator t12r,
-                           const size_t position,
-                           CharChunk **left_new_chunk) {
+                           const size_t position, CharChunk **left_new_chunk) {
   if (position <= 0 || position >= GetLength(t12r)) {
     LOG(WARNING) << "Invalid position: " << position;
     return false;
   }
 
-  string raw_lhs, raw_rhs, converted_lhs, converted_rhs;
-  Transliterators::GetTransliterator(GetTransliterator(t12r))->Split(
-      position,
-      Table::DeleteSpecialKey(raw_),
-      Table::DeleteSpecialKey(conversion_ + pending_),
-      &raw_lhs, &raw_rhs, &converted_lhs, &converted_rhs);
+  local_length_cache_ = std::string::npos;
+  std::string raw_lhs, raw_rhs, converted_lhs, converted_rhs;
+  Transliterators::GetTransliterator(GetTransliterator(t12r))
+      ->Split(position, Table::DeleteSpecialKey(raw_),
+              Table::DeleteSpecialKey(conversion_ + pending_), &raw_lhs,
+              &raw_rhs, &converted_lhs, &converted_rhs);
 
   *left_new_chunk = new CharChunk(transliterator_, table_);
   (*left_new_chunk)->set_raw(raw_lhs);
@@ -567,7 +566,7 @@ bool CharChunk::SplitChunk(Transliterators::Transliterator t12r,
 
   if (converted_lhs.size() > conversion_.size()) {
     // [ conversion | pending ] => [ conv | pend#1 ] [ pend#2 ]
-    const string pending_lhs(converted_lhs, conversion_.size());
+    const std::string pending_lhs(converted_lhs, conversion_.size());
     (*left_new_chunk)->set_conversion(conversion_);
     (*left_new_chunk)->set_pending(pending_lhs);
 
@@ -585,10 +584,9 @@ bool CharChunk::SplitChunk(Transliterators::Transliterator t12r,
   return true;
 }
 
-Transliterators::Transliterator
-CharChunk::GetTransliterator(
+Transliterators::Transliterator CharChunk::GetTransliterator(
     Transliterators::Transliterator transliterator) const {
-  if (attributes_ && NO_TRANSLITERATION) {
+  if (attributes_ & NO_TRANSLITERATION) {
     if (transliterator == Transliterators::LOCAL ||
         transliterator == Transliterators::HALF_ASCII ||
         transliterator == Transliterators::FULL_ASCII) {
@@ -597,19 +595,18 @@ CharChunk::GetTransliterator(
     return transliterator;
   }
   if (transliterator == Transliterators::LOCAL) {
-      return transliterator_;
+    return transliterator_;
   }
   return transliterator;
 }
 
-string CharChunk::Transliterate(
-    Transliterators::Transliterator transliterator,
-    const string &raw, const string &converted) const {
-  return Transliterators::GetTransliterator(
-      GetTransliterator(transliterator))->Transliterate(raw, converted);
+std::string CharChunk::Transliterate(
+    Transliterators::Transliterator transliterator, const std::string &raw,
+    const std::string &converted) const {
+  return Transliterators::GetTransliterator(GetTransliterator(transliterator))
+      ->Transliterate(raw, converted);
 }
 
-
 CharChunk *CharChunk::Clone() const {
   // TODO(hsumita): Implements TransliteratorFactory and uses it instead of
   // copying a pointer.
