@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,8 +36,8 @@
 
 #include "base/port.h"
 #include "base/protobuf/repeated_field.h"
-#include "base/string_piece.h"
 #include "protocol/config.pb.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 
@@ -60,8 +60,7 @@ class TypingCorrector {
   // insertion.
   // Returns up to |max_correction_query_results| results from
   // GetQueriesForPrediction.
-  TypingCorrector(const Table *table,
-                  size_t max_correction_query_candidates,
+  TypingCorrector(const Table *table, size_t max_correction_query_candidates,
                   size_t max_correction_query_results);
   ~TypingCorrector();
 
@@ -87,7 +86,7 @@ class TypingCorrector {
   // If |probable_key_events| is non-empty, |key| is ignored.
   // If |probable_key_events| is empty, |key| is used instead assuming that
   // the probability is 1.0.
-  void InsertCharacter(const StringPiece key,
+  void InsertCharacter(const absl::string_view key,
                        const ProbableKeyEvents &probable_key_events);
 
   // Extracts type-corrected queries for prediction.
@@ -97,7 +96,7 @@ class TypingCorrector {
   friend class TypingCorrectorTest;
 
   // Represents one type-correction: key sequence and its penalty (cost).
-  typedef std::pair<string, int> KeyAndPenalty;
+  typedef std::pair<std::string, int> KeyAndPenalty;
 
   // Less-than comparator for KeyAndPenalty. Since this functor accesses
   // KeyAndPenalty, we need to define it in private member.
@@ -108,7 +107,7 @@ class TypingCorrector {
   size_t max_correction_query_candidates_;
   size_t max_correction_query_results_;
   const config::Config *config_;
-  string raw_key_;
+  std::string raw_key_;
   std::vector<KeyAndPenalty> top_n_;
 
   DISALLOW_COPY_AND_ASSIGN(TypingCorrector);
