@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,15 +34,15 @@
 namespace mozc {
 namespace composer {
 
-class TypingModelTest : public ::testing::Test {
-};
+class TypingModelTest : public ::testing::Test {};
 
 TEST_F(TypingModelTest, Constructor) {
   const char* characters = "abcd";
   const uint8 costs[] = {
-    0, 1, 2, 3, 4, 5, 6,
+      0, 1, 2, 3, 4, 5, 6,
   };
-  TypingModel model(characters, strlen(characters), costs, arraysize(costs), NULL);
+  TypingModel model(characters, strlen(characters), costs, arraysize(costs),
+                    nullptr);
   model.character_to_radix_table_['a'] = 1;
   model.character_to_radix_table_['b'] = 2;
   model.character_to_radix_table_['c'] = 3;
@@ -53,9 +53,10 @@ TEST_F(TypingModelTest, Constructor) {
 TEST_F(TypingModelTest, GetIndex) {
   const char* characters = "abcd";
   const uint8 costs[] = {
-    0, 1, 2, 3, 4, 5, 6,
+      0, 1, 2, 3, 4, 5, 6,
   };
-  TypingModel model(characters, strlen(characters), costs, arraysize(costs), NULL);
+  TypingModel model(characters, strlen(characters), costs, arraysize(costs),
+                    nullptr);
   ASSERT_EQ(0, model.GetIndex(""));
   ASSERT_EQ(1, model.GetIndex("a"));
   ASSERT_EQ(4, model.GetIndex("d"));
