@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -52,12 +52,12 @@ TEST(KeyParserTest, KeyCode) {
   // "あ" (not half width)
   const char32 kHiraganaA = 0x3042;
   key_event.Clear();
-  EXPECT_TRUE(KeyParser::ParseKey("\xE3\x81\x82", &key_event));
+  EXPECT_TRUE(KeyParser::ParseKey("あ", &key_event));
   EXPECT_EQ(kHiraganaA, key_event.key_code());
 }
 
 TEST(KeyParserTest, ModifierKeys) {
-  const std::pair<string, uint32> kTestData[] = {
+  const std::pair<std::string, uint32> kTestData[] = {
       std::make_pair("ctrl", commands::KeyEvent::CTRL),
       std::make_pair("leftctrl",
                      commands::KeyEvent::CTRL | commands::KeyEvent::LEFT_CTRL),
@@ -101,7 +101,7 @@ TEST(KeyParserTest, MultipleModifierKeys) {
 }
 
 TEST(KeyParserTest, SpecialKeys) {
-  const std::pair<string, commands::KeyEvent::SpecialKey> kTestData[] = {
+  const std::pair<std::string, commands::KeyEvent::SpecialKey> kTestData[] = {
       std::make_pair("on", commands::KeyEvent::ON),
       std::make_pair("off", commands::KeyEvent::OFF),
       std::make_pair("left", commands::KeyEvent::LEFT),
@@ -198,7 +198,7 @@ TEST(KeyParserTest, Combination) {
   EXPECT_TRUE(KeyParser::ParseKey("LeftShift CTRL a", &key_event));
   EXPECT_EQ('a', key_event.key_code());
   EXPECT_EQ(commands::KeyEvent::LEFT_SHIFT | commands::KeyEvent::SHIFT |
-            commands::KeyEvent::CTRL,
+                commands::KeyEvent::CTRL,
             KeyEventUtil::GetModifiers(key_event));
 
   EXPECT_TRUE(KeyParser::ParseKey("rightalt On", &key_event));
