@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,7 @@
 #include <string>
 #include <vector>
 
+#include "base/mozc_hash_set.h"
 #include "base/port.h"
 #include "base/trie.h"
 #include "data_manager/data_manager_interface.h"
@@ -68,7 +69,7 @@ enum TableAttribute {
   // This flag suppresses any transliteration performed in CharChunk
   // and treated as an as-is key event.
   NO_TRANSLITERATION = 2,
-  // This flag indicates that the composition should be ended and commited.
+  // This flag indicates that the composition should be ended and committed.
   DIRECT_INPUT = 4,
 
   // This flag treats the next typing as a new input.  This flag is
@@ -79,19 +80,18 @@ typedef uint32 TableAttributes;
 
 class Entry {
  public:
-  Entry(const string &input,
-        const string &result,
-        const string &pending,
-        TableAttributes attributes);
+  Entry(const std::string &input, const std::string &result,
+        const std::string &pending, TableAttributes attributes);
   virtual ~Entry() {}
-  const string &input() const { return input_; }
-  const string &result() const { return result_; }
-  const string &pending() const { return pending_; }
+  const std::string &input() const { return input_; }
+  const std::string &result() const { return result_; }
+  const std::string &pending() const { return pending_; }
   TableAttributes attributes() const { return attributes_; }
+
  private:
-  const string input_;
-  const string result_;
-  const string pending_;
+  const std::string input_;
+  const std::string result_;
+  const std::string pending_;
   TableAttributes attributes_;
 };
 
@@ -104,47 +104,48 @@ class Table {
                                       const config::Config &config,
                                       const DataManagerInterface &data_manager);
 
-
   // Return true if adding the input-pending pair makes a loop of
   // conversion rules.
-  bool IsLoopingEntry(const string &input, const string &pending) const;
-  const Entry *AddRule(const string &input,
-                       const string &output,
-                       const string &pending);
+  bool IsLoopingEntry(const std::string &input,
+                      const std::string &pending) const;
+  const Entry *AddRule(const std::string &input, const std::string &output,
+                       const std::string &pending);
 
-  const Entry *AddRuleWithAttributes(const string &input,
-                                     const string &output,
-                                     const string &pending,
+  const Entry *AddRuleWithAttributes(const std::string &input,
+                                     const std::string &output,
+                                     const std::string &pending,
                                      TableAttributes attributes);
 
-  void DeleteRule(const string &input);
+  void DeleteRule(const std::string &input);
 
-  bool LoadFromString(const string &str);
+  bool LoadFromString(const std::string &str);
   bool LoadFromFile(const char *filepath);
 
-  const Entry *LookUp(const string &input) const;
-  const Entry *LookUpPrefix(const string &input,
-                            size_t *key_length,
+  const Entry *LookUp(const std::string &input) const;
+  const Entry *LookUpPrefix(const std::string &input, size_t *key_length,
                             bool *fixed) const;
-  void LookUpPredictiveAll(const string &input,
+  void LookUpPredictiveAll(const std::string &input,
                            std::vector<const Entry *> *results) const;
   // TODO(komatsu): Delete this function.
-  bool HasSubRules(const string &input) const;
+  bool HasSubRules(const std::string &input) const;
 
-  bool HasNewChunkEntry(const string &input) const;
+  bool HasNewChunkEntry(const std::string &input) const;
 
   bool case_sensitive() const;
   void set_case_sensitive(bool case_sensitive);
 
-  const TypingModel* typing_model() const;
+  const TypingModel *typing_model() const;
 
   // Parse special key strings escaped with the pair of "{" and "}"
   // and return the parsed string.
-  static string ParseSpecialKey(const string &input);
+  static std::string ParseSpecialKey(const std::string &input);
 
   // Delete invisible special keys wrapped with ("\x0F", "\x0E") and
   // return the trimmed visible string.
-  static string DeleteSpecialKey(const string &input);
+  static std::string DeleteSpecialKey(const std::string &input);
+
+  // Return the default table.
+  static const Table &GetDefaultTable();
 
  private:
   friend class mozc::DictionaryPredictorTest;
@@ -155,9 +156,9 @@ class Table {
   void DeleteEntry(const Entry *entry);
   void ResetEntrySet();
 
-  typedef Trie<const Entry*> EntryTrie;
+  typedef Trie<const Entry *> EntryTrie;
   std::unique_ptr<EntryTrie> entries_;
-  typedef std::set<const Entry*> EntrySet;
+  typedef mozc_hash_set<const Entry *> EntrySet;
   EntrySet entry_set_;
 
   // If false, input alphabet characters are normalized to lower
