@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,6 +30,7 @@
 #include "composer/table.h"
 
 #include "base/file_util.h"
+#include "base/mozc_hash_set.h"
 #include "base/port.h"
 #include "base/system_util.h"
 #include "composer/internal/composition_input.h"
@@ -37,19 +38,18 @@
 #include "data_manager/testing/mock_data_manager.h"
 #include "protocol/commands.pb.h"
 #include "protocol/config.pb.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 namespace composer {
 
-using mozc::config::Config;
 using mozc::commands::Request;
+using mozc::config::Config;
 
-static void InitTable(Table* table) {
-  table->AddRule("a",  "あ", "");
-  table->AddRule("i",  "い", "");
+static void InitTable(Table *table) {
+  table->AddRule("a", "あ", "");
+  table->AddRule("i", "い", "");
   table->AddRule("ka", "か", "");
   table->AddRule("ki", "き", "");
   table->AddRule("ku", "く", "");
@@ -58,22 +58,22 @@ static void InitTable(Table* table) {
   table->AddRule("kk", "っ", "k");
   table->AddRule("na", "な", "");
   table->AddRule("ni", "に", "");
-  table->AddRule("n",  "ん", "");
+  table->AddRule("n", "ん", "");
   table->AddRule("nn", "ん", "");
 }
 
-string GetResult(const Table &table, const string &key) {
+std::string GetResult(const Table &table, const std::string &key) {
   const Entry *entry = table.LookUp(key);
-  if (entry == NULL) {
-    return "<NULL>";
+  if (entry == nullptr) {
+    return "<nullptr>";
   }
   return entry->result();
 }
 
-string GetInput(const Table &table, const string &key) {
+std::string GetInput(const Table &table, const std::string &key) {
   const Entry *entry = table.LookUp(key);
-  if (entry == NULL) {
-    return "<NULL>";
+  if (entry == nullptr) {
+    return "<nullptr>";
   }
   return entry->input();
 }
@@ -83,9 +83,7 @@ class TableTest : public ::testing::Test {
   TableTest() = default;
   ~TableTest() override = default;
 
-  void SetUp() override {
-    config::ConfigHandler::GetDefaultConfig(&config_);
-  }
+  void SetUp() override { config::ConfigHandler::GetDefaultConfig(&config_); }
 
   const testing::MockDataManager mock_data_manager_;
   config::Config config_;
@@ -96,21 +94,15 @@ class TableTest : public ::testing::Test {
 
 TEST_F(TableTest, LookUp) {
   static const struct TestCase {
-    const char* input;
+    const char *input;
     const bool expected_result;
-    const char* expected_output;
-    const char* expected_pending;
+    const char *expected_output;
+    const char *expected_pending;
   } test_cases[] = {
-    { "a", true, "あ", "" },
-    { "k", false, "", "" },
-    { "ka", true, "か", "" },
-    { "ki", true, "き", "" },
-    { "ku", true, "く", "" },
-    { "kk", true, "っ", "k" },
-    { "aka", false, "", "" },
-    { "na", true, "な", "" },
-    { "n", true, "ん", "" },
-    { "nn", true, "ん", "" },
+      {"a", true, "あ", ""},  {"k", false, "", ""},   {"ka", true, "か", ""},
+      {"ki", true, "き", ""}, {"ku", true, "く", ""}, {"kk", true, "っ", "k"},
+      {"aka", false, "", ""}, {"na", true, "な", ""}, {"n", true, "ん", ""},
+      {"nn", true, "ん", ""},
   };
   static const int size = arraysize(test_cases);
 
@@ -118,14 +110,14 @@ TEST_F(TableTest, LookUp) {
   InitTable(&table);
 
   for (int i = 0; i < size; ++i) {
-    const TestCase& test = test_cases[i];
-    string output;
-    string pending;
-    const Entry* entry;
+    const TestCase &test = test_cases[i];
+    std::string output;
+    std::string pending;
+    const Entry *entry;
     entry = table.LookUp(test.input);
 
-    EXPECT_EQ(test.expected_result, (entry != NULL));
-    if (entry == NULL) {
+    EXPECT_EQ(test.expected_result, (entry != nullptr));
+    if (entry == nullptr) {
       continue;
     }
     EXPECT_EQ(test.expected_output, entry->result());
@@ -149,14 +141,14 @@ TEST_F(TableTest, Punctuations) {
     const char *input;
     const char *expected;
   } test_cases[] = {
-    { config::Config::KUTEN_TOUTEN, ",",  "、" },
-    { config::Config::KUTEN_TOUTEN, ".",  "。" },
-    { config::Config::COMMA_PERIOD, ",",  "，" },
-    { config::Config::COMMA_PERIOD, ".",  "．" },
-    { config::Config::KUTEN_PERIOD, ",",  "、" },
-    { config::Config::KUTEN_PERIOD, ".",  "．" },
-    { config::Config::COMMA_TOUTEN, ",",  "，" },
-    { config::Config::COMMA_TOUTEN, ".",  "。" },
+      {config::Config::KUTEN_TOUTEN, ",", "、"},
+      {config::Config::KUTEN_TOUTEN, ".", "。"},
+      {config::Config::COMMA_PERIOD, ",", "，"},
+      {config::Config::COMMA_PERIOD, ".", "．"},
+      {config::Config::KUTEN_PERIOD, ",", "、"},
+      {config::Config::KUTEN_PERIOD, ".", "．"},
+      {config::Config::COMMA_TOUTEN, ",", "，"},
+      {config::Config::COMMA_TOUTEN, ".", "。"},
   };
 
   commands::Request request;
@@ -168,7 +160,7 @@ TEST_F(TableTest, Punctuations) {
     ASSERT_TRUE(table.InitializeWithRequestAndConfig(request, config,
                                                      mock_data_manager_));
     const Entry *entry = table.LookUp(test_cases[i].input);
-    EXPECT_TRUE(entry != NULL) << "Failed index = " << i;
+    EXPECT_TRUE(entry != nullptr) << "Failed index = " << i;
     if (entry) {
       EXPECT_EQ(test_cases[i].expected, entry->result());
     }
@@ -181,18 +173,18 @@ TEST_F(TableTest, Symbols) {
     const char *input;
     const char *expected;
   } test_cases[] = {
-    { config::Config::CORNER_BRACKET_MIDDLE_DOT, "[",  "「" },
-    { config::Config::CORNER_BRACKET_MIDDLE_DOT, "]",  "」" },
-    { config::Config::CORNER_BRACKET_MIDDLE_DOT, "/",  "・" },
-    { config::Config::SQUARE_BRACKET_SLASH, "[",  "["      },
-    { config::Config::SQUARE_BRACKET_SLASH, "]",  "]"      },
-    { config::Config::SQUARE_BRACKET_SLASH, "/",  "／"      },
-    { config::Config::CORNER_BRACKET_SLASH, "[",  "「"      },
-    { config::Config::CORNER_BRACKET_SLASH, "]",  "」"      },
-    { config::Config::CORNER_BRACKET_SLASH, "/",  "／"      },
-    { config::Config::SQUARE_BRACKET_MIDDLE_DOT, "[",  "[" },
-    { config::Config::SQUARE_BRACKET_MIDDLE_DOT, "]",  "]" },
-    { config::Config::SQUARE_BRACKET_MIDDLE_DOT, "/",  "・" },
+      {config::Config::CORNER_BRACKET_MIDDLE_DOT, "[", "「"},
+      {config::Config::CORNER_BRACKET_MIDDLE_DOT, "]", "」"},
+      {config::Config::CORNER_BRACKET_MIDDLE_DOT, "/", "・"},
+      {config::Config::SQUARE_BRACKET_SLASH, "[", "["},
+      {config::Config::SQUARE_BRACKET_SLASH, "]", "]"},
+      {config::Config::SQUARE_BRACKET_SLASH, "/", "／"},
+      {config::Config::CORNER_BRACKET_SLASH, "[", "「"},
+      {config::Config::CORNER_BRACKET_SLASH, "]", "」"},
+      {config::Config::CORNER_BRACKET_SLASH, "/", "／"},
+      {config::Config::SQUARE_BRACKET_MIDDLE_DOT, "[", "["},
+      {config::Config::SQUARE_BRACKET_MIDDLE_DOT, "]", "]"},
+      {config::Config::SQUARE_BRACKET_MIDDLE_DOT, "/", "・"},
   };
 
   commands::Request request;
@@ -204,7 +196,7 @@ TEST_F(TableTest, Symbols) {
     ASSERT_TRUE(table.InitializeWithRequestAndConfig(request, config,
                                                      mock_data_manager_));
     const Entry *entry = table.LookUp(test_cases[i].input);
-    EXPECT_TRUE(entry != NULL) << "Failed index = " << i;
+    EXPECT_TRUE(entry != nullptr) << "Failed index = " << i;
     if (entry) {
       EXPECT_EQ(test_cases[i].expected, entry->result());
     }
@@ -221,7 +213,7 @@ TEST_F(TableTest, KanaSuppressed) {
                                                    mock_data_manager_));
 
   const Entry *entry = table.LookUp("a");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("あ", entry->result());
   EXPECT_TRUE(entry->pending().empty());
 }
@@ -232,7 +224,7 @@ TEST_F(TableTest, KanaCombination) {
   ASSERT_TRUE(table.InitializeWithRequestAndConfig(request, config_,
                                                    mock_data_manager_));
   const Entry *entry = table.LookUp("か゛");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("が", entry->result());
   EXPECT_TRUE(entry->pending().empty());
 }
@@ -246,8 +238,8 @@ TEST_F(TableTest, InvalidEntryTest) {
     EXPECT_TRUE(table.IsLoopingEntry("b", "a"));
     table.AddRule("b", "aa", "a");  // looping
 
-    EXPECT_TRUE(table.LookUp("a") != NULL);
-    EXPECT_TRUE(table.LookUp("b") == NULL);
+    EXPECT_TRUE(table.LookUp("a") != nullptr);
+    EXPECT_TRUE(table.LookUp("b") == nullptr);
   }
 
   {
@@ -258,8 +250,8 @@ TEST_F(TableTest, InvalidEntryTest) {
     EXPECT_TRUE(table.IsLoopingEntry("b", "a"));
     table.AddRule("b", "aa", "a");  // looping
 
-    EXPECT_TRUE(table.LookUp("a") != NULL);
-    EXPECT_TRUE(table.LookUp("b") == NULL);
+    EXPECT_TRUE(table.LookUp("a") != nullptr);
+    EXPECT_TRUE(table.LookUp("b") == nullptr);
   }
 
   {
@@ -276,10 +268,10 @@ TEST_F(TableTest, InvalidEntryTest) {
     EXPECT_TRUE(table.IsLoopingEntry("d", "a"));
     table.AddRule("d", "aa", "a");  // looping
 
-    EXPECT_TRUE(table.LookUp("a") != NULL);
-    EXPECT_TRUE(table.LookUp("b") != NULL);
-    EXPECT_TRUE(table.LookUp("c") != NULL);
-    EXPECT_TRUE(table.LookUp("d") == NULL);
+    EXPECT_TRUE(table.LookUp("a") != nullptr);
+    EXPECT_TRUE(table.LookUp("b") != nullptr);
+    EXPECT_TRUE(table.LookUp("c") != nullptr);
+    EXPECT_TRUE(table.LookUp("d") == nullptr);
   }
 
   {
@@ -290,9 +282,9 @@ TEST_F(TableTest, InvalidEntryTest) {
     EXPECT_FALSE(table.IsLoopingEntry("www", "ww"));
     table.AddRule("www", "W", "ww");  // not looping
 
-    EXPECT_TRUE(table.LookUp("wa") != NULL);
-    EXPECT_TRUE(table.LookUp("ww") != NULL);
-    EXPECT_TRUE(table.LookUp("www") != NULL);
+    EXPECT_TRUE(table.LookUp("wa") != nullptr);
+    EXPECT_TRUE(table.LookUp("ww") != nullptr);
+    EXPECT_TRUE(table.LookUp("www") != nullptr);
   }
 
   {
@@ -303,9 +295,9 @@ TEST_F(TableTest, InvalidEntryTest) {
     EXPECT_FALSE(table.IsLoopingEntry("ww", "w"));
     table.AddRule("ww", "X", "w");
 
-    EXPECT_TRUE(table.LookUp("wa") != NULL);
-    EXPECT_TRUE(table.LookUp("ww") != NULL);
-    EXPECT_TRUE(table.LookUp("www") != NULL);
+    EXPECT_TRUE(table.LookUp("wa") != nullptr);
+    EXPECT_TRUE(table.LookUp("ww") != nullptr);
+    EXPECT_TRUE(table.LookUp("www") != nullptr);
   }
 
   {
@@ -313,49 +305,49 @@ TEST_F(TableTest, InvalidEntryTest) {
     EXPECT_TRUE(table.IsLoopingEntry("a", "a"));
     table.AddRule("a", "aa", "a");  // looping
 
-    EXPECT_TRUE(table.LookUp("a") == NULL);
+    EXPECT_TRUE(table.LookUp("a") == nullptr);
   }
 
   // Too long input
   {
     Table table;
-    string too_long;
+    std::string too_long;
     // Maximum size is 300 now.
     for (int i = 0; i < 1024; ++i) {
       too_long += 'a';
     }
     table.AddRule(too_long, "test", "test");
-    EXPECT_TRUE(table.LookUp(too_long) == NULL);
+    EXPECT_TRUE(table.LookUp(too_long) == nullptr);
 
     table.AddRule("a", too_long, "test");
-    EXPECT_TRUE(table.LookUp("a") == NULL);
+    EXPECT_TRUE(table.LookUp("a") == nullptr);
 
     table.AddRule("a", "test", too_long);
-    EXPECT_TRUE(table.LookUp("a") == NULL);
+    EXPECT_TRUE(table.LookUp("a") == nullptr);
   }
 
   // reasonably long
   {
     Table table;
-    string reasonably_long;
+    std::string reasonably_long;
     // Maximum size is 300 now.
     for (int i = 0; i < 200; ++i) {
       reasonably_long += 'a';
     }
     table.AddRule(reasonably_long, "test", "test");
-    EXPECT_TRUE(table.LookUp(reasonably_long) != NULL);
+    EXPECT_TRUE(table.LookUp(reasonably_long) != nullptr);
 
     table.AddRule("a", reasonably_long, "test");
-    EXPECT_TRUE(table.LookUp("a") != NULL);
+    EXPECT_TRUE(table.LookUp("a") != nullptr);
 
     table.AddRule("a", "test", reasonably_long);
-    EXPECT_TRUE(table.LookUp("a") != NULL);
+    EXPECT_TRUE(table.LookUp("a") != nullptr);
   }
 }
 
 TEST_F(TableTest, CustomPunctuationsAndSymbols) {
   // Test against Issue2465801.
-  string custom_roman_table;
+  std::string custom_roman_table;
   custom_roman_table.append("mozc\tMOZC\n");
   custom_roman_table.append(",\tCOMMA\n");
   custom_roman_table.append(".\tPERIOD\n");
@@ -369,29 +361,29 @@ TEST_F(TableTest, CustomPunctuationsAndSymbols) {
   commands::Request request;
   table.InitializeWithRequestAndConfig(request, config_, mock_data_manager_);
 
-  const Entry *entry = NULL;
+  const Entry *entry = nullptr;
   entry = table.LookUp("mozc");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("MOZC", entry->result());
 
   entry = table.LookUp(",");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("COMMA", entry->result());
 
   entry = table.LookUp(".");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("PERIOD", entry->result());
 
   entry = table.LookUp("/");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("SLASH", entry->result());
 
   entry = table.LookUp("[");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("OPEN", entry->result());
 
   entry = table.LookUp("]");
-  ASSERT_TRUE(entry != NULL);
+  ASSERT_TRUE(entry != nullptr);
   EXPECT_EQ("CLOSE", entry->result());
 }
 
@@ -426,11 +418,11 @@ TEST_F(TableTest, CaseSensitive) {
   EXPECT_TRUE(table.HasSubRules("Z"));
 
   {  // Test for LookUpPrefix
-    const Entry *entry = NULL;
+    const Entry *entry = nullptr;
     size_t key_length = 0;
     bool fixed = false;
     entry = table.LookUpPrefix("bA", &key_length, &fixed);
-    EXPECT_TRUE(entry != NULL);
+    EXPECT_TRUE(entry != nullptr);
     EXPECT_EQ("[ba]", entry->result());
     EXPECT_EQ(2, key_length);
     EXPECT_TRUE(fixed);
@@ -444,24 +436,24 @@ TEST_F(TableTest, CaseSensitive) {
   EXPECT_EQ("[ba]", GetResult(table, "ba"));
   EXPECT_EQ("[BA]", GetResult(table, "BA"));
   EXPECT_EQ("[Ba]", GetResult(table, "Ba"));
-  EXPECT_EQ("<NULL>", GetResult(table, "bA"));
+  EXPECT_EQ("<nullptr>", GetResult(table, "bA"));
 
   EXPECT_EQ("a", GetInput(table, "a"));
   EXPECT_EQ("A", GetInput(table, "A"));
   EXPECT_EQ("ba", GetInput(table, "ba"));
   EXPECT_EQ("BA", GetInput(table, "BA"));
   EXPECT_EQ("Ba", GetInput(table, "Ba"));
-  EXPECT_EQ("<NULL>", GetInput(table, "bA"));
+  EXPECT_EQ("<nullptr>", GetInput(table, "bA"));
 
   // Test for HasSubRules
   EXPECT_FALSE(table.HasSubRules("Z"));
 
   {  // Test for LookUpPrefix
-    const Entry *entry = NULL;
+    const Entry *entry = nullptr;
     size_t key_length = 0;
     bool fixed = false;
     entry = table.LookUpPrefix("bA", &key_length, &fixed);
-    EXPECT_TRUE(entry == NULL);
+    EXPECT_TRUE(entry == nullptr);
     EXPECT_EQ(1, key_length);
     EXPECT_TRUE(fixed);
   }
@@ -530,24 +522,24 @@ TEST_F(TableTest, CaseSensitiveByConfiguration) {
     EXPECT_EQ("[ba]", GetResult(table, "ba"));
     EXPECT_EQ("[BA]", GetResult(table, "BA"));
     EXPECT_EQ("[Ba]", GetResult(table, "Ba"));
-    EXPECT_EQ("<NULL>", GetResult(table, "bA"));
+    EXPECT_EQ("<nullptr>", GetResult(table, "bA"));
 
     EXPECT_EQ("a", GetInput(table, "a"));
     EXPECT_EQ("A", GetInput(table, "A"));
     EXPECT_EQ("ba", GetInput(table, "ba"));
     EXPECT_EQ("BA", GetInput(table, "BA"));
     EXPECT_EQ("Ba", GetInput(table, "Ba"));
-    EXPECT_EQ("<NULL>", GetInput(table, "bA"));
+    EXPECT_EQ("<nullptr>", GetInput(table, "bA"));
 
     // Test for HasSubRules
     EXPECT_FALSE(table.HasSubRules("Z"));
 
-    { // Test for LookUpPrefix
-      const Entry *entry = NULL;
+    {  // Test for LookUpPrefix
+      const Entry *entry = nullptr;
       size_t key_length = 0;
       bool fixed = false;
       entry = table.LookUpPrefix("bA", &key_length, &fixed);
-      EXPECT_TRUE(entry == NULL);
+      EXPECT_TRUE(entry == nullptr);
       EXPECT_EQ(1, key_length);
       EXPECT_TRUE(fixed);
     }
@@ -570,24 +562,24 @@ TEST_F(TableTest, CaseSensitiveByConfiguration) {
     EXPECT_EQ("[ba]", GetResult(table, "ba"));
     EXPECT_EQ("[BA]", GetResult(table, "BA"));
     EXPECT_EQ("[Ba]", GetResult(table, "Ba"));
-    EXPECT_EQ("<NULL>", GetResult(table, "bA"));
+    EXPECT_EQ("<nullptr>", GetResult(table, "bA"));
 
     EXPECT_EQ("a", GetInput(table, "a"));
     EXPECT_EQ("A", GetInput(table, "A"));
     EXPECT_EQ("ba", GetInput(table, "ba"));
     EXPECT_EQ("BA", GetInput(table, "BA"));
     EXPECT_EQ("Ba", GetInput(table, "Ba"));
-    EXPECT_EQ("<NULL>", GetInput(table, "bA"));
+    EXPECT_EQ("<nullptr>", GetInput(table, "bA"));
 
     // Test for HasSubRules
     EXPECT_FALSE(table.HasSubRules("Z"));
 
-    { // Test for LookUpPrefix
-      const Entry *entry = NULL;
+    {  // Test for LookUpPrefix
+      const Entry *entry = nullptr;
       size_t key_length = 0;
       bool fixed = false;
       entry = table.LookUpPrefix("bA", &key_length, &fixed);
-      EXPECT_TRUE(entry == NULL);
+      EXPECT_TRUE(entry == nullptr);
       EXPECT_EQ(1, key_length);
       EXPECT_TRUE(fixed);
     }
@@ -610,24 +602,24 @@ TEST_F(TableTest, CaseSensitiveByConfiguration) {
     EXPECT_EQ("[ba]", GetResult(table, "ba"));
     EXPECT_EQ("[BA]", GetResult(table, "BA"));
     EXPECT_EQ("[Ba]", GetResult(table, "Ba"));
-    EXPECT_EQ("<NULL>", GetResult(table, "bA"));
+    EXPECT_EQ("<nullptr>", GetResult(table, "bA"));
 
     EXPECT_EQ("a", GetInput(table, "a"));
     EXPECT_EQ("A", GetInput(table, "A"));
     EXPECT_EQ("ba", GetInput(table, "ba"));
     EXPECT_EQ("BA", GetInput(table, "BA"));
     EXPECT_EQ("Ba", GetInput(table, "Ba"));
-    EXPECT_EQ("<NULL>", GetInput(table, "bA"));
+    EXPECT_EQ("<nullptr>", GetInput(table, "bA"));
 
     // Test for HasSubRules
     EXPECT_FALSE(table.HasSubRules("Z"));
 
-    { // Test for LookUpPrefix
-      const Entry *entry = NULL;
+    {  // Test for LookUpPrefix
+      const Entry *entry = nullptr;
       size_t key_length = 0;
       bool fixed = false;
       entry = table.LookUpPrefix("bA", &key_length, &fixed);
-      EXPECT_TRUE(entry == NULL);
+      EXPECT_TRUE(entry == nullptr);
       EXPECT_EQ(1, key_length);
       EXPECT_TRUE(fixed);
     }
@@ -644,12 +636,12 @@ TEST_F(TableTest, CaseSensitiveByConfiguration) {
 // table enables and disables this "case-sensitive mode", respectively.
 TEST_F(TableTest, AutomaticCaseSensitiveDetection) {
   static const char kCaseInsensitiveRomanTable[] = {
-    "m\tmozc\n"     // m -> mozc
-    "n\tnamazu\n"   // n -> namazu
+      "m\tmozc\n"    // m -> mozc
+      "n\tnamazu\n"  // n -> namazu
   };
   static const char kCaseSensitiveRomanTable[] = {
-    "m\tmozc\n"     // m -> mozc
-    "M\tMozc\n"     // M -> Mozc
+      "m\tmozc\n"  // m -> mozc
+      "M\tMozc\n"  // M -> Mozc
   };
 
   commands::Request request;
@@ -695,10 +687,9 @@ TEST_F(TableTest, MobileMode) {
     request.set_special_romanji_table(
         mozc::commands::Request::TWELVE_KEYS_TO_HIRAGANA);
     mozc::composer::Table table;
-    table.InitializeWithRequestAndConfig(request, config_,
-                                         mock_data_manager_);
+    table.InitializeWithRequestAndConfig(request, config_, mock_data_manager_);
     {
-      const mozc::composer::Entry *entry = NULL;
+      const mozc::composer::Entry *entry = nullptr;
       size_t key_length = 0;
       bool fixed = false;
       entry = table.LookUpPrefix("2", &key_length, &fixed);
@@ -709,7 +700,7 @@ TEST_F(TableTest, MobileMode) {
       EXPECT_TRUE(fixed);
     }
     {
-      const mozc::composer::Entry *entry = NULL;
+      const mozc::composer::Entry *entry = nullptr;
       size_t key_length = 0;
       bool fixed = false;
       entry = table.LookUpPrefix("し*", &key_length, &fixed);
@@ -728,12 +719,15 @@ TEST_F(TableTest, MobileMode) {
         mozc::commands::Request::TWELVE_KEYS_TO_HALFWIDTHASCII);
     Table table;
     table.InitializeWithRequestAndConfig(request, config_, mock_data_manager_);
-    const mozc::composer::Entry *entry = NULL;
+    const mozc::composer::Entry *entry = nullptr;
     size_t key_length = 0;
     bool fixed = false;
     entry = table.LookUpPrefix("2", &key_length, &fixed);
     // "{?}" is to be replaced by "\x0F?\x0E".
-    EXPECT_EQ("\x0F?\x0E" "a", entry->pending());
+    EXPECT_EQ(
+        "\x0F?\x0E"
+        "a",
+        entry->pending());
   }
 
   {
@@ -743,7 +737,7 @@ TEST_F(TableTest, MobileMode) {
     Table table;
     table.InitializeWithRequestAndConfig(request, config_, mock_data_manager_);
     {
-      const mozc::composer::Entry *entry = NULL;
+      const mozc::composer::Entry *entry = nullptr;
       size_t key_length = 0;
       bool fixed = false;
       entry = table.LookUpPrefix("しゃ*", &key_length, &fixed);
@@ -760,8 +754,8 @@ TEST_F(TableTest, MobileMode) {
 
     size_t key_length = 0;
     bool fixed = false;
-    const mozc::composer::Entry *entry = table.LookUpPrefix("a", &key_length,
-                                                            &fixed);
+    const mozc::composer::Entry *entry =
+        table.LookUpPrefix("a", &key_length, &fixed);
     EXPECT_EQ("き", entry->pending());
   }
 
@@ -774,8 +768,8 @@ TEST_F(TableTest, MobileMode) {
 
     size_t key_length = 0;
     bool fixed = false;
-    const mozc::composer::Entry *entry = table.LookUpPrefix("a", &key_length,
-                                                            &fixed);
+    const mozc::composer::Entry *entry =
+        table.LookUpPrefix("a", &key_length, &fixed);
     EXPECT_EQ("き", entry->pending());
   }
 }
@@ -791,12 +785,12 @@ TEST_F(TableTest, OrderOfAddRule) {
 
     const Entry *entry;
     entry = table.LookUp("ww");
-    EXPECT_TRUE(NULL != entry);
+    EXPECT_TRUE(nullptr != entry);
 
     size_t key_length;
     bool fixed;
     entry = table.LookUpPrefix("ww", &key_length, &fixed);
-    EXPECT_TRUE(NULL != entry);
+    EXPECT_TRUE(nullptr != entry);
     EXPECT_EQ(2, key_length);
     EXPECT_FALSE(fixed);
   }
@@ -807,21 +801,21 @@ TEST_F(TableTest, OrderOfAddRule) {
     table.AddRule("www", "w", "ww");
     EXPECT_TRUE(table.HasSubRules("ww"));
 
-    const Entry *entry = NULL;
+    const Entry *entry = nullptr;
     entry = table.LookUp("ww");
-    EXPECT_TRUE(NULL != entry);
+    EXPECT_TRUE(nullptr != entry);
 
     size_t key_length = 0;
     bool fixed = false;
     entry = table.LookUpPrefix("ww", &key_length, &fixed);
-    EXPECT_TRUE(NULL != entry);
+    EXPECT_TRUE(nullptr != entry);
     EXPECT_EQ(2, key_length);
     EXPECT_FALSE(fixed);
   }
 }
 
 TEST_F(TableTest, AddRuleWithAttributes) {
-  const string kInput = "1";
+  const std::string kInput = "1";
   Table table;
   table.AddRuleWithAttributes(kInput, "", "a", NEW_CHUNK);
 
@@ -832,13 +826,13 @@ TEST_F(TableTest, AddRuleWithAttributes) {
   const Entry *entry = table.LookUpPrefix(kInput, &key_length, &fixed);
   EXPECT_EQ(1, key_length);
   EXPECT_TRUE(fixed);
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ(kInput, entry->input());
   EXPECT_EQ("", entry->result());
   EXPECT_EQ("a", entry->pending());
   EXPECT_EQ(NEW_CHUNK, entry->attributes());
 
-  const string kInput2 = "22";
+  const std::string kInput2 = "22";
   table.AddRuleWithAttributes(kInput2, "", "b", NEW_CHUNK | NO_TRANSLITERATION);
 
   EXPECT_TRUE(table.HasNewChunkEntry(kInput2));
@@ -848,7 +842,7 @@ TEST_F(TableTest, AddRuleWithAttributes) {
   entry = table.LookUpPrefix(kInput2, &key_length, &fixed);
   EXPECT_EQ(2, key_length);
   EXPECT_TRUE(fixed);
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ(kInput2, entry->input());
   EXPECT_EQ("", entry->result());
   EXPECT_EQ("b", entry->pending());
@@ -856,38 +850,38 @@ TEST_F(TableTest, AddRuleWithAttributes) {
 }
 
 TEST_F(TableTest, LoadFromString) {
-  const string kRule =
-    "# This is a comment\n"
-    "\n"  // Empty line to be ignored.
-    "a\t[A]\n"  // 2 entry rule
-    "kk\t[X]\tk\n"  // 3 entry rule
-    "ww\t[W]\tw\tNewChunk\n"  // 3 entry rule + attribute rule
-    "xx\t[X]\tx\tNewChunk NoTransliteration\n"  // multiple attribute rules
-    // all attributes
-    "yy\t[Y]\ty\tNewChunk NoTransliteration DirectInput EndChunk\n"
-    "#\t[#]\n";  // This line starts with '#' but should be a rule.
+  const std::string kRule =
+      "# This is a comment\n"
+      "\n"                      // Empty line to be ignored.
+      "a\t[A]\n"                // 2 entry rule
+      "kk\t[X]\tk\n"            // 3 entry rule
+      "ww\t[W]\tw\tNewChunk\n"  // 3 entry rule + attribute rule
+      "xx\t[X]\tx\tNewChunk NoTransliteration\n"  // multiple attribute rules
+      // all attributes
+      "yy\t[Y]\ty\tNewChunk NoTransliteration DirectInput EndChunk\n"
+      "#\t[#]\n";  // This line starts with '#' but should be a rule.
   Table table;
   table.LoadFromString(kRule);
 
-  const Entry *entry = NULL;
+  const Entry *entry = nullptr;
   // Test for "a\t[A]\n"  -- 2 entry rule
   EXPECT_FALSE(table.HasNewChunkEntry("a"));
   entry = table.LookUp("a");
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ("[A]", entry->result());
   EXPECT_EQ("", entry->pending());
 
   // Test for "kk\t[X]\tk\n"  -- 3 entry rule
   EXPECT_FALSE(table.HasNewChunkEntry("kk"));
   entry = table.LookUp("kk");
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ("[X]", entry->result());
   EXPECT_EQ("k", entry->pending());
 
   // Test for "ww\t[W]\tw\tNewChunk\n"  -- 3 entry rule + attribute rule
   EXPECT_TRUE(table.HasNewChunkEntry("ww"));
   entry = table.LookUp("ww");
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ("[W]", entry->result());
   EXPECT_EQ("w", entry->pending());
   EXPECT_EQ(NEW_CHUNK, entry->attributes());
@@ -896,7 +890,7 @@ TEST_F(TableTest, LoadFromString) {
   // attribute rules
   EXPECT_TRUE(table.HasNewChunkEntry("xx"));
   entry = table.LookUp("xx");
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ("[X]", entry->result());
   EXPECT_EQ("x", entry->pending());
   EXPECT_EQ((NEW_CHUNK | NO_TRANSLITERATION), entry->attributes());
@@ -905,7 +899,7 @@ TEST_F(TableTest, LoadFromString) {
   // -- all attributes
   EXPECT_TRUE(table.HasNewChunkEntry("yy"));
   entry = table.LookUp("yy");
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ("[Y]", entry->result());
   EXPECT_EQ("y", entry->pending());
   EXPECT_EQ((NEW_CHUNK | NO_TRANSLITERATION | DIRECT_INPUT | END_CHUNK),
@@ -913,7 +907,7 @@ TEST_F(TableTest, LoadFromString) {
 
   // Test for "#\t[#]\n"  -- This line starts with '#' but should be a rule.
   entry = table.LookUp("#");
-  ASSERT_TRUE(NULL != entry);
+  ASSERT_TRUE(nullptr != entry);
   EXPECT_EQ("[#]", entry->result());
   EXPECT_EQ("", entry->pending());
 }
@@ -926,26 +920,26 @@ TEST_F(TableTest, SpecialKeys) {
     table.AddRule("x{{}", "X{", "");
     table.AddRule("xy", "XY", "");
 
-    const Entry *entry = NULL;
+    const Entry *entry = nullptr;
     entry = table.LookUp("x{#1}y");
-    EXPECT_TRUE(NULL == entry);
+    EXPECT_TRUE(nullptr == entry);
 
-    string key;
+    std::string key;
     key = Table::ParseSpecialKey("x{#1}y");
     entry = table.LookUp(key);
-    ASSERT_TRUE(NULL != entry);
+    ASSERT_TRUE(nullptr != entry);
     EXPECT_EQ(key, entry->input());
     EXPECT_EQ("X1Y", entry->result());
 
     key = Table::ParseSpecialKey("x{#2}y");
     entry = table.LookUp(key);
-    ASSERT_TRUE(NULL != entry);
+    ASSERT_TRUE(nullptr != entry);
     EXPECT_EQ(key, entry->input());
     EXPECT_EQ("X2Y", entry->result());
 
     key = "x{";
     entry = table.LookUp(key);
-    ASSERT_TRUE(NULL != entry);
+    ASSERT_TRUE(nullptr != entry);
     EXPECT_EQ(key, entry->input());
     EXPECT_EQ("X{", entry->result());
   }
@@ -954,7 +948,10 @@ TEST_F(TableTest, SpecialKeys) {
     // "{{}" is replaced with "{".
     // "{*}" is replaced with "\x0F*\x0E".
     Table table;
-    EXPECT_EQ("\x0F" "\x0E", table.AddRule("{}", "", "")->input());
+    EXPECT_EQ(
+        "\x0F"
+        "\x0E",
+        table.AddRule("{}", "", "")->input());
     EXPECT_EQ("{", table.AddRule("{", "", "")->input());
     EXPECT_EQ("}", table.AddRule("}", "", "")->input());
     EXPECT_EQ("{", table.AddRule("{{}", "", "")->input());
@@ -965,53 +962,67 @@ TEST_F(TableTest, SpecialKeys) {
     EXPECT_EQ("a}", table.AddRule("a}", "", "")->input());
     EXPECT_EQ("}a", table.AddRule("}a", "", "")->input());
     EXPECT_EQ("a}a", table.AddRule("a}a", "", "")->input());
-    EXPECT_EQ("a" "\x0F" "b" "\x0E" "c",
-              table.AddRule("a{b}c", "", "")->input());
-    EXPECT_EQ("a" "\x0F" "b" "\x0E" "c" "\x0F" "d" "\x0E" "\x0F" "e" "\x0E",
-              table.AddRule("a{b}c{d}{e}", "", "")->input());
+    EXPECT_EQ(
+        "a"
+        "\x0F"
+        "b"
+        "\x0E"
+        "c",
+        table.AddRule("a{b}c", "", "")->input());
+    EXPECT_EQ(
+        "a"
+        "\x0F"
+        "b"
+        "\x0E"
+        "c"
+        "\x0F"
+        "d"
+        "\x0E"
+        "\x0F"
+        "e"
+        "\x0E",
+        table.AddRule("a{b}c{d}{e}", "", "")->input());
     EXPECT_EQ("}-{", table.AddRule("}-{", "", "")->input());
     EXPECT_EQ("a{bc", table.AddRule("a{bc", "", "")->input());
 
     // This is not a fixed specification, but a current behavior.
-    EXPECT_EQ("\x0F" "{-" "\x0E" "}",
-              table.AddRule("{{-}}", "", "")->input());
+    EXPECT_EQ(
+        "\x0F"
+        "{-"
+        "\x0E"
+        "}",
+        table.AddRule("{{-}}", "", "")->input());
   }
 }
 
 TEST_F(TableTest, TableManager) {
   TableManager table_manager;
-  std::set<const Table*> table_set;
-  static const commands::Request::SpecialRomanjiTable
-      special_romanji_table[] = {
-    commands::Request::DEFAULT_TABLE,
-    commands::Request::TWELVE_KEYS_TO_HIRAGANA,
-    commands::Request::TWELVE_KEYS_TO_HALFWIDTHASCII,
-    commands::Request::FLICK_TO_HIRAGANA,
-    commands::Request::FLICK_TO_HALFWIDTHASCII,
-    commands::Request::TOGGLE_FLICK_TO_HIRAGANA,
-    commands::Request::TOGGLE_FLICK_TO_HALFWIDTHASCII,
-    commands::Request::GODAN_TO_HIRAGANA,
-    commands::Request::QWERTY_MOBILE_TO_HIRAGANA,
-    commands::Request::QWERTY_MOBILE_TO_HALFWIDTHASCII,
-    commands::Request::NOTOUCH_TO_HIRAGANA,
-    commands::Request::NOTOUCH_TO_HALFWIDTHASCII,
-  };
+  mozc_hash_set<const Table *> table_set;
+  static const commands::Request::SpecialRomanjiTable special_romanji_table[] =
+      {
+          commands::Request::DEFAULT_TABLE,
+          commands::Request::TWELVE_KEYS_TO_HIRAGANA,
+          commands::Request::TWELVE_KEYS_TO_HALFWIDTHASCII,
+          commands::Request::FLICK_TO_HIRAGANA,
+          commands::Request::FLICK_TO_HALFWIDTHASCII,
+          commands::Request::TOGGLE_FLICK_TO_HIRAGANA,
+          commands::Request::TOGGLE_FLICK_TO_HALFWIDTHASCII,
+          commands::Request::GODAN_TO_HIRAGANA,
+          commands::Request::QWERTY_MOBILE_TO_HIRAGANA,
+          commands::Request::QWERTY_MOBILE_TO_HALFWIDTHASCII,
+          commands::Request::NOTOUCH_TO_HIRAGANA,
+          commands::Request::NOTOUCH_TO_HALFWIDTHASCII,
+      };
   static const config::Config::PreeditMethod preedit_method[] = {
-    config::Config::ROMAN,
-    config::Config::KANA
-  };
+      config::Config::ROMAN, config::Config::KANA};
   static const config::Config::PunctuationMethod punctuation_method[] = {
-    config::Config::KUTEN_TOUTEN,
-    config::Config::COMMA_PERIOD,
-    config::Config::KUTEN_PERIOD,
-    config::Config::COMMA_TOUTEN
-  };
+      config::Config::KUTEN_TOUTEN, config::Config::COMMA_PERIOD,
+      config::Config::KUTEN_PERIOD, config::Config::COMMA_TOUTEN};
   static const config::Config::SymbolMethod symbol_method[] = {
-    config::Config::CORNER_BRACKET_MIDDLE_DOT,
-    config::Config::SQUARE_BRACKET_SLASH,
-    config::Config::CORNER_BRACKET_SLASH,
-    config::Config::SQUARE_BRACKET_MIDDLE_DOT
-  };
+      config::Config::CORNER_BRACKET_MIDDLE_DOT,
+      config::Config::SQUARE_BRACKET_SLASH,
+      config::Config::CORNER_BRACKET_SLASH,
+      config::Config::SQUARE_BRACKET_MIDDLE_DOT};
 
   for (int romanji = 0; romanji < arraysize(special_romanji_table); ++romanji) {
     for (int preedit = 0; preedit < arraysize(preedit_method); ++preedit) {
@@ -1024,9 +1035,9 @@ TEST_F(TableTest, TableManager) {
           config.set_preedit_method(preedit_method[preedit]);
           config.set_punctuation_method(punctuation_method[punctuation]);
           config.set_symbol_method(symbol_method[symbol]);
-          const Table *table = table_manager.GetTable(request, config,
-                                                      mock_data_manager_);
-          EXPECT_TRUE(table != NULL);
+          const Table *table =
+              table_manager.GetTable(request, config, mock_data_manager_);
+          EXPECT_TRUE(table != nullptr);
           EXPECT_TRUE(table_manager.GetTable(request, config,
                                              mock_data_manager_) == table);
           EXPECT_TRUE(table_set.find(table) == table_set.end());
@@ -1038,8 +1049,7 @@ TEST_F(TableTest, TableManager) {
 
   {
     // b/6788850.
-    const string kRule =
-        "a\t[A]\n";  // 2 entry rule
+    const std::string kRule = "a\t[A]\n";  // 2 entry rule
 
     commands::Request request;
     request.set_special_romanji_table(Request::DEFAULT_TABLE);
@@ -1048,25 +1058,25 @@ TEST_F(TableTest, TableManager) {
     config.set_punctuation_method(Config::KUTEN_TOUTEN);
     config.set_symbol_method(Config::CORNER_BRACKET_MIDDLE_DOT);
     config.set_custom_roman_table(kRule);
-    const Table *table = table_manager.GetTable(request, config,
-                                                mock_data_manager_);
-    EXPECT_TRUE(table != NULL);
-    EXPECT_TRUE(table_manager.GetTable(request, config,
-                                       mock_data_manager_) == table);
-    EXPECT_TRUE(NULL != table->LookUp("a"));
-    EXPECT_TRUE(NULL == table->LookUp("kk"));
+    const Table *table =
+        table_manager.GetTable(request, config, mock_data_manager_);
+    EXPECT_TRUE(table != nullptr);
+    EXPECT_TRUE(table_manager.GetTable(request, config, mock_data_manager_) ==
+                table);
+    EXPECT_TRUE(nullptr != table->LookUp("a"));
+    EXPECT_TRUE(nullptr == table->LookUp("kk"));
 
-    const string kRule2 =
-        "a\t[A]\n"  // 2 entry rule
+    const std::string kRule2 =
+        "a\t[A]\n"       // 2 entry rule
         "kk\t[X]\tk\n";  // 3 entry rule
     config.set_custom_roman_table(kRule2);
-    const Table *table2 = table_manager.GetTable(request, config,
-                                                 mock_data_manager_);
-    EXPECT_TRUE(table2 != NULL);
-    EXPECT_TRUE(table_manager.GetTable(request, config,
-                                       mock_data_manager_) == table2);
-    EXPECT_TRUE(NULL != table2->LookUp("a"));
-    EXPECT_TRUE(NULL != table2->LookUp("kk"));
+    const Table *table2 =
+        table_manager.GetTable(request, config, mock_data_manager_);
+    EXPECT_TRUE(table2 != nullptr);
+    EXPECT_TRUE(table_manager.GetTable(request, config, mock_data_manager_) ==
+                table2);
+    EXPECT_TRUE(nullptr != table2->LookUp("a"));
+    EXPECT_TRUE(nullptr != table2->LookUp("kk"));
   }
 }
 
