@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,8 +37,6 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 namespace config {
 
@@ -65,79 +63,55 @@ TEST_F(CharacterFormManagerTest, DefaultTest) {
 
   manager->ClearHistory();
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("カタカナ"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetPreeditCharacterForm("カタカナ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("012"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetPreeditCharacterForm("012"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("["));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("["));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("/"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("/"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("・"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("・"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("。"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("。"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("、"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("、"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("\\"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("\\"));
 
-  EXPECT_EQ(
-      config::Config::NO_CONVERSION,
-      manager->GetConversionCharacterForm("ABC012ほげ"));
+  EXPECT_EQ(config::Config::NO_CONVERSION,
+            manager->GetConversionCharacterForm("ABC012ほげ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("カタカナ"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("カタカナ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("012"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("012"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("["));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("["));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("/"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("/"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("・"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("・"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("。"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("。"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("、"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("、"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("\\"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("\\"));
 
-  EXPECT_EQ(
-      config::Config::NO_CONVERSION,
-      manager->GetConversionCharacterForm("ABC012ほげ"));
+  EXPECT_EQ(config::Config::NO_CONVERSION,
+            manager->GetConversionCharacterForm("ABC012ほげ"));
 
-  string output;
+  std::string output;
   manager->ConvertPreeditString("京都東京ABCインターネット", &output);
   EXPECT_EQ("京都東京ＡＢＣインターネット", output);
 
@@ -191,73 +165,50 @@ TEST_F(CharacterFormManagerTest, DefaultTest) {
   manager->SetCharacterForm("\\", config::Config::HALF_WIDTH);
 
   // retry
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("カタカナ"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetPreeditCharacterForm("カタカナ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("012"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetPreeditCharacterForm("012"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("["));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("["));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("/"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("/"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("・"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("・"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("。"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("。"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("、"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("、"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("\\"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("\\"));
 
-  EXPECT_EQ(
-      config::Config::NO_CONVERSION,
-      manager->GetConversionCharacterForm("ABC012ほげ"));
+  EXPECT_EQ(config::Config::NO_CONVERSION,
+            manager->GetConversionCharacterForm("ABC012ほげ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("カタカナ"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("カタカナ"));
 
-  EXPECT_EQ(
-      config::Config::HALF_WIDTH,
-      manager->GetConversionCharacterForm("012"));
+  EXPECT_EQ(config::Config::HALF_WIDTH,
+            manager->GetConversionCharacterForm("012"));
 
-  EXPECT_EQ(
-      config::Config::HALF_WIDTH,
-      manager->GetConversionCharacterForm("["));
+  EXPECT_EQ(config::Config::HALF_WIDTH,
+            manager->GetConversionCharacterForm("["));
 
-  EXPECT_EQ(
-      config::Config::HALF_WIDTH,
-      manager->GetConversionCharacterForm("/"));
+  EXPECT_EQ(config::Config::HALF_WIDTH,
+            manager->GetConversionCharacterForm("/"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("・"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("・"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("。"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("。"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("、"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("、"));
 
-  EXPECT_EQ(
-      config::Config::HALF_WIDTH,
-      manager->GetConversionCharacterForm("\\"));
+  EXPECT_EQ(config::Config::HALF_WIDTH,
+            manager->GetConversionCharacterForm("\\"));
 
   manager->ConvertPreeditString("京都東京ABCインターネット", &output);
   EXPECT_EQ("京都東京ＡＢＣインターネット", output);
@@ -331,73 +282,50 @@ TEST_F(CharacterFormManagerTest, DefaultTest) {
   manager->SetCharacterForm("、", config::Config::FULL_WIDTH);
   manager->SetCharacterForm("\\", config::Config::FULL_WIDTH);
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("カタカナ"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetPreeditCharacterForm("カタカナ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("012"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetPreeditCharacterForm("012"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("["));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("["));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("/"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("/"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("・"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("・"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("。"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("。"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("、"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("、"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetPreeditCharacterForm("\\"));
+  EXPECT_EQ(config::Config::FULL_WIDTH, manager->GetPreeditCharacterForm("\\"));
 
-  EXPECT_EQ(
-      config::Config::NO_CONVERSION,
-      manager->GetConversionCharacterForm("ABC012ほげ"));
+  EXPECT_EQ(config::Config::NO_CONVERSION,
+            manager->GetConversionCharacterForm("ABC012ほげ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("カタカナ"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("カタカナ"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("012"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("012"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("["));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("["));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("/"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("/"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("・"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("・"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("。"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("。"));
 
-  EXPECT_EQ(
-      config::Config::FULL_WIDTH,
-      manager->GetConversionCharacterForm("、"));
+  EXPECT_EQ(config::Config::FULL_WIDTH,
+            manager->GetConversionCharacterForm("、"));
 
-  EXPECT_EQ(
-      config::Config::NO_CONVERSION,
-      manager->GetConversionCharacterForm("ABC012ほげ"));
+  EXPECT_EQ(config::Config::NO_CONVERSION,
+            manager->GetConversionCharacterForm("ABC012ほげ"));
 
   manager->ConvertPreeditString("京都東京ABCインターネット", &output);
   EXPECT_EQ("京都東京ＡＢＣインターネット", output);
@@ -451,7 +379,7 @@ TEST_F(CharacterFormManagerTest, MixedFormTest) {
   manager->AddPreeditRule("0", config::Config::FULL_WIDTH);
   manager->AddPreeditRule(".,", config::Config::HALF_WIDTH);
 
-  string output;
+  std::string output;
   manager->ConvertConversionString("1.23", &output);
   EXPECT_EQ("1.23", output);
 
@@ -472,42 +400,30 @@ TEST_F(CharacterFormManagerTest, GroupTest) {
     manager->AddPreeditRule("ア", config::Config::HALF_WIDTH);
     manager->AddConversionRule("[]", config::Config::HALF_WIDTH);
     manager->AddPreeditRule("[]", config::Config::FULL_WIDTH);
-    manager->AddConversionRule("!@#$%^&*()-=",
-                               config::Config::FULL_WIDTH);
-    manager->AddConversionRule("!@#$%^&*()-=",
-                               config::Config::HALF_WIDTH);
+    manager->AddConversionRule("!@#$%^&*()-=", config::Config::FULL_WIDTH);
+    manager->AddConversionRule("!@#$%^&*()-=", config::Config::HALF_WIDTH);
 
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("["));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("["));
 
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("["));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("["));
 
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetPreeditCharacterForm("ア"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetPreeditCharacterForm("ア"));
 
+    manager->SetCharacterForm("[", config::Config::FULL_WIDTH);
+    manager->SetCharacterForm("ア", config::Config::FULL_WIDTH);
+    manager->SetCharacterForm("@", config::Config::FULL_WIDTH);
 
-    manager->SetCharacterForm("[",
-                              config::Config::FULL_WIDTH);
-    manager->SetCharacterForm("ア",
-                              config::Config::FULL_WIDTH);
-    manager->SetCharacterForm("@",
-                              config::Config::FULL_WIDTH);
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("["));
 
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("["));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("["));
 
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("["));
-
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetPreeditCharacterForm("ア"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetPreeditCharacterForm("ア"));
   }
 
   {
@@ -515,20 +431,16 @@ TEST_F(CharacterFormManagerTest, GroupTest) {
     manager->Clear();
     manager->AddConversionRule("ア", config::Config::FULL_WIDTH);
     manager->AddConversionRule("[]", config::Config::LAST_FORM);
-    manager->AddConversionRule("!@#$%^&*()-=",
-                               config::Config::FULL_WIDTH);
+    manager->AddConversionRule("!@#$%^&*()-=", config::Config::FULL_WIDTH);
 
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,  // default
-        manager->GetConversionCharacterForm("["));
+    EXPECT_EQ(config::Config::FULL_WIDTH,  // default
+              manager->GetConversionCharacterForm("["));
 
     // same group
-    manager->SetCharacterForm("]",
-                              config::Config::HALF_WIDTH);
+    manager->SetCharacterForm("]", config::Config::HALF_WIDTH);
 
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("["));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("["));
   }
 
   {
@@ -536,38 +448,28 @@ TEST_F(CharacterFormManagerTest, GroupTest) {
     manager->Clear();
     manager->AddConversionRule("ア", config::Config::FULL_WIDTH);
     manager->AddConversionRule("[](){}", config::Config::LAST_FORM);
-    manager->AddConversionRule("!@#$%^&*-=",
-                               config::Config::FULL_WIDTH);
+    manager->AddConversionRule("!@#$%^&*-=", config::Config::FULL_WIDTH);
 
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm("{"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm("}"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm("("));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm(")"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm("{"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm("}"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm("("));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm(")"));
 
     // same group
-    manager->SetCharacterForm(")",
-                              config::Config::HALF_WIDTH);
+    manager->SetCharacterForm(")", config::Config::HALF_WIDTH);
 
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("{"));
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("}"));
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("("));
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm(")"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("{"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("}"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("("));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm(")"));
   }
 
   {
@@ -576,149 +478,115 @@ TEST_F(CharacterFormManagerTest, GroupTest) {
     manager->AddConversionRule("ア", config::Config::FULL_WIDTH);
     manager->AddConversionRule("[](){}", config::Config::LAST_FORM);
     manager->AddPreeditRule("[](){}", config::Config::FULL_WIDTH);
-    manager->AddConversionRule("!@#$%^&*-=",
-                               config::Config::FULL_WIDTH);
+    manager->AddConversionRule("!@#$%^&*-=", config::Config::FULL_WIDTH);
 
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm("{"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm("}"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm("("));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetConversionCharacterForm(")"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm("{"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm("}"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm("("));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetConversionCharacterForm(")"));
 
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("{"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("}"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("("));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm(")"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("{"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("}"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("("));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm(")"));
 
     // same group
-    manager->SetCharacterForm(")",
-                              config::Config::HALF_WIDTH);
+    manager->SetCharacterForm(")", config::Config::HALF_WIDTH);
 
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("{"));
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("}"));
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm("("));
-    EXPECT_EQ(
-        config::Config::HALF_WIDTH,
-        manager->GetConversionCharacterForm(")"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("{"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("}"));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm("("));
+    EXPECT_EQ(config::Config::HALF_WIDTH,
+              manager->GetConversionCharacterForm(")"));
 
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("{"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("}"));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm("("));
-    EXPECT_EQ(
-        config::Config::FULL_WIDTH,
-        manager->GetPreeditCharacterForm(")"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("{"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("}"));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm("("));
+    EXPECT_EQ(config::Config::FULL_WIDTH,
+              manager->GetPreeditCharacterForm(")"));
   }
 }
 
 TEST_F(CharacterFormManagerTest, GetFormTypesFromStringPair) {
   CharacterFormManager::FormType f1, f2;
 
-  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "", &f1,
-      "", &f2));
+  EXPECT_FALSE(
+      CharacterFormManager::GetFormTypesFromStringPair("", &f1, "", &f2));
 
-  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "abc", &f1,
-      "ab", &f2));
+  EXPECT_FALSE(
+      CharacterFormManager::GetFormTypesFromStringPair("abc", &f1, "ab", &f2));
 
-  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "abc", &f1,
-      "abc", &f2));
+  EXPECT_FALSE(
+      CharacterFormManager::GetFormTypesFromStringPair("abc", &f1, "abc", &f2));
 
-  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "12", &f1,
-      "12", &f2));
+  EXPECT_FALSE(
+      CharacterFormManager::GetFormTypesFromStringPair("12", &f1, "12", &f2));
 
-  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "あいう", &f1,
-      "あいう", &f2));
+  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair("あいう", &f1,
+                                                                "あいう", &f2));
 
-  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "アイウ", &f1,
-      "アイウ", &f2));
+  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair("アイウ", &f1,
+                                                                "アイウ", &f2));
 
-  EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "愛", &f1,
-      "恋", &f2));
+  EXPECT_FALSE(
+      CharacterFormManager::GetFormTypesFromStringPair("愛", &f1, "恋", &f2));
 
-  EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "ABC", &f1,
-      "ＡＢＣ", &f2));
+  EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair("ABC", &f1,
+                                                               "ＡＢＣ", &f2));
+  EXPECT_EQ(f1, CharacterFormManager::HALF_WIDTH);
+  EXPECT_EQ(f2, CharacterFormManager::FULL_WIDTH);
+
+  EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair("ａｂｃ", &f1,
+                                                               "abc", &f2));
+  EXPECT_EQ(f1, CharacterFormManager::FULL_WIDTH);
+  EXPECT_EQ(f2, CharacterFormManager::HALF_WIDTH);
+
+  EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair("おばQ", &f1,
+                                                               "おばＱ", &f2));
   EXPECT_EQ(f1, CharacterFormManager::HALF_WIDTH);
   EXPECT_EQ(f2, CharacterFormManager::FULL_WIDTH);
 
   EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "ａｂｃ", &f1,
-      "abc", &f2));
+      "よろしくヨロシク", &f1, "よろしくﾖﾛｼｸ", &f2));
   EXPECT_EQ(f1, CharacterFormManager::FULL_WIDTH);
   EXPECT_EQ(f2, CharacterFormManager::HALF_WIDTH);
 
   EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "おばQ", &f1,
-      "おばＱ", &f2));
-  EXPECT_EQ(f1, CharacterFormManager::HALF_WIDTH);
-  EXPECT_EQ(f2, CharacterFormManager::FULL_WIDTH);
-
-  EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "よろしくヨロシク", &f1,
-      "よろしくﾖﾛｼｸ", &f2));
-  EXPECT_EQ(f1, CharacterFormManager::FULL_WIDTH);
-  EXPECT_EQ(f2, CharacterFormManager::HALF_WIDTH);
-
-  EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "よろしくグーグル", &f1,
-      "よろしくｸﾞｰｸﾞﾙ", &f2));
+      "よろしくグーグル", &f1, "よろしくｸﾞｰｸﾞﾙ", &f2));
   EXPECT_EQ(f1, CharacterFormManager::FULL_WIDTH);
   EXPECT_EQ(f2, CharacterFormManager::HALF_WIDTH);
 
   // semi voice sound mark
   EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "カッパよろしくグーグル", &f1,
-      "ｶｯﾊﾟよろしくｸﾞｰｸﾞﾙ", &f2));
+      "カッパよろしくグーグル", &f1, "ｶｯﾊﾟよろしくｸﾞｰｸﾞﾙ", &f2));
   EXPECT_EQ(f1, CharacterFormManager::FULL_WIDTH);
   EXPECT_EQ(f2, CharacterFormManager::HALF_WIDTH);
 
   EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "ヨロシクＱ", &f1,
-      "ﾖﾛｼｸQ", &f2));
+      "ヨロシクＱ", &f1, "ﾖﾛｼｸQ", &f2));
   EXPECT_EQ(f1, CharacterFormManager::FULL_WIDTH);
   EXPECT_EQ(f2, CharacterFormManager::HALF_WIDTH);
 
   // mixed
   EXPECT_FALSE(CharacterFormManager::GetFormTypesFromStringPair(
-      "ヨロシクQ", &f1,
-      "ﾖﾛｼｸＱ", &f2));
+      "ヨロシクQ", &f1, "ﾖﾛｼｸＱ", &f2));
 
   EXPECT_TRUE(CharacterFormManager::GetFormTypesFromStringPair(
-      "京都Qぐーぐる", &f1,
-      "京都Ｑぐーぐる", &f2));
+      "京都Qぐーぐる", &f1, "京都Ｑぐーぐる", &f2));
   EXPECT_EQ(f1, CharacterFormManager::HALF_WIDTH);
   EXPECT_EQ(f2, CharacterFormManager::FULL_WIDTH);
 }
