@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,12 +33,12 @@
 
 #include <algorithm>
 #include <memory>
+#include <string>
 
 #include "base/clock.h"
 #include "base/config_file_stream.h"
 #include "base/logging.h"
 #include "base/mutex.h"
-#include "base/number_util.h"
 #include "base/port.h"
 #include "base/singleton.h"
 #include "base/system_util.h"
@@ -55,8 +55,7 @@ void AddCharacterFormRule(const char *group,
                           const Config::CharacterForm preedit_form,
                           const Config::CharacterForm conversion_form,
                           Config *config) {
-  Config::CharacterFormRule *rule =
-      config->add_character_form_rules();
+  Config::CharacterFormRule *rule = config->add_character_form_rules();
   rule->set_group(group);
   rule->set_preedit_character_form(preedit_form);
   rule->set_conversion_character_form(conversion_form);
@@ -80,7 +79,7 @@ class ConfigHandlerImpl {
   ConfigHandlerImpl() {
     // <user_profile>/config1.db
     filename_ = kFileNamePrefix;
-    filename_ += NumberUtil::SimpleItoa(CONFIG_VERSION);
+    filename_ += std::to_string(CONFIG_VERSION);
     filename_ += ".db";
     Reload();
     ConfigHandler::GetDefaultConfig(&default_config_);
@@ -92,8 +91,8 @@ class ConfigHandlerImpl {
   bool SetConfig(const Config &config);
   void SetImposedConfig(const Config &config);
   bool Reload();
-  void SetConfigFileName(const string &filename);
-  string GetConfigFileName();
+  void SetConfigFileName(const std::string &filename);
+  std::string GetConfigFileName();
 
  private:
   // copy config to config_ and do some
@@ -101,7 +100,7 @@ class ConfigHandlerImpl {
   bool SetConfigInternal(const Config &config);
   void UpdateMergedConfig();
 
-  string filename_;
+  std::string filename_;
   Config stored_config_;
   Config imposed_config_;
   // equals to config_.MergeFrom(imposed_config_)
@@ -136,7 +135,7 @@ bool ConfigHandlerImpl::GetStoredConfig(Config *config) const {
 bool ConfigHandlerImpl::SetConfigInternal(const Config &config) {
   stored_config_.CopyFrom(config);
 
-#ifdef NO_LOGGING
+#ifdef MOZC_NO_LOGGING
   // Delete the optional field from the config.
   stored_config_.clear_verbose_level();
   // Fall back if the default value is not the expected value.
@@ -215,12 +214,12 @@ bool ConfigHandlerImpl::Reload() {
   Config input_proto;
   bool ret_code = true;
 
-  if (is.get() == NULL) {
+  if (is == nullptr) {
     LOG(ERROR) << filename_ << " is not found";
     ret_code = false;
   } else if (!input_proto.ParseFromIstream(is.get())) {
     LOG(ERROR) << filename_ << " is broken";
-    input_proto.Clear();   // revert to default setting
+    input_proto.Clear();  // revert to default setting
     ret_code = false;
   }
 
@@ -230,14 +229,14 @@ bool ConfigHandlerImpl::Reload() {
   return ret_code;
 }
 
-void ConfigHandlerImpl::SetConfigFileName(const string &filename) {
+void ConfigHandlerImpl::SetConfigFileName(const std::string &filename) {
   scoped_lock lock(&mutex_);
   VLOG(1) << "set new config file name: " << filename;
   filename_ = filename;
   Reload();
 }
 
-string ConfigHandlerImpl::GetConfigFileName() {
+std::string ConfigHandlerImpl::GetConfigFileName() {
   scoped_lock lock(&mutex_);
   return filename_;
 }
@@ -270,17 +269,15 @@ void ConfigHandler::GetDefaultConfig(Config *config) {
   const Config::CharacterForm kFullWidth = Config::FULL_WIDTH;
   const Config::CharacterForm kLastForm = Config::LAST_FORM;
   // "ア"
-  AddCharacterFormRule("\xE3\x82\xA2", kFullWidth, kFullWidth, config);
+  AddCharacterFormRule("ア", kFullWidth, kFullWidth, config);
   AddCharacterFormRule("A", kFullWidth, kLastForm, config);
   AddCharacterFormRule("0", kFullWidth, kLastForm, config);
   AddCharacterFormRule("(){}[]", kFullWidth, kLastForm, config);
   AddCharacterFormRule(".,", kFullWidth, kLastForm, config);
   // "。、",
-  AddCharacterFormRule("\xE3\x80\x82\xE3\x80\x81", kFullWidth, kFullWidth,
-                       config);
+  AddCharacterFormRule("。、", kFullWidth, kFullWidth, config);
   // "・「」"
-  AddCharacterFormRule("\xE3\x83\xBB\xE3\x80\x8C\xE3\x80\x8D",
-                       kFullWidth, kFullWidth, config);
+  AddCharacterFormRule("・「」", kFullWidth, kFullWidth, config);
   AddCharacterFormRule("\"'", kFullWidth, kLastForm, config);
   AddCharacterFormRule(":;", kFullWidth, kLastForm, config);
   AddCharacterFormRule("#%&@$^_|`\\", kFullWidth, kLastForm, config);
@@ -298,20 +295,18 @@ void ConfigHandler::GetDefaultConfig(Config *config) {
 }
 
 // static
-const Config& ConfigHandler::DefaultConfig() {
+const Config &ConfigHandler::DefaultConfig() {
   return GetConfigHandlerImpl()->DefaultConfig();
 }
 
 // Reload from file
-bool ConfigHandler::Reload() {
-  return GetConfigHandlerImpl()->Reload();
-}
+bool ConfigHandler::Reload() { return GetConfigHandlerImpl()->Reload(); }
 
-void ConfigHandler::SetConfigFileName(const string &filename) {
+void ConfigHandler::SetConfigFileName(const std::string &filename) {
   GetConfigHandlerImpl()->SetConfigFileName(filename);
 }
 
-string ConfigHandler::GetConfigFileName() {
+std::string ConfigHandler::GetConfigFileName() {
   return GetConfigHandlerImpl()->GetConfigFileName();
 }
 
@@ -325,13 +320,13 @@ void ConfigHandler::SetMetaData(Config *config) {
 }
 
 Config::SessionKeymap ConfigHandler::GetDefaultKeyMap() {
-#if defined(OS_MACOSX)
+#if defined(__APPLE__)
   return config::Config::KOTOERI;
-#elif defined(OS_NACL)  // OS_MACOSX
+#elif defined(OS_NACL)  // __APPLE__
   return config::Config::CHROMEOS;
-#else  // OS_MACOSX or OS_NACL
+#else                   // __APPLE__ or OS_NACL
   return config::Config::MSIME;
-#endif  // OS_MACOSX or OS_NACL
+#endif                  // __APPLE__ or OS_NACL
 }
 
 }  // namespace config
