@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -68,13 +68,14 @@ class ConfigHandlerTest : public ::testing::Test {
     ConfigHandler::GetDefaultConfig(&default_config);
     ConfigHandler::SetConfig(default_config);
   }
+
  private:
-  string default_config_filename_;
+  std::string default_config_filename_;
 };
 
 class ScopedSetConfigFileName {
  public:
-  explicit ScopedSetConfigFileName(const string &new_name)
+  explicit ScopedSetConfigFileName(const std::string &new_name)
       : default_config_filename_(ConfigHandler::GetConfigFileName()) {
     ConfigHandler::SetConfigFileName(new_name);
   }
@@ -84,7 +85,7 @@ class ScopedSetConfigFileName {
   }
 
  private:
-  string default_config_filename_;
+  std::string default_config_filename_;
 
   DISALLOW_IMPLICIT_CONSTRUCTORS(ScopedSetConfigFileName);
 };
@@ -93,8 +94,8 @@ TEST_F(ConfigHandlerTest, SetConfig) {
   Config input;
   Config output;
 
-  const string config_file = FileUtil::JoinPath(FLAGS_test_tmpdir,
-                                                "mozc_config_test_tmp");
+  const std::string config_file =
+      FileUtil::JoinPath(FLAGS_test_tmpdir, "mozc_config_test_tmp");
   FileUtil::Unlink(config_file);
   ScopedSetConfigFileName scoped_config_file_name(config_file);
   EXPECT_EQ(config_file, ConfigHandler::GetConfigFileName());
@@ -103,9 +104,9 @@ TEST_F(ConfigHandlerTest, SetConfig) {
 
   ConfigHandler::GetDefaultConfig(&input);
   input.set_incognito_mode(true);
-#ifndef NO_LOGGING
+#ifndef MOZC_NO_LOGGING
   input.set_verbose_level(2);
-#endif  // NO_LOGGING
+#endif  // MOZC_NO_LOGGING
   ConfigHandler::SetMetaData(&input);
   EXPECT_TRUE(ConfigHandler::SetConfig(input));
   output.Clear();
@@ -116,9 +117,9 @@ TEST_F(ConfigHandlerTest, SetConfig) {
 
   ConfigHandler::GetDefaultConfig(&input);
   input.set_incognito_mode(false);
-#ifndef NO_LOGGING
+#ifndef MOZC_NO_LOGGING
   input.set_verbose_level(0);
-#endif  // NO_LOGGING
+#endif  // MOZC_NO_LOGGING
   ConfigHandler::SetMetaData(&input);
   EXPECT_TRUE(ConfigHandler::SetConfig(input));
   output.Clear();
@@ -153,8 +154,8 @@ TEST_F(ConfigHandlerTest, SetImposedConfig) {
   Config input;
   Config output;
 
-  const string config_file = FileUtil::JoinPath(FLAGS_test_tmpdir,
-                                                "mozc_config_test_tmp");
+  const std::string config_file =
+      FileUtil::JoinPath(FLAGS_test_tmpdir, "mozc_config_test_tmp");
   FileUtil::Unlink(config_file);
   ScopedSetConfigFileName scoped_config_file_name(config_file);
   ASSERT_TRUE(ConfigHandler::Reload())
@@ -162,16 +163,16 @@ TEST_F(ConfigHandlerTest, SetImposedConfig) {
 
   struct Testcase {
     bool stored_config_value;
-    enum {DO_NOT_IMPOSE, IMPOSE_TRUE, IMPOSE_FALSE} imposed_config_value;
+    enum { DO_NOT_IMPOSE, IMPOSE_TRUE, IMPOSE_FALSE } imposed_config_value;
     bool expected_value;
   };
   const Testcase kTestcases[] = {
-    {true, Testcase::IMPOSE_TRUE, true},
-    {true, Testcase::IMPOSE_FALSE, false},
-    {false, Testcase::IMPOSE_TRUE, true},
-    {false, Testcase::IMPOSE_FALSE, false},
-    {true, Testcase::DO_NOT_IMPOSE, true},
-    {false, Testcase::DO_NOT_IMPOSE, false},
+      {true, Testcase::IMPOSE_TRUE, true},
+      {true, Testcase::IMPOSE_FALSE, false},
+      {false, Testcase::IMPOSE_TRUE, true},
+      {false, Testcase::IMPOSE_FALSE, false},
+      {true, Testcase::DO_NOT_IMPOSE, true},
+      {false, Testcase::DO_NOT_IMPOSE, false},
   };
 
   for (size_t i = 0; i < arraysize(kTestcases); ++i) {
@@ -186,8 +187,8 @@ TEST_F(ConfigHandlerTest, SetImposedConfig) {
     // Set imposed config.
     input.Clear();
     if (kTestcases[i].imposed_config_value != Testcase::DO_NOT_IMPOSE) {
-      input.set_incognito_mode(
-          kTestcases[i].imposed_config_value == Testcase::IMPOSE_TRUE);
+      input.set_incognito_mode(kTestcases[i].imposed_config_value ==
+                               Testcase::IMPOSE_TRUE);
     }
     ConfigHandler::SetImposedConfig(input);
     // Check post-condition.
@@ -225,10 +226,11 @@ TEST_F(ConfigHandlerTest, SetImposedConfig) {
 }
 
 TEST_F(ConfigHandlerTest, ConfigFileNameConfig) {
-  const string config_file =
-      string("config") + std::to_string(config::CONFIG_VERSION);
+  const std::string config_file =
+      std::string("config") + std::to_string(config::CONFIG_VERSION);
 
-  const string filename = FileUtil::JoinPath(FLAGS_test_tmpdir, config_file);
+  const std::string filename =
+      FileUtil::JoinPath(FLAGS_test_tmpdir, config_file);
   FileUtil::Unlink(filename);
   Config input;
   ConfigHandler::SetConfig(input);
@@ -259,22 +261,22 @@ TEST_F(ConfigHandlerTest, LoadTestConfig) {
   //     the compatibility among variety of config files.
   // TODO(yukawa): Enumerate test data in the directory automatically.
   const char *kDataFiles[] = {
-    "linux_config1.db",
-    "mac_config1.db",
-    "win_config1.db",
+      "linux_config1.db",
+      "mac_config1.db",
+      "win_config1.db",
   };
 
   for (size_t i = 0; i < arraysize(kDataFiles); ++i) {
     const char *file_name = kDataFiles[i];
-    const string &src_path = mozc::testing::GetSourceFileOrDie({
-        "data", "test", "config", file_name});
-    const string &dest_path = FileUtil::JoinPath(
-        SystemUtil::GetUserProfileDirectory(), file_name);
+    const std::string &src_path = mozc::testing::GetSourceFileOrDie(
+        {"data", "test", "config", file_name});
+    const std::string &dest_path =
+        FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(), file_name);
     ASSERT_TRUE(FileUtil::CopyFile(src_path, dest_path))
         << "Copy failed: " << src_path << " to " << dest_path;
 
-    ScopedSetConfigFileName scoped_config_file_name(
-        "user://" + string(file_name));
+    ScopedSetConfigFileName scoped_config_file_name("user://" +
+                                                    std::string(file_name));
     ASSERT_TRUE(ConfigHandler::Reload())
         << "failed to reload: " << ConfigHandler::GetConfigFileName();
 
@@ -301,13 +303,13 @@ TEST_F(ConfigHandlerTest, GetDefaultConfig) {
 
   output.Clear();
   ConfigHandler::GetDefaultConfig(&output);
-#ifdef OS_MACOSX
+#ifdef __APPLE__
   EXPECT_EQ(output.session_keymap(), Config::KOTOERI);
-#elif defined(OS_NACL)  // OS_MACOSX
+#elif defined(OS_NACL)  // __APPLE__
   EXPECT_EQ(output.session_keymap(), Config::CHROMEOS);
-#else  // OS_MACOSX || OS_NACL
+#else                   // __APPLE__ || OS_NACL
   EXPECT_EQ(output.session_keymap(), Config::MSIME);
-#endif  // OS_MACOSX || OS_NACL
+#endif                  // __APPLE__ || OS_NACL
   EXPECT_EQ(output.character_form_rules_size(), 13);
 
   struct TestCase {
@@ -316,29 +318,26 @@ TEST_F(ConfigHandlerTest, GetDefaultConfig) {
     Config::CharacterForm conversion_character_form;
   };
   const TestCase testcases[] = {
-    // "ア"
-    {"ア", Config::FULL_WIDTH, Config::FULL_WIDTH},
-    {"A", Config::FULL_WIDTH, Config::LAST_FORM},
-    {"0", Config::FULL_WIDTH, Config::LAST_FORM},
-    {"(){}[]", Config::FULL_WIDTH, Config::LAST_FORM},
-    {".,", Config::FULL_WIDTH, Config::LAST_FORM},
-    // "。、",
-    {"。、",
-      Config::FULL_WIDTH, Config::FULL_WIDTH},
-    // "・「」"
-    {"・「」",
-      Config::FULL_WIDTH, Config::FULL_WIDTH},
-    {"\"'", Config::FULL_WIDTH, Config::LAST_FORM},
-    {":;", Config::FULL_WIDTH, Config::LAST_FORM},
-    {"#%&@$^_|`\\", Config::FULL_WIDTH, Config::LAST_FORM},
-    {"~", Config::FULL_WIDTH, Config::LAST_FORM},
-    {"<>=+-/*", Config::FULL_WIDTH, Config::LAST_FORM},
-    {"?!", Config::FULL_WIDTH, Config::LAST_FORM},
+      // "ア"
+      {"ア", Config::FULL_WIDTH, Config::FULL_WIDTH},
+      {"A", Config::FULL_WIDTH, Config::LAST_FORM},
+      {"0", Config::FULL_WIDTH, Config::LAST_FORM},
+      {"(){}[]", Config::FULL_WIDTH, Config::LAST_FORM},
+      {".,", Config::FULL_WIDTH, Config::LAST_FORM},
+      // "。、",
+      {"。、", Config::FULL_WIDTH, Config::FULL_WIDTH},
+      // "・「」"
+      {"・「」", Config::FULL_WIDTH, Config::FULL_WIDTH},
+      {"\"'", Config::FULL_WIDTH, Config::LAST_FORM},
+      {":;", Config::FULL_WIDTH, Config::LAST_FORM},
+      {"#%&@$^_|`\\", Config::FULL_WIDTH, Config::LAST_FORM},
+      {"~", Config::FULL_WIDTH, Config::LAST_FORM},
+      {"<>=+-/*", Config::FULL_WIDTH, Config::LAST_FORM},
+      {"?!", Config::FULL_WIDTH, Config::LAST_FORM},
   };
   EXPECT_EQ(output.character_form_rules_size(), arraysize(testcases));
   for (size_t i = 0; i < arraysize(testcases); ++i) {
-    EXPECT_EQ(output.character_form_rules(i).group(),
-              testcases[i].group);
+    EXPECT_EQ(output.character_form_rules(i).group(), testcases[i].group);
     EXPECT_EQ(output.character_form_rules(i).preedit_character_form(),
               testcases[i].preedit_character_form);
     EXPECT_EQ(output.character_form_rules(i).conversion_character_form(),
@@ -354,16 +353,13 @@ TEST_F(ConfigHandlerTest, GetDefaultConfig) {
 TEST_F(ConfigHandlerTest, DefaultConfig) {
   Config config;
   ConfigHandler::GetDefaultConfig(&config);
-  EXPECT_EQ(config.DebugString(),
-            ConfigHandler::DefaultConfig().DebugString());
+  EXPECT_EQ(config.DebugString(), ConfigHandler::DefaultConfig().DebugString());
 }
 
 class SetConfigThread final : public Thread {
  public:
   explicit SetConfigThread(const std::vector<Config> &configs)
-      : quitting_(false),
-        configs_(configs) {
-  }
+      : quitting_(false), configs_(configs) {}
 
   ~SetConfigThread() override {
     quitting_ = true;
@@ -384,8 +380,8 @@ class SetConfigThread final : public Thread {
 };
 
 // Returns concatenated serialized data of |Config::character_form_rules|.
-string ExtractCharacterFormRules(const Config &config) {
-  string rules;
+std::string ExtractCharacterFormRules(const Config &config) {
+  std::string rules;
   for (size_t i = 0; i < config.character_form_rules_size(); ++i) {
     config.character_form_rules(i).AppendToString(&rules);
   }
@@ -395,10 +391,8 @@ string ExtractCharacterFormRules(const Config &config) {
 class GetConfigThread final : public Thread {
  public:
   explicit GetConfigThread(
-      const mozc_hash_set<string> &character_form_rules_set)
-      : quitting_(false),
-        character_form_rules_set_(character_form_rules_set) {
-  }
+      const mozc_hash_set<std::string> &character_form_rules_set)
+      : quitting_(false), character_form_rules_set_(character_form_rules_set) {}
 
   ~GetConfigThread() override {
     quitting_ = true;
@@ -418,10 +412,9 @@ class GetConfigThread final : public Thread {
 
  private:
   std::atomic<bool> quitting_;
-  const mozc_hash_set<string> character_form_rules_set_;
+  const mozc_hash_set<std::string> character_form_rules_set_;
 };
 
-
 TEST_F(ConfigHandlerTest, ConcurrentAccess) {
   std::vector<Config> configs;
 
@@ -470,7 +463,7 @@ TEST_F(ConfigHandlerTest, ConcurrentAccess) {
   // |GeneralConfig|, the returned object from |ConfigHandler::GetConfig()|
   // is not predictable.  Hence we only make sure that
   // |Config::character_form_rules()| is one of expected values.
-  mozc_hash_set<string> character_form_rules_set;
+  mozc_hash_set<std::string> character_form_rules_set;
   for (const auto &config : configs) {
     character_form_rules_set.insert(ExtractCharacterFormRules(config));
   }
@@ -500,8 +493,8 @@ TEST_F(ConfigHandlerTest, ConcurrentAccess) {
     // Set up background threads for concurrent access.
     std::vector<std::unique_ptr<SetConfigThread>> set_threads;
     for (size_t i = 0; i < kNumSetThread; ++i) {
-      set_threads.emplace_back(std::unique_ptr<SetConfigThread>(
-          new SetConfigThread(configs)));
+      set_threads.emplace_back(
+          std::unique_ptr<SetConfigThread>(new SetConfigThread(configs)));
     }
     std::vector<std::unique_ptr<GetConfigThread>> get_threads;
     for (size_t i = 0; i < kNumGetThread; ++i) {
