@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -62,7 +62,7 @@ class CandidateFilter {
   };
 
   // Checks if the candidate should be filtered out.
-  ResultType FilterCandidate(const string &original_key,
+  ResultType FilterCandidate(const std::string &original_key,
                              const Segment::Candidate *candidate,
                              const std::vector<const Node *> &nodes,
                              Segments::RequestType request_type);
@@ -71,7 +71,7 @@ class CandidateFilter {
   void Reset();
 
  private:
-  ResultType FilterCandidateInternal(const string &original_key,
+  ResultType FilterCandidateInternal(const std::string &original_key,
                                      const Segment::Candidate *candidate,
                                      const std::vector<const Node *> &nodes,
                                      Segments::RequestType request_type);
@@ -80,7 +80,7 @@ class CandidateFilter {
   const dictionary::POSMatcher *pos_matcher_;
   const SuggestionFilter *suggestion_filter_;
 
-  std::set<string> seen_;
+  std::set<std::string> seen_;
   const Segment::Candidate *top_candidate_;
   bool apply_suggestion_filter_for_exact_match_;
 
