@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,32 +36,28 @@
 #include "request/conversion_request.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
-void SetSegments(Segments *segments, const string &cand_value) {
+
+void SetSegments(Segments *segments, absl::string_view cand_value) {
   Segment *segment = segments->add_segment();
-  // "Testてすと"
-  segment->set_key("\x54\x65\x73\x74\xe3\x81\xa6\xe3\x81\x99\xe3\x81\xa8");
+  segment->set_key("Testてすと");
   Segment::Candidate *candidate = segment->add_candidate();
-  candidate->value = cand_value;
+  candidate->value = std::string(cand_value);
 
   // Add meta candidates
   Segment::Candidate *meta_cand = segment->add_meta_candidate();
   meta_cand->Init();
   meta_cand->value = "TestT13N";
 }
-}  // namespace
 
-class ConverterMockTest : public testing::Test {
+class ConverterMockTest : public ::testing::Test {
  protected:
-  virtual void SetUp() {
-    mock_.reset(new ConverterMock);
-  }
+  void SetUp() override { mock_.reset(new ConverterMock); }
 
-  ConverterMock *GetMock() {
-    return mock_.get();
-  }
+  ConverterMock *GetMock() { return mock_.get(); }
 
  private:
   std::unique_ptr<ConverterMock> mock_;
@@ -77,8 +73,7 @@ TEST_F(ConverterMockTest, CopySegment) {
   EXPECT_EQ(expect.DebugString(), output.DebugString());
   EXPECT_EQ(1, output.segments_size());
   const Segment &seg = output.segment(0);
-  // "Testてすと"
-  EXPECT_EQ("\x54\x65\x73\x74\xe3\x81\xa6\xe3\x81\x99\xe3\x81\xa8", seg.key());
+  EXPECT_EQ("Testてすと", seg.key());
   EXPECT_EQ(1, seg.candidates_size());
   EXPECT_EQ("StartConvert", seg.candidate(0).value);
   EXPECT_EQ(1, seg.meta_candidates_size());
@@ -245,15 +240,15 @@ TEST_F(ConverterMockTest, GetStartConversion) {
   ConverterInterface *converter = GetMock();
 
   Segments input;
-  const string input_key = "Key";
+  const std::string input_key = "Key";
   SetSegments(&input, "StartConversion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->StartConversion(&input, input_key);
 
   Segments last_segment;
-  string last_key;
+  std::string last_key;
   GetMock()->GetStartConversion(&last_segment, &last_key);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_key, last_key);
@@ -263,15 +258,15 @@ TEST_F(ConverterMockTest, GetStartReverseConversion) {
   ConverterInterface *converter = GetMock();
 
   Segments input;
-  const string input_key = "Key";
+  const std::string input_key = "Key";
   SetSegments(&input, "StartReverseConversion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->StartReverseConversion(&input, input_key);
 
   Segments last_segment;
-  string last_key;
+  std::string last_key;
   GetMock()->GetStartReverseConversion(&last_segment, &last_key);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_key, last_key);
@@ -281,15 +276,15 @@ TEST_F(ConverterMockTest, GetStartPrediction) {
   ConverterInterface *converter = GetMock();
 
   Segments input;
-  const string input_key = "Key";
+  const std::string input_key = "Key";
   SetSegments(&input, "StartPrediction");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->StartPrediction(&input, input_key);
 
   Segments last_segment;
-  string last_key;
+  std::string last_key;
   GetMock()->GetStartPrediction(&last_segment, &last_key);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_key, last_key);
@@ -299,15 +294,15 @@ TEST_F(ConverterMockTest, GetStartSuggestion) {
   ConverterInterface *converter = GetMock();
 
   Segments input;
-  const string input_key = "Key";
+  const std::string input_key = "Key";
   SetSegments(&input, "StartSuggestion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->StartSuggestion(&input, input_key);
 
   Segments last_segment;
-  string last_key;
+  std::string last_key;
   GetMock()->GetStartSuggestion(&last_segment, &last_key);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_key, last_key);
@@ -317,15 +312,15 @@ TEST_F(ConverterMockTest, GetStartPartialPrediction) {
   ConverterInterface *converter = GetMock();
 
   Segments input;
-  const string input_key = "Key";
+  const std::string input_key = "Key";
   SetSegments(&input, "StartPartialPrediction");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->StartPartialPrediction(&input, input_key);
 
   Segments last_segment;
-  string last_key;
+  std::string last_key;
   GetMock()->GetStartPartialPrediction(&last_segment, &last_key);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_key, last_key);
@@ -335,15 +330,15 @@ TEST_F(ConverterMockTest, GetStartPartialSuggestion) {
   ConverterInterface *converter = GetMock();
 
   Segments input;
-  const string input_key = "Key";
+  const std::string input_key = "Key";
   SetSegments(&input, "StartPartialSuggestion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->StartPartialSuggestion(&input, input_key);
 
   Segments last_segment;
-  string last_key;
+  std::string last_key;
   GetMock()->GetStartPartialSuggestion(&last_segment, &last_key);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_key, last_key);
@@ -354,13 +349,13 @@ TEST_F(ConverterMockTest, GetFinishConversion) {
 
   Segments input;
   SetSegments(&input, "FinishConversion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   ConversionRequest default_request;
   converter->FinishConversion(default_request, &input);
 
   Segments last_segment;
   GetMock()->GetFinishConversion(&last_segment);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
 }
@@ -370,12 +365,12 @@ TEST_F(ConverterMockTest, GetCancelConversion) {
 
   Segments input;
   SetSegments(&input, "CancelConversion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->CancelConversion(&input);
 
   Segments last_segment;
   GetMock()->GetCancelConversion(&last_segment);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
 }
@@ -385,12 +380,12 @@ TEST_F(ConverterMockTest, GetResetConversion) {
 
   Segments input;
   SetSegments(&input, "ResetConversion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->ResetConversion(&input);
 
   Segments last_segment;
   GetMock()->GetResetConversion(&last_segment);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
 }
@@ -402,14 +397,14 @@ TEST_F(ConverterMockTest, GetCommitSegmentValue) {
   size_t input_idx = 1;
   int input_cidx = 5;
   SetSegments(&input, "CommitSegmentValue");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->CommitSegmentValue(&input, input_idx, input_cidx);
 
   Segments last_segment;
   size_t last_idx;
   int last_cidx;
   GetMock()->GetCommitSegmentValue(&last_segment, &last_idx, &last_cidx);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_idx, last_idx);
@@ -423,14 +418,14 @@ TEST_F(ConverterMockTest, GetFocusSegmentValue) {
   size_t input_idx = 1;
   int input_cidx = 5;
   SetSegments(&input, "FocueSegmentValue");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->FocusSegmentValue(&input, input_idx, input_cidx);
 
   Segments last_segment;
   size_t last_idx;
   int last_cidx;
   GetMock()->GetFocusSegmentValue(&last_segment, &last_idx, &last_cidx);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_idx, last_idx);
@@ -443,13 +438,13 @@ TEST_F(ConverterMockTest, GetFreeSegmentValue) {
   Segments input;
   size_t input_idx = 1;
   SetSegments(&input, "FreeSegmentValue");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   converter->FreeSegmentValue(&input, input_idx);
 
   Segments last_segment;
   size_t last_idx;
   GetMock()->GetFreeSegmentValue(&last_segment, &last_idx);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_idx, last_idx);
@@ -462,7 +457,7 @@ TEST_F(ConverterMockTest, GetCommitSegments) {
   size_t input_idx1 = 1;
   size_t input_idx2 = 2;
   SetSegments(&input, "CommitSegments");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   std::vector<size_t> index_list;
   index_list.push_back(input_idx1);
   index_list.push_back(input_idx2);
@@ -471,7 +466,7 @@ TEST_F(ConverterMockTest, GetCommitSegments) {
   Segments last_segment;
   std::vector<size_t> last_idx;
   GetMock()->GetCommitSegments(&last_segment, &last_idx);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_idx1, last_idx[0]);
@@ -485,16 +480,15 @@ TEST_F(ConverterMockTest, GetResizeSegment1) {
   size_t input_idx = 1;
   int input_offset = 3;
   SetSegments(&input, "ResizeSegment1");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   const ConversionRequest default_request;
-  converter->ResizeSegment(
-      &input, default_request, input_idx, input_offset);
+  converter->ResizeSegment(&input, default_request, input_idx, input_offset);
 
   Segments last_segment;
   size_t last_idx;
   int last_offset;
   GetMock()->GetResizeSegment1(&last_segment, &last_idx, &last_offset);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_idx, last_idx);
@@ -508,7 +502,7 @@ TEST_F(ConverterMockTest, GetResizeSegment2) {
   size_t input_idx = 1, input_size = 3;
   uint8 input_array[] = {1, 2, 3};
   SetSegments(&input, "ResizeSegment2");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   const ConversionRequest default_request;
   converter->ResizeSegment(&input, default_request, input_idx, input_size,
                            input_array, arraysize(input_array));
@@ -520,7 +514,7 @@ TEST_F(ConverterMockTest, GetResizeSegment2) {
 
   GetMock()->GetResizeSegment2(&last_segment, &last_idx, &last_size,
                                &last_array, &last_array_size);
-  const string last_segment_str = last_segment.DebugString();
+  const std::string last_segment_str = last_segment.DebugString();
 
   EXPECT_EQ(input_str, last_segment_str);
   EXPECT_EQ(input_idx, last_idx);
@@ -535,13 +529,14 @@ TEST_F(ConverterMockTest, DefaultBehavior) {
   ConverterInterface *converter = GetMock();
 
   Segments input;
-  const string input_key = "Key";
+  const std::string input_key = "Key";
   SetSegments(&input, "StartConversion");
-  const string input_str = input.DebugString();
+  const std::string input_str = input.DebugString();
   EXPECT_FALSE(converter->StartConversion(&input, input_key));
 
-  const string last_str = input.DebugString();
+  const std::string last_str = input.DebugString();
   EXPECT_EQ(input_str, last_str);
 }
 
+}  // namespace
 }  // namespace mozc
