@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,8 +33,8 @@
 
 namespace mozc {
 
-void ConverterUtil::InitSegmentsFromString(const string &key,
-                                           const string &preedit,
+void ConverterUtil::InitSegmentsFromString(const std::string &key,
+                                           const std::string &preedit,
                                            Segments *segments) {
   segments->clear_conversion_segments();
   // the request mode is CONVERSION, as the user experience
