@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,28 +30,32 @@
 #include "converter/segments.h"
 
 #include <algorithm>
+#include <limits>
 #include <sstream>  // For DebugString()
 #include <string>
 
 #include "base/logging.h"
 #include "base/util.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
 const size_t kMaxHistorySize = 32;
 const size_t kMaxConversionCandidatesSize = 200;
+}  // namespace
+
+absl::string_view Segment::Candidate::functional_key() const {
+  return key.size() <= content_key.size()
+             ? absl::string_view()
+             : absl::string_view(key.data() + content_key.size(),
+                                 key.size() - content_key.size());
 }
 
-StringPiece Segment::Candidate::functional_key() const {
-  return key.size() <= content_key.size() ?
-      StringPiece() : StringPiece(key.data() + content_key.size(),
-                                  key.size() - content_key.size());
-}
-
-StringPiece Segment::Candidate::functional_value() const {
-  return value.size() <= content_value.size() ?
-      StringPiece() : StringPiece(value.data() + content_value.size(),
-                                  value.size() - content_value.size());
+absl::string_view Segment::Candidate::functional_value() const {
+  return value.size() <= content_value.size()
+             ? absl::string_view()
+             : absl::string_view(value.data() + content_value.size(),
+                                 value.size() - content_value.size());
 }
 
 void Segment::Candidate::CopyFrom(const Candidate &src) {
@@ -100,8 +104,7 @@ bool Segment::Candidate::IsValid() const {
     sum_content_key_len += iter.GetContentKey().size();
     sum_content_value_len += iter.GetContentValue().size();
   }
-  if (sum_key_len != key.size() ||
-      sum_value_len != value.size() ||
+  if (sum_key_len != key.size() || sum_value_len != value.size() ||
       sum_content_key_len != content_key.size() ||
       sum_content_value_len != content_value.size()) {
     return false;
@@ -109,11 +112,14 @@ bool Segment::Candidate::IsValid() const {
   return true;
 }
 
-bool Segment::Candidate::EncodeLengths(
-    size_t key_len, size_t value_len,
-    size_t content_key_len, size_t content_value_len, uint32 *result) {
-  if (key_len > kuint8max || value_len > kuint8max ||
-      content_key_len > kuint8max || content_value_len > kuint8max) {
+bool Segment::Candidate::EncodeLengths(size_t key_len, size_t value_len,
+                                       size_t content_key_len,
+                                       size_t content_value_len,
+                                       uint32 *result) {
+  if (key_len > std::numeric_limits<uint8>::max() ||
+      value_len > std::numeric_limits<uint8>::max() ||
+      content_key_len > std::numeric_limits<uint8>::max() ||
+      content_value_len > std::numeric_limits<uint8>::max()) {
     return false;
   }
   *result = (static_cast<uint32>(key_len) << 24) |
@@ -124,8 +130,8 @@ bool Segment::Candidate::EncodeLengths(
 }
 
 bool Segment::Candidate::PushBackInnerSegmentBoundary(
-    size_t key_len, size_t value_len,
-    size_t content_key_len, size_t content_value_len) {
+    size_t key_len, size_t value_len, size_t content_key_len,
+    size_t content_value_len) {
   uint32 encoded;
   if (EncodeLengths(key_len, value_len, content_key_len, content_value_len,
                     &encoded)) {
@@ -135,18 +141,12 @@ bool Segment::Candidate::PushBackInnerSegmentBoundary(
   return false;
 }
 
-string Segment::Candidate::DebugString() const {
+std::string Segment::Candidate::DebugString() const {
   std::stringstream os;
-  os << "(key=" << key
-     << " ckey=" << content_key
-     << " val=" << value
-     << " cval=" << content_value
-     << " cost=" << cost
-     << " scost=" << structure_cost
-     << " wcost=" << wcost
-     << " lid=" << lid
-     << " rid=" << rid
-     << " attributes=" << attributes
+  os << "(key=" << key << " ckey=" << content_key << " val=" << value
+     << " cval=" << content_value << " cost=" << cost
+     << " scost=" << structure_cost << " wcost=" << wcost << " lid=" << lid
+     << " rid=" << rid << " attributes=" << attributes
      << " consumed_key_size=" << consumed_key_size;
   if (!prefix.empty()) {
     os << " prefix=" << prefix;
@@ -180,56 +180,60 @@ void Segment::Candidate::InnerSegmentIterator::Next() {
   value_offset_ += (encoded_lengths >> 16) & 0xff;
 }
 
-StringPiece Segment::Candidate::InnerSegmentIterator::GetKey() const {
+absl::string_view Segment::Candidate::InnerSegmentIterator::GetKey() const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
   const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
-  return StringPiece(key_offset_, encoded_lengths >> 24);
+  return absl::string_view(key_offset_, encoded_lengths >> 24);
 }
 
-StringPiece Segment::Candidate::InnerSegmentIterator::GetValue() const {
+absl::string_view Segment::Candidate::InnerSegmentIterator::GetValue() const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
   const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
-  return StringPiece(value_offset_, (encoded_lengths >> 16) & 0xff);
+  return absl::string_view(value_offset_, (encoded_lengths >> 16) & 0xff);
 }
 
-StringPiece Segment::Candidate::InnerSegmentIterator::GetContentKey() const {
+absl::string_view Segment::Candidate::InnerSegmentIterator::GetContentKey()
+    const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
   const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
-  return StringPiece(key_offset_, (encoded_lengths >> 8) & 0xff);
+  return absl::string_view(key_offset_, (encoded_lengths >> 8) & 0xff);
 }
 
-StringPiece Segment::Candidate::InnerSegmentIterator::GetContentValue() const {
+absl::string_view Segment::Candidate::InnerSegmentIterator::GetContentValue()
+    const {
   DCHECK_LT(index_, candidate_->inner_segment_boundary.size());
   const uint32 encoded_lengths = candidate_->inner_segment_boundary[index_];
-  return StringPiece(value_offset_, encoded_lengths & 0xff);
+  return absl::string_view(value_offset_, encoded_lengths & 0xff);
 }
 
 Segment::Segment()
-    : segment_type_(FREE),
-      pool_(new ObjectPool<Candidate>(16)) {}
+    : segment_type_(FREE), pool_(new ObjectPool<Candidate>(16)) {}
 
 Segment::~Segment() {}
 
-Segment::SegmentType Segment::segment_type() const {
-  return segment_type_;
-}
+Segment::SegmentType Segment::segment_type() const { return segment_type_; }
 
-void Segment::set_segment_type(
-    const Segment::SegmentType &segment_type) {
+void Segment::set_segment_type(const Segment::SegmentType &segment_type) {
   segment_type_ = segment_type;
 }
 
-const string& Segment::key() const {
-  return key_;
+const std::string &Segment::key() const { return key_; }
+
+void Segment::set_key(absl::string_view key) {
+  key_.assign(key.data(), key.size());
 }
 
-void Segment::set_key(const string &key) {
-  key_ = key;
+bool Segment::is_valid_index(int i) const {
+  if (i < 0) {
+    return (-i - 1 < meta_candidates_.size());
+  } else {
+    return (i < candidates_.size());
+  }
 }
 
 const Segment::Candidate &Segment::candidate(int i) const {
   if (i < 0) {
-    return meta_candidate(-i-1);
+    return meta_candidate(-i - 1);
   }
   DCHECK(i < candidates_.size());
   return *candidates_[i];
@@ -237,7 +241,7 @@ const Segment::Candidate &Segment::candidate(int i) const {
 
 Segment::Candidate *Segment::mutable_candidate(int i) {
   if (i < 0) {
-    const size_t meta_index = -i-1;
+    const size_t meta_index = -i - 1;
     DCHECK_LT(meta_index, meta_candidates_.size());
     return &meta_candidates_[meta_index];
   }
@@ -246,7 +250,7 @@ Segment::Candidate *Segment::mutable_candidate(int i) {
 }
 
 int Segment::indexOf(const Segment::Candidate *candidate) {
-  if (candidate == NULL) {
+  if (candidate == nullptr) {
     return static_cast<int>(candidates_size());
   }
 
@@ -258,16 +262,14 @@ int Segment::indexOf(const Segment::Candidate *candidate) {
 
   for (int i = 0; i < static_cast<int>(meta_candidates_.size()); ++i) {
     if (&(meta_candidates_[i]) == candidate) {
-      return -i-1;
+      return -i - 1;
     }
   }
 
   return static_cast<int>(candidates_size());
 }
 
-size_t Segment::candidates_size() const {
-  return candidates_.size();
-}
+size_t Segment::candidates_size() const { return candidates_.size(); }
 
 void Segment::clear_candidates() {
   pool_->Free();
@@ -288,19 +290,17 @@ Segment::Candidate *Segment::push_front_candidate() {
   return candidate;
 }
 
-Segment::Candidate *Segment::add_candidate() {
-  return push_back_candidate();
-}
+Segment::Candidate *Segment::add_candidate() { return push_back_candidate(); }
 
 Segment::Candidate *Segment::insert_candidate(int i) {
   if (i < 0) {
-    LOG(WARNING) << "Invalid insert position [negative]: "
-                 << i << " / " << candidates_.size();
+    LOG(WARNING) << "Invalid insert position [negative]: " << i << " / "
+                 << candidates_.size();
     return nullptr;
   }
   if (i > static_cast<int>(candidates_.size())) {
-    LOG(DFATAL) << "Invalid insert position [out of bounds]: "
-                << i << " / " << candidates_.size();
+    LOG(DFATAL) << "Invalid insert position [out of bounds]: " << i << " / "
+                << candidates_.size();
     i = static_cast<int>(candidates_.size());
   }
   Candidate *candidate = pool_->Alloc();
@@ -336,8 +336,7 @@ void Segment::erase_candidate(int i) {
 
 void Segment::erase_candidates(int i, size_t size) {
   const size_t end = i + size;
-  if (i < 0 ||
-      i >= static_cast<int>(candidates_size()) ||
+  if (i < 0 || i >= static_cast<int>(candidates_size()) ||
       end > candidates_size()) {
     LOG(WARNING) << "invalid index";
     return;
@@ -345,17 +344,12 @@ void Segment::erase_candidates(int i, size_t size) {
   for (int j = i; j < static_cast<int>(end); ++j) {
     pool_->Release(mutable_candidate(j));
   }
-  candidates_.erase(candidates_.begin() + i,
-                    candidates_.begin() + end);
+  candidates_.erase(candidates_.begin() + i, candidates_.begin() + end);
 }
 
-size_t Segment::meta_candidates_size() const {
-  return meta_candidates_.size();
-}
+size_t Segment::meta_candidates_size() const { return meta_candidates_.size(); }
 
-void Segment::clear_meta_candidates() {
-  meta_candidates_.clear();
-}
+void Segment::clear_meta_candidates() { meta_candidates_.clear(); }
 
 const std::vector<Segment::Candidate> &Segment::meta_candidates() const {
   return meta_candidates_;
@@ -385,13 +379,13 @@ Segment::Candidate *Segment::add_meta_candidate() {
   Candidate candidate;
   candidate.Init();
   meta_candidates_.push_back(candidate);
-  return &meta_candidates_[meta_candidates_size()-1];
+  return &meta_candidates_[meta_candidates_size() - 1];
 }
 
 void Segment::move_candidate(int old_idx, int new_idx) {
   // meta candidates
   if (old_idx < 0) {
-    const int meta_idx = -old_idx-1;
+    const int meta_idx = -old_idx - 1;
     DCHECK_LT(meta_idx, meta_candidates_size());
     Candidate *c = insert_candidate(new_idx);
     *c = meta_candidates_[meta_idx];
@@ -412,7 +406,7 @@ void Segment::move_candidate(int old_idx, int new_idx) {
     candidates_[new_idx] = c;
   } else {  // demotion
     Candidate *c = candidates_[old_idx];
-    for (int i = old_idx; i <  new_idx; ++i) {
+    for (int i = old_idx; i < new_idx; ++i) {
       candidates_[i] = candidates_[i + 1];
     }
     candidates_[new_idx] = c;
@@ -443,11 +437,10 @@ void Segment::CopyFrom(const Segment &src) {
   }
 }
 
-string Segment::DebugString() const {
+std::string Segment::DebugString() const {
   std::stringstream os;
   os << "[segtype=" << segment_type() << " key=" << key() << std::endl;
-  const int size =
-      static_cast<int>(candidates_size() + meta_candidates_size());
+  const int size = static_cast<int>(candidates_size() + meta_candidates_size());
   for (int l = 0; l < size; ++l) {
     int j = 0;
     if (l < meta_candidates_size()) {
@@ -469,20 +462,18 @@ void Segments::RevertEntry::CopyFrom(const RevertEntry &src) {
 }
 
 Segments::Segments()
-  : max_history_segments_size_(0),
-    max_prediction_candidates_size_(0),
-    max_conversion_candidates_size_(kMaxConversionCandidatesSize),
-    resized_(false),
-    user_history_enabled_(true),
-    request_type_(Segments::CONVERSION),
-    pool_(new ObjectPool<Segment>(32)),
-    cached_lattice_(new Lattice()) {}
+    : max_history_segments_size_(0),
+      max_prediction_candidates_size_(0),
+      max_conversion_candidates_size_(kMaxConversionCandidatesSize),
+      resized_(false),
+      user_history_enabled_(true),
+      request_type_(Segments::CONVERSION),
+      pool_(new ObjectPool<Segment>(32)),
+      cached_lattice_(new Lattice()) {}
 
 Segments::~Segments() {}
 
-Segments::RequestType Segments::request_type() const {
-  return request_type_;
-}
+Segments::RequestType Segments::request_type() const { return request_type_; }
 
 void Segments::set_request_type(Segments::RequestType request_type) {
   request_type_ = request_type;
@@ -492,25 +483,17 @@ void Segments::set_user_history_enabled(bool user_history_enabled) {
   user_history_enabled_ = user_history_enabled;
 }
 
-bool Segments::user_history_enabled() const {
-  return user_history_enabled_;
-}
+bool Segments::user_history_enabled() const { return user_history_enabled_; }
 
-const Segment &Segments::segment(size_t i) const {
-  return *segments_[i];
-}
+const Segment &Segments::segment(size_t i) const { return *segments_[i]; }
 
-Segment *Segments::mutable_segment(size_t i) {
-  return segments_[i];
-}
+Segment *Segments::mutable_segment(size_t i) { return segments_[i]; }
 
 const Segment &Segments::history_segment(size_t i) const {
   return *segments_[i];
 }
 
-Segment *Segments::mutable_history_segment(size_t i) {
-  return segments_[i];
-}
+Segment *Segments::mutable_history_segment(size_t i) { return segments_[i]; }
 
 const Segment &Segments::conversion_segment(size_t i) const {
   return *segments_[i + history_segments_size()];
@@ -520,9 +503,7 @@ Segment *Segments::mutable_conversion_segment(size_t i) {
   return segments_[i + history_segments_size()];
 }
 
-Segment *Segments::add_segment() {
-  return push_back_segment();
-}
+Segment *Segments::add_segment() { return push_back_segment(); }
 
 Segment *Segments::insert_segment(size_t i) {
   Segment *segment = pool_->Alloc();
@@ -545,9 +526,7 @@ Segment *Segments::push_front_segment() {
   return segment;
 }
 
-size_t Segments::segments_size() const {
-  return segments_.size();
-}
+size_t Segments::segments_size() const { return segments_.size(); }
 
 size_t Segments::history_segments_size() const {
   size_t result = 0;
@@ -578,11 +557,10 @@ void Segments::erase_segments(size_t i, size_t size) {
   if (i >= segments_size() || end > segments_size()) {
     return;
   }
-  for (size_t j = i ; j < end; ++j) {
+  for (size_t j = i; j < end; ++j) {
     pool_->Release(mutable_segment(j));
   }
-  segments_.erase(segments_.begin() + i,
-                  segments_.begin() + end);
+  segments_.erase(segments_.begin() + i, segments_.begin() + end);
 }
 
 void Segments::pop_front_segment() {
@@ -663,13 +641,9 @@ void Segments::set_max_history_segments_size(size_t max_history_segments_size) {
                std::min(max_history_segments_size, kMaxHistorySize));
 }
 
-void Segments::set_resized(bool resized) {
-  resized_ = resized;
-}
+void Segments::set_resized(bool resized) { resized_ = resized; }
 
-bool Segments::resized() const {
-  return resized_;
-}
+bool Segments::resized() const { return resized_; }
 
 size_t Segments::max_prediction_candidates_size() const {
   return max_prediction_candidates_size_;
@@ -687,13 +661,9 @@ void Segments::set_max_conversion_candidates_size(size_t size) {
   max_conversion_candidates_size_ = size;
 }
 
-void Segments::clear_revert_entries() {
-  revert_entries_.clear();
-}
+void Segments::clear_revert_entries() { revert_entries_.clear(); }
 
-size_t Segments::revert_entries_size() const {
-  return revert_entries_.size();
-}
+size_t Segments::revert_entries_size() const { return revert_entries_.size(); }
 
 Segments::RevertEntry *Segments::push_back_revert_entry() {
   revert_entries_.resize(revert_entries_.size() + 1);
@@ -713,11 +683,9 @@ Segments::RevertEntry *Segments::mutable_revert_entry(size_t i) {
   return &revert_entries_[i];
 }
 
-Lattice *Segments::mutable_cached_lattice() {
-  return cached_lattice_.get();
-}
+Lattice *Segments::mutable_cached_lattice() { return cached_lattice_.get(); }
 
-string Segments::DebugString() const {
+std::string Segments::DebugString() const {
   std::stringstream os;
   os << "{" << std::endl;
   for (size_t i = 0; i < segments_size(); ++i) {
