@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,7 @@ namespace mozc {
 // }
 class ConnectionFileReader {
  public:
-  explicit ConnectionFileReader(const string &filename);
+  explicit ConnectionFileReader(const std::string &filename);
   ~ConnectionFileReader();
 
   bool done() const { return done_; }
