@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,22 +36,22 @@
 #include "base/port.h"
 #include "base/unverified_sha1.h"
 #include "base/util.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace {
 
-bool IsValidAlignment(int a) {
-  return a == 8 || a == 16 || a == 32 || a == 64;
-}
+bool IsValidAlignment(int a) { return a == 8 || a == 16 || a == 32 || a == 64; }
 
 }  // namespace
 
-DataSetWriter::DataSetWriter(StringPiece magic)
+DataSetWriter::DataSetWriter(absl::string_view magic)
     : image_(magic.data(), magic.size()) {}
 
 DataSetWriter::~DataSetWriter() = default;
 
-void DataSetWriter::Add(const string &name, int alignment, StringPiece data) {
+void DataSetWriter::Add(const string &name, int alignment,
+                        absl::string_view data) {
   CHECK(seen_names_.insert(name).second) << name << " was already added";
   AppendPadding(alignment);
   DataSetMetadata::Entry *entry = metadata_.add_entries();
@@ -71,7 +71,7 @@ void DataSetWriter::AddFile(const string &name, int alignment,
 
 void DataSetWriter::Finish(std::ostream *output) {
   const string s = metadata_.SerializeAsString();
-  image_.append(s);  // Metadata
+  image_.append(s);                                // Metadata
   image_.append(Util::SerializeUint64(s.size()));  // Metadata size
 
   // SHA1 checksum
