@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,11 +39,11 @@ namespace {
 
 #include "data_manager/testing/segmenter_inl.inc"
 
-std::pair<string, string> GetTypingModelEntry(const string &fname) {
-  return std::pair<string, string>(
-      fname,
-      mozc::testing::GetSourceFileOrDie(
-          {"data_manager", "testing", fname + ".data"}));
+std::pair<std::string, std::string> GetTypingModelEntry(
+    const std::string &fname) {
+  return std::pair<std::string, std::string>(
+      fname, mozc::testing::GetSourceFileOrDie(
+                 {"data_manager", "testing", fname + ".data"}));
 }
 
 }  // namespace
@@ -52,19 +52,14 @@ class MockDataManagerTest : public DataManagerTestBase {
  protected:
   MockDataManagerTest()
       : DataManagerTestBase(
-            new MockDataManager,
-            kLSize,
-            kRSize,
-            IsBoundaryInternal,
+            new MockDataManager, kLSize, kRSize, IsBoundaryInternal,
             mozc::testing::GetSourceFileOrDie(
                 {"data_manager", "testing", "connection_single_column.txt"}),
             1,
             mozc::testing::GetSourceFilesInDirOrDie(
-                {"data", "test", "dictionary"},
-                {"dictionary.txt"}),
+                {"data", "test", "dictionary"}, {"dictionary.txt"}),
             mozc::testing::GetSourceFilesInDirOrDie(
-                {"data", "test", "dictionary"},
-                {"suggestion_filter.txt"}),
+                {"data", "test", "dictionary"}, {"suggestion_filter.txt"}),
             {
                 GetTypingModelEntry("typing_model_12keys-hiragana.tsv"),
                 GetTypingModelEntry("typing_model_flick-hiragana.tsv"),
@@ -74,9 +69,7 @@ class MockDataManagerTest : public DataManagerTestBase {
             }) {}
 };
 
-TEST_F(MockDataManagerTest, AllTests) {
-  RunAllTests();
-}
+TEST_F(MockDataManagerTest, AllTests) { RunAllTests(); }
 
 }  // namespace testing
 }  // namespace mozc
