@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -40,6 +40,7 @@
 #include "dictionary/file/section.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace dictionary {
@@ -51,20 +52,18 @@ class CodecTest : public ::testing::Test {
 
  protected:
   void SetUp() override {
-    DictionaryFileCodecFactory::SetCodec(NULL);
+    DictionaryFileCodecFactory::SetCodec(nullptr);
     FileUtil::Unlink(test_file_);
   }
 
   void TearDown() override {
     // Reset to default setting
-    DictionaryFileCodecFactory::SetCodec(NULL);
+    DictionaryFileCodecFactory::SetCodec(nullptr);
     FileUtil::Unlink(test_file_);
   }
 
   void AddSection(const DictionaryFileCodecInterface *codec,
-                  const string &name,
-                  const char *ptr,
-                  int len,
+                  const std::string &name, const char *ptr, int len,
                   std::vector<DictionaryFileSection> *sections) const {
     CHECK(codec);
     CHECK(sections);
@@ -74,11 +73,10 @@ class CodecTest : public ::testing::Test {
 
   bool FindSection(const DictionaryFileCodecInterface *codec,
                    const std::vector<DictionaryFileSection> &sections,
-                   const string &name,
-                   int *index) const {
+                   const std::string &name, int *index) const {
     CHECK(codec);
     CHECK(index);
-    const string name_find = codec->GetSectionName(name);
+    const std::string name_find = codec->GetSectionName(name);
     for (size_t i = 0; i < sections.size(); ++i) {
       if (sections[i].name == name_find) {
         *index = i;
@@ -89,40 +87,40 @@ class CodecTest : public ::testing::Test {
   }
 
   bool CheckValue(const DictionaryFileSection &section,
-                  const string &expected) const {
-    const string value = string(section.ptr, section.len);
+                  const std::string &expected) const {
+    const std::string value(section.ptr, section.len);
     return (expected == value);
   }
 
-  const string test_file_;
+  const std::string test_file_;
 };
 
 class CodecMock : public DictionaryFileCodecInterface {
  public:
-  virtual void WriteSections(const std::vector<DictionaryFileSection> &sections,
-                             std::ostream *ofs) const {
-    const string value = "dummy value";
+  void WriteSections(const std::vector<DictionaryFileSection> &sections,
+                     std::ostream *ofs) const override {
+    const std::string value = "dummy value";
     ofs->write(value.data(), value.size());
   }
 
-  virtual bool ReadSections(
+  mozc::Status ReadSections(
       const char *image, int length,
-      std::vector<DictionaryFileSection> *sections) const {
-    sections->push_back(DictionaryFileSection(NULL, 0, "dummy name"));
-    return true;
+      std::vector<DictionaryFileSection> *sections) const override {
+    sections->emplace_back(nullptr, 0, "dummy name");
+    return mozc::Status();
   }
 
-  virtual string GetSectionName(const string &name) const {
+  std::string GetSectionName(const std::string &name) const override {
     return "dummy section name";
   }
 };
 
 TEST_F(CodecTest, FactoryTest) {
-  std::unique_ptr<CodecMock> codec_mock(new CodecMock);
+  auto codec_mock = absl::make_unique<CodecMock>();
   DictionaryFileCodecFactory::SetCodec(codec_mock.get());
   const DictionaryFileCodecInterface *codec =
       DictionaryFileCodecFactory::GetCodec();
-  EXPECT_TRUE(codec != NULL);
+  EXPECT_TRUE(codec != nullptr);
   std::vector<DictionaryFileSection> sections;
   {
     OutputFileStream ofs;
@@ -138,87 +136,84 @@ TEST_F(CodecTest, FactoryTest) {
     ifs.seekg(0, std::ios::beg);
     char buf[64];
     ifs.read(buf, len);
-    EXPECT_EQ("dummy value", string(buf, len));
+    EXPECT_EQ("dummy value", std::string(buf, len));
   }
   {
     EXPECT_EQ(0, sections.size());
-    EXPECT_TRUE(codec->ReadSections(NULL, 0, &sections));
+    EXPECT_TRUE(codec->ReadSections(nullptr, 0, &sections).ok());
     EXPECT_EQ(1, sections.size());
     EXPECT_EQ("dummy name", sections[0].name);
   }
-  {
-    EXPECT_EQ("dummy section name", codec->GetSectionName("test"));
-  }
+  { EXPECT_EQ("dummy section name", codec->GetSectionName("test")); }
 }
 
 TEST_F(CodecTest, DefaultTest) {
   const DictionaryFileCodecInterface *codec =
       DictionaryFileCodecFactory::GetCodec();
-  EXPECT_TRUE(codec != NULL);
+  EXPECT_TRUE(codec != nullptr);
   {
     std::vector<DictionaryFileSection> write_sections;
-    const string value0 = "Value 0 test";
+    const std::string value0 = "Value 0 test";
     AddSection(codec, "Section 0", value0.data(), value0.size(),
                &write_sections);
-    const string value1 = "Value 1 test test";
+    const std::string value1 = "Value 1 test test";
     AddSection(codec, "Section 1", value1.data(), value1.size(),
                &write_sections);
     OutputFileStream ofs;
     ofs.open(test_file_.c_str(), std::ios_base::out | std::ios_base::binary);
     codec->WriteSections(write_sections, &ofs);
   }
-  char buf[1024] = {};  // sections will reference this buffer.
+  std::string buf;  // sections will reference this buffer.
   std::vector<DictionaryFileSection> sections;
-  {
-    EXPECT_TRUE(FileUtil::FileExists(test_file_));
-    InputFileStream ifs;
-    ifs.open(test_file_.c_str(), std::ios_base::in | std::ios_base::binary);
-    ifs.read(buf, 1024);
-    EXPECT_TRUE(codec->ReadSections(buf, 1024, &sections));
-  }
-  EXPECT_EQ(2, sections.size());
+  ASSERT_TRUE(FileUtil::FileExists(test_file_));
+  buf = InputFileStream(test_file_.c_str(),
+                        std::ios_base::in | std::ios_base::binary)
+            .Read();
+  ASSERT_TRUE(codec->ReadSections(buf.data(), buf.size(), &sections).ok());
+  ASSERT_EQ(2, sections.size());
   int index = -1;
-  EXPECT_TRUE(FindSection(codec, sections, "Section 0", &index));
+  ASSERT_TRUE(FindSection(codec, sections, "Section 0", &index));
+  ASSERT_EQ(0, index);
   EXPECT_TRUE(CheckValue(sections[index], "Value 0 test"));
 
-  EXPECT_TRUE(FindSection(codec, sections, "Section 1", &index));
+  ASSERT_TRUE(FindSection(codec, sections, "Section 1", &index));
+  ASSERT_EQ(1, index);
   EXPECT_TRUE(CheckValue(sections[index], "Value 1 test test"));
 }
 
 TEST_F(CodecTest, RandomizedCodecTest) {
-  std::unique_ptr<DictionaryFileCodec> internal_codec(
-      new DictionaryFileCodec);
+  auto internal_codec = absl::make_unique<DictionaryFileCodec>();
   DictionaryFileCodecFactory::SetCodec(internal_codec.get());
   const DictionaryFileCodecInterface *codec =
       DictionaryFileCodecFactory::GetCodec();
-  EXPECT_TRUE(codec != NULL);
+  EXPECT_TRUE(codec != nullptr);
   {
     std::vector<DictionaryFileSection> write_sections;
-    const string value0 = "Value 0 test";
+    const std::string value0 = "Value 0 test";
     AddSection(codec, "Section 0", value0.data(), value0.size(),
                &write_sections);
-    const string value1 = "Value 1 test test";
+    const std::string value1 = "Value 1 test test";
     AddSection(codec, "Section 1", value1.data(), value1.size(),
                &write_sections);
     OutputFileStream ofs;
     ofs.open(test_file_.c_str(), std::ios_base::out | std::ios_base::binary);
     codec->WriteSections(write_sections, &ofs);
   }
-  char buf[1024] = {};  // sections will reference this buffer.
+  std::string buf;  // sections will reference this buffer.
   std::vector<DictionaryFileSection> sections;
-  {
-    EXPECT_TRUE(FileUtil::FileExists(test_file_));
-    InputFileStream ifs;
-    ifs.open(test_file_.c_str(), std::ios_base::in | std::ios_base::binary);
-    ifs.read(buf, 1024);
-    EXPECT_TRUE(codec->ReadSections(buf, 1024, &sections));
-  }
-  EXPECT_EQ(2, sections.size());
+  ASSERT_TRUE(FileUtil::FileExists(test_file_));
+  buf = InputFileStream(test_file_.c_str(),
+                        std::ios_base::in | std::ios_base::binary)
+            .Read();
+  ASSERT_TRUE(codec->ReadSections(buf.data(), buf.size(), &sections).ok());
+  ASSERT_EQ(2, sections.size());
   int index = -1;
-  EXPECT_TRUE(FindSection(codec, sections, "Section 0", &index));
+  ASSERT_TRUE(FindSection(codec, sections, "Section 0", &index));
+  ASSERT_EQ(0, index);
   EXPECT_TRUE(CheckValue(sections[index], "Value 0 test"));
 
-  EXPECT_TRUE(FindSection(codec, sections, "Section 1", &index));
+  ASSERT_TRUE(FindSection(codec, sections, "Section 1", &index));
+  ASSERT_EQ(1, index);
   EXPECT_TRUE(CheckValue(sections[index], "Value 1 test test"));
 }
 
