@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2010-2018, Google Inc.
+# Copyright 2010-2020, Google Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -31,10 +31,11 @@
 """A script to generate a C++ header file for the POS conversion map.
 """
 
-__author__ = "keni"
-
+from __future__ import absolute_import
+import codecs
 import optparse
-import sys
+
+import six  # pylint: disable=g-import-not-at-top
 
 from build_tools import code_generator_util
 
@@ -53,8 +54,9 @@ FOOTER = """};
 #endif  // MOZC_DICTIONARY_POS_MAP_H_
 """
 
+
 def ParseUserPos(user_pos_file):
-  with open(user_pos_file, 'r') as stream:
+  with codecs.open(user_pos_file, 'r', encoding='utf8') as stream:
     stream = code_generator_util.SkipLineComment(stream)
     stream = code_generator_util.ParseColumnStream(stream, num_column=2)
     return dict((key, enum_value) for key, enum_value in stream)
@@ -64,7 +66,7 @@ def GeneratePosMap(third_party_pos_map_file, user_pos_file):
   user_pos_map = ParseUserPos(user_pos_file)
 
   result = {}
-  with open(third_party_pos_map_file, 'r') as stream:
+  with codecs.open(third_party_pos_map_file, 'r', encoding='utf8') as stream:
     stream = code_generator_util.SkipLineComment(stream)
     for columns in code_generator_util.ParseColumnStream(stream, num_column=2):
       third_party_pos_name, mozc_pos = (columns + [None])[:2]
@@ -78,7 +80,7 @@ def GeneratePosMap(third_party_pos_map_file, user_pos_file):
       result[third_party_pos_name] = mozc_pos
 
   # Create mozc_pos to mozc_pos map.
-  for key, value in user_pos_map.iteritems():
+  for key, value in six.iteritems(user_pos_map):
     if key in result:
       assert (result[key] == value)
       continue
