@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,14 +44,11 @@ namespace user_dictionary {
 
 UserDictionarySessionHandler::UserDictionarySessionHandler()
     : session_id_(kInvalidSessionId),
-      dictionary_path_(UserDictionaryUtil::GetUserDictionaryFileName()) {
-}
-UserDictionarySessionHandler::~UserDictionarySessionHandler() {
-}
+      dictionary_path_(UserDictionaryUtil::GetUserDictionaryFileName()) {}
+UserDictionarySessionHandler::~UserDictionarySessionHandler() {}
 
 bool UserDictionarySessionHandler::Evaluate(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   if (!command.has_type()) {
     return false;
   }
@@ -132,10 +129,9 @@ bool UserDictionarySessionHandler::Evaluate(
 }
 
 void UserDictionarySessionHandler::NoOperation(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -144,23 +140,16 @@ void UserDictionarySessionHandler::NoOperation(
 }
 
 void UserDictionarySessionHandler::ClearStorage(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
-#ifdef OS_NACL
-  // File operation is not supported on NaCl.
-  status->set_status(UserDictionaryCommandStatus::UNKNOWN_ERROR);
-#else  // OS_NACL
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   // Note: session_ might not be created when ClearStorage is called.  So create
   // a local session to clear the storage.
   UserDictionarySession session(dictionary_path_);
   session.ClearDictionariesAndUndoHistory();
   status->set_status(session.Save());
-#endif  // OS_NACL
 }
 
 void UserDictionarySessionHandler::CreateSession(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   uint64 new_id = CreateNewSessionId();
 
   session_id_ = new_id;
@@ -173,10 +162,9 @@ void UserDictionarySessionHandler::CreateSession(
 }
 
 void UserDictionarySessionHandler::DeleteSession(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -187,10 +175,9 @@ void UserDictionarySessionHandler::DeleteSession(
 }
 
 void UserDictionarySessionHandler::SetDefaultDictionaryName(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -204,23 +191,22 @@ void UserDictionarySessionHandler::SetDefaultDictionaryName(
 }
 
 void UserDictionarySessionHandler::CheckUndoability(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
   status->set_status(
-      session->has_undo_history() ?
-      UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS :
-      UserDictionaryCommandStatus::NO_UNDO_HISTORY);
+      session->has_undo_history()
+          ? UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS
+          : UserDictionaryCommandStatus::NO_UNDO_HISTORY);
 }
 
 void UserDictionarySessionHandler::Undo(const UserDictionaryCommand &command,
                                         UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -230,7 +216,7 @@ void UserDictionarySessionHandler::Undo(const UserDictionaryCommand &command,
 void UserDictionarySessionHandler::Load(const UserDictionaryCommand &command,
                                         UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -244,7 +230,7 @@ void UserDictionarySessionHandler::Load(const UserDictionaryCommand &command,
 void UserDictionarySessionHandler::Save(const UserDictionaryCommand &command,
                                         UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -252,10 +238,9 @@ void UserDictionarySessionHandler::Save(const UserDictionaryCommand &command,
 }
 
 void UserDictionarySessionHandler::GetUserDictionaryNameList(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -277,10 +262,9 @@ void UserDictionarySessionHandler::GetUserDictionaryNameList(
 }
 
 void UserDictionarySessionHandler::GetEntrySize(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -291,7 +275,7 @@ void UserDictionarySessionHandler::GetEntrySize(
 
   const UserDictionary *dictionary = UserDictionaryUtil::GetUserDictionaryById(
       session_->storage(), command.dictionary_id());
-  if (dictionary == NULL) {
+  if (dictionary == nullptr) {
     status->set_status(UserDictionaryCommandStatus::UNKNOWN_DICTIONARY_ID);
     return;
   }
@@ -302,10 +286,9 @@ void UserDictionarySessionHandler::GetEntrySize(
 }
 
 void UserDictionarySessionHandler::GetEntries(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -316,7 +299,7 @@ void UserDictionarySessionHandler::GetEntries(
 
   const UserDictionary *dictionary = UserDictionaryUtil::GetUserDictionaryById(
       session_->storage(), command.dictionary_id());
-  if (dictionary == NULL) {
+  if (dictionary == nullptr) {
     status->set_status(UserDictionaryCommandStatus::UNKNOWN_DICTIONARY_ID);
     return;
   }
@@ -343,10 +326,9 @@ void UserDictionarySessionHandler::GetEntries(
 }
 
 void UserDictionarySessionHandler::CheckNewDictionaryAvailability(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -361,10 +343,9 @@ void UserDictionarySessionHandler::CheckNewDictionaryAvailability(
 }
 
 void UserDictionarySessionHandler::CreateDictionary(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -374,8 +355,8 @@ void UserDictionarySessionHandler::CreateDictionary(
   }
 
   uint64 new_dictionary_id;
-  status->set_status(session->CreateDictionary(
-      command.dictionary_name(), &new_dictionary_id));
+  status->set_status(
+      session->CreateDictionary(command.dictionary_name(), &new_dictionary_id));
   if (status->status() ==
       UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS) {
     status->set_dictionary_id(new_dictionary_id);
@@ -383,10 +364,9 @@ void UserDictionarySessionHandler::CreateDictionary(
 }
 
 void UserDictionarySessionHandler::DeleteDictionary(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -404,10 +384,9 @@ void UserDictionarySessionHandler::DeleteDictionary(
 }
 
 void UserDictionarySessionHandler::RenameDictionary(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -416,15 +395,14 @@ void UserDictionarySessionHandler::RenameDictionary(
     return;
   }
 
-  status->set_status(session->RenameDictionary(
-      command.dictionary_id(), command.dictionary_name()));
+  status->set_status(session->RenameDictionary(command.dictionary_id(),
+                                               command.dictionary_name()));
 }
 
 void UserDictionarySessionHandler::CheckNewEntryAvailability(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -435,15 +413,13 @@ void UserDictionarySessionHandler::CheckNewEntryAvailability(
 
   const UserDictionary *dictionary = UserDictionaryUtil::GetUserDictionaryById(
       session->storage(), command.dictionary_id());
-  if (dictionary == NULL) {
+  if (dictionary == nullptr) {
     status->set_status(UserDictionaryCommandStatus::UNKNOWN_DICTIONARY_ID);
     return;
   }
 
-
   if (UserDictionaryUtil::IsDictionaryFull(*dictionary)) {
-    status->set_status(
-        UserDictionaryCommandStatus::ENTRY_SIZE_LIMIT_EXCEEDED);
+    status->set_status(UserDictionaryCommandStatus::ENTRY_SIZE_LIMIT_EXCEEDED);
     return;
   }
 
@@ -452,10 +428,9 @@ void UserDictionarySessionHandler::CheckNewEntryAvailability(
 }
 
 void UserDictionarySessionHandler::AddEntry(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -469,15 +444,13 @@ void UserDictionarySessionHandler::AddEntry(
 }
 
 void UserDictionarySessionHandler::EditEntry(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
-  if (!command.has_dictionary_id() ||
-      command.entry_index_size() != 1 ||
+  if (!command.has_dictionary_id() || command.entry_index_size() != 1 ||
       !command.has_entry()) {
     status->set_status(UserDictionaryCommandStatus::INVALID_ARGUMENT);
     return;
@@ -488,10 +461,9 @@ void UserDictionarySessionHandler::EditEntry(
 }
 
 void UserDictionarySessionHandler::DeleteEntry(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -500,17 +472,15 @@ void UserDictionarySessionHandler::DeleteEntry(
     return;
   }
 
-  const vector<int> index_list(command.entry_index().begin(),
-                               command.entry_index().end());
-  status->set_status(
-      session->DeleteEntry(command.dictionary_id(), index_list));
+  const std::vector<int> index_list(command.entry_index().begin(),
+                                    command.entry_index().end());
+  status->set_status(session->DeleteEntry(command.dictionary_id(), index_list));
 }
 
 void UserDictionarySessionHandler::ImportData(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
 
@@ -529,9 +499,14 @@ void UserDictionarySessionHandler::ImportData(
       dictionary_id = command.dictionary_id();
     }
   } else {
+    result_status = session->ImportToNewDictionaryFromString(
+        command.dictionary_name(), command.data(), &dictionary_id);
+  }
+  if (result_status == UserDictionaryCommandStatus::IMPORT_INVALID_ENTRIES &&
+      command.ignore_invalid_entries()) {
+    LOG(INFO) << "There are some invalid entries but ignored.";
     result_status =
-        session->ImportToNewDictionaryFromString(
-            command.dictionary_name(), command.data(), &dictionary_id);
+        UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS;
   }
 
   if (dictionary_id != 0) {
@@ -541,10 +516,9 @@ void UserDictionarySessionHandler::ImportData(
 }
 
 void UserDictionarySessionHandler::GetStorage(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   UserDictionarySession *session = GetSession(command, status);
-  if (session == NULL) {
+  if (session == nullptr) {
     return;
   }
   status->mutable_storage()->CopyFrom(session->storage());
@@ -553,16 +527,15 @@ void UserDictionarySessionHandler::GetStorage(
 }
 
 UserDictionarySession *UserDictionarySessionHandler::GetSession(
-    const UserDictionaryCommand &command,
-    UserDictionaryCommandStatus *status) {
+    const UserDictionaryCommand &command, UserDictionaryCommandStatus *status) {
   if (!command.has_session_id()) {
     status->set_status(UserDictionaryCommandStatus::INVALID_ARGUMENT);
-    return NULL;
+    return nullptr;
   }
 
-  if (session_.get() == NULL || session_id_ != command.session_id()) {
+  if (session_ == nullptr || session_id_ != command.session_id()) {
     status->set_status(UserDictionaryCommandStatus::UNKNOWN_SESSION_ID);
-    return NULL;
+    return nullptr;
   }
 
   return session_.get();
@@ -574,13 +547,13 @@ uint64 UserDictionarySessionHandler::CreateNewSessionId() const {
     Util::GetRandomSequence(reinterpret_cast<char *>(&id), sizeof(id));
 
     if (id != kInvalidSessionId &&
-        (session_.get() == NULL || session_id_ != id)) {
+        (session_ == nullptr || session_id_ != id)) {
       // New id is generated.
       break;
     }
 
-    LOG(WARNING)
-        << "User Dictionary Session Id " << id << " is already used. Retry.";
+    LOG(WARNING) << "User Dictionary Session Id " << id
+                 << " is already used. Retry.";
   }
 
   DCHECK_NE(0, id);
