@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,8 +39,9 @@ namespace mozc {
 using user_dictionary::UserDictionary;
 using user_dictionary::UserDictionaryCommandStatus;
 
-static void TestNormalizeReading(const string &golden, const string &input) {
-  string output;
+static void TestNormalizeReading(const std::string &golden,
+                                 const std::string &input) {
+  std::string output;
   UserDictionaryUtil::NormalizeReading(input, &output);
   EXPECT_EQ(golden, output);
 }
@@ -57,12 +58,19 @@ TEST(UserDictionaryUtilTest, TestIsValidReading) {
 
   // KATAKANA-HIRAGANA VOICED/SEMI-VOICED SOUND MARK (u309B, u309C)
   EXPECT_TRUE(UserDictionaryUtil::IsValidReading("゛゜"));
+
+  EXPECT_FALSE(UserDictionaryUtil::IsValidReading("𠮷"));
+  EXPECT_FALSE(UserDictionaryUtil::IsValidReading("😁"));
+  EXPECT_FALSE(UserDictionaryUtil::IsValidReading("ヷ"));
+  EXPECT_FALSE(UserDictionaryUtil::IsValidReading("ヺ"));
+  EXPECT_TRUE(UserDictionaryUtil::IsValidReading("。「」、・"));
 }
 
 TEST(UserDictionaryUtilTest, TestNormalizeReading) {
   TestNormalizeReading("あいうゔゎ", "アイウヴヮ");
   TestNormalizeReading("あいうゃ", "ｱｲｳｬ");
   TestNormalizeReading("ABab01@&=|", "ＡＢａｂ０１＠＆＝｜");
+  TestNormalizeReading("。「」、・", "｡｢｣､･");
 }
 
 namespace {
@@ -73,8 +81,8 @@ struct UserDictionaryEntryData {
   const char *comment;
 };
 
-void ConvertUserDictionaryEntry(
-    const UserDictionaryEntryData &input, UserDictionary::Entry *output) {
+void ConvertUserDictionaryEntry(const UserDictionaryEntryData &input,
+                                UserDictionary::Entry *output) {
   output->set_key(input.key);
   output->set_value(input.value);
   output->set_pos(input.pos);
@@ -84,39 +92,42 @@ void ConvertUserDictionaryEntry(
 
 TEST(UserDictionaryUtilTest, TestSanitizeEntry) {
   const UserDictionaryEntryData golden_data = {
-    "abc", "abc", UserDictionary::NOUN, "abc",
+      "abc",
+      "abc",
+      UserDictionary::NOUN,
+      "abc",
   };
 
   UserDictionary::Entry golden, input;
   ConvertUserDictionaryEntry(golden_data, &golden);
 
   {
-    UserDictionaryEntryData input_data = {
-      "abc", "abc", UserDictionary::NOUN, "abc" };
+    UserDictionaryEntryData input_data = {"abc", "abc", UserDictionary::NOUN,
+                                          "abc"};
     ConvertUserDictionaryEntry(input_data, &input);
     EXPECT_FALSE(UserDictionaryUtil::SanitizeEntry(&input));
     EXPECT_EQ(golden.DebugString(), input.DebugString());
   }
 
   {
-    UserDictionaryEntryData input_data = {
-      "ab\tc", "abc", UserDictionary::NOUN, "abc" };
+    UserDictionaryEntryData input_data = {"ab\tc", "abc", UserDictionary::NOUN,
+                                          "abc"};
     ConvertUserDictionaryEntry(input_data, &input);
     EXPECT_TRUE(UserDictionaryUtil::SanitizeEntry(&input));
     EXPECT_EQ(golden.DebugString(), input.DebugString());
   }
 
   {
-    UserDictionaryEntryData input_data = {
-      "abc", "ab\tc", UserDictionary::NOUN, "ab\tc" };
+    UserDictionaryEntryData input_data = {"abc", "ab\tc", UserDictionary::NOUN,
+                                          "ab\tc"};
     ConvertUserDictionaryEntry(input_data, &input);
     EXPECT_TRUE(UserDictionaryUtil::SanitizeEntry(&input));
     EXPECT_EQ(golden.DebugString(), input.DebugString());
   }
 
   {
-    UserDictionaryEntryData input_data = {
-      "ab\tc", "ab\tc", UserDictionary::NOUN, "ab\tc" };
+    UserDictionaryEntryData input_data = {"ab\tc", "ab\tc",
+                                          UserDictionary::NOUN, "ab\tc"};
     ConvertUserDictionaryEntry(input_data, &input);
     EXPECT_TRUE(UserDictionaryUtil::SanitizeEntry(&input));
     EXPECT_EQ(golden.DebugString(), input.DebugString());
@@ -124,7 +135,7 @@ TEST(UserDictionaryUtilTest, TestSanitizeEntry) {
 }
 
 TEST(UserDictionaryUtilTest, TestSanitize) {
-  string str(10, '\t');
+  std::string str(10, '\t');
   EXPECT_TRUE(UserDictionaryUtil::Sanitize(&str, 5));
   EXPECT_EQ("", str);
 
@@ -172,7 +183,7 @@ TEST(UserDictionaryUtilTest, ValidateEntry) {
             UserDictionaryUtil::ValidateEntry(entry));
 
   entry.CopyFrom(base_entry);
-  entry.set_key(string(500, 'a'));
+  entry.set_key(std::string(500, 'a'));
   EXPECT_EQ(UserDictionaryCommandStatus::READING_TOO_LONG,
             UserDictionaryUtil::ValidateEntry(entry));
 
@@ -187,7 +198,7 @@ TEST(UserDictionaryUtilTest, ValidateEntry) {
             UserDictionaryUtil::ValidateEntry(entry));
 
   entry.CopyFrom(base_entry);
-  entry.set_value(string(500, 'a'));
+  entry.set_value(std::string(500, 'a'));
   EXPECT_EQ(UserDictionaryCommandStatus::WORD_TOO_LONG,
             UserDictionaryUtil::ValidateEntry(entry));
 
@@ -202,7 +213,7 @@ TEST(UserDictionaryUtilTest, ValidateEntry) {
             UserDictionaryUtil::ValidateEntry(entry));
 
   entry.CopyFrom(base_entry);
-  entry.set_comment(string(500, 'a'));
+  entry.set_comment(std::string(500, 'a'));
   EXPECT_EQ(UserDictionaryCommandStatus::COMMENT_TOO_LONG,
             UserDictionaryUtil::ValidateEntry(entry));
 
@@ -218,27 +229,25 @@ TEST(UserDictionaryUtilTest, ValidateEntry) {
 }
 
 TEST(UserDictionaryUtilTest, ValidateDictionaryName) {
-  EXPECT_EQ(UserDictionaryCommandStatus::DICTIONARY_NAME_EMPTY,
-            UserDictionaryUtil::ValidateDictionaryName(
-                user_dictionary::UserDictionaryStorage::default_instance(),
-                ""));
+  EXPECT_EQ(
+      UserDictionaryCommandStatus::DICTIONARY_NAME_EMPTY,
+      UserDictionaryUtil::ValidateDictionaryName(
+          user_dictionary::UserDictionaryStorage::default_instance(), ""));
 
   EXPECT_EQ(UserDictionaryCommandStatus::DICTIONARY_NAME_TOO_LONG,
             UserDictionaryUtil::ValidateDictionaryName(
                 user_dictionary::UserDictionaryStorage::default_instance(),
-                string(500, 'a')));
+                std::string(500, 'a')));
 
-  EXPECT_EQ(UserDictionaryCommandStatus
-                ::DICTIONARY_NAME_CONTAINS_INVALID_CHARACTER,
-            UserDictionaryUtil::ValidateDictionaryName(
-                user_dictionary::UserDictionaryStorage::default_instance(),
-                "a\nbc"));
+  EXPECT_EQ(
+      UserDictionaryCommandStatus ::DICTIONARY_NAME_CONTAINS_INVALID_CHARACTER,
+      UserDictionaryUtil::ValidateDictionaryName(
+          user_dictionary::UserDictionaryStorage::default_instance(), "a\nbc"));
 
   user_dictionary::UserDictionaryStorage storage;
   storage.add_dictionaries()->set_name("abc");
   EXPECT_EQ(UserDictionaryCommandStatus::DICTIONARY_NAME_DUPLICATED,
-            UserDictionaryUtil::ValidateDictionaryName(
-                storage, "abc"));
+            UserDictionaryUtil::ValidateDictionaryName(storage, "abc"));
 }
 
 TEST(UserDictionaryUtilTest, IsStorageFull) {
@@ -270,7 +279,8 @@ TEST(UserDictionaryUtilTest, GetUserDictionaryById) {
               &storage.dictionaries(0));
   EXPECT_TRUE(UserDictionaryUtil::GetUserDictionaryById(storage, 2) ==
               &storage.dictionaries(1));
-  EXPECT_TRUE(UserDictionaryUtil::GetUserDictionaryById(storage, -1) == NULL);
+  EXPECT_TRUE(UserDictionaryUtil::GetUserDictionaryById(storage, -1) ==
+              nullptr);
 }
 
 TEST(UserDictionaryUtilTest, GetMutableUserDictionaryById) {
@@ -282,8 +292,8 @@ TEST(UserDictionaryUtilTest, GetMutableUserDictionaryById) {
               storage.mutable_dictionaries(0));
   EXPECT_TRUE(UserDictionaryUtil::GetMutableUserDictionaryById(&storage, 2) ==
               storage.mutable_dictionaries(1));
-  EXPECT_TRUE(
-      UserDictionaryUtil::GetMutableUserDictionaryById(&storage, -1) == NULL);
+  EXPECT_TRUE(UserDictionaryUtil::GetMutableUserDictionaryById(&storage, -1) ==
+              nullptr);
 }
 
 TEST(UserDictionaryUtilTest, GetUserDictionaryIndexById) {
@@ -304,8 +314,7 @@ TEST(UserDictionaryUtilTest, CreateDictionary) {
 
   // Check dictionary validity.
   EXPECT_EQ(UserDictionaryCommandStatus::DICTIONARY_NAME_EMPTY,
-            UserDictionaryUtil::CreateDictionary(
-                &storage, "", &dictionary_id));
+            UserDictionaryUtil::CreateDictionary(&storage, "", &dictionary_id));
 
   // Check the limit of the number of dictionaries.
   storage.Clear();
@@ -314,22 +323,23 @@ TEST(UserDictionaryUtilTest, CreateDictionary) {
   }
 
   EXPECT_EQ(UserDictionaryCommandStatus::DICTIONARY_SIZE_LIMIT_EXCEEDED,
-            UserDictionaryUtil::CreateDictionary(
-                &storage, "new dictionary", &dictionary_id));
+            UserDictionaryUtil::CreateDictionary(&storage, "new dictionary",
+                                                 &dictionary_id));
 
   storage.Clear();
   EXPECT_EQ(UserDictionaryCommandStatus::UNKNOWN_ERROR,
-            UserDictionaryUtil::CreateDictionary(
-                &storage, "new dictionary", NULL));
+            UserDictionaryUtil::CreateDictionary(&storage, "new dictionary",
+                                                 nullptr));
 
   ASSERT_EQ(UserDictionaryCommandStatus::USER_DICTIONARY_COMMAND_SUCCESS,
-            UserDictionaryUtil::CreateDictionary(
-                &storage, "new dictionary", &dictionary_id));
+            UserDictionaryUtil::CreateDictionary(&storage, "new dictionary",
+                                                 &dictionary_id));
 
-  EXPECT_PROTO_PEQ("dictionaries <\n"
-                   "  name: \"new dictionary\"\n"
-                   ">\n",
-                   storage);
+  EXPECT_PROTO_PEQ(
+      "dictionaries <\n"
+      "  name: \"new dictionary\"\n"
+      ">\n",
+      storage);
   EXPECT_EQ(dictionary_id, storage.dictionaries(0).id());
 }
 
@@ -340,8 +350,8 @@ TEST(UserDictionaryUtilTest, DeleteDictionary) {
 
   // Simplest deleting case.
   int original_index;
-  ASSERT_TRUE(UserDictionaryUtil::DeleteDictionary(
-      &storage, 1, &original_index, NULL));
+  ASSERT_TRUE(UserDictionaryUtil::DeleteDictionary(&storage, 1, &original_index,
+                                                   nullptr));
   EXPECT_EQ(0, original_index);
   ASSERT_EQ(1, storage.dictionaries_size());
   EXPECT_EQ(2, storage.dictionaries(0).id());
@@ -350,18 +360,17 @@ TEST(UserDictionaryUtilTest, DeleteDictionary) {
   storage.Clear();
   storage.add_dictionaries()->set_id(1);
   storage.add_dictionaries()->set_id(2);
-  EXPECT_FALSE(UserDictionaryUtil::DeleteDictionary(
-      &storage, 100, NULL, NULL));
+  EXPECT_FALSE(
+      UserDictionaryUtil::DeleteDictionary(&storage, 100, nullptr, nullptr));
 
   // Keep deleted dictionary.
   storage.Clear();
   storage.add_dictionaries()->set_id(1);
   storage.add_dictionaries()->set_id(2);
-  UserDictionary *expected_deleted_dictionary =
-      storage.mutable_dictionaries(0);
+  UserDictionary *expected_deleted_dictionary = storage.mutable_dictionaries(0);
   UserDictionary *deleted_dictionary;
-  EXPECT_TRUE(UserDictionaryUtil::DeleteDictionary(
-      &storage, 1, NULL, &deleted_dictionary));
+  EXPECT_TRUE(UserDictionaryUtil::DeleteDictionary(&storage, 1, nullptr,
+                                                   &deleted_dictionary));
   ASSERT_EQ(1, storage.dictionaries_size());
   EXPECT_EQ(2, storage.dictionaries(0).id());
   EXPECT_TRUE(expected_deleted_dictionary == deleted_dictionary);
