@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,7 @@
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/user_pos_interface.h"
 #include "testing/base/public/gunit.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace dictionary {
@@ -46,7 +47,7 @@ namespace {
 class UserPOSTest : public ::testing::Test {
  protected:
   void SetUp() override {
-    StringPiece token_array_data, string_array_data;
+    absl::string_view token_array_data, string_array_data;
     mock_data_manager_.GetUserPOSData(&token_array_data, &string_array_data);
     user_pos_.reset(new UserPOS(token_array_data, string_array_data));
     CHECK(user_pos_.get());
@@ -59,7 +60,7 @@ class UserPOSTest : public ::testing::Test {
 };
 
 TEST_F(UserPOSTest, UserPOSBasicTest) {
-  std::vector<string> pos_list;
+  std::vector<std::string> pos_list;
   user_pos_->GetPOSList(&pos_list);
   EXPECT_FALSE(pos_list.empty());
 
@@ -72,7 +73,7 @@ TEST_F(UserPOSTest, UserPOSBasicTest) {
 }
 
 TEST_F(UserPOSTest, UserPOSGetTokensTest) {
-  std::vector<string> pos_list;
+  std::vector<std::string> pos_list;
   user_pos_->GetPOSList(&pos_list);
 
   std::vector<UserPOS::Token> tokens;
@@ -89,6 +90,24 @@ TEST_F(UserPOSTest, UserPOSGetTokensTest) {
   }
 }
 
+TEST_F(UserPOSTest, UserPOSGetTokensWithLocaleTest) {
+  std::vector<std::string> pos_list;
+  user_pos_->GetPOSList(&pos_list);
+
+  std::vector<UserPOS::Token> tokens, tokens_ja, tokens_en;
+  EXPECT_TRUE(user_pos_->GetTokens("あか", "赤", "形容詞", "", &tokens));
+  EXPECT_TRUE(user_pos_->GetTokens("あか", "赤", "形容詞", "ja", &tokens_ja));
+  EXPECT_TRUE(user_pos_->GetTokens("あか", "赤", "形容詞", "en", &tokens_en));
+  EXPECT_EQ(tokens.size(), tokens_ja.size());
+  EXPECT_EQ(tokens.size(), tokens_en.size());
+
+  for (size_t i = 0; i < tokens.size(); ++i) {
+    EXPECT_EQ(tokens[i].cost, tokens_ja[i].cost);
+    EXPECT_GT(tokens_en[i].cost, tokens_ja[i].cost);
+    EXPECT_GT(tokens_en[i].cost, tokens[i].cost);
+  }
+}
+
 TEST_F(UserPOSTest, ConjugationTest) {
   std::vector<UserPOS::Token> tokens1, tokens2;
   EXPECT_TRUE(user_pos_->GetTokens("わら", "嗤", "動詞ワ行五段", &tokens1));
