@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,8 +35,12 @@
 namespace mozc {
 
 Engine *MockDataEngineFactory::Create() {
-  return Engine::CreateDesktopEngineHelper<mozc::testing::MockDataManager>()
-      .release();
+  auto engine =
+      Engine::CreateDesktopEngineHelper<mozc::testing::MockDataManager>();
+  if (!engine.ok()) {
+    LOG(ERROR) << engine.status();
+  }
+  return engine->release();
 }
 
 }  // namespace mozc
