@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@
 
 #ifdef OS_WIN
 #include <memory>  // for std::unique_ptr
-#endif  // OS_WIN
+#endif             // OS_WIN
 
 #include "base/file_stream.h"
 #include "base/logging.h"
@@ -47,27 +47,27 @@
 #include "base/util.h"
 #include "gui/base/win_util.h"
 #include "ipc/window_info.pb.h"
+#include "absl/memory/memory.h"
 
 namespace mozc {
 namespace gui {
 namespace {
-bool ReadWindowInfo(const string &lock_name,
+bool ReadWindowInfo(const std::string &lock_name,
                     ipc::WindowInfo *window_info) {
 #ifdef OS_WIN
   std::wstring wfilename;
   mozc::Util::UTF8ToWide(lock_name, &wfilename);
   {
     mozc::ScopedHandle handle(
-      ::CreateFileW(wfilename.c_str(),
-                    GENERIC_READ,
-                    FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
-                    NULL, OPEN_EXISTING, 0, NULL));
-    if (NULL == handle.get()) {
+        ::CreateFileW(wfilename.c_str(), GENERIC_READ,
+                      FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
+                      nullptr, OPEN_EXISTING, 0, nullptr));
+    if (nullptr == handle.get()) {
       LOG(ERROR) << "cannot open: " << lock_name << " " << ::GetLastError();
       return false;
     }
 
-    const DWORD size = ::GetFileSize(handle.get(), NULL);
+    const DWORD size = ::GetFileSize(handle.get(), nullptr);
     if (-1 == static_cast<int>(size)) {
       LOG(ERROR) << "GetFileSize failed:" << ::GetLastError();
       return false;
@@ -82,8 +82,7 @@ bool ReadWindowInfo(const string &lock_name,
     std::unique_ptr<char[]> buf(new char[size]);
 
     DWORD read_size = 0;
-    if (!::ReadFile(handle.get(), buf.get(),
-                    size, &read_size, NULL)) {
+    if (!::ReadFile(handle.get(), buf.get(), size, &read_size, nullptr)) {
       LOG(ERROR) << "ReadFile failed: " << ::GetLastError();
       return false;
     }
@@ -99,7 +98,7 @@ bool ReadWindowInfo(const string &lock_name,
     }
   }
 #else
-  InputFileStream is(lock_name.c_str(), std::ios::binary|std::ios::in);
+  InputFileStream is(lock_name.c_str(), std::ios::binary | std::ios::in);
   if (!is) {
     LOG(ERROR) << "cannot open: " << lock_name;
     return false;
@@ -114,8 +113,8 @@ bool ReadWindowInfo(const string &lock_name,
 }
 }  // namespace
 
-SingletonWindowHelper::SingletonWindowHelper(const string &name) {
-  mutex_.reset(new mozc::ProcessMutex(name.c_str()));
+SingletonWindowHelper::SingletonWindowHelper(const std::string &name) {
+  mutex_ = absl::make_unique<mozc::ProcessMutex>(name.c_str());
 }
 
 SingletonWindowHelper::~SingletonWindowHelper() {}
@@ -128,7 +127,7 @@ bool SingletonWindowHelper::FindPreviousWindow() {
   window_info.set_process_id(static_cast<uint32>(getpid()));
 #endif
 
-  string window_info_str;
+  std::string window_info_str;
   if (!window_info.SerializeToString(&window_info_str)) {
     LOG(ERROR) << "SerializeToString failed";
     return false;
