@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,8 +41,8 @@ class TableUtil {
  public:
   // Returns text data associate with the specified table item.
   // Returns an empty string if fails.
-  static QString SafeGetItemText(
-      const QTableWidget *table_widget, int row, int column);
+  static QString SafeGetItemText(const QTableWidget *table_widget, int row,
+                                 int column);
 
  private:
   TableUtil() {}
