@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,7 +34,6 @@
 
 #include <QtCore/QObject>
 #include <QtCore/QTimer>
-
 #include <map>
 #include <memory>
 #include <string>
@@ -54,24 +53,23 @@ class Config;
 }
 
 namespace gui {
-class ConfigDialog : public QDialog,
-                     private Ui::ConfigDialog {
+class ConfigDialog : public QDialog, private Ui::ConfigDialog {
   Q_OBJECT;
 
  public:
   ConfigDialog();
-  virtual ~ConfigDialog();
+  ~ConfigDialog() override;
 
- // Methods defined in the 'slots' section (Qt's extention) will be processed
- // by Qt's moc tool (moc.exe on Windows). Unfortunately, preprocessor macros
- // defined for C/C++ are not automatically passed into the moc tool.
- // For example, you need to call the moc tool with '-D' option as
- // 'moc -DENABLE_FOOBER ...' to make the moc tool aware of the ENABLE_FOOBER
- // macro. http://developer.qt.nokia.com/doc/qt-4.8/moc.html
- // So basically we must not use any #ifdef macro in slot declarations.
- // Otherwise, methods enclosed by "ifdef ENABLE_FOOBER" will be simply ignored
- // by the moc tool and |QObject::connect| against these methods results in
- // failure. See b/5935351 about how we found this issue.
+  // Methods defined in the 'slots' section (Qt's extention) will be processed
+  // by Qt's moc tool (moc.exe on Windows). Unfortunately, preprocessor macros
+  // defined for C/C++ are not automatically passed into the moc tool.
+  // For example, you need to call the moc tool with '-D' option as
+  // 'moc -DENABLE_FOOBER ...' to make the moc tool aware of the ENABLE_FOOBER
+  // macro. http://developer.qt.nokia.com/doc/qt-4.8/moc.html
+  // So basically we must not use any #ifdef macro in slot declarations.
+  // Otherwise, methods enclosed by "ifdef ENABLE_FOOBER" will be simply ignored
+  // by the moc tool and |QObject::connect| against these methods results in
+  // failure. See b/5935351 about how we found this issue.
  protected slots:
   virtual void clicked(QAbstractButton *button);
   virtual void ClearUserHistory();
@@ -88,7 +86,7 @@ class ConfigDialog : public QDialog,
   virtual void EnableApplyButton();
 
  protected:
-  bool eventFilter(QObject *obj, QEvent *event);
+  bool eventFilter(QObject *obj, QEvent *event) override;
 
  private:
   bool GetConfig(config::Config *config);
@@ -103,8 +101,8 @@ class ConfigDialog : public QDialog,
   void Reload();
 
   std::unique_ptr<client::ClientInterface> client_;
-  string custom_keymap_table_;
-  string custom_roman_table_;
+  std::string custom_keymap_table_;
+  std::string custom_roman_table_;
   config::Config::InformationListConfig information_list_config_;
   int initial_preedit_method_;
   bool initial_use_keyboard_to_change_preedit_method_;
