@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,9 +30,8 @@
 #ifndef MOZC_GUI_CONFIG_DIALOG_KEYBINDING_EDITOR_H_
 #define MOZC_GUI_CONFIG_DIALOG_KEYBINDING_EDITOR_H_
 
-#include <QtGui/QtGui>
 #include <QtGui/QGuiApplication>
-
+#include <QtGui/QtGui>
 #include <memory>
 #include <string>
 
@@ -42,8 +41,7 @@
 namespace mozc {
 namespace gui {
 class KeyBindingFilter;
-class KeyBindingEditor : public QDialog,
-                         private Ui::KeyBindingEditor {
+class KeyBindingEditor : public QDialog, private Ui::KeyBindingEditor {
   Q_OBJECT;
 
  public:
@@ -51,11 +49,9 @@ class KeyBindingEditor : public QDialog,
   // |trigger_parent| is the object who was the trigger of launching the editor.
   // QPushButton can be a trigger_parent.
   KeyBindingEditor(QWidget *parent, QWidget *trigger_parent);
-  virtual ~KeyBindingEditor();
+  ~KeyBindingEditor() override;
 
-  QWidget *mutable_trigger_parent() const {
-    return trigger_parent_;
-  }
+  QWidget *mutable_trigger_parent() const { return trigger_parent_; }
 
   // return current binding in QString
   const QString GetBinding() const;
@@ -64,7 +60,7 @@ class KeyBindingEditor : public QDialog,
   // For some reason, KeyBindingEditor lanuched by
   // QItemDelegate looses focus. We overwrite
   // setVisible() function to call raise() and activateWindow().
-  virtual void setVisible(bool visible) {
+  void setVisible(bool visible) override {
     QWidget::setVisible(visible);
     if (visible) {
       raise();
