@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,8 +27,8 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#ifndef MOZC_GUI_KEYCOMMAND_DIALOG_KEYBINDING_EDITOR_DELEGATE_H_
-#define MOZC_GUI_KEYCOMMAND_DIALOG_KEYBINDING_EDITOR_DELEGATE_H_
+#ifndef MOZC_GUI_CONFIG_DIALOG_KEYBINDING_EDITOR_DELEGATE_H_
+#define MOZC_GUI_CONFIG_DIALOG_KEYBINDING_EDITOR_DELEGATE_H_
 
 #include <QtCore/QModelIndex>
 #include <QtCore/QObject>
@@ -42,27 +42,23 @@ class KeyBindingEditor;
 class KeyBindingEditorDelegate : public QItemDelegate {
   Q_OBJECT
  public:
-  explicit KeyBindingEditorDelegate(QObject *parent = NULL);
-  virtual ~KeyBindingEditorDelegate();
+  explicit KeyBindingEditorDelegate(QObject *parent = nullptr);
+  ~KeyBindingEditorDelegate() override;
 
-  QWidget *createEditor(QWidget *parent,
-                        const QStyleOptionViewItem &option,
-                        const QModelIndex &index) const;
+  QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
+                        const QModelIndex &index) const override;
 
-  void setEditorData(QWidget *editor,
-                     const QModelIndex &index) const;
-  void setModelData(QWidget *editor,
-                    QAbstractItemModel *model,
-                    const QModelIndex &index) const;
+  void setEditorData(QWidget *editor, const QModelIndex &index) const override;
+  void setModelData(QWidget *editor, QAbstractItemModel *model,
+                    const QModelIndex &index) const override;
 
-  void updateEditorGeometry(QWidget *editor,
-                            const QStyleOptionViewItem &option,
-                            const QModelIndex &index) const;
+  void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option,
+                            const QModelIndex &index) const override;
 
  private slots:
   void CommitAndCloseEditor();
   void CloseEditor();
 };
-}  // gui
-}  // mozc
-#endif  // MOZC_GUI_KEYCOMMAND_DIALOG_KEYBINDING_EDITOR_DELEGATE_H_
+}  // namespace gui
+}  // namespace mozc
+#endif  // MOZC_GUI_CONFIG_DIALOG_KEYBINDING_EDITOR_DELEGATE_H_
