@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,14 +34,14 @@
 #include "base/logging.h"
 #include "base/process_mutex.h"
 #include "base/system_util.h"
-#include "gui/base/locale_util.h"
+#include "gui/base/util.h"
 #include "gui/error_message_dialog/error_message_dialog.h"
 
 int RunErrorMessageDialog(int argc, char *argv[]) {
   Q_INIT_RESOURCE(qrc_error_message_dialog);
 
   mozc::SystemUtil::DisableIME();
-  QApplication app(argc, argv);
+  auto app = mozc::gui::GuiUtil::InitQt(argc, argv);
 
   string name = "error_message_dialog.";
   name += mozc::SystemUtil::GetDesktopNameAsString();
@@ -52,8 +52,7 @@ int RunErrorMessageDialog(int argc, char *argv[]) {
     return -1;
   }
 
-  mozc::gui::LocaleUtil::InstallTranslationMessageAndFont
-      ("error_message_dialog");
+  mozc::gui::GuiUtil::InstallTranslator("error_message_dialog");
 
   mozc::gui::ErrorMessageDialog::Show();
   return 0;
