@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@
 
 #ifdef OS_WIN
 #include <windows.h>
-#endif
+#endif  // OS_WIN
 
 #include <QtGui/QGuiApplication>
 #include <QtGui/QtGui>
@@ -37,10 +37,13 @@
 #include "base/logging.h"
 #include "base/process_mutex.h"
 #include "base/system_util.h"
-#include "base/win_util.h"
-#include "gui/base/locale_util.h"
+#include "gui/base/util.h"
 #include "gui/set_default_dialog/set_default_dialog.h"
 
+#ifdef OS_WIN
+#include "base/win_util.h"
+#endif  // OS_WIN
+
 int RunSetDefaultDialog(int argc, char *argv[]) {
   Q_INIT_RESOURCE(qrc_set_default_dialog);
 
@@ -60,10 +63,9 @@ int RunSetDefaultDialog(int argc, char *argv[]) {
   mozc::ScopedCOMInitializer com_initializer;
 #endif
 
-  QApplication app(argc, argv);
+  auto app = mozc::gui::GuiUtil::InitQt(argc, argv);
 
-  mozc::gui::LocaleUtil::InstallTranslationMessageAndFont
-      ("set_default_dialog");
+  mozc::gui::GuiUtil::InstallTranslator("set_default_dialog");
 
   mozc::gui::SetDefaultDialog dialog;
   return dialog.exec();
