@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,4 @@
 
 #include "base/winmain.h"
 
-int main(int argc, char *argv[]) {
-  return 0;
-}
-
+int main(int argc, char *argv[]) { return 0; }
