@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,9 +44,7 @@ const int kInvalidSocket = -1;
 }  // namespace
 
 // Server
-IPCServer::IPCServer(const string &name,
-                     int32 num_connections,
-                     int32 timeout)
+IPCServer::IPCServer(const string &name, int32 num_connections, int32 timeout)
     : connected_(false), socket_(kInvalidSocket), timeout_(timeout) {
   // do nothing
 }
@@ -55,9 +53,7 @@ IPCServer::~IPCServer() {
   // do nothing
 }
 
-bool IPCServer::Connected() const {
-  return true;
-}
+bool IPCServer::Connected() const { return true; }
 
 void IPCServer::Loop() {
   // do nothing
