@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,7 +34,7 @@
 #include <time.h>  // for time_t
 #else
 #include <sys/time.h>  // for time_t
-#endif  // OS_WIN
+#endif                 // OS_WIN
 #ifdef OS_WIN
 #include <map>
 #endif  // OS_WIN
@@ -76,7 +76,7 @@ class IPCPathManager {
   bool LoadPathName();
 
   // Get a pathanem from the heap. If pathanme is empty, returns false.
-  bool GetPathName(string *path_name) const;
+  bool GetPathName(std::string *path_name) const;
 
   // return protocol version.
   // return 0 if protocol version is not defined.
@@ -84,7 +84,7 @@ class IPCPathManager {
 
   // return product version.
   // return "0.0.0.0" if product version is not defined
-  const string &GetServerProductVersion() const;
+  const std::string &GetServerProductVersion() const;
 
   // return process id of the server
   uint32 GetServerProcessId() const;
@@ -102,16 +102,16 @@ class IPCPathManager {
   // returns false.
   // To keep backward compatibility and other operationg system
   // having no support of getting peer's pid, you can set 0 pid.
-  bool IsValidServer(uint32 pid, const string &server_path);
+  bool IsValidServer(uint32 pid, const std::string &server_path);
 
   // clear ipc_key;
   void Clear();
 
   // return singleton instance corresponding to "name"
-  static IPCPathManager *GetIPCPathManager(const string &name);
+  static IPCPathManager *GetIPCPathManager(const std::string &name);
 
   // do not call constructor directly.
-  explicit IPCPathManager(const string &name);
+  explicit IPCPathManager(const std::string &name);
   virtual ~IPCPathManager();
 
  private:
@@ -126,12 +126,12 @@ class IPCPathManager {
   // Returns the last modified timestamp of the IPC file.
   time_t GetIPCFileTimeStamp() const;
 
-  std::unique_ptr<ProcessMutex> path_mutex_;   // lock ipc path file
-  std::unique_ptr<Mutex> mutex_;   // mutex for methods
+  std::unique_ptr<ProcessMutex> path_mutex_;  // lock ipc path file
+  std::unique_ptr<Mutex> mutex_;              // mutex for methods
   std::unique_ptr<ipc::IPCPathInfo> ipc_path_info_;
-  string name_;
-  string server_path_;   // cache for server_path
-  uint32 server_pid_;    // cache for pid of server_path
+  std::string name_;
+  std::string server_path_;  // cache for server_path
+  uint32 server_pid_;   // cache for pid of server_path
   time_t last_modified_;
 #ifdef OS_WIN
   std::map<string, std::wstring> expected_server_ntpath_cache_;
