@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
 #ifndef MOZC_NET_HTTP_CLIENT_MAC_H_
 #define MOZC_NET_HTTP_CLIENT_MAC_H_
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
 #include <iostream>
 #include <string>
 #include "net/http_client.h"
@@ -51,5 +51,5 @@ class MacHTTPRequestHandler {
 };
 }  // namespace mozc
 
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 #endif  // MOZC_NET_HTTP_CLIENT_MAC_H_
