@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,44 +31,25 @@
 
 #include "net/http_client_null.h"
 
-#ifdef OS_NACL
-#include <ppapi/cpp/instance.h>
-#endif  // OS_NACL
-
 #include "base/logging.h"
 
 namespace mozc {
 
 namespace {
 
-void Error() {
-  LOG(ERROR) << "HttpClient is not enabled.";
-}
+void Error() { LOG(ERROR) << "HttpClient is not enabled."; }
 
 }  // namespace
 
 // static
-bool NullHTTPRequestHandler::Request(HTTPMethodType type,
-                                     const string &url,
-                                     const char *post_data,
-                                     size_t post_size,
+bool NullHTTPRequestHandler::Request(HTTPMethodType type, const string &url,
+                                     const char *post_data, size_t post_size,
                                      const HTTPClient::Option &option,
                                      string *output_string) {
   Error();
   return false;
 }
 
-#ifdef OS_NACL
-void RegisterPepperInstanceForHTTPClient(pp::Instance *instance) {
-  Error();
-}
-
-pp::Instance *GetPepperInstanceForHTTPClient() {
-  Error();
-  return nullptr;
-}
-#endif  // OS_NACL
-
 }  // namespace mozc
 
 #endif  // !GOOGLE_JAPANESE_INPUT_BUILD
