@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,30 +37,17 @@
 #include "net/http_client.h"
 #include "net/http_client_common.h"
 
-#ifdef OS_NACL
-namespace pp {
-class Instance;
-}  // namespace pp
-#endif  // OS_NACL
-
 namespace mozc {
 class NullHTTPRequestHandler {
  public:
-  static bool Request(HTTPMethodType type,
-                      const string &url,
-                      const char *post_data,
-                      size_t post_size,
-                      const HTTPClient::Option &option,
-                      string *output_string);
+  static bool Request(HTTPMethodType type, const string &url,
+                      const char *post_data, size_t post_size,
+                      const HTTPClient::Option &option, string *output_string);
+
  private:
   DISALLOW_IMPLICIT_CONSTRUCTORS(NullHTTPRequestHandler);
 };
 
-#ifdef OS_NACL
-void RegisterPepperInstanceForHTTPClient(pp::Instance *instance);
-pp::Instance *GetPepperInstanceForHTTPClient();
-#endif  // OS_NACL
-
 }  // namespace mozc
 
 #endif  // !GOOGLE_JAPANESE_INPUT_BUILD
