@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,20 +31,20 @@
 
 #include <string>
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
 #include <CFNetwork/CFNetwork.h>
 #include <SystemConfiguration/SystemConfiguration.h>
-#include "base/scoped_cftyperef.h"
 #include "base/mac_util.h"
+#include "base/scoped_cftyperef.h"
 #endif
 
-#include "base/port.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/singleton.h"
 
 namespace mozc {
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
 namespace {
 // Helper functions for proxy configuration for Mac.
 
@@ -53,14 +53,14 @@ namespace {
 // location.
 // The implementation is inspired by
 // http://developer.apple.com/samplecode/CFProxySupportTool/
-static void PACResultCallback(
-    void * client, CFArrayRef proxies, CFErrorRef error) {
-  DCHECK((proxies == NULL && error != NULL) ||
-         (proxies != NULL && error == NULL));
+static void PACResultCallback(void *client, CFArrayRef proxies,
+                              CFErrorRef error) {
+  DCHECK((proxies == nullptr && error != nullptr) ||
+         (proxies != nullptr && error == nullptr));
   CFTypeRef *result = static_cast<CFTypeRef *>(client);
 
-  if (result != NULL && *result == NULL) {
-    if (error != NULL) {
+  if (result != nullptr && *result == nullptr) {
+    if (error != nullptr) {
       *result = CFRetain(error);
     } else {
       *result = CFRetain(proxies);
@@ -77,7 +77,7 @@ static void PACResultCallback(
 // The implementation is inspired by
 // http://developer.apple.com/samplecode/CFProxySupportTool/
 CFDictionaryRef RetainOrExpandPacFile(CFURLRef cfurl, CFDictionaryRef proxy) {
-  CFDictionaryRef final_proxy = NULL;
+  CFDictionaryRef final_proxy = nullptr;
   CFStringRef proxy_type = reinterpret_cast<CFStringRef>(
       CFDictionaryGetValue(proxy, kCFProxyTypeKey));
 
@@ -86,31 +86,29 @@ CFDictionaryRef RetainOrExpandPacFile(CFURLRef cfurl, CFDictionaryRef proxy) {
   // the pac URL server.  However, it seems that the function seems to
   // take care of caching in memory.  So there are no additional
   // latency problems here.
-  if (proxy_type != NULL && CFGetTypeID(proxy_type) == CFStringGetTypeID() &&
+  if (proxy_type != nullptr && CFGetTypeID(proxy_type) == CFStringGetTypeID() &&
       CFEqual(proxy_type, kCFProxyTypeAutoConfigurationURL)) {
     CFURLRef script_url = reinterpret_cast<CFURLRef>(
         CFDictionaryGetValue(proxy, kCFProxyAutoConfigurationURLKey));
-    if (script_url != NULL && CFGetTypeID(script_url) == CFURLGetTypeID()) {
-      CFTypeRef result = NULL;
-      CFStreamClientContext context = {0, &result, NULL, NULL, NULL};
+    if (script_url != nullptr && CFGetTypeID(script_url) == CFURLGetTypeID()) {
+      CFTypeRef result = nullptr;
+      CFStreamClientContext context = {0, &result, nullptr, nullptr, nullptr};
       scoped_cftyperef<CFRunLoopSourceRef> runloop_source(
           CFNetworkExecuteProxyAutoConfigurationURL(
               script_url, cfurl, PACResultCallback, &context));
       const string label = MacUtil::GetLabelForSuffix("ProxyResolverMac");
       scoped_cftyperef<CFStringRef> private_runloop_mode(
-          CFStringCreateWithBytes(
-              NULL, reinterpret_cast<const UInt8 *>(label.data()),
-              label.size(), kCFStringEncodingUTF8, false));
-      CFRunLoopAddSource(
-          CFRunLoopGetCurrent(), runloop_source.get(),
-          private_runloop_mode.get());
+          CFStringCreateWithBytes(nullptr,
+                                  reinterpret_cast<const UInt8 *>(label.data()),
+                                  label.size(), kCFStringEncodingUTF8, false));
+      CFRunLoopAddSource(CFRunLoopGetCurrent(), runloop_source.get(),
+                         private_runloop_mode.get());
       CFRunLoopRunInMode(private_runloop_mode.get(), 1.0e10, false);
-      CFRunLoopRemoveSource(
-          CFRunLoopGetCurrent(), runloop_source.get(),
-          private_runloop_mode.get());
+      CFRunLoopRemoveSource(CFRunLoopGetCurrent(), runloop_source.get(),
+                            private_runloop_mode.get());
 
       // resolving PAC succeeds
-      if (result != NULL && CFGetTypeID(result) == CFArrayGetTypeID() &&
+      if (result != nullptr && CFGetTypeID(result) == CFArrayGetTypeID() &&
           CFArrayGetCount(reinterpret_cast<CFArrayRef>(result)) > 0) {
         final_proxy = reinterpret_cast<CFDictionaryRef>(
             CFArrayGetValueAtIndex(reinterpret_cast<CFArrayRef>(result), 0));
@@ -119,7 +117,7 @@ CFDictionaryRef RetainOrExpandPacFile(CFURLRef cfurl, CFDictionaryRef proxy) {
         LOG(WARNING) << "Failed to resolve PAC file. "
                      << "Possibly wrong PAC file is specified.";
       }
-      if (result != NULL) {
+      if (result != nullptr) {
         CFRelease(result);
       }
     }
@@ -127,7 +125,7 @@ CFDictionaryRef RetainOrExpandPacFile(CFURLRef cfurl, CFDictionaryRef proxy) {
 
   // If configuration isn't PAC or resolving PAC fails, just returns
   // the retained proxy.
-  if (final_proxy == NULL) {
+  if (final_proxy == nullptr) {
     final_proxy = reinterpret_cast<CFDictionaryRef>(CFRetain(proxy));
   }
 
@@ -143,16 +141,21 @@ class MacProxyManager : public ProxyManagerInterface {
   bool GetProxyData(const string &url, string *hostdata, string *authdata) {
     DCHECK(hostdata);
     DCHECK(authdata);
+#ifdef OS_IOS
     scoped_cftyperef<CFDictionaryRef> proxy_settings(
-        SCDynamicStoreCopyProxies(NULL));
+        CFNetworkCopySystemProxySettings());
+#else
+    scoped_cftyperef<CFDictionaryRef> proxy_settings(
+        SCDynamicStoreCopyProxies(nullptr));
+#endif  // OS_IOS
     if (!proxy_settings.Verify(CFDictionaryGetTypeID())) {
       LOG(ERROR) << "Failed to create proxy setting";
       return false;
     }
 
     scoped_cftyperef<CFURLRef> cfurl(CFURLCreateWithBytes(
-        NULL, reinterpret_cast<const UInt8 *>(url.data()), url.size(),
-        kCFStringEncodingUTF8, NULL));
+        nullptr, reinterpret_cast<const UInt8 *>(url.data()), url.size(),
+        kCFStringEncodingUTF8, nullptr));
     if (!cfurl.Verify(CFURLGetTypeID())) {
       LOG(ERROR) << "Failed to create URL object from the specified URL";
       return false;
@@ -167,9 +170,9 @@ class MacProxyManager : public ProxyManagerInterface {
 
     bool proxy_available = false;
     if (CFArrayGetCount(proxies.get()) > 0) {
-      scoped_cftyperef<CFDictionaryRef> proxy(
-          RetainOrExpandPacFile(cfurl.get(), reinterpret_cast<CFDictionaryRef>(
-              CFArrayGetValueAtIndex(proxies.get(), 0))));
+      scoped_cftyperef<CFDictionaryRef> proxy(RetainOrExpandPacFile(
+          cfurl.get(), reinterpret_cast<CFDictionaryRef>(
+                           CFArrayGetValueAtIndex(proxies.get(), 0))));
 
       CFStringRef proxy_type = static_cast<CFStringRef>(
           CFDictionaryGetValue(proxy.get(), kCFProxyTypeKey));
@@ -187,7 +190,7 @@ class MacProxyManager : public ProxyManagerInterface {
           scoped_cftyperef<CFStringRef> host_desc;
           if (port.Verify(CFNumberGetTypeID())) {
             host_desc.reset(CFStringCreateWithFormat(
-                NULL, NULL, CFSTR("%@:%@"), host.get(), port.get()));
+                nullptr, nullptr, CFSTR("%@:%@"), host.get(), port.get()));
           } else {
             host_desc.reset(reinterpret_cast<CFStringRef>(host.get()));
             CFRetain(host.get());
@@ -195,7 +198,7 @@ class MacProxyManager : public ProxyManagerInterface {
           if (host_desc.Verify(CFStringGetTypeID())) {
             const char *hostdata_ptr =
                 CFStringGetCStringPtr(host_desc.get(), kCFStringEncodingUTF8);
-            if (hostdata_ptr != NULL) {
+            if (hostdata_ptr != nullptr) {
               hostdata->assign(hostdata_ptr);
               proxy_available = true;
             } else {
@@ -205,15 +208,15 @@ class MacProxyManager : public ProxyManagerInterface {
             LOG(ERROR) << "Invalid proxy spec: no host is specified";
           }
         }
-        if (proxy_available &&
-            username.Verify(CFStringGetTypeID()) &&
+        if (proxy_available && username.Verify(CFStringGetTypeID()) &&
             password.Verify(CFStringGetTypeID())) {
-          scoped_cftyperef<CFStringRef> auth_desc(CFStringCreateWithFormat(
-              NULL, NULL, CFSTR("%@:%@"), username.get(), password.get()));
+          scoped_cftyperef<CFStringRef> auth_desc(
+              CFStringCreateWithFormat(nullptr, nullptr, CFSTR("%@:%@"),
+                                       username.get(), password.get()));
           if (auth_desc.Verify(CFStringGetTypeID())) {
             const char *authdata_ptr =
                 CFStringGetCStringPtr(auth_desc.get(), kCFStringEncodingUTF8);
-            if (authdata_ptr != NULL) {
+            if (authdata_ptr != nullptr) {
               authdata->assign(authdata_ptr);
             }
           }
@@ -224,21 +227,22 @@ class MacProxyManager : public ProxyManagerInterface {
     return proxy_available;
   }
 };
-#endif  // OS_MACOSX
+#endif  // __APPLE__
 
-bool DummyProxyManager::GetProxyData(
-    const string &url, string *hostdata, string *authdata) {
+bool DummyProxyManager::GetProxyData(const std::string &url,
+                                     std::string *hostdata,
+                                     std::string *authdata) {
   return false;
 }
 
 namespace {
 
 // This is only used for dependency injection
-ProxyManagerInterface *g_proxy_manager = NULL;
+ProxyManagerInterface *g_proxy_manager = nullptr;
 
 ProxyManagerInterface *GetProxyManager() {
-  if (g_proxy_manager == NULL) {
-#ifdef OS_MACOSX
+  if (g_proxy_manager == nullptr) {
+#ifdef __APPLE__
     return Singleton<MacProxyManager>::get();
 #else
     return Singleton<DummyProxyManager>::get();
@@ -249,19 +253,16 @@ ProxyManagerInterface *GetProxyManager() {
 }
 }  // namespace
 
-void ProxyManager::SetProxyManager(
-    ProxyManagerInterface *proxy_manager) {
+void ProxyManager::SetProxyManager(ProxyManagerInterface *proxy_manager) {
   g_proxy_manager = proxy_manager;
 }
 
-bool ProxyManager::GetProxyData(
-    const string &url, string *hostdata, string *authdata) {
+bool ProxyManager::GetProxyData(const std::string &url, std::string *hostdata,
+                                std::string *authdata) {
   return GetProxyManager()->GetProxyData(url, hostdata, authdata);
 }
 
-ProxyManagerInterface::ProxyManagerInterface() {
-}
+ProxyManagerInterface::ProxyManagerInterface() {}
 
-ProxyManagerInterface::~ProxyManagerInterface() {
-}
+ProxyManagerInterface::~ProxyManagerInterface() {}
 }  // namespace mozc
