@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,8 +32,6 @@
 
 #include <Cocoa/Cocoa.h>
 
-#include "base/scoped_nsobject.h"
-
 namespace mozc {
 namespace renderer {
 namespace mac {
@@ -51,8 +49,8 @@ class RendererBaseWindow {
   RendererBaseWindow();
   virtual ~RendererBaseWindow();
 
-  scoped_nsobject<NSPanel> window_;
-  scoped_nsobject<NSView> view_;
+  NSPanel *window_;
+  NSView *view_;
   virtual void InitWindow();
 
  private:
