@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,6 @@
 #include <string>
 
 #include "base/coordinates.h"
-#include "base/port_string.h"
 #include "protocol/renderer_style.pb.h"
 
 namespace mozc {
@@ -48,7 +47,8 @@ class MacViewUtil {
   static NSColor *ToNSColor(
       const mozc::renderer::RendererStyle::RGBAColor &color);
 
-  static NSAttributedString *ToNSAttributedString(const string &str,
+  static NSAttributedString *ToNSAttributedString(
+      const std::string &str,
       const mozc::renderer::RendererStyle::TextStyle &style);
 
   static NSPoint ToNSPoint(const mozc::Point &point);
