@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -46,8 +46,9 @@
 #include "ipc/ipc.h"
 #include "ipc/named_event.h"
 #include "protocol/renderer_command.pb.h"
+#include "absl/memory/memory.h"
 
-#ifdef OS_MACOSX
+#ifdef __APPLE__
 #include "base/mac_util.h"
 #endif
 
@@ -59,34 +60,32 @@ namespace mozc {
 namespace renderer {
 namespace {
 
-const int    kIPCTimeout            = 100;        // 100 msec
-const int    kRendererWaitTimeout   = 30 * 1000;  // 30 sec
-const int    kRendererWaitSleepTime = 10 * 1000;  // 10 sec
-const size_t kMaxErrorTimes         = 5;
-const uint64 kRetryIntervalTime     = 30;  // 30 sec
-const char   kServiceName[]         = "renderer";
+const int kIPCTimeout = 100;                   // 100 msec
+const int kRendererWaitTimeout = 30 * 1000;    // 30 sec
+const int kRendererWaitSleepTime = 10 * 1000;  // 10 sec
+const size_t kMaxErrorTimes = 5;
+const uint64 kRetryIntervalTime = 30;  // 30 sec
+const char kServiceName[] = "renderer";
 
 inline void CallCommand(IPCClientInterface *client,
                         const commands::RendererCommand &command) {
-  string buf;
+  std::string buf;
   command.SerializeToString(&buf);
 
   // basically, we don't need to get the result
   char result[32];
   size_t result_size = sizeof(result);
 
-  if (!client->Call(buf.data(), buf.size(),
-                    result, &result_size,
+  if (!client->Call(buf.data(), buf.size(), result, &result_size,
                     kIPCTimeout)) {
     LOG(ERROR) << "Cannot send the request: ";
   }
 }
 }  // namespace
 
-class RendererLauncher : public RendererLauncherInterface,
-                         public Thread {
+class RendererLauncher : public RendererLauncherInterface, public Thread {
  public:
-  bool CanConnect() const {
+  bool CanConnect() const override {
     switch (renderer_status_) {
       case RendererLauncher::RENDERER_UNKNOWN:
       case RendererLauncher::RENDERER_READY:
@@ -113,13 +112,14 @@ class RendererLauncher : public RendererLauncherInterface,
     return false;
   }
 
-  bool IsAvailable() const {
+  bool IsAvailable() const override {
     return (renderer_status_ == RendererLauncher::RENDERER_READY);
   }
 
-  void StartRenderer(const string &name, const string &path,
-                     bool disable_renderer_path_check,
-                     IPCClientFactoryInterface *ipc_client_factory_interface) {
+  void StartRenderer(
+      const std::string &name, const std::string &path,
+      bool disable_renderer_path_check,
+      IPCClientFactoryInterface *ipc_client_factory_interface) override {
     renderer_status_ = RendererLauncher::RENDERER_LAUNCHING;
     name_ = name;
     path_ = path;
@@ -128,7 +128,7 @@ class RendererLauncher : public RendererLauncherInterface,
     Thread::Start("Renderer");
   }
 
-  void Run() {
+  void Run() override {
     last_launch_time_ = Clock::GetTime();
 
     NamedEventListener listener(name_.c_str());
@@ -146,14 +146,14 @@ class RendererLauncher : public RendererLauncherInterface,
     // If the current process is in a job, you cannot use
     // CREATE_BREAKAWAY_FROM_JOB. b/1571395
     info.use_locked_down_job = !process_in_job;
-    info.allow_ui_operation = true;   // skip UI protection
+    info.allow_ui_operation = true;  // skip UI protection
     info.in_system_dir = true;  // use system dir not to lock current directory
     info.creation_flags = CREATE_DEFAULT_ERROR_MODE;
 
     // start renreder process
-    const bool result = WinSandbox::SpawnSandboxedProcess(path_, arg, info,
-                                                          &pid);
-#elif defined(OS_MACOSX)  // OS_WIN
+    const bool result =
+        WinSandbox::SpawnSandboxedProcess(path_, arg, info, &pid);
+#elif defined(__APPLE__)  // OS_WIN
     // Start renderer process by using launch_msg API.
     pid_t pid = 0;
     const bool result = MacUtil::StartLaunchdService("Renderer", &pid);
@@ -161,7 +161,7 @@ class RendererLauncher : public RendererLauncherInterface,
     size_t tmp = 0;
     const bool result = Process::SpawnProcess(path_, "", &tmp);
     uint32 pid = static_cast<uint32>(tmp);
-#endif  // OS_WIN, OS_MACOSX
+#endif  // OS_WIN, __APPLE__
 
     if (!result) {
       LOG(ERROR) << "Can't start process";
@@ -170,8 +170,7 @@ class RendererLauncher : public RendererLauncherInterface,
     }
 
     if (listener_is_available) {
-      const int ret = listener.WaitEventOrProcess(kRendererWaitTimeout,
-                                                  pid);
+      const int ret = listener.WaitEventOrProcess(kRendererWaitTimeout, pid);
       switch (ret) {
         case NamedEventListener::TIMEOUT:
           LOG(ERROR) << "seems that mozc_renderer is not ready within "
@@ -209,14 +208,14 @@ class RendererLauncher : public RendererLauncherInterface,
     }
   }
 
-  bool ForceTerminateRenderer(const string &name) {
+  bool ForceTerminateRenderer(const std::string &name) override {
     return IPCClient::TerminateServer(name);
   }
 
-  void OnFatal(RendererErrorType type) {
+  void OnFatal(RendererErrorType type) override {
     LOG(ERROR) << "OnFatal is called: " << static_cast<int>(type);
 
-    string error_type;
+    std::string error_type;
     switch (type) {
       case RendererLauncherInterface::RENDERER_VERSION_MISMATCH:
         error_type = "renderer_version_mismatch";
@@ -234,18 +233,18 @@ class RendererLauncher : public RendererLauncherInterface,
     }
   }
 
-  void SetPendingCommand(const commands::RendererCommand &command) {
+  void SetPendingCommand(const commands::RendererCommand &command) override {
     // ignore NOOP|SHUTDOWN
     if (command.type() == commands::RendererCommand::UPDATE) {
       scoped_lock l(&pending_command_mutex_);
-      if (pending_command_.get() == NULL) {
-        pending_command_.reset(new commands::RendererCommand);
+      if (!pending_command_) {
+        pending_command_ = absl::make_unique<commands::RendererCommand>();
       }
-      pending_command_->CopyFrom(command);
+      *pending_command_ = command;
     }
   }
 
-  void set_suppress_error_dialog(bool suppress) {
+  void set_suppress_error_dialog(bool suppress) override {
     suppress_error_dialog_ = suppress;
   }
 
@@ -255,9 +254,9 @@ class RendererLauncher : public RendererLauncherInterface,
         error_times_(0),
         disable_renderer_path_check_(false),
         suppress_error_dialog_(false),
-        ipc_client_factory_interface_(NULL) {}
+        ipc_client_factory_interface_(nullptr) {}
 
-  virtual ~RendererLauncher() {
+  ~RendererLauncher() override {
     if (!IsRunning()) {
       return;
     }
@@ -268,20 +267,19 @@ class RendererLauncher : public RendererLauncherInterface,
 
  private:
   enum RendererStatus {
-    RENDERER_UNKNOWN    = 0,
-    RENDERER_LAUNCHING  = 1,
-    RENDERER_READY      = 2,
-    RENDERER_TIMEOUT    = 3,
+    RENDERER_UNKNOWN = 0,
+    RENDERER_LAUNCHING = 1,
+    RENDERER_READY = 2,
+    RENDERER_TIMEOUT = 3,
     RENDERER_TERMINATED = 4,
-    RENDERER_FATAL      = 5,
+    RENDERER_FATAL = 5,
   };
 
   void FlushPendingCommand() {
     scoped_lock l(&pending_command_mutex_);
-    if (ipc_client_factory_interface_ != NULL &&
-        pending_command_.get() != NULL) {
+    if (ipc_client_factory_interface_ != nullptr && pending_command_) {
       std::unique_ptr<IPCClientInterface> client(CreateIPCClient());
-      if (client.get() != NULL) {
+      if (!client) {
         CallCommand(client.get(), *(pending_command_.get()));
       }
     }
@@ -295,8 +293,8 @@ class RendererLauncher : public RendererLauncherInterface,
   }
 
   IPCClientInterface *CreateIPCClient() const {
-    if (ipc_client_factory_interface_ == NULL) {
-      return NULL;
+    if (ipc_client_factory_interface_ == nullptr) {
+      return nullptr;
     }
     if (disable_renderer_path_check_) {
       return ipc_client_factory_interface_->NewClient(name_, "");
@@ -304,8 +302,8 @@ class RendererLauncher : public RendererLauncherInterface,
     return ipc_client_factory_interface_->NewClient(name_, path_);
   }
 
-  string name_;
-  string path_;
+  std::string name_;
+  std::string path_;
   volatile RendererStatus renderer_status_;
   volatile uint64 last_launch_time_;
   volatile size_t error_times_;
@@ -322,11 +320,11 @@ RendererClient::RendererClient()
       version_mismatch_nums_(0),
       ipc_client_factory_interface_(IPCClientFactory::GetIPCClientFactory()),
       renderer_launcher_(new RendererLauncher),
-      renderer_launcher_interface_(NULL) {
+      renderer_launcher_interface_(nullptr) {
   renderer_launcher_interface_ = renderer_launcher_.get();
 
   name_ = kServiceName;
-  const string desktop_name(SystemUtil::GetDesktopNameAsString());
+  const std::string desktop_name(SystemUtil::GetDesktopNameAsString());
   if (!desktop_name.empty()) {
     name_ += ".";
     name_ += desktop_name;
@@ -346,17 +344,17 @@ RendererClient::~RendererClient() {
 }
 
 void RendererClient::SetIPCClientFactory(
-      IPCClientFactoryInterface *ipc_client_factory_interface) {
+    IPCClientFactoryInterface *ipc_client_factory_interface) {
   ipc_client_factory_interface_ = ipc_client_factory_interface;
 }
 
 void RendererClient::SetRendererLauncherInterface(
-      RendererLauncherInterface *renderer_launcher_interface) {
+    RendererLauncherInterface *renderer_launcher_interface) {
   renderer_launcher_interface_ = renderer_launcher_interface;
 }
 
 bool RendererClient::Activate() {
-  if (IsAvailable()) {   // already running
+  if (IsAvailable()) {  // already running
     return true;
   }
   commands::RendererCommand command;
@@ -365,8 +363,8 @@ bool RendererClient::Activate() {
 }
 
 bool RendererClient::IsAvailable() const {
-  if (renderer_launcher_interface_ == NULL) {
-    LOG(ERROR) << "renderer_launcher_interface is NULL";
+  if (renderer_launcher_interface_ == nullptr) {
+    LOG(ERROR) << "renderer_launcher_interface is nullptr";
     return false;
   }
   return renderer_launcher_interface_->IsAvailable();
@@ -375,7 +373,7 @@ bool RendererClient::IsAvailable() const {
 bool RendererClient::Shutdown(bool force) {
   std::unique_ptr<IPCClientInterface> client(CreateIPCClient());
 
-  if (client.get() == NULL) {
+  if (!client) {
     LOG(ERROR) << "Cannot make client object";
     return false;
   }
@@ -404,21 +402,21 @@ void RendererClient::DisableRendererServerCheck() {
 }
 
 void RendererClient::set_suppress_error_dialog(bool suppress) {
-  if (renderer_launcher_interface_ == NULL) {
-    LOG(ERROR) << "RendererLauncher is NULL";
+  if (renderer_launcher_interface_ == nullptr) {
+    LOG(ERROR) << "RendererLauncher is nullptr";
     return;
   }
   renderer_launcher_interface_->set_suppress_error_dialog(suppress);
 }
 
 bool RendererClient::ExecCommand(const commands::RendererCommand &command) {
-  if (renderer_launcher_interface_ == NULL) {
-    LOG(ERROR) << "RendererLauncher is NULL";
+  if (renderer_launcher_interface_ == nullptr) {
+    LOG(ERROR) << "RendererLauncher is nullptr";
     return false;
   }
 
-  if (ipc_client_factory_interface_ == NULL) {
-    LOG(ERROR) << "IPCClientFactory is NULL";
+  if (ipc_client_factory_interface_ == nullptr) {
+    LOG(ERROR) << "IPCClientFactory is nullptr";
     return false;
   }
 
@@ -488,9 +486,8 @@ bool RendererClient::ExecCommand(const commands::RendererCommand &command) {
 
   if (Version::CompareVersion(client->GetServerProductVersion(),
                               Version::GetMozcVersion())) {
-    LOG(WARNING) << "Version mismatch: "
-                 << client->GetServerProductVersion() << " "
-                 << Version::GetMozcVersion();
+    LOG(WARNING) << "Version mismatch: " << client->GetServerProductVersion()
+                 << " " << Version::GetMozcVersion();
     renderer_launcher_interface_->SetPendingCommand(command);
     commands::RendererCommand shutdown_command;
     shutdown_command.set_type(commands::RendererCommand::SHUTDOWN);
@@ -505,8 +502,8 @@ bool RendererClient::ExecCommand(const commands::RendererCommand &command) {
 }
 
 IPCClientInterface *RendererClient::CreateIPCClient() const {
-  if (ipc_client_factory_interface_ == NULL) {
-    return NULL;
+  if (ipc_client_factory_interface_ == nullptr) {
+    return nullptr;
   }
   if (disable_renderer_path_check_) {
     return ipc_client_factory_interface_->NewClient(name_, "");
