@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,8 +27,9 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include "protocol/renderer_style.pb.h"
 #include "renderer/renderer_style_handler.h"
+
+#include "protocol/renderer_style.pb.h"
 #include "testing/base/public/gunit.h"
 
 namespace mozc {
@@ -48,5 +49,5 @@ TEST(RendererStyleHandlerTest, GetDefaultRendererStyleTest) {
   RendererStyleHandler::GetDefaultRendererStyle(&style);
   EXPECT_EQ(true, style.has_window_border());
 }
-} // renderer
-} // mozc
+}  // namespace renderer
+}  // namespace mozc
