@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -51,13 +51,10 @@ class DrawTool : public DrawToolInterface {
   virtual void Restore();
   virtual void FillRect(const Rect &rect, const RGBA &color);
 
-  virtual void FrameRect(const Rect &rect,
-                         const RGBA &color,
+  virtual void FrameRect(const Rect &rect, const RGBA &color,
                          const uint32 line_width);
 
-  virtual void DrawLine(const Point &from,
-                        const Point &to,
-                        const RGBA &color,
+  virtual void DrawLine(const Point &from, const Point &to, const RGBA &color,
                         const uint32 line_width);
 
   // DrawTool class takes ownership of CairoWrapper.
