@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -61,8 +61,8 @@ class FontSpecInterface {
   // this function returns non-const value. This is due to API restriction which
   // is pango_attr_list_copy.
   virtual PangoAttrList *GetFontAttributes(FONT_TYPE font_type) const = 0;
-  virtual const PangoFontDescription *GetFontDescription(FONT_TYPE font_type)
-      const = 0;
+  virtual const PangoFontDescription *GetFontDescription(
+      FONT_TYPE font_type) const = 0;
 };
 }  // namespace gtk
 }  // namespace renderer
