@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -105,9 +105,7 @@ WTL::CRect ToCRect(const Rect &rect) {
 // This function returns the size of the given candidate list when there
 // aren't any candidates satisfying the above condition.
 int GetCandidateArrayIndexByCandidateIndex(
-    const commands::Candidates &candidates,
-    int candidate_index) {
-
+    const commands::Candidates &candidates, int candidate_index) {
   for (size_t i = 0; i < candidates.candidate_size(); ++i) {
     const commands::Candidates::Candidate &candidate = candidates.candidate(i);
 
@@ -133,9 +131,7 @@ string GetIndexGuideString(const commands::Candidates &candidates) {
   const int total_items = candidates.size();
 
   std::stringstream footer_string;
-  footer_string << focused_index + 1
-                << "/"
-                << total_items
+  footer_string << focused_index + 1 << "/" << total_items
                 << " ";  // for padding.
 
   return footer_string.str();
@@ -160,8 +156,7 @@ int GetFocusedArrayIndex(const commands::Candidates &candidates) {
 // Retrieves the display string from the specified candidate for the specified
 // column and returns it.
 std::wstring GetDisplayStringByColumn(
-    const commands::Candidates::Candidate &candidate,
-    COLUMN_TYPE column_type) {
+    const commands::Candidates::Candidate &candidate, COLUMN_TYPE column_type) {
   std::wstring display_string;
 
   switch (column_type) {
@@ -217,8 +212,8 @@ HBITMAP LoadBitmapFromResource(HMODULE module, int resource_id) {
   // You cannot load a a top-down DIB with LoadImage in Windows XP.
   // http://b/2076264
   return reinterpret_cast<HBITMAP>(
-      ::LoadImage(module, MAKEINTRESOURCE(resource_id), IMAGE_BITMAP,
-                  0, 0, LR_CREATEDIBSECTION));
+      ::LoadImage(module, MAKEINTRESOURCE(resource_id), IMAGE_BITMAP, 0, 0,
+                  LR_CREATEDIBSECTION));
 }
 
 }  // namespace
@@ -238,24 +233,23 @@ CandidateWindow::CandidateWindow()
       send_command_interface_(nullptr) {
   double scale_factor_x = 1.0;
   double scale_factor_y = 1.0;
-  RendererStyleHandler::GetDPIScalingFactor(&scale_factor_x,
-                                            &scale_factor_y);
+  RendererStyleHandler::GetDPIScalingFactor(&scale_factor_x, &scale_factor_y);
   double image_scale_factor = 1.0;
   if (scale_factor_x < 1.125 || scale_factor_y < 1.125) {
-    footer_logo_.Attach(LoadBitmapFromResource(
-      ::GetModuleHandle(nullptr), IDB_FOOTER_LOGO_COLOR_100));
+    footer_logo_.Attach(LoadBitmapFromResource(::GetModuleHandle(nullptr),
+                                               IDB_FOOTER_LOGO_COLOR_100));
     image_scale_factor = 1.0;
   } else if (scale_factor_x < 1.375 || scale_factor_y < 1.375) {
-    footer_logo_.Attach(LoadBitmapFromResource(
-      ::GetModuleHandle(nullptr), IDB_FOOTER_LOGO_COLOR_125));
+    footer_logo_.Attach(LoadBitmapFromResource(::GetModuleHandle(nullptr),
+                                               IDB_FOOTER_LOGO_COLOR_125));
     image_scale_factor = 1.25;
   } else if (scale_factor_x < 1.75 || scale_factor_y < 1.75) {
-    footer_logo_.Attach(LoadBitmapFromResource(
-      ::GetModuleHandle(nullptr), IDB_FOOTER_LOGO_COLOR_150));
+    footer_logo_.Attach(LoadBitmapFromResource(::GetModuleHandle(nullptr),
+                                               IDB_FOOTER_LOGO_COLOR_150));
     image_scale_factor = 1.5;
   } else {
-    footer_logo_.Attach(LoadBitmapFromResource(
-      ::GetModuleHandle(nullptr), IDB_FOOTER_LOGO_COLOR_200));
+    footer_logo_.Attach(LoadBitmapFromResource(::GetModuleHandle(nullptr),
+                                               IDB_FOOTER_LOGO_COLOR_200));
     image_scale_factor = 2.0;
   }
 
@@ -284,8 +278,8 @@ void CandidateWindow::EnableOrDisableWindowForWorkaround() {
   // TODO(yukawa): Support mouse operations before we add a GUI feature which
   //   requires UI interaction by mouse and/or touch. (b/2954874)
   BOOL is_tracking_enabled = FALSE;
-  if (::SystemParametersInfo(SPI_GETACTIVEWINDOWTRACKING,
-                             0, &is_tracking_enabled, 0)) {
+  if (::SystemParametersInfo(SPI_GETACTIVEWINDOWTRACKING, 0,
+                             &is_tracking_enabled, 0)) {
     EnableWindow(!is_tracking_enabled);
   }
 }
@@ -311,8 +305,8 @@ void CandidateWindow::OnGetMinMaxInfo(MINMAXINFO *min_max_info) {
   SetMsgHandled(TRUE);
 }
 
-void CandidateWindow::HandleMouseEvent(
-    UINT nFlags, const WTL::CPoint &point, bool close_candidatewindow) {
+void CandidateWindow::HandleMouseEvent(UINT nFlags, const WTL::CPoint &point,
+                                       bool close_candidatewindow) {
   if (send_command_interface_ == nullptr) {
     LOG(ERROR) << "send_command_interface_ is nullptr";
     return;
@@ -321,8 +315,8 @@ void CandidateWindow::HandleMouseEvent(
   const int focused_array_index = GetFocusedArrayIndex(*candidates_);
 
   for (size_t i = 0; i < candidates_->candidate_size(); ++i) {
-    const commands::Candidates::Candidate &candidate
-        = candidates_->candidate(i);
+    const commands::Candidates::Candidate &candidate =
+        candidates_->candidate(i);
 
     const CRect rect = ToCRect(table_layout_->GetRowRect(i));
     if (rect.PtInRect(point)) {
@@ -373,9 +367,9 @@ void CandidateWindow::OnPaint(CDCHandle dc) {
   if (dc != nullptr) {
     CMemoryDC memdc(dc, client_rect);
     DoPaint(memdc.m_hDC);
-  } else  {
+  } else {
     CPaintDC paint_dc(this->m_hWnd);
-    { // Create a copy of |paint_dc| and render the candidate strings in it.
+    {  // Create a copy of |paint_dc| and render the candidate strings in it.
       // The image rendered to this |memdc| is to be copied into the original
       // |paint_dc| in its destructor. So, we don't have to explicitly call
       // any functions that copy this |memdc| to the |paint_dc| but putting
@@ -386,9 +380,7 @@ void CandidateWindow::OnPaint(CDCHandle dc) {
   }
 }
 
-void CandidateWindow::OnPrintClient(CDCHandle dc, UINT uFlags) {
-  OnPaint(dc);
-}
+void CandidateWindow::OnPrintClient(CDCHandle dc, UINT uFlags) { OnPaint(dc); }
 
 void CandidateWindow::DoPaint(CDCHandle dc) {
   switch (candidates_->category()) {
@@ -477,14 +469,12 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
     // Calculate the size to display a label string.
     if (candidates_->footer().has_label()) {
       std::wstring footer_label;
-      mozc::Util::UTF8ToWide(candidates_->footer().label(),
-                             &footer_label);
+      mozc::Util::UTF8ToWide(candidates_->footer().label(), &footer_label);
       const Size label_string_size = text_renderer_->MeasureString(
-          TextRenderer::FONTSET_FOOTER_LABEL,
-          L" " + footer_label + L" ");
+          TextRenderer::FONTSET_FOOTER_LABEL, L" " + footer_label + L" ");
       footer_size.width += label_string_size.width;
-      footer_size.height = std::max(footer_size.height,
-                                    label_string_size.height);
+      footer_size.height =
+          std::max(footer_size.height, label_string_size.height);
     } else if (candidates_->footer().has_sub_label()) {
       // Currently the sub label will not be shown unless (main) label is
       // absent.
@@ -492,12 +482,12 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
       std::wstring footer_sub_label;
       mozc::Util::UTF8ToWide(candidates_->footer().sub_label(),
                              &footer_sub_label);
-      const Size label_string_size = text_renderer_->MeasureString(
-          TextRenderer::FONTSET_FOOTER_SUBLABEL,
-          L" " + footer_sub_label + L" ");
+      const Size label_string_size =
+          text_renderer_->MeasureString(TextRenderer::FONTSET_FOOTER_SUBLABEL,
+                                        L" " + footer_sub_label + L" ");
       footer_size.width += label_string_size.width;
-      footer_size.height = std::max(footer_size.height,
-                                    label_string_size.height);
+      footer_size.height =
+          std::max(footer_size.height, label_string_size.height);
     }
 
     // Calculate the size to display a index string.
@@ -508,22 +498,22 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
       const Size index_guide_size = text_renderer_->MeasureString(
           TextRenderer::FONTSET_FOOTER_INDEX, index_guide_string);
       footer_size.width += index_guide_size.width;
-      footer_size.height = std::max(footer_size.height,
-                                    index_guide_size.height);
+      footer_size.height =
+          std::max(footer_size.height, index_guide_size.height);
     }
 
     // Calculate the size to display a Footer logo.
     if (!footer_logo_.IsNull()) {
       if (candidates_->footer().logo_visible()) {
         footer_size.width += footer_logo_display_size_.width;
-        footer_size.height = std::max(footer_size.height,
-                                      footer_logo_display_size_.height);
+        footer_size.height =
+            std::max(footer_size.height, footer_logo_display_size_.height);
       } else if (footer_size.height > 0) {
         // Ensure the footer height is greater than the Footer logo height
         // even if the Footer logo is absent.  This hack prevents the footer
         // from changing its height too frequently.
-        footer_size.height = std::max(footer_size.height,
-                                      footer_logo_display_size_.height);
+        footer_size.height =
+            std::max(footer_size.height, footer_logo_display_size_.height);
       }
     }
 
@@ -532,13 +522,12 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
     if (candidates_->candidate_size() < candidates_->size()) {
       // We use FONTSET_CANDIDATE for calculating the minimum width.
       std::wstring minimum_width_as_wstring;
-      mozc::Util::UTF8ToWide(
-          kMinimumCandidateAndDescriptionWidthAsString,
-          &minimum_width_as_wstring);
+      mozc::Util::UTF8ToWide(kMinimumCandidateAndDescriptionWidthAsString,
+                             &minimum_width_as_wstring);
       const Size minimum_size = text_renderer_->MeasureString(
           TextRenderer::FONTSET_CANDIDATE, minimum_width_as_wstring.c_str());
-      table_layout_->EnsureColumnsWidth(
-          COLUMN_CANDIDATE, COLUMN_DESCRIPTION, minimum_size.width);
+      table_layout_->EnsureColumnsWidth(COLUMN_CANDIDATE, COLUMN_DESCRIPTION,
+                                        minimum_size.width);
     }
 
     // Add separator height
@@ -573,8 +562,8 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
       text.push_back(L' ');  // put a space for padding
       text.append(shortcut);
       text.push_back(L' ');  // put a space for padding
-      const Size rendering_size = text_renderer_->MeasureString(
-          TextRenderer::FONTSET_SHORTCUT, text);
+      const Size rendering_size =
+          text_renderer_->MeasureString(TextRenderer::FONTSET_SHORTCUT, text);
       table_layout_->EnsureCellSize(COLUMN_SHORTCUT, rendering_size);
     }
 
@@ -582,8 +571,8 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
       std::wstring text;
       text.append(candidate_string);
 
-      const Size rendering_size = text_renderer_->MeasureString(
-          TextRenderer::FONTSET_CANDIDATE, text);
+      const Size rendering_size =
+          text_renderer_->MeasureString(TextRenderer::FONTSET_CANDIDATE, text);
       table_layout_->EnsureCellSize(COLUMN_CANDIDATE, rendering_size);
     }
 
@@ -610,7 +599,7 @@ void CandidateWindow::UpdateLayout(const commands::Candidates &candidates) {
 }
 
 void CandidateWindow::SetSendCommandInterface(
-  client::SendCommandInterface *send_command_interface) {
+    client::SendCommandInterface *send_command_interface) {
   send_command_interface_ = send_command_interface;
 }
 
@@ -650,15 +639,15 @@ Rect CandidateWindow::GetFirstRowInClientCord() const {
 }
 
 void CandidateWindow::DrawCells(CDCHandle dc) {
-  COLUMN_TYPE kColumnTypes[] =
-      {COLUMN_SHORTCUT, COLUMN_CANDIDATE, COLUMN_DESCRIPTION};
-  TextRenderer::FONT_TYPE kFontTypes[] =
-      {TextRenderer::FONTSET_SHORTCUT, TextRenderer::FONTSET_CANDIDATE,
-       TextRenderer::FONTSET_DESCRIPTION};
+  COLUMN_TYPE kColumnTypes[] = {COLUMN_SHORTCUT, COLUMN_CANDIDATE,
+                                COLUMN_DESCRIPTION};
+  TextRenderer::FONT_TYPE kFontTypes[] = {TextRenderer::FONTSET_SHORTCUT,
+                                          TextRenderer::FONTSET_CANDIDATE,
+                                          TextRenderer::FONTSET_DESCRIPTION};
 
   DCHECK_EQ(arraysize(kColumnTypes), arraysize(kFontTypes));
-  for (size_t type_index = 0;
-       type_index < arraysize(kColumnTypes); ++type_index) {
+  for (size_t type_index = 0; type_index < arraysize(kColumnTypes);
+       ++type_index) {
     const COLUMN_TYPE column_type = kColumnTypes[type_index];
     const TextRenderer::FONT_TYPE font_type = kFontTypes[type_index];
 
@@ -668,8 +657,7 @@ void CandidateWindow::DrawCells(CDCHandle dc) {
           candidates_->candidate(i);
       const std::wstring display_string =
           GetDisplayStringByColumn(candidate, column_type);
-      const Rect text_rect =
-          table_layout_->GetCellRect(i, column_type);
+      const Rect text_rect = table_layout_->GetCellRect(i, column_type);
       display_list.push_back(TextRenderingInfo(display_string, text_rect));
     }
     text_renderer_->RenderTextList(dc, display_list, font_type);
@@ -689,9 +677,8 @@ void CandidateWindow::DrawVScrollBar(CDCHandle dc) {
     const CRect background_crect = ToCRect(vscroll_rect);
     dc.FillSolidRect(&background_crect, kIndicatorBackgroundColor);
 
-    const mozc::Rect &indicator_rect =
-        table_layout_->GetVScrollIndicatorRect(
-            begin_index, end_index, candidates_total);
+    const mozc::Rect &indicator_rect = table_layout_->GetVScrollIndicatorRect(
+        begin_index, end_index, candidates_total);
 
     const CRect indicator_crect = ToCRect(indicator_rect);
     dc.FillSolidRect(&indicator_crect, kIndicatorColor);
@@ -723,13 +710,12 @@ void CandidateWindow::DrawFooter(CDCHandle dc) {
     return;
   }
 
-  const COLORREF kFooterSeparatorColors[kFooterSeparatorHeight] = {
-      kFrameColor };
+  const COLORREF kFooterSeparatorColors[kFooterSeparatorHeight] = {kFrameColor};
 
   // DC pen is available in Windows 2000 and later.
   CPenHandle prev_pen(dc.SelectPen(static_cast<HPEN>(GetStockObject(DC_PEN))));
-  for (size_t i = 0, y = footer_rect.Top();
-       i < kFooterSeparatorHeight; y++, i++) {
+  for (size_t i = 0, y = footer_rect.Top(); i < kFooterSeparatorHeight;
+       y++, i++) {
     if (i < ARRAYSIZE(kFooterSeparatorColors)) {
       dc.SetDCPenColor(kFooterSeparatorColors[i]);
       dc.MoveTo(footer_rect.Left(), y, nullptr);
@@ -739,30 +725,21 @@ void CandidateWindow::DrawFooter(CDCHandle dc) {
   dc.SelectPen(prev_pen);
 
   const Rect footer_content_rect(
-      footer_rect.Left(),
-      footer_rect.Top() + kFooterSeparatorHeight,
-      footer_rect.Width(),
-      footer_rect.Height() - kFooterSeparatorHeight);
+      footer_rect.Left(), footer_rect.Top() + kFooterSeparatorHeight,
+      footer_rect.Width(), footer_rect.Height() - kFooterSeparatorHeight);
 
   // Draw gradient rect in the footer area
   {
     TRIVERTEX vertices[] = {
-      { footer_content_rect.Left(),
-        footer_content_rect.Top(),
-        GetRValue(kFooterTopColor) << 8,
-        GetGValue(kFooterTopColor) << 8,
-        GetBValue(kFooterTopColor) << 8,
-        0xff00 },
-      { footer_content_rect.Right(),
-        footer_content_rect.Bottom(),
-        GetRValue(kFooterBottomColor) << 8,
-        GetGValue(kFooterBottomColor) << 8,
-        GetBValue(kFooterBottomColor) << 8,
-        0xff00 }
-    };
-    GRADIENT_RECT indices[] = { {0, 1} };
-    dc.GradientFill(&vertices[0], ARRAYSIZE(vertices),
-                    &indices[0],  ARRAYSIZE(indices), GRADIENT_FILL_RECT_V);
+        {footer_content_rect.Left(), footer_content_rect.Top(),
+         GetRValue(kFooterTopColor) << 8, GetGValue(kFooterTopColor) << 8,
+         GetBValue(kFooterTopColor) << 8, 0xff00},
+        {footer_content_rect.Right(), footer_content_rect.Bottom(),
+         GetRValue(kFooterBottomColor) << 8, GetGValue(kFooterBottomColor) << 8,
+         GetBValue(kFooterBottomColor) << 8, 0xff00}};
+    GRADIENT_RECT indices[] = {{0, 1}};
+    dc.GradientFill(&vertices[0], ARRAYSIZE(vertices), &indices[0],
+                    ARRAYSIZE(indices), GRADIENT_FILL_RECT_V);
   }
 
   int left_used = 0;
@@ -779,11 +756,10 @@ void CandidateWindow::DrawFooter(CDCHandle dc) {
 
     // NOTE: AC_SRC_ALPHA requires PBGRA (pre-multiplied alpha) DIB.
     const BLENDFUNCTION bf = {AC_SRC_OVER, 0, 255, AC_SRC_ALPHA};
-    dc.AlphaBlend(footer_content_rect.Left(),
-                  footer_content_rect.Top() + top_offset,
-                  footer_logo_display_size_.width,
-                  footer_logo_display_size_.height,
-                  src_dc, 0, 0, src_size.cx, src_size.cy, bf);
+    dc.AlphaBlend(
+        footer_content_rect.Left(), footer_content_rect.Top() + top_offset,
+        footer_logo_display_size_.width, footer_logo_display_size_.height,
+        src_dc, 0, 0, src_size.cx, src_size.cy, bf);
 
     src_dc.SelectBitmap(old_bitmap);
     left_used = footer_content_rect.Left() + footer_logo_display_size_.width;
@@ -797,8 +773,7 @@ void CandidateWindow::DrawFooter(CDCHandle dc) {
     const Size index_guide_size = text_renderer_->MeasureString(
         TextRenderer::FONTSET_FOOTER_INDEX, index_guide_string);
     const Rect index_rect(footer_content_rect.Right() - index_guide_size.width,
-                          footer_content_rect.Top(),
-                          index_guide_size.width,
+                          footer_content_rect.Top(), index_guide_size.width,
                           footer_content_rect.Height());
     text_renderer_->RenderText(dc, index_guide_string, index_rect,
                                TextRenderer::FONTSET_FOOTER_INDEX);
@@ -806,28 +781,22 @@ void CandidateWindow::DrawFooter(CDCHandle dc) {
   }
 
   if (candidates_->footer().has_label()) {
-    const Rect label_rect(left_used,
-                          footer_content_rect.Top(),
+    const Rect label_rect(left_used, footer_content_rect.Top(),
                           footer_content_rect.Width() - left_used - right_used,
                           footer_content_rect.Height());
     std::wstring footer_label;
     mozc::Util::UTF8ToWide(candidates_->footer().label(), &footer_label);
-    text_renderer_->RenderText(dc,
-                               L" " + footer_label + L" ",
-                               label_rect,
+    text_renderer_->RenderText(dc, L" " + footer_label + L" ", label_rect,
                                TextRenderer::FONTSET_FOOTER_LABEL);
   } else if (candidates_->footer().has_sub_label()) {
     std::wstring footer_sub_label;
     mozc::Util::UTF8ToWide(candidates_->footer().sub_label(),
                            &footer_sub_label);
-    const Rect label_rect(left_used,
-                          footer_content_rect.Top(),
+    const Rect label_rect(left_used, footer_content_rect.Top(),
                           footer_content_rect.Width() - left_used - right_used,
                           footer_content_rect.Height());
     const std::wstring text = L" " + footer_sub_label + L" ";
-    text_renderer_->RenderText(dc,
-                               text,
-                               label_rect,
+    text_renderer_->RenderText(dc, text, label_rect,
                                TextRenderer::FONTSET_FOOTER_SUBLABEL);
   }
 }
@@ -839,16 +808,15 @@ void CandidateWindow::DrawSelectedRect(CDCHandle dc) {
 
   if (0 <= focused_array_index &&
       focused_array_index < candidates_->candidate_size()) {
-    const commands::Candidates::Candidate &candidate
-        = candidates_->candidate(focused_array_index);
+    const commands::Candidates::Candidate &candidate =
+        candidates_->candidate(focused_array_index);
 
     const CRect selected_rect =
         ToCRect(table_layout_->GetRowRect(focused_array_index));
     dc.FillSolidRect(&selected_rect, kSelectedRowBackgroundColor);
 
     dc.SetDCBrushColor(kSelectedRowFrameColor);
-    dc.FrameRect(&selected_rect,
-                 static_cast<HBRUSH>(GetStockObject(DC_BRUSH)));
+    dc.FrameRect(&selected_rect, static_cast<HBRUSH>(GetStockObject(DC_BRUSH)));
   }
 }
 
@@ -856,8 +824,7 @@ void CandidateWindow::DrawInformationIcon(CDCHandle dc) {
   DCHECK(table_layout_->IsLayoutFrozen()) << "Table layout is not frozen.";
   double scale_factor_x = 1.0;
   double scale_factor_y = 1.0;
-  RendererStyleHandler::GetDPIScalingFactor(&scale_factor_x,
-                                            &scale_factor_y);
+  RendererStyleHandler::GetDPIScalingFactor(&scale_factor_x, &scale_factor_y);
   for (size_t i = 0; i < candidates_->candidate_size(); ++i) {
     if (candidates_->candidate(i).has_information_id()) {
       CRect rect = ToCRect(table_layout_->GetRowRect(i));
@@ -867,8 +834,7 @@ void CandidateWindow::DrawInformationIcon(CDCHandle dc) {
       rect.bottom -= (2.0 * scale_factor_y);
       dc.FillSolidRect(&rect, kIndicatorColor);
       dc.SetDCBrushColor(kIndicatorColor);
-      dc.FrameRect(&rect,
-                   static_cast<HBRUSH>(GetStockObject(DC_BRUSH)));
+      dc.FrameRect(&rect, static_cast<HBRUSH>(GetStockObject(DC_BRUSH)));
     }
   }
 }
@@ -885,13 +851,10 @@ void CandidateWindow::DrawFrame(CDCHandle dc) {
 
   // DC brush is available in Windows 2000 and later.
   dc.SetDCBrushColor(kFrameColor);
-  dc.FrameRect(&client_crect,
-               static_cast<HBRUSH>(GetStockObject(DC_BRUSH)));
+  dc.FrameRect(&client_crect, static_cast<HBRUSH>(GetStockObject(DC_BRUSH)));
 }
 
-void CandidateWindow::set_mouse_moving(bool moving) {
-  mouse_moving_ = moving;
-}
+void CandidateWindow::set_mouse_moving(bool moving) { mouse_moving_ = moving; }
 }  // namespace win32
 }  // namespace renderer
 }  // namespace mozc
