@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,6 +29,7 @@
 
 #include "renderer/win32/composition_window.h"
 
+// clang-format off
 #include <windows.h>
 #define _ATL_NO_AUTOMATIC_NAMESPACE
 #define _WTL_NO_AUTOMATIC_NAMESPACE
@@ -38,6 +39,7 @@
 #include <atlgdi.h>
 #include <atlmisc.h>
 #include <atlwin.h>
+// clang-format on
 
 #include <string>
 #include <vector>
@@ -60,12 +62,11 @@ using WTL::CFontHandle;
 using WTL::CLogFont;
 using WTL::CMemoryDC;
 using WTL::CPaintDC;
+using WTL::CPen;
 using WTL::CPenHandle;
 using WTL::CPoint;
 using WTL::CRect;
 using WTL::CSize;
-using WTL::CPen;
-using WTL::CPenHandle;
 
 namespace {
 // As Discussed in b/2317702, UI windows are disabled by default because it is
@@ -74,26 +75,24 @@ namespace {
 // SPI_GETACTIVEWINDOWTRACKING is enabled.
 // TODO(yukawa): Support mouse operations before we add a GUI feature which
 //   requires UI interaction by mouse and/or touch. (b/2954874)
-typedef ATL::CWinTraits<
-            WS_POPUP | WS_DISABLED,
-            WS_EX_TOOLWINDOW | WS_EX_TOPMOST | WS_EX_NOACTIVATE>
-        CompositionLineWindowTraits;
+typedef ATL::CWinTraits<WS_POPUP | WS_DISABLED,
+                        WS_EX_TOOLWINDOW | WS_EX_TOPMOST | WS_EX_NOACTIVATE>
+    CompositionLineWindowTraits;
 
 // A class which implements an IME composition window for Windows. This class
 // is derived from an ATL CWindowImpl<T> class, which provides methods for
 // creating a window and handling windows messages.
 class CompositionLineWindow
-    : public ATL::CWindowImpl<CompositionLineWindow,
-                              ATL::CWindow,
+    : public ATL::CWindowImpl<CompositionLineWindow, ATL::CWindow,
                               CompositionLineWindowTraits> {
  public:
   DECLARE_WND_CLASS_EX(kCompositionWindowClassName, CS_SAVEBITS, COLOR_WINDOW);
 
   BEGIN_MSG_MAP_EX(CandidateWindow)
-    MSG_WM_CREATE(OnCreate)
-    MSG_WM_ERASEBKGND(OnEraseBkgnd)
-    MSG_WM_PAINT(OnPaint)
-    MSG_WM_PRINTCLIENT(OnPrintClient)
+  MSG_WM_CREATE(OnCreate)
+  MSG_WM_ERASEBKGND(OnEraseBkgnd)
+  MSG_WM_PAINT(OnPaint)
+  MSG_WM_PRINTCLIENT(OnPrintClient)
   END_MSG_MAP()
 
   CompositionLineWindow() {}
@@ -116,9 +115,9 @@ class CompositionLineWindow
     if (dc != nullptr) {
       CMemoryDC memdc(dc, client_rect);
       DoPaint(memdc.m_hDC);
-    } else  {
+    } else {
       CPaintDC paint_dc(this->m_hWnd);
-      { // Create a copy of |paint_dc| and render the candidate strings in it.
+      {  // Create a copy of |paint_dc| and render the candidate strings in it.
         // The image rendered to this |memdc| is to be copied into the original
         // |paint_dc| in its destructor. So, we don't have to explicitly call
         // any functions that copy this |memdc| to the |paint_dc| but putting
@@ -128,13 +127,12 @@ class CompositionLineWindow
       }
     }
   }
-  void OnPrintClient(CDCHandle dc, UINT uFlags) {
-    OnPaint(dc);
-  }
+  void OnPrintClient(CDCHandle dc, UINT uFlags) { OnPaint(dc); }
   void UpdateLayout(const CompositionWindowLayout &layout) {
     layout_ = layout;
     font_ = CLogFont(layout.log_font).CreateFontIndirect();
   }
+
  private:
   void DoPaint(WTL::CDCHandle dc) {
     const CFontHandle old_font = dc.SelectFont(font_);
@@ -142,13 +140,9 @@ class CompositionLineWindow
     GetClientRect(&client_rect);
     dc.SetBkMode(TRANSPARENT);
     dc.FillSolidRect(&client_rect, RGB(0xff, 0xff, 0xff));
-    dc.ExtTextOutW(
-      layout_.base_position.x,
-      layout_.base_position.y,
-      0,
-      &layout_.text_area,
-      layout_.text.c_str(),
-      layout_.text.size());
+    dc.ExtTextOutW(layout_.base_position.x, layout_.base_position.y, 0,
+                   &layout_.text_area, layout_.text.c_str(),
+                   layout_.text.size());
     dc.SelectFont(old_font);
     dc.SetDCPenColor(RGB(0, 0, 0));
     CPenHandle old_pen = dc.GetCurrentPen();
@@ -162,9 +156,9 @@ class CompositionLineWindow
       } else {
         if (dotted_pen_.IsNull()) {
           const LOGBRUSH logbrush = {
-            BS_SOLID,      // lbStyle
-            RGB(0, 0, 0),  // lbColor;
-            0,             // lbHatch;
+              BS_SOLID,      // lbStyle
+              RGB(0, 0, 0),  // lbColor;
+              0,             // lbHatch;
           };
           // TODO(yukawa): Check the following issue on remote desktop.
           // http://msdn.microsoft.com/en-us/library/dd162705.aspx#1
@@ -184,18 +178,15 @@ class CompositionLineWindow
   }
   CompositionWindowLayout layout_;
   CFont font_;
-  CPen  dotted_pen_;
-  CPen  highlighted_pen_;
+  CPen dotted_pen_;
+  CPen highlighted_pen_;
   DISALLOW_COPY_AND_ASSIGN(CompositionLineWindow);
 };
 
 class CompositionWindowListImpl : public CompositionWindowList {
  public:
-  CompositionWindowListImpl() {
-  }
-  virtual ~CompositionWindowListImpl() {
-    Destroy();
-  }
+  CompositionWindowListImpl() {}
+  virtual ~CompositionWindowListImpl() { Destroy(); }
 
   virtual void UpdateLayout(
       const std::vector<CompositionWindowLayout> &layouts) {
@@ -218,9 +209,9 @@ class CompositionWindowListImpl : public CompositionWindowList {
         // We have to ensure the composition window will be placed at the top
         // most of the TOPMOST layer because the attached window might also be
         // in the TOPMOST layer.
-        line_windows_[i]->SetWindowPos(
-            HWND_TOPMOST, rect.left, rect.top, rect.Width(), rect.Height(),
-            SWP_NOACTIVATE | SWP_SHOWWINDOW);
+        line_windows_[i]->SetWindowPos(HWND_TOPMOST, rect.left, rect.top,
+                                       rect.Width(), rect.Height(),
+                                       SWP_NOACTIVATE | SWP_SHOWWINDOW);
         line_windows_[i]->Invalidate(FALSE);
       }
     }
