@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,7 @@ class RendererCommand;
 // allow forward declaration of a nested-type.
 class RendererCommand_ApplicationInfo;
 class RendererCommand_CandidateForm;
-}  // commands
+}  // namespace commands
 
 namespace renderer {
 namespace win32 {
@@ -74,7 +74,7 @@ struct LineLayout {
 struct SegmentMarkerLayout {
   POINT from;
   POINT to;
-  bool  highlighted;
+  bool highlighted;
   SegmentMarkerLayout();
 };
 
@@ -110,8 +110,8 @@ class CandidateWindowLayout {
 
   // Initializes fields with given target position and exclude region and
   // sets true to |initialized_|.
-  void InitializeWithPositionAndExcludeRegion(
-      const POINT &position, const RECT &exclude_region);
+  void InitializeWithPositionAndExcludeRegion(const POINT &position,
+                                              const RECT &exclude_region);
 
   // Clears fields and sets false to |initialized_|.
   void Clear();
@@ -196,9 +196,9 @@ class WindowPositionInterface {
   // Returns true if this method can convert the given coordinate into
   // physical space.  We do not declare this method as const method so
   // that a mock class can implement this method in non-const way.
-  virtual bool LogicalToPhysicalPoint(
-      HWND window_handle, const POINT &logical_coordinate,
-      POINT *physical_coordinate) = 0;
+  virtual bool LogicalToPhysicalPoint(HWND window_handle,
+                                      const POINT &logical_coordinate,
+                                      POINT *physical_coordinate) = 0;
 
   // This method wraps API call of GetWindowRect.
   virtual bool GetWindowRect(HWND window_handle, RECT *rect) = 0;
@@ -230,10 +230,11 @@ class WindowPositionEmulator : public WindowPositionInterface {
   // Returns a dummy window handle for this emulator.  You can call methods of
   // WindowPositionInterface with this dummy handle.  You need not to release
   // the returned handle.
-  virtual HWND RegisterWindow(
-      const std::wstring &class_name, const RECT &window_rect,
-      const POINT &client_area_offset, const SIZE &client_area_size,
-      double scale_factor) = 0;
+  virtual HWND RegisterWindow(const std::wstring &class_name,
+                              const RECT &window_rect,
+                              const POINT &client_area_offset,
+                              const SIZE &client_area_size,
+                              double scale_factor) = 0;
 
   virtual void SetRoot(HWND child_window, HWND root_window) = 0;
 };
@@ -294,8 +295,8 @@ class LayoutManager {
   //    displayed.
   bool LayoutCompositionWindow(
       const commands::RendererCommand &command,
-     std::vector<CompositionWindowLayout> *composition_window_layouts,
-      CandidateWindowLayout* candidate_layout) const;
+      std::vector<CompositionWindowLayout> *composition_window_layouts,
+      CandidateWindowLayout *candidate_layout) const;
 
   // Returns compatibility bits for given target application.
   int GetCompatibilityMode(
@@ -329,12 +330,12 @@ class LayoutManager {
   // See remarks of the following document for details about the limitations.
   // http://msdn.microsoft.com/en-us/library/ms633533.aspx
   // This method is thread-safe.
-  void GetPointInPhysicalCoords(
-      HWND window_handle, const POINT &point, POINT *result) const;
+  void GetPointInPhysicalCoords(HWND window_handle, const POINT &point,
+                                POINT *result) const;
 
   // RECT version of GetPointInPhysicalCoords.  This method is thread-safe.
-  void GetRectInPhysicalCoords(
-      HWND window_handle, const RECT &rect, RECT *result) const;
+  void GetRectInPhysicalCoords(HWND window_handle, const RECT &rect,
+                               RECT *result) const;
 
   // Converts a local coordinate into a logical screen coordinate assuming
   // |src_point| is the relative offset from the top-left of the
@@ -418,12 +419,11 @@ class LayoutManager {
   //    the |str| starts from if there is enough space to show the first
   //    character.
   //  LineLayout: Layout information for each split line.
-  static bool CalcLayoutWithTextWrapping(
-      const LOGFONTW &font,
-      const std::wstring &text,
-      int maximum_line_length,
-      int initial_offset,
-     std::vector<LineLayout> *line_layouts);
+  static bool CalcLayoutWithTextWrapping(const LOGFONTW &font,
+                                         const std::wstring &text,
+                                         int maximum_line_length,
+                                         int initial_offset,
+                                         std::vector<LineLayout> *line_layouts);
 
   std::unique_ptr<SystemPreferenceInterface> system_preference_;
   std::unique_ptr<WindowPositionInterface> window_position_;
