@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,6 @@
 #include "base/flags.h"
 #include "base/hash.h"
 #include "base/logging.h"
-#include "base/string_piece.h"
 #include "base/util.h"
 #include "converter/segments.h"
 #include "data_manager/data_manager_interface.h"
@@ -45,6 +44,8 @@
 #include "request/conversion_request.h"
 #include "rewriter/collocation_util.h"
 #include "storage/existence_filter.h"
+#include "absl/strings/str_cat.h"
+#include "absl/strings/string_view.h"
 
 DEFINE_bool(use_collocation, true, "use collocation rewrite");
 
@@ -63,7 +64,7 @@ enum SegmentLookupType {
 };
 
 // returns true if the given string contains number including Kanji.
-bool ContainsNumber(const string &str) {
+bool ContainsNumber(const std::string &str) {
   for (ConstChar32Iterator iter(str); !iter.Done(); iter.Next()) {
     if (CollocationUtil::IsNumber(iter.Get())) {
       return true;
@@ -77,103 +78,94 @@ bool ContainsNumber(const string &str) {
 // one Kanji character. In the value matches the pattern, XXX and YYY are
 // substituted to |first_content| and |second|, respectively. Returns false if
 // the value isn't of the form XXXPPPYYY.
-bool ParseCompound(const StringPiece value, const StringPiece pattern,
-                   StringPiece *first_content, StringPiece *second) {
+bool ParseCompound(const absl::string_view value,
+                   const absl::string_view pattern,
+                   absl::string_view *first_content,
+                   absl::string_view *second) {
   DCHECK(!value.empty());
   DCHECK(!pattern.empty());
 
   // Find the |first_content| candidate and check if it consists of Kanji only.
-  StringPiece::const_iterator pattern_begin =
+  absl::string_view::const_iterator pattern_begin =
       std::find(value.begin(), value.end(), pattern[0]);
   if (pattern_begin == value.end()) {
     return false;
   }
-  first_content->set(value.data(), std::distance(value.begin(), pattern_begin));
+  *first_content = absl::string_view(
+      value.data(), std::distance(value.begin(), pattern_begin));
   if (!Util::IsScriptType(*first_content, Util::KANJI)) {
     return false;
   }
 
   // Check if the middle part matches |pattern|.
-  const StringPiece remaining_value = value.substr(first_content->size());
+  const absl::string_view remaining_value =
+      absl::ClippedSubstr(value, first_content->size());
   if (!Util::StartsWith(remaining_value, pattern)) {
     return false;
   }
 
   // Check if the last substring is eligible for |second|.
-  *second = remaining_value.substr(pattern.size());
+  *second = absl::ClippedSubstr(remaining_value, pattern.size());
   if (second->empty() || !Util::ContainsScriptType(*second, Util::KANJI)) {
     return false;
   }
 
   // Just verify that |value| = |first_content| + |pattern| + |second|.
-  DCHECK_EQ(
-      value,
-      first_content->as_string() + pattern.as_string() + second->as_string());
+  DCHECK_EQ(value, std::string(*first_content) + std::string(pattern) +
+                       std::string(*second));
   return true;
 }
 
-// Fast way of pushing back a string piece to a vector.
-inline void PushBackStringPiece(const StringPiece s, std::vector<string> *v) {
-  v->push_back(string());
-  v->back().assign(s.data(), s.size());
-}
-
-// Fast way of pushing back the concatenated string of two string pieces to a
-// vector.
-inline void PushBackJoinedStringPieces(
-    const StringPiece s1, const StringPiece s2, std::vector<string> *v) {
-  v->push_back(string());
-  v->back().reserve(s1.size() + s2.size());
-  v->back().assign(s1.data(), s1.size()).append(s2.data(), s2.size());
+// A helper function to push back a string view to a vector.
+inline void PushBackStringView(const absl::string_view s,
+                               std::vector<std::string> *v) {
+  v->emplace_back(s.data(), s.size());
 }
 
 // Handles compound such as "本を読む"(one segment)
 // we want to rewrite using it as if it was "<本|を><読む>"
 // so that we can use collocation data like "厚い本"
-void ResolveCompoundSegment(const string &top_value, const string &value,
-                            SegmentLookupType type,
-                            std::vector<string> *output) {
-  // "格助詞"
+void ResolveCompoundSegment(const std::string &top_value,
+                            const std::string &value, SegmentLookupType type,
+                            std::vector<std::string> *output) {
   // see "http://ja.wikipedia.org/wiki/助詞"
-  static const char kPat1[] = "\xE3\x81\x8C";  // "が"
+  static const char kPat1[] = "が";
   // "の" was not good...
-  // static const char kPat2[] = "\xE3\x81\xAE";  // "の"
-  static const char kPat3[] = "\xE3\x82\x92";  // "を"
-  static const char kPat4[] = "\xE3\x81\xAB";  // "に"
-  static const char kPat5[] = "\xE3\x81\xB8";  // "へ"
-  static const char kPat6[] = "\xE3\x81\xA8";  // "と"
-  static const char kPat7[] = "\xE3\x81\x8B\xE3\x82\x89";  // "から"
-  static const char kPat8[] = "\xE3\x82\x88\xE3\x82\x8A";  // "より"
-  static const char kPat9[] = "\xE3\x81\xA7";  // "で"
+  // static const char kPat2[] = "の";
+  static const char kPat3[] = "を";
+  static const char kPat4[] = "に";
+  static const char kPat5[] = "へ";
+  static const char kPat6[] = "と";
+  static const char kPat7[] = "から";
+  static const char kPat8[] = "より";
+  static const char kPat9[] = "で";
 
   static const struct {
     const char *pat;
     size_t len;
-  } kParticles[] = {
-    {kPat1, arraysize(kPat1) - 1},
-    //    {kPat2, arraysize(kPat2) - 1},
-    {kPat3, arraysize(kPat3) - 1},
-    {kPat4, arraysize(kPat4) - 1},
-    {kPat5, arraysize(kPat5) - 1},
-    {kPat6, arraysize(kPat6) - 1},
-    {kPat7, arraysize(kPat7) - 1},
-    {kPat8, arraysize(kPat8) - 1},
-    {kPat9, arraysize(kPat9) - 1},
-    {NULL, 0}
-  };
+  } kParticles[] = {{kPat1, arraysize(kPat1) - 1},
+                    //    {kPat2, arraysize(kPat2) - 1},
+                    {kPat3, arraysize(kPat3) - 1},
+                    {kPat4, arraysize(kPat4) - 1},
+                    {kPat5, arraysize(kPat5) - 1},
+                    {kPat6, arraysize(kPat6) - 1},
+                    {kPat7, arraysize(kPat7) - 1},
+                    {kPat8, arraysize(kPat8) - 1},
+                    {kPat9, arraysize(kPat9) - 1},
+                    {nullptr, 0}};
 
-  for (size_t i = 0; kParticles[i].pat != NULL; ++i) {
-    const StringPiece particle(kParticles[i].pat, kParticles[i].len);
-    StringPiece first_content, second;
+  for (size_t i = 0; kParticles[i].pat != nullptr; ++i) {
+    const absl::string_view particle(kParticles[i].pat, kParticles[i].len);
+    absl::string_view first_content, second;
     if (!ParseCompound(top_value, particle, &first_content, &second)) {
       continue;
     }
     if (ParseCompound(value, particle, &first_content, &second)) {
       if (type == LEFT) {
-        PushBackStringPiece(second, output);
-        PushBackJoinedStringPieces(first_content, particle, output);
+        output->emplace_back(second.data(), second.size());
+        output->push_back(absl::StrCat(first_content, particle));
       } else {
-        PushBackStringPiece(first_content, output);
+        output->emplace_back(first_content.data(), first_content.size());
       }
       return;
     }
@@ -183,18 +175,16 @@ void ResolveCompoundSegment(const string &top_value, const string &value,
 bool IsNaturalContent(const Segment::Candidate &cand,
                       const Segment::Candidate &top_cand,
                       SegmentLookupType type,
-                      std::vector<string> *output) {
-  const string &content = cand.content_value;
-  const string &value = cand.value;
-  const string &top_content = top_cand.content_value;
-  const string &top_value = top_cand.value;
+                      std::vector<std::string> *output) {
+  const std::string &content = cand.content_value;
+  const std::string &value = cand.value;
+  const std::string &top_content = top_cand.content_value;
+  const std::string &top_value = top_cand.value;
 
   const size_t top_content_len = Util::CharsLen(top_content);
   const size_t content_len = Util::CharsLen(content);
 
-  if (type == RIGHT &&
-      value != top_value &&
-      top_content_len >= 2 &&
+  if (type == RIGHT && value != top_value && top_content_len >= 2 &&
       content_len == 1) {
     return false;
   }
@@ -205,10 +195,10 @@ bool IsNaturalContent(const Segment::Candidate &cand,
     output->push_back(content);
     // "舞って" workaround
     // V+"て" is often treated as one compound.
-    static const char kPat[] = "\xE3\x81\xA6";  // "て"
-    if (Util::EndsWith(content, StringPiece(kPat, arraysize(kPat) - 1))) {
-      PushBackStringPiece(
-          Util::SubStringPiece(content, 0, content_len - 1), output);
+    static const char kPat[] = "て";
+    if (Util::EndsWith(content, absl::string_view(kPat, arraysize(kPat) - 1))) {
+      PushBackStringView(Util::Utf8SubString(content, 0, content_len - 1),
+                         output);
     }
   }
 
@@ -217,16 +207,14 @@ bool IsNaturalContent(const Segment::Candidate &cand,
     return false;
   }
 
-  const StringPiece top_aux_value =
-      Util::SubStringPiece(top_value, top_content_len, string::npos);
+  const absl::string_view top_aux_value =
+      Util::Utf8SubString(top_value, top_content_len, std::string::npos);
   const size_t top_aux_value_len = Util::CharsLen(top_aux_value);
   const Util::ScriptType top_value_script_type = Util::GetScriptType(top_value);
 
   // we don't rewrite KATAKANA segment
   // for example, we don't rewrite "コーヒー飲みます" to "珈琲飲みます"
-  if (type == LEFT &&
-      top_aux_value_len == 0 &&
-      top_value != value &&
+  if (type == LEFT && top_aux_value_len == 0 && top_value != value &&
       top_value_script_type == Util::KATAKANA) {
     return false;
   }
@@ -248,15 +236,15 @@ bool IsNaturalContent(const Segment::Candidate &cand,
     }
   }
 
-  const StringPiece aux_value =
-      Util::SubStringPiece(value, content_len, string::npos);
+  const absl::string_view aux_value =
+      Util::Utf8SubString(value, content_len, std::string::npos);
 
   // Remove number in normalization for the left segment.
-  string aux_normalized, top_aux_normalized;
-  CollocationUtil::GetNormalizedScript(
-      aux_value, (type == LEFT), &aux_normalized);
-  CollocationUtil::GetNormalizedScript(
-      top_aux_value, (type == LEFT), &top_aux_normalized);
+  std::string aux_normalized, top_aux_normalized;
+  CollocationUtil::GetNormalizedScript(aux_value, (type == LEFT),
+                                       &aux_normalized);
+  CollocationUtil::GetNormalizedScript(top_aux_value, (type == LEFT),
+                                       &top_aux_normalized);
   if (!aux_normalized.empty() &&
       !Util::IsScriptType(aux_normalized, Util::HIRAGANA)) {
     if (type == RIGHT) {
@@ -274,10 +262,9 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXいる|>" can be rewrited to "<YY|いる>" and vice versa
   {
-    static const char kPat[] = "\xE3\x81\x84\xE3\x82\x8B";  // "いる"
-    const StringPiece kSuffix(kPat, arraysize(kPat) - 1);
-    if (top_aux_value_len == 0 &&
-        aux_value_len == 2 &&
+    static const char kPat[] = "いる";  // "いる"
+    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
+    if (top_aux_value_len == 0 && aux_value_len == 2 &&
         Util::EndsWith(top_value, kSuffix) &&
         Util::EndsWith(aux_value, kSuffix)) {
       if (type == RIGHT) {
@@ -286,14 +273,13 @@ bool IsNaturalContent(const Segment::Candidate &cand,
       }
       return true;
     }
-    if (aux_value_len == 0 &&
-        top_aux_value_len == 2 &&
+    if (aux_value_len == 0 && top_aux_value_len == 2 &&
         Util::EndsWith(value, kSuffix) &&
         Util::EndsWith(top_aux_value, kSuffix)) {
       if (type == RIGHT) {
         // "YY" in addition to "YYいる"
-        PushBackStringPiece(
-            Util::SubStringPiece(value, 0, value_len - 2), output);
+        PushBackStringView(Util::Utf8SubString(value, 0, value_len - 2),
+                           output);
       }
       return true;
     }
@@ -301,10 +287,9 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXせる|>" can be rewrited to "<YY|せる>" and vice versa
   {
-    const char kPat[] = "\xE3\x81\x9B\xE3\x82\x8B";  // "せる"
-    const StringPiece kSuffix(kPat, arraysize(kPat) - 1);
-    if (top_aux_value_len == 0 &&
-        aux_value_len == 2 &&
+    const char kPat[] = "せる";
+    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
+    if (top_aux_value_len == 0 && aux_value_len == 2 &&
         Util::EndsWith(top_value, kSuffix) &&
         Util::EndsWith(aux_value, kSuffix)) {
       if (type == RIGHT) {
@@ -313,14 +298,13 @@ bool IsNaturalContent(const Segment::Candidate &cand,
       }
       return true;
     }
-    if (aux_value_len == 0 &&
-        top_aux_value_len == 2 &&
+    if (aux_value_len == 0 && top_aux_value_len == 2 &&
         Util::EndsWith(value, kSuffix) &&
         Util::EndsWith(top_aux_value, kSuffix)) {
       if (type == RIGHT) {
         // "YY" in addition to "YYせる"
-        PushBackStringPiece(
-            Util::SubStringPiece(value, 0, value_len - 2), output);
+        PushBackStringView(Util::Utf8SubString(value, 0, value_len - 2),
+                           output);
       }
       return true;
     }
@@ -330,12 +314,10 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XX|する>" can be rewrited using "<XXす|る>" and "<XX|する>"
   // in "<XX|する>", XX must be single script type
-  // "評する"
   {
-    static const char kPat[] = "\xE3\x81\x99\xE3\x82\x8B";  // "する"
-    const StringPiece kSuffix(kPat, arraysize(kPat) - 1);
-    if (aux_value_len == 2 &&
-        Util::EndsWith(aux_value, kSuffix)) {
+    static const char kPat[] = "する";
+    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
+    if (aux_value_len == 2 && Util::EndsWith(aux_value, kSuffix)) {
       if (content_script_type != Util::KATAKANA &&
           content_script_type != Util::HIRAGANA &&
           content_script_type != Util::KANJI &&
@@ -344,8 +326,8 @@ bool IsNaturalContent(const Segment::Candidate &cand,
       }
       if (type == RIGHT) {
         // "YYす" in addition to "YY"
-        PushBackStringPiece(
-            Util::SubStringPiece(value, 0, value_len - 1), output);
+        PushBackStringView(Util::Utf8SubString(value, 0, value_len - 1),
+                           output);
       }
       return true;
     }
@@ -354,14 +336,13 @@ bool IsNaturalContent(const Segment::Candidate &cand,
   // "<XXる>" can be rewrited using "<XX|る>"
   // "まとめる", "衰える"
   {
-    static const char kPat[] = "\xE3\x82\x8B";  // "る"
-    const StringPiece kSuffix(kPat, arraysize(kPat) - 1);
-    if (aux_value_len == 0 &&
-        Util::EndsWith(value, kSuffix)) {
+    static const char kPat[] = "る";
+    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
+    if (aux_value_len == 0 && Util::EndsWith(value, kSuffix)) {
       if (type == RIGHT) {
         // "YY" in addition to "YYる"
-        PushBackStringPiece(
-            Util::SubStringPiece(value, 0, value_len - 1), output);
+        PushBackStringView(Util::Utf8SubString(value, 0, value_len - 1),
+                           output);
       }
       return true;
     }
@@ -369,17 +350,16 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXす>" can be rewrited using "XXする"
   {
-    static const char kPat[] = "\xE3\x81\x99";  // "す"
-    const StringPiece kSuffix(kPat, arraysize(kPat) - 1);
+    static const char kPat[] = "す";
+    const absl::string_view kSuffix(kPat, arraysize(kPat) - 1);
     if (Util::EndsWith(value, kSuffix) &&
-        Util::IsScriptType(
-            Util::SubStringPiece(value, 0, value_len - 1),
-            Util::KANJI)) {
+        Util::IsScriptType(Util::Utf8SubString(value, 0, value_len - 1),
+                           Util::KANJI)) {
       if (type == RIGHT) {
-        const char kRu[] = "\xE3\x82\x8B";
+        const char kRu[] = "る";
         // "YYする" in addition to "YY"
-        PushBackJoinedStringPieces(
-            value, StringPiece(kRu, arraysize(kRu) - 1), output);
+        output->push_back(
+            absl::StrCat(value, absl::string_view(kRu, arraysize(kRu) - 1)));
       }
       return true;
     }
@@ -387,18 +367,16 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // "<XXし|た>" can be rewrited using "<XX|した>"
   {
-    static const char kPat[] = "\xE3\x81\x97\xE3\x81\x9F";  // "した"
-    const StringPiece kShi(kPat, 3), kTa(kPat + 3, 3);
-    if (Util::EndsWith(content, kShi) &&
-        aux_value == kTa &&
-        Util::EndsWith(top_content, kShi) &&
-        top_aux_value == kTa) {
+    static const char kPat[] = "した";
+    const absl::string_view kShi(kPat, 3), kTa(kPat + 3, 3);
+    if (Util::EndsWith(content, kShi) && aux_value == kTa &&
+        Util::EndsWith(top_content, kShi) && top_aux_value == kTa) {
       if (type == RIGHT) {
-        const StringPiece val =
-            Util::SubStringPiece(content, 0, content_len - 1);
+        const absl::string_view val =
+            Util::Utf8SubString(content, 0, content_len - 1);
         // XX must be KANJI
         if (Util::IsScriptType(val, Util::KANJI)) {
-          PushBackStringPiece(val, output);
+          PushBackStringView(val, output);
         }
       }
       return true;
@@ -422,25 +400,19 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 
   // we don't rewrite second KATAKANA
   // for example, we don't rewrite "このコーヒー" to "この珈琲"
-  if (type == RIGHT &&
-      top_content_script_type == Util::KATAKANA &&
+  if (type == RIGHT && top_content_script_type == Util::KATAKANA &&
       value != top_value) {
     return false;
   }
 
-  if (top_content_len == 1 &&
-      top_content_script_type == Util::HIRAGANA) {
+  if (top_content_len == 1 && top_content_script_type == Util::HIRAGANA) {
     return false;
   }
 
   // suppress "<身|ています>" etc.
-  if (top_content_len == 1 &&
-      content_len == 1 &&
-      top_aux_value_len >= 2 &&
-      aux_value_len >= 2 &&
-      top_content_script_type == Util::KANJI &&
-      content_script_type == Util::KANJI &&
-      top_content != content) {
+  if (top_content_len == 1 && content_len == 1 && top_aux_value_len >= 2 &&
+      aux_value_len >= 2 && top_content_script_type == Util::KANJI &&
+      content_script_type == Util::KANJI && top_content != content) {
     return false;
   }
 
@@ -451,7 +423,7 @@ bool IsNaturalContent(const Segment::Candidate &cand,
 bool VerifyNaturalContent(const Segment::Candidate &cand,
                           const Segment::Candidate &top_cand,
                           SegmentLookupType type) {
-  std::vector<string> nexts;
+  std::vector<std::string> nexts;
   return IsNaturalContent(cand, top_cand, RIGHT, &nexts);
 }
 
@@ -490,9 +462,7 @@ bool CollocationRewriter::RewriteCollocation(Segments *segments) const {
       segs_changed[i + 1] = true;
     }
 
-    if (!segs_changed[i] &&
-        !rewrited_next &&
-        i > 0 &&
+    if (!segs_changed[i] && !rewrited_next && i > 0 &&
         RewriteFromPrevSegment(segments->segment(i - 1).candidate(0),
                                segments->mutable_segment(i))) {
       changed = true;
@@ -511,18 +481,16 @@ bool CollocationRewriter::RewriteCollocation(Segments *segments) const {
          pos_matcher_.IsAdverbSegmentSuffix(
              segments->segment(i - 1).candidate(0).rid)) &&
         (cand.content_value != cand.value ||
-         cand.value != "\xe3\x83\xbb")) {  // "・" workaround
-      if (!segs_changed[i - 2] &&
-          !segs_changed[i] &&
+         cand.value != "・")) {  // "・" workaround
+      if (!segs_changed[i - 2] && !segs_changed[i] &&
           RewriteUsingNextSegment(segments->mutable_segment(i),
                                   segments->mutable_segment(i - 2))) {
         changed = true;
         segs_changed[i] = true;
         segs_changed[i - 2] = true;
       } else if (!segs_changed[i] &&
-                 RewriteFromPrevSegment(
-                     segments->segment(i - 2).candidate(0),
-                     segments->mutable_segment(i))) {
+                 RewriteFromPrevSegment(segments->segment(i - 2).candidate(0),
+                                        segments->mutable_segment(i))) {
         changed = true;
         segs_changed[i] = true;
         segs_changed[i - 2] = true;
@@ -536,16 +504,14 @@ bool CollocationRewriter::RewriteCollocation(Segments *segments) const {
 class CollocationRewriter::CollocationFilter {
  public:
   CollocationFilter(const char *existence_data, size_t size)
-      : filter_(ExistenceFilter::Read(existence_data, size)) {
-  }
-  ~CollocationFilter() {
-  }
+      : filter_(ExistenceFilter::Read(existence_data, size)) {}
+  ~CollocationFilter() {}
 
-  bool Exists(const string &left, const string &right) const {
+  bool Exists(const std::string &left, const std::string &right) const {
     if (left.empty() || right.empty()) {
       return false;
     }
-    string key;
+    std::string key;
     key.reserve(left.size() + right.size());
     key.assign(left).append(right);
     const uint64 id = Hash::Fingerprint(key);
@@ -561,15 +527,13 @@ class CollocationRewriter::CollocationFilter {
 class CollocationRewriter::SuppressionFilter {
  public:
   SuppressionFilter(const char *suppression_data, size_t size)
-      : filter_(ExistenceFilter::Read(suppression_data, size)) {
-  }
-  ~SuppressionFilter() {
-  }
+      : filter_(ExistenceFilter::Read(suppression_data, size)) {}
+  ~SuppressionFilter() {}
 
   bool Exists(const Segment::Candidate &cand) const {
     // TODO(noriyukit): We should share key generation rule with
     // gen_collocation_suppression_data_main.cc.
-    string key;
+    std::string key;
     key.reserve(cand.content_value.size() + 1 + cand.content_key.size());
     key.assign(cand.content_value).append("\t").append(cand.content_key);
     const uint64 id = Hash::Fingerprint(key);
@@ -587,7 +551,7 @@ CollocationRewriter::CollocationRewriter(
     : pos_matcher_(data_manager->GetPOSMatcherData()),
       first_name_id_(pos_matcher_.GetFirstNameId()),
       last_name_id_(pos_matcher_.GetLastNameId()) {
-  const char *data = NULL;
+  const char *data = nullptr;
   size_t size = 0;
 
   data_manager->GetCollocationData(&data, &size);
@@ -609,21 +573,22 @@ bool CollocationRewriter::Rewrite(const ConversionRequest &request,
 
 bool CollocationRewriter::IsName(const Segment::Candidate &cand) const {
   const bool ret = (cand.lid == last_name_id_ || cand.lid == first_name_id_);
-  VLOG_IF(3, ret) << cand.value << " is name sagment";
+  if (ret) {
+    VLOG(3) << cand.value << " is name sagment";
+  }
   return ret;
 }
 
 bool CollocationRewriter::RewriteFromPrevSegment(
-    const Segment::Candidate &prev_cand,
-    Segment *seg) const {
-  string prev;
+    const Segment::Candidate &prev_cand, Segment *seg) const {
+  std::string prev;
   CollocationUtil::GetNormalizedScript(prev_cand.value, true, &prev);
 
-  const size_t i_max = min(seg->candidates_size(), kCandidateSize);
+  const size_t i_max = std::min(seg->candidates_size(), kCandidateSize);
 
   // Reuse |curs| and |cur| in the loop as this method is performance critical.
-  std::vector<string> curs;
-  string cur;
+  std::vector<std::string> curs;
+  std::string cur;
   for (size_t i = 0; i < i_max; ++i) {
     if (seg->candidate(i).cost > seg->candidate(0).cost + kMaxCostDiff) {
       continue;
@@ -643,12 +608,13 @@ bool CollocationRewriter::RewriteFromPrevSegment(
       cur.clear();
       CollocationUtil::GetNormalizedScript(curs[j], false, &cur);
       if (collocation_filter_->Exists(prev, cur)) {
-        VLOG_IF(3, i != 0) << prev << cur << " "
-                           << seg->candidate(0).value << "->"
-                           << seg->candidate(i).value;
+        if (i != 0) {
+          VLOG(3) << prev << cur << " " << seg->candidate(0).value << "->"
+                  << seg->candidate(i).value;
+        }
         seg->move_candidate(i, 0);
-        seg->mutable_candidate(0)->attributes
-            |= Segment::Candidate::CONTEXT_SENSITIVE;
+        seg->mutable_candidate(0)->attributes |=
+            Segment::Candidate::CONTEXT_SENSITIVE;
         return true;
       }
     }
@@ -658,15 +624,15 @@ bool CollocationRewriter::RewriteFromPrevSegment(
 
 bool CollocationRewriter::RewriteUsingNextSegment(Segment *next_seg,
                                                   Segment *seg) const {
-  const size_t i_max = min(seg->candidates_size(), kCandidateSize);
-  const size_t j_max = min(next_seg->candidates_size(), kCandidateSize);
+  const size_t i_max = std::min(seg->candidates_size(), kCandidateSize);
+  const size_t j_max = std::min(next_seg->candidates_size(), kCandidateSize);
 
   // Cache the results for the next segment
-  std::vector<int> next_seg_ok(j_max);  // Avoiding vector<bool>
-  std::vector<std::vector<string> > normalized_string(j_max);
+  std::vector<int> next_seg_ok(j_max);  // Avoiding std::vector<bool>
+  std::vector<std::vector<std::string> > normalized_string(j_max);
 
   // Reuse |nexts| in the loop as this method is performance critical.
-  std::vector<string> nexts;
+  std::vector<std::string> nexts;
   for (size_t j = 0; j < j_max; ++j) {
     next_seg_ok[j] = 0;
 
@@ -677,23 +643,23 @@ bool CollocationRewriter::RewriteUsingNextSegment(Segment *next_seg,
       continue;
     }
     nexts.clear();
-    if (!IsNaturalContent(next_seg->candidate(j),
-                          next_seg->candidate(0), RIGHT, &nexts)) {
+    if (!IsNaturalContent(next_seg->candidate(j), next_seg->candidate(0), RIGHT,
+                          &nexts)) {
       continue;
     }
 
     next_seg_ok[j] = 1;
-    for (std::vector<string>::const_iterator it = nexts.begin();
+    for (std::vector<std::string>::const_iterator it = nexts.begin();
          it != nexts.end(); ++it) {
-      normalized_string[j].push_back(string());
-      CollocationUtil::GetNormalizedScript(
-          *it, false, &normalized_string[j].back());
+      normalized_string[j].push_back(std::string());
+      CollocationUtil::GetNormalizedScript(*it, false,
+                                           &normalized_string[j].back());
     }
   }
 
   // Reuse |curs| and |cur| in the loop as this method is performance critical.
-  std::vector<string> curs;
-  string cur;
+  std::vector<std::string> curs;
+  std::string cur;
   for (size_t i = 0; i < i_max; ++i) {
     if (seg->candidate(i).cost > seg->candidate(0).cost + kMaxCostDiff) {
       continue;
@@ -722,17 +688,17 @@ bool CollocationRewriter::RewriteUsingNextSegment(Segment *next_seg,
         }
 
         for (int l = 0; l < normalized_string[j].size(); ++l) {
-          const string &next = normalized_string[j][l];
+          const std::string &next = normalized_string[j][l];
           if (collocation_filter_->Exists(cur, next)) {
-            DCHECK(VerifyNaturalContent(
-                next_seg->candidate(j), next_seg->candidate(0), RIGHT))
+            DCHECK(VerifyNaturalContent(next_seg->candidate(j),
+                                        next_seg->candidate(0), RIGHT))
                 << "IsNaturalContent() should not fail here.";
             seg->move_candidate(i, 0);
-            seg->mutable_candidate(0)->attributes
-                |= Segment::Candidate::CONTEXT_SENSITIVE;
+            seg->mutable_candidate(0)->attributes |=
+                Segment::Candidate::CONTEXT_SENSITIVE;
             next_seg->move_candidate(j, 0);
-            next_seg->mutable_candidate(0)->attributes
-                |= Segment::Candidate::CONTEXT_SENSITIVE;
+            next_seg->mutable_candidate(0)->attributes |=
+                Segment::Candidate::CONTEXT_SENSITIVE;
             return true;
           }
         }
