@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,7 @@ namespace mozc {
 namespace {
 
 TEST(CollocationUtilTest, GetNormalizedScript) {
-  string result;
+  std::string result;
   CollocationUtil::GetNormalizedScript("あいうえお", true, &result);
   EXPECT_EQ("あいうえお", result);
 
