@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@
 #include "base/init_mozc.h"
 #include "base/logging.h"
 #include "base/mozc_hash_map.h"
-#include "base/string_piece.h"
 #include "base/util.h"
 #include "data_manager/serialized_dictionary.h"
+#include "absl/strings/string_view.h"
 
 DEFINE_string(input, "", "Emoticon dictionary file");
 DEFINE_string(output_token_array, "", "Output token array");
@@ -48,24 +48,24 @@ DEFINE_string(output_string_array, "", "Output string array");
 namespace mozc {
 namespace {
 
-using KeyList = std::vector<string>;
+using KeyList = std::vector<std::string>;
 using CompilerToken = SerializedDictionary::CompilerToken;
 using TokenList = SerializedDictionary::TokenList;
 
-int LookupCount(const mozc_hash_map<string, int> &key_count,
-                const string &key) {
+int LookupCount(const mozc_hash_map<std::string, int> &key_count,
+                const std::string &key) {
   const auto iter = key_count.find(key);
   return (iter == key_count.end()) ? 0 : iter->second;
 }
 
-string GetDescription(const KeyList &key_list,
-                      const mozc_hash_map<string, int> &key_count) {
+std::string GetDescription(const KeyList &key_list,
+                           const mozc_hash_map<std::string, int> &key_count) {
   if (key_list.size() == 1) {
     return key_list[0];
   }
   KeyList sorted_key_list(key_list);
   std::sort(sorted_key_list.begin(), sorted_key_list.end(),
-            [&key_count](const string &x, const string &y) {
+            [&key_count](const std::string &x, const std::string &y) {
               const int x_count = LookupCount(key_count, x);
               const int y_count = LookupCount(key_count, y);
               if (x_count == y_count) {
@@ -77,39 +77,39 @@ string GetDescription(const KeyList &key_list,
                             sorted_key_list.front().c_str());
 }
 
-std::map<string, TokenList> ReadEmoticonTsv(const string &path) {
+std::map<std::string, TokenList> ReadEmoticonTsv(const std::string &path) {
   InputFileStream ifs(path.c_str());
 
-  string line;
-  getline(ifs, line);  // Skip header
+  std::string line;
+  std::getline(ifs, line);  // Skip header
 
-  std::vector<std::pair<string, KeyList>> data;
-  mozc_hash_map<string, int> key_count;
-  while (getline(ifs, line)) {
-    std::vector<StringPiece> field_list;
+  std::vector<std::pair<std::string, KeyList>> data;
+  mozc_hash_map<std::string, int> key_count;
+  while (std::getline(ifs, line)) {
+    std::vector<absl::string_view> field_list;
     Util::SplitStringUsing(line, "\t", &field_list);
     CHECK_GE(field_list.size(), 2) << "Format error: " << line;
     LOG_IF(WARNING, field_list.size() > 3) << "Ignore extra columns: " << line;
 
-    string replaced;
+    std::string replaced;
     Util::StringReplace(field_list[1], "　",  // Full-width space
                         " ", true, &replaced);
     KeyList key_list;
     Util::SplitStringUsing(field_list[1], " ", &key_list);
 
-    data.emplace_back(field_list[0].as_string(), std::move(key_list));
+    data.emplace_back(std::string(field_list[0]), std::move(key_list));
     for (const auto &key : key_list) {
       ++key_count[key];
     }
   }
 
-  std::map<string, TokenList> input_data;
+  std::map<std::string, TokenList> input_data;
   int16 cost = 10;
   for (const auto &kv : data) {
-    const string &value = kv.first;
+    const std::string &value = kv.first;
     const KeyList &key_list = kv.second;
-    const string &description = GetDescription(key_list, key_count);
-    for (const string &key : key_list) {
+    const std::string &description = GetDescription(key_list, key_count);
+    for (const std::string &key : key_list) {
       std::unique_ptr<CompilerToken> token(new CompilerToken());
       token->value = value;
       token->description = description;
@@ -128,7 +128,7 @@ std::map<string, TokenList> ReadEmoticonTsv(const string &path) {
 }  // namespace mozc
 
 int main(int argc, char **argv) {
-  mozc::InitMozc(argv[0], &argc, &argv, true);
+  mozc::InitMozc(argv[0], &argc, &argv);
   const auto &input_data = mozc::ReadEmoticonTsv(FLAGS_input);
   mozc::SerializedDictionary::CompileToFiles(
       input_data, FLAGS_output_token_array, FLAGS_output_string_array);
