@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -47,13 +47,12 @@ using mozc::storage::ExistenceFilter;
 namespace mozc {
 namespace {
 
-void GenExistenceData(const std::vector<string> &entries,
-                      double error_rate,
-                      char **existence_data,
+void GenExistenceData(const std::vector<std::string> &entries,
+                      double error_rate, char **existence_data,
                       size_t *existence_data_size) {
   const int n = entries.size();
-  const int m =  ExistenceFilter::MinFilterSizeInBytesForErrorRate(
-      error_rate, n);
+  const int m =
+      ExistenceFilter::MinFilterSizeInBytesForErrorRate(error_rate, n);
   LOG(INFO) << "entry: " << n << " err: " << error_rate << " bytes: " << m;
 
   std::unique_ptr<ExistenceFilter> filter(ExistenceFilter::CreateOptimal(m, n));
@@ -68,10 +67,10 @@ void GenExistenceData(const std::vector<string> &entries,
 
 }  // namespace
 
-void OutputExistenceHeader(const std::vector<string> &entries,
-                           const string &data_namespace, std::ostream *ofs,
+void OutputExistenceHeader(const std::vector<std::string> &entries,
+                           const std::string &data_namespace, std::ostream *ofs,
                            double error_rate) {
-  char *existence_data = NULL;
+  char *existence_data = nullptr;
   size_t existence_data_size = 0;
   GenExistenceData(entries, error_rate, &existence_data, &existence_data_size);
 
@@ -80,17 +79,17 @@ void OutputExistenceHeader(const std::vector<string> &entries,
 
   *ofs << "namespace " << data_namespace << "{" << std::endl;
 
-  CodeGenByteArrayOutputStream codegen_stream(
-      ofs, codegenstream::NOT_OWN_STREAM);
+  CodeGenByteArrayOutputStream codegen_stream(ofs,
+                                              codegenstream::NOT_OWN_STREAM);
   codegen_stream.OpenVarDef("ExistenceFilter");
   codegen_stream.write(existence_data, existence_data_size);
   codegen_stream.CloseVarDef();
   *ofs << "}  // namespace " << data_namespace << std::endl;
 }
 
-void OutputExistenceBinary(const std::vector<string> &entries,
+void OutputExistenceBinary(const std::vector<std::string> &entries,
                            std::ostream *ofs, double error_rate) {
-  char *existence_data = NULL;
+  char *existence_data = nullptr;
   size_t existence_data_size = 0;
   GenExistenceData(entries, error_rate, &existence_data, &existence_data_size);
   ofs->write(existence_data, existence_data_size);
