@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,10 +36,10 @@
 
 namespace mozc {
 
-void OutputExistenceHeader(const std::vector<string> &entries,
-                           const string &data_namespace, std::ostream *ofs,
+void OutputExistenceHeader(const std::vector<std::string> &entries,
+                           const std::string &data_namespace, std::ostream *ofs,
                            double error_rate);
-void OutputExistenceBinary(const std::vector<string> &entries,
+void OutputExistenceBinary(const std::vector<std::string> &entries,
                            std::ostream *ofs, double error_rate);
 
 }  // namespace mozc
