@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,6 +29,8 @@
 
 #include "server/mozc_server.h"
 
+#include "absl/flags/flag.h"
+
 #ifdef OS_WIN
 #include <windows.h>
 #endif
@@ -49,7 +51,7 @@
 #include "config/stats_config_util.h"
 #include "session/session_server.h"
 
-DECLARE_bool(restricted);   // in SessionHandler
+DECLARE_bool(restricted);  // in SessionHandler
 
 namespace {
 mozc::SessionServer *g_session_server = NULL;
@@ -58,9 +60,7 @@ mozc::SessionServer *g_session_server = NULL;
 namespace mozc {
 namespace server {
 
-void InitMozcAndMozcServer(const char *arg0,
-                           int *argc,
-                           char ***argv,
+void InitMozcAndMozcServer(const char *arg0, int *argc, char ***argv,
                            bool remove_flags) {
   mozc::SystemUtil::DisableIME();
 
@@ -88,18 +88,16 @@ void InitMozcAndMozcServer(const char *arg0,
   if (mozc::config::StatsConfigUtil::IsEnabled()) {
     mozc::CrashReportHandler::Initialize(false);
   }
-  mozc::InitMozc(arg0, argc, argv, remove_flags);
+  mozc::InitMozc(arg0, argc, argv);
 
   if (run_level == mozc::RunLevel::RESTRICTED) {
     VLOG(1) << "Mozc server starts with timeout mode";
-    FLAGS_restricted = true;
+    mozc::SetFlag(&FLAGS_restricted, true);
   }
-
-  return;
 }
 
 int MozcServer::Run() {
-  string mutex_name = "server";
+  std::string mutex_name = "server";
   mozc::ProcessMutex mutex(mutex_name.c_str());
   if (!mutex.Lock()) {
     LOG(INFO) << "Mozc Server is already running";
