@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,9 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "base/port.h"
+#ifdef OS_WIN
 #include "base/winmain.h"
+#endif  // OS_WIN
 #include "server/mozc_server.h"
 
 int main(int argc, char* argv[]) {
