@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -54,16 +54,10 @@ class ImeContext {
   ImeContext();
   virtual ~ImeContext();
 
-  uint64 create_time() const {
-    return create_time_;
-  }
-  void set_create_time(uint64 create_time) {
-    create_time_ = create_time;
-  }
+  uint64 create_time() const { return create_time_; }
+  void set_create_time(uint64 create_time) { create_time_ = create_time; }
 
-  uint64 last_command_time() const {
-    return last_command_time_;
-  }
+  uint64 last_command_time() const { return last_command_time_; }
   void set_last_command_time(uint64 last_command_time) {
     last_command_time_ = last_command_time;
   }
@@ -89,21 +83,13 @@ class ImeContext {
     COMPOSITION = 4,
     CONVERSION = 8,
   };
-  State state() const {
-    return state_;
-  }
-  void set_state(State state) {
-    state_ = state;
-  }
+  State state() const { return state_; }
+  void set_state(State state) { state_ = state; }
 
   // Returns the current keymap.  This might be temporary and different from
   // the keymap in the config.
-  config::Config::SessionKeymap keymap() const {
-    return keymap_;
-  }
-  void set_keymap(config::Config::SessionKeymap keymap) {
-    keymap_ = keymap;
-  }
+  config::Config::SessionKeymap keymap() const { return keymap_; }
+  void set_keymap(config::Config::SessionKeymap keymap) { keymap_ = keymap; }
 
   void SetRequest(const commands::Request *request);
   const commands::Request &GetRequest() const;
@@ -128,19 +114,11 @@ class ImeContext {
   // Note that this may not be the latest info: this is likely to be a snapshot
   // of during the precomposition state and may not be updated during
   // composition/conversion state.
-  const commands::Context &client_context() const {
-    return client_context_;
-  }
-  commands::Context *mutable_client_context() {
-    return &client_context_;
-  }
+  const commands::Context &client_context() const { return client_context_; }
+  commands::Context *mutable_client_context() { return &client_context_; }
 
-  const commands::Output &output() const {
-    return output_;
-  }
-  commands::Output *mutable_output() {
-    return &output_;
-  }
+  const commands::Output &output() const { return output_; }
+  commands::Output *mutable_output() { return &output_; }
 
   // Copy |source| context to |destination| context.
   // TODO(hsumita): Renames it as CopyFrom and make it non-static to keep
