@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,7 +38,7 @@ namespace mozc {
 bool OutputUtil::GetCandidateIndexById(const commands::Output &output,
                                        int32 mozc_candidate_id,
                                        int32 *candidate_index) {
-  if (candidate_index == NULL) {
+  if (candidate_index == nullptr) {
     return false;
   }
   if (!output.has_all_candidate_words()) {
@@ -52,7 +52,7 @@ bool OutputUtil::GetCandidateIndexById(const commands::Output &output,
       continue;
     }
     if (word.id() == mozc_candidate_id) {
-      DCHECK(NULL != candidate_index);
+      DCHECK(nullptr != candidate_index);
       *candidate_index = word.index();
       return true;
     }
@@ -63,7 +63,7 @@ bool OutputUtil::GetCandidateIndexById(const commands::Output &output,
 bool OutputUtil::GetCandidateIdByIndex(const commands::Output &output,
                                        int32 candidate_index,
                                        int32 *mozc_candidate_id) {
-  if (mozc_candidate_id == NULL) {
+  if (mozc_candidate_id == nullptr) {
     return false;
   }
   if (!output.has_all_candidate_words()) {
@@ -77,7 +77,7 @@ bool OutputUtil::GetCandidateIdByIndex(const commands::Output &output,
       continue;
     }
     if (word.index() == candidate_index) {
-      DCHECK(NULL != mozc_candidate_id);
+      DCHECK(nullptr != mozc_candidate_id);
       *mozc_candidate_id = word.id();
       return true;
     }
@@ -87,7 +87,7 @@ bool OutputUtil::GetCandidateIdByIndex(const commands::Output &output,
 
 bool OutputUtil::GetFocusedCandidateId(const commands::Output &output,
                                        int32 *mozc_candidate_id) {
-  if (mozc_candidate_id == NULL) {
+  if (mozc_candidate_id == nullptr) {
     return false;
   }
   if (!output.has_all_candidate_words()) {
@@ -105,7 +105,7 @@ bool OutputUtil::GetFocusedCandidateId(const commands::Output &output,
       continue;
     }
     if (word.index() == focused_index) {
-      DCHECK(NULL != mozc_candidate_id);
+      DCHECK(nullptr != mozc_candidate_id);
       *mozc_candidate_id = word.id();
       return true;
     }
