@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,6 +37,7 @@
 #include "base/port.h"
 #include "base/util.h"
 #include "protocol/commands.pb.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace session {
@@ -49,59 +50,35 @@ const double kMostPossibleKeyProbability = 0.98;
 const size_t kProbableKeyEventSize = 8;
 
 const commands::KeyEvent::SpecialKey kSpecialKeys[] = {
-  commands::KeyEvent::SPACE,
-  commands::KeyEvent::BACKSPACE,
-  commands::KeyEvent::DEL,
-  commands::KeyEvent::DOWN,
-  commands::KeyEvent::END,
-  commands::KeyEvent::ENTER,
-  commands::KeyEvent::ESCAPE,
-  commands::KeyEvent::HOME,
-  commands::KeyEvent::INSERT,
-  commands::KeyEvent::HENKAN,
-  commands::KeyEvent::MUHENKAN,
-  commands::KeyEvent::LEFT,
-  commands::KeyEvent::RIGHT,
-  commands::KeyEvent::UP,
-  commands::KeyEvent::DOWN,
-  commands::KeyEvent::PAGE_UP,
-  commands::KeyEvent::PAGE_DOWN,
-  commands::KeyEvent::TAB,
-  commands::KeyEvent::F1,
-  commands::KeyEvent::F2,
-  commands::KeyEvent::F3,
-  commands::KeyEvent::F4,
-  commands::KeyEvent::F5,
-  commands::KeyEvent::F6,
-  commands::KeyEvent::F7,
-  commands::KeyEvent::F8,
-  commands::KeyEvent::F9,
-  commands::KeyEvent::F10,
-  commands::KeyEvent::F11,
-  commands::KeyEvent::F12,
-  commands::KeyEvent::NUMPAD0,
-  commands::KeyEvent::NUMPAD1,
-  commands::KeyEvent::NUMPAD2,
-  commands::KeyEvent::NUMPAD3,
-  commands::KeyEvent::NUMPAD4,
-  commands::KeyEvent::NUMPAD5,
-  commands::KeyEvent::NUMPAD6,
-  commands::KeyEvent::NUMPAD7,
-  commands::KeyEvent::NUMPAD8,
-  commands::KeyEvent::NUMPAD9,
-  commands::KeyEvent::MULTIPLY,
-  commands::KeyEvent::ADD,
-  commands::KeyEvent::SEPARATOR,
-  commands::KeyEvent::SUBTRACT,
-  commands::KeyEvent::DECIMAL,
-  commands::KeyEvent::DIVIDE,
-  commands::KeyEvent::EQUALS,
-  commands::KeyEvent::COMMA,
+    commands::KeyEvent::SPACE,     commands::KeyEvent::BACKSPACE,
+    commands::KeyEvent::DEL,       commands::KeyEvent::DOWN,
+    commands::KeyEvent::END,       commands::KeyEvent::ENTER,
+    commands::KeyEvent::ESCAPE,    commands::KeyEvent::HOME,
+    commands::KeyEvent::INSERT,    commands::KeyEvent::HENKAN,
+    commands::KeyEvent::MUHENKAN,  commands::KeyEvent::LEFT,
+    commands::KeyEvent::RIGHT,     commands::KeyEvent::UP,
+    commands::KeyEvent::DOWN,      commands::KeyEvent::PAGE_UP,
+    commands::KeyEvent::PAGE_DOWN, commands::KeyEvent::TAB,
+    commands::KeyEvent::F1,        commands::KeyEvent::F2,
+    commands::KeyEvent::F3,        commands::KeyEvent::F4,
+    commands::KeyEvent::F5,        commands::KeyEvent::F6,
+    commands::KeyEvent::F7,        commands::KeyEvent::F8,
+    commands::KeyEvent::F9,        commands::KeyEvent::F10,
+    commands::KeyEvent::F11,       commands::KeyEvent::F12,
+    commands::KeyEvent::NUMPAD0,   commands::KeyEvent::NUMPAD1,
+    commands::KeyEvent::NUMPAD2,   commands::KeyEvent::NUMPAD3,
+    commands::KeyEvent::NUMPAD4,   commands::KeyEvent::NUMPAD5,
+    commands::KeyEvent::NUMPAD6,   commands::KeyEvent::NUMPAD7,
+    commands::KeyEvent::NUMPAD8,   commands::KeyEvent::NUMPAD9,
+    commands::KeyEvent::MULTIPLY,  commands::KeyEvent::ADD,
+    commands::KeyEvent::SEPARATOR, commands::KeyEvent::SUBTRACT,
+    commands::KeyEvent::DECIMAL,   commands::KeyEvent::DIVIDE,
+    commands::KeyEvent::EQUALS,    commands::KeyEvent::COMMA,
 };
 
 uint32 GetRandomAsciiKey() {
   return static_cast<uint32>(' ') +
-      Util::Random(static_cast<uint32>('~' - ' '));
+         Util::Random(static_cast<uint32>('~' - ' '));
 }
 
 void InitSeedWithRandomValue() {
@@ -128,7 +105,7 @@ void RandomKeyEventsGenerator::PrepareForMemoryLeakTest() {
 }
 
 // Generates KeyEvent instances based on |romaji| and stores into |keys|.
-void TypeRawKeys(StringPiece romaji, bool create_probable_key_events,
+void TypeRawKeys(absl::string_view romaji, bool create_probable_key_events,
                  std::vector<commands::KeyEvent> *keys) {
   for (ConstChar32Iterator iter(romaji); !iter.Done(); iter.Next()) {
     const uint32 ucs4 = iter.Get();
@@ -140,8 +117,8 @@ void TypeRawKeys(StringPiece romaji, bool create_probable_key_events,
     if (create_probable_key_events) {
       commands::KeyEvent::ProbableKeyEvent *probable_key_event =
           key.add_probable_key_event();
-        probable_key_event->set_key_code(ucs4);
-        probable_key_event->set_probability(kMostPossibleKeyProbability);
+      probable_key_event->set_key_code(ucs4);
+      probable_key_event->set_probability(kMostPossibleKeyProbability);
       for (size_t i = 0; i < kProbableKeyEventSize; ++i) {
         commands::KeyEvent::ProbableKeyEvent *probable_key_event =
             key.add_probable_key_event();
@@ -155,8 +132,8 @@ void TypeRawKeys(StringPiece romaji, bool create_probable_key_events,
 }
 
 // Converts from Hiragana to Romaji.
-string ToRomaji(StringPiece hiragana) {
-  string tmp, result;
+std::string ToRomaji(absl::string_view hiragana) {
+  std::string tmp, result;
   Util::HiraganaToRomanji(hiragana, &tmp);
   Util::FullWidthToHalfWidth(tmp, &result);
   return result;
@@ -170,10 +147,10 @@ void RandomKeyEventsGenerator::InitSeed(uint32 seed) {
 // Generates KeyEvent instances based on |sentence| and stores into |keys|.
 // And Enter key event is appended at the tail.
 // The instances have ProbableKeyEvent if |create_probable_key_events| is set.
-void GenerateMobileSequenceInternal(
-    StringPiece sentence, bool create_probable_key_events,
-    std::vector<commands::KeyEvent> *keys) {
-  const string input = ToRomaji(sentence);
+void GenerateMobileSequenceInternal(absl::string_view sentence,
+                                    bool create_probable_key_events,
+                                    std::vector<commands::KeyEvent> *keys) {
+  const std::string input = ToRomaji(sentence);
   VLOG(1) << input;
 
   // Type the sentence
@@ -192,14 +169,14 @@ void RandomKeyEventsGenerator::GenerateMobileSequence(
   // If seed was not initialized, set seed randomly.
   CallOnce(&seed_init_once, &InitSeedWithRandomValue);
 
-  const StringPiece sentence(
+  const absl::string_view sentence(
       kTestSentences[Util::Random(arraysize(kTestSentences))]);
   CHECK(!sentence.empty());
-  for (size_t i = 0; i < sentence.size(); ) {
+  for (size_t i = 0; i < sentence.size();) {
     // To simulate mobile key events, split given sentence into smaller parts.
     // Average 5, Min 1, Max 15
     const size_t len = Util::Random(5) + Util::Random(5) + Util::Random(5);
-    GenerateMobileSequenceInternal(ClippedSubstr(sentence, i, len),
+    GenerateMobileSequenceInternal(absl::ClippedSubstr(sentence, i, len),
                                    create_probable_key_events, keys);
     i += len;
   }
@@ -213,11 +190,11 @@ void RandomKeyEventsGenerator::GenerateSequence(
   // If seed was not initialized, set seed randomly.
   CallOnce(&seed_init_once, &InitSeedWithRandomValue);
 
-  const string sentence =
+  const std::string sentence =
       kTestSentences[Util::Random(arraysize(kTestSentences))];
   CHECK(!sentence.empty());
 
-  const string input = ToRomaji(sentence);
+  const std::string input = ToRomaji(sentence);
 
   VLOG(1) << input;
 
@@ -281,15 +258,13 @@ void RandomKeyEventsGenerator::GenerateSequence(
             key.add_modifier_keys(commands::KeyEvent::SHIFT);
           }
           break;
-        default:
-          {
-            const size_t space_num = Util::Random(20) + 3;
-            for (size_t i = 0; i < space_num; ++i) {
-              key.set_special_key(commands::KeyEvent::SPACE);
-              keys->push_back(key);
-            }
+        default: {
+          const size_t space_num = Util::Random(20) + 3;
+          for (size_t i = 0; i < space_num; ++i) {
+            key.set_special_key(commands::KeyEvent::SPACE);
+            keys->push_back(key);
           }
-          break;
+        } break;
       }
 
       if (Util::Random(4) == 0) {
@@ -330,14 +305,13 @@ void RandomKeyEventsGenerator::GenerateSequence(
         case 3:
           key.set_special_key(commands::KeyEvent::BACKSPACE);
           break;
-        default:
-          {
-            // add any ascii
-            const size_t insert_num = Util::Random(5) + 1;
-            for (size_t i = 0; i < insert_num; ++i) {
-              key.set_key_code(GetRandomAsciiKey());
-            }
+        default: {
+          // add any ascii
+          const size_t insert_num = Util::Random(5) + 1;
+          for (size_t i = 0; i < insert_num; ++i) {
+            key.set_key_code(GetRandomAsciiKey());
           }
+        }
       }
       keys->push_back(key);
     }
