@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -74,8 +74,8 @@ class SessionInterface {
       const commands::Capability &capability) = 0;
 
   // Set application information for this session.
-  virtual void set_application_info(const commands::ApplicationInfo
-                                    &application_info) = 0;
+  virtual void set_application_info(
+      const commands::ApplicationInfo &application_info) = 0;
 
   // Get application information
   virtual const commands::ApplicationInfo &application_info() const = 0;
