@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,8 +27,8 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include "protocol/commands.pb.h"
 #include "session/session_observer_handler.h"
+#include "protocol/commands.pb.h"
 #include "session/session_observer_interface.h"
 #include "testing/base/public/gunit.h"
 
@@ -45,13 +45,9 @@ class SessionObserverMock : public SessionObserverInterface {
     ++eval_count_;
   }
 
-  int eval_count() const {
-    return eval_count_;
-  }
+  int eval_count() const { return eval_count_; }
 
-  const commands::Command &command() const {
-    return command_;
-  }
+  const commands::Command &command() const { return command_; }
 
  private:
   int eval_count_;
@@ -59,7 +55,6 @@ class SessionObserverMock : public SessionObserverInterface {
   DISALLOW_COPY_AND_ASSIGN(SessionObserverMock);
 };
 
-
 TEST(SessionObserverHandlerTest, ObserverTest) {
   SessionObserverHandler handler;
   SessionObserverMock observer1;
