@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -70,8 +70,8 @@ class SessionUsageObserver : public SessionObserverInterface {
     // Memory usage estimation: TouchEventStat message uses 240 bytes and
     // the number of source_id can be a few hundreds, so these variables seem to
     // use less than 100 KBytes.
-    std::map<string, usage_stats::TouchEventStatsMap> touch_event;
-    std::map<string, usage_stats::TouchEventStatsMap> miss_touch_event;
+    std::map<std::string, usage_stats::TouchEventStatsMap> touch_event;
+    std::map<std::string, usage_stats::TouchEventStatsMap> miss_touch_event;
     void Clear();
   };
 
@@ -81,11 +81,10 @@ class SessionUsageObserver : public SessionObserverInterface {
   static bool SaveCachedStats(void *data);
 
   void EvalCreateSession(const commands::Input &input,
-                        const commands::Output &output,
-                        std::map<uint64, protocol::SessionState> *states);
+                         const commands::Output &output,
+                         std::map<uint64, protocol::SessionState> *states);
   // Update state and update stats using input and output.
-  void UpdateState(const commands::Input &input,
-                   const commands::Output &output,
+  void UpdateState(const commands::Input &input, const commands::Output &output,
                    protocol::SessionState *state);
   // Update client side stats.
   void UpdateClientSideStats(const commands::Input &input,
@@ -96,8 +95,8 @@ class SessionUsageObserver : public SessionObserverInterface {
                      const protocol::SessionState &state);
   // Stores KeyTouch message to TouchEventStats.
   void StoreTouchEventStats(
-       const commands::Input_TouchEvent &touch_event,
-       usage_stats::TouchEventStatsMap *touch_event_stats_map);
+      const commands::Input_TouchEvent &touch_event,
+      usage_stats::TouchEventStatsMap *touch_event_stats_map);
 
   std::map<uint64, protocol::SessionState> states_;
   UsageCache usage_cache_;
