@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,8 +41,7 @@ namespace louds {
 // supporting Rank/Select operations.
 class BitVectorBasedArray {
  public:
-  BitVectorBasedArray() {
-  }
+  BitVectorBasedArray() {}
 
   void Open(const uint8 *image);
   void Close();
