@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -40,8 +40,7 @@ namespace {
 using ::mozc::storage::louds::BitVectorBasedArray;
 using ::mozc::storage::louds::BitVectorBasedArrayBuilder;
 
-class BitVectorBasedArrayTest : public ::testing::Test {
-};
+class BitVectorBasedArrayTest : public ::testing::Test {};
 
 TEST_F(BitVectorBasedArrayTest, Get) {
   struct {
@@ -50,22 +49,22 @@ TEST_F(BitVectorBasedArrayTest, Get) {
     const char* expected_element;
     const size_t expected_length;
   } kTestData[] = {
-    { "", 0, "\x00\x00\x00\x00", 4 },
-    { "a", 1, "a\x00\x00\x00", 4 },
-    { "b", 1, "b\x00\x00\x00", 4 },
-    { "c", 1, "c\x00\x00\x00", 4 },
-    { "d", 1, "d\x00\x00\x00", 4 },
-    { "abcdefg", 7, "abcdefg\x00", 8 },
-    { "mozc", 4, "mozc", 4 },
-    { "google-japanese-input", 21, "google-japanese-input\x00", 22 },
-    { "abcdefg", 7, "abcdefg\x00", 8 },  // Test for storing a same element.
-    { "testdata", 8, "testdata", 8 },
-    { "another-test-data", 17, "another-test-data\x00", 18 },
+      {"", 0, "\x00\x00\x00\x00", 4},
+      {"a", 1, "a\x00\x00\x00", 4},
+      {"b", 1, "b\x00\x00\x00", 4},
+      {"c", 1, "c\x00\x00\x00", 4},
+      {"d", 1, "d\x00\x00\x00", 4},
+      {"abcdefg", 7, "abcdefg\x00", 8},
+      {"mozc", 4, "mozc", 4},
+      {"google-japanese-input", 21, "google-japanese-input\x00", 22},
+      {"abcdefg", 7, "abcdefg\x00", 8},  // Test for storing a same element.
+      {"testdata", 8, "testdata", 8},
+      {"another-test-data", 17, "another-test-data\x00", 18},
   };
 
   BitVectorBasedArrayBuilder builder;
   for (size_t i = 0; i < arraysize(kTestData); ++i) {
-    builder.Add(string(kTestData[i].element, kTestData[i].length));
+    builder.Add(std::string(kTestData[i].element, kTestData[i].length));
   }
   builder.SetSize(4, 2);
   builder.Build();
@@ -74,10 +73,10 @@ TEST_F(BitVectorBasedArrayTest, Get) {
   array.Open(reinterpret_cast<const uint8*>(builder.image().data()));
   for (size_t i = 0; i < arraysize(kTestData); ++i) {
     size_t length;
-    const char *result = array.Get(i, &length);
-    EXPECT_EQ(
-        string(kTestData[i].expected_element, kTestData[i].expected_length),
-        string(result, length));
+    const char* result = array.Get(i, &length);
+    EXPECT_EQ(std::string(kTestData[i].expected_element,
+                          kTestData[i].expected_length),
+              std::string(result, length));
   }
 
   array.Close();
