@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,15 +33,15 @@
 #include <vector>
 
 #include "base/port.h"
-#include "base/string_piece.h"
 #include "testing/base/public/gunit.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace storage {
 namespace louds {
 namespace {
 
-std::vector<uint8> MakeSequence(StringPiece s) {
+std::vector<uint8> MakeSequence(absl::string_view s) {
   std::vector<uint8> seq;
   int bit_len = 0;
   for (size_t i = 0; i < s.size(); ++i) {
@@ -107,10 +107,8 @@ TEST_P(LoudsTest, Basic) {
   // Test with the trie illustrated in louds.h.
   const std::vector<uint8> kSeq = MakeSequence("10 110 0 110 0 0");
   Louds louds;
-  louds.Init(kSeq.data(), kSeq.size(),
-             param.bitvec_lb0_cache_size,
-             param.bitvec_lb1_cache_size,
-             param.select0_cache_size,
+  louds.Init(kSeq.data(), kSeq.size(), param.bitvec_lb0_cache_size,
+             param.bitvec_lb1_cache_size, param.select0_cache_size,
              param.select1_cache_size);
 
   // root -> 2 -> 3 -> 4 -> 5
@@ -154,26 +152,17 @@ TEST_P(LoudsTest, Basic) {
   }
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     GenLoudsTest, LoudsTest,
-    ::testing::Values(CacheSizeParam(0, 0, 0, 0),
-                      CacheSizeParam(0, 0, 0, 1),
-                      CacheSizeParam(0, 0, 1, 0),
-                      CacheSizeParam(0, 0, 1, 1),
-                      CacheSizeParam(0, 1, 0, 0),
-                      CacheSizeParam(0, 1, 0, 1),
-                      CacheSizeParam(0, 1, 1, 0),
-                      CacheSizeParam(0, 1, 1, 1),
-                      CacheSizeParam(1, 0, 0, 0),
-                      CacheSizeParam(1, 0, 0, 1),
-                      CacheSizeParam(1, 0, 1, 0),
-                      CacheSizeParam(1, 0, 1, 1),
-                      CacheSizeParam(1, 1, 0, 0),
-                      CacheSizeParam(1, 1, 0, 1),
-                      CacheSizeParam(1, 1, 1, 0),
-                      CacheSizeParam(1, 1, 1, 1),
-                      CacheSizeParam(2, 2, 2, 2),
-                      CacheSizeParam(8, 8, 8, 8),
+    ::testing::Values(CacheSizeParam(0, 0, 0, 0), CacheSizeParam(0, 0, 0, 1),
+                      CacheSizeParam(0, 0, 1, 0), CacheSizeParam(0, 0, 1, 1),
+                      CacheSizeParam(0, 1, 0, 0), CacheSizeParam(0, 1, 0, 1),
+                      CacheSizeParam(0, 1, 1, 0), CacheSizeParam(0, 1, 1, 1),
+                      CacheSizeParam(1, 0, 0, 0), CacheSizeParam(1, 0, 0, 1),
+                      CacheSizeParam(1, 0, 1, 0), CacheSizeParam(1, 0, 1, 1),
+                      CacheSizeParam(1, 1, 0, 0), CacheSizeParam(1, 1, 0, 1),
+                      CacheSizeParam(1, 1, 1, 0), CacheSizeParam(1, 1, 1, 1),
+                      CacheSizeParam(2, 2, 2, 2), CacheSizeParam(8, 8, 8, 8),
                       CacheSizeParam(1024, 1024, 1024, 1024)));
 
 }  // namespace
