@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,8 +34,6 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 namespace storage {
 
@@ -77,16 +75,15 @@ TEST(RegistryTest, TinyStorageTest) {
   {
     bool value = true;
     EXPECT_TRUE(Registry::Insert("bool", value));
-    bool expected = 0;
+    bool expected = false;
     EXPECT_TRUE(Registry::Lookup("bool", &expected));
     EXPECT_EQ(expected, value);
   }
 
-
   {
-    string value = "test";
+    std::string value = "test";
     EXPECT_TRUE(Registry::Insert("string", value));
-    string expected;
+    std::string expected;
     EXPECT_TRUE(Registry::Lookup("string", &expected));
     EXPECT_EQ(expected, value);
   }
