@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -51,13 +51,13 @@ namespace {
 const uint32 kStorageVersion = 0;
 const uint32 kStorageMagicId = 0x431fe241;  // random seed
 const size_t kMaxElementSize = 1024;        // max map size
-const size_t kMaxKeySize     = 4096;        // 4k for key/value
-const size_t kMaxValueSize   = 4096;        // 4k for key/value
+const size_t kMaxKeySize = 4096;            // 4k for key/value
+const size_t kMaxValueSize = 4096;          // 4k for key/value
 // 1024 * (4096 + 4096) =~ 8MByte
 // so 10Mbyte data is reasonable upper bound for file size
-const size_t kMaxFileSize     = 1024 * 1024 * 10;  // 10Mbyte
+const size_t kMaxFileSize = 1024 * 1024 * 10;  // 10Mbyte
 
-template<typename T>
+template <typename T>
 bool ReadData(char **begin, const char *end, T *value) {
   if (*begin + sizeof(*value) > end) {
     LOG(WARNING) << "accessing invalid pointer";
@@ -68,7 +68,7 @@ bool ReadData(char **begin, const char *end, T *value) {
   return true;
 }
 
-bool IsInvalid(const string &key, const string &value, size_t size) {
+bool IsInvalid(const std::string &key, const std::string &value, size_t size) {
   if (size >= kMaxElementSize) {
     LOG(ERROR) << "too many elements";
     return true;
@@ -89,20 +89,18 @@ class TinyStorageImpl : public StorageInterface {
   TinyStorageImpl();
   virtual ~TinyStorageImpl();
 
-  virtual bool Open(const string &filename);
+  virtual bool Open(const std::string &filename);
   virtual bool Sync();
-  virtual bool Lookup(const string &key, string *value) const;
-  virtual bool Insert(const string &key, const string &value);
-  virtual bool Erase(const string &key);
+  virtual bool Lookup(const std::string &key, std::string *value) const;
+  virtual bool Insert(const std::string &key, const std::string &value);
+  virtual bool Erase(const std::string &key);
   virtual bool Clear();
-  virtual size_t Size() const {
-    return dic_.size();
-  }
+  virtual size_t Size() const { return dic_.size(); }
 
  private:
-  string filename_;
+  std::string filename_;
   bool should_sync_;
-  std::map<string, string> dic_;
+  std::map<std::string, std::string> dic_;
 
   DISALLOW_COPY_AND_ASSIGN(TinyStorageImpl);
 };
@@ -111,9 +109,8 @@ TinyStorageImpl::TinyStorageImpl() : should_sync_(true) {
   // the each entry consumes at most
   // sizeof(uint32) * 2 (key/value length) +
   // kMaxKeySize + kMaxValueSize
-  DCHECK_GT(
-      kMaxFileSize,
-      kMaxElementSize * (kMaxKeySize + kMaxValueSize + sizeof(uint32) * 2));
+  DCHECK_GT(kMaxFileSize, kMaxElementSize * (kMaxKeySize + kMaxValueSize +
+                                             sizeof(uint32) * 2));
 }
 
 TinyStorageImpl::~TinyStorageImpl() {
@@ -122,7 +119,7 @@ TinyStorageImpl::~TinyStorageImpl() {
   }
 }
 
-bool TinyStorageImpl::Open(const string &filename) {
+bool TinyStorageImpl::Open(const std::string &filename) {
   Mmap mmap;
   dic_.clear();
   filename_ = filename;
@@ -185,7 +182,7 @@ bool TinyStorageImpl::Open(const string &filename) {
       return false;
     }
 
-    const string key(begin, key_size);
+    const std::string key(begin, key_size);
     begin += key_size;
 
     if (!ReadData<uint32>(&begin, end, &value_size)) {
@@ -198,7 +195,7 @@ bool TinyStorageImpl::Open(const string &filename) {
       return false;
     }
 
-    const string value(begin, value_size);
+    const std::string value(begin, value_size);
     begin += value_size;
 
     if (IsInvalid(key, value, dic_.size())) {
@@ -227,7 +224,7 @@ bool TinyStorageImpl::Sync() {
     return true;
   }
 
-  const string output_filename = filename_ + ".tmp";
+  const std::string output_filename = filename_ + ".tmp";
 
   OutputFileStream ofs(output_filename.c_str(),
                        std::ios::binary | std::ios::out);
@@ -238,27 +235,23 @@ bool TinyStorageImpl::Sync() {
 
   uint32 magic = 0;
   uint32 size = 0;
-  ofs.write(reinterpret_cast<const char *>(&magic),
-            sizeof(magic));
+  ofs.write(reinterpret_cast<const char *>(&magic), sizeof(magic));
   ofs.write(reinterpret_cast<const char *>(&kStorageVersion),
             sizeof(kStorageVersion));
-  ofs.write(reinterpret_cast<const char *>(&size),
-            sizeof(size));
+  ofs.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
-  for (std::map<string, string>::const_iterator it = dic_.begin();
+  for (std::map<std::string, std::string>::const_iterator it = dic_.begin();
        it != dic_.end(); ++it) {
     if (it->first.empty()) {
       continue;
     }
-    const string &key = it->first;
-    const string &value = it->second;
+    const std::string &key = it->first;
+    const std::string &value = it->second;
     const uint32 key_size = static_cast<uint32>(key.size());
     const uint32 value_size = static_cast<uint32>(value.size());
-    ofs.write(reinterpret_cast<const char *>(&key_size),
-              sizeof(key_size));
+    ofs.write(reinterpret_cast<const char *>(&key_size), sizeof(key_size));
     ofs.write(key.data(), key_size);
-    ofs.write(reinterpret_cast<const char *>(&value_size),
-              sizeof(value_size));
+    ofs.write(reinterpret_cast<const char *>(&value_size), sizeof(value_size));
     ofs.write(value.data(), value_size);
     ++size;
   }
@@ -267,12 +260,10 @@ bool TinyStorageImpl::Sync() {
   ofs.seekp(0);
   magic ^= kStorageMagicId;
 
-  ofs.write(reinterpret_cast<const char *>(&magic),
-            sizeof(magic));
+  ofs.write(reinterpret_cast<const char *>(&magic), sizeof(magic));
   ofs.write(reinterpret_cast<const char *>(&kStorageVersion),
             sizeof(kStorageVersion));
-  ofs.write(reinterpret_cast<const char *>(&size),
-            sizeof(size));
+  ofs.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
   // should call close(). Othrwise AtomicRename will be failed.
   ofs.close();
@@ -284,8 +275,8 @@ bool TinyStorageImpl::Sync() {
 
 #ifdef OS_WIN
   if (!FileUtil::HideFile(filename_)) {
-    LOG(ERROR) << "Cannot make hidden: " << filename_
-               << " " << ::GetLastError();
+    LOG(ERROR) << "Cannot make hidden: " << filename_ << " "
+               << ::GetLastError();
   }
 #endif
 
@@ -294,7 +285,7 @@ bool TinyStorageImpl::Sync() {
   return true;
 }
 
-bool TinyStorageImpl::Insert(const string &key, const string &value) {
+bool TinyStorageImpl::Insert(const std::string &key, const std::string &value) {
   if (IsInvalid(key, value, dic_.size())) {
     LOG(WARNING) << "invalid key/value is passed";
     return false;
@@ -304,8 +295,8 @@ bool TinyStorageImpl::Insert(const string &key, const string &value) {
   return true;
 }
 
-bool TinyStorageImpl::Erase(const string &key) {
-  std::map<string, string>::iterator it = dic_.find(key);
+bool TinyStorageImpl::Erase(const std::string &key) {
+  std::map<std::string, std::string>::iterator it = dic_.find(key);
   if (it == dic_.end()) {
     VLOG(2) << "cannot erase key: " << key;
     return false;
@@ -315,8 +306,8 @@ bool TinyStorageImpl::Erase(const string &key) {
   return true;
 }
 
-bool TinyStorageImpl::Lookup(const string &key, string *value) const {
-  std::map<string, string>::const_iterator it = dic_.find(key);
+bool TinyStorageImpl::Lookup(const std::string &key, std::string *value) const {
+  std::map<std::string, std::string>::const_iterator it = dic_.find(key);
   if (it == dic_.end()) {
     VLOG(3) << "cannot find key: " << key;
     return false;
@@ -337,14 +328,12 @@ StorageInterface *TinyStorage::Create(const char *filename) {
   std::unique_ptr<TinyStorageImpl> storage(new TinyStorageImpl);
   if (!storage->Open(filename)) {
     LOG(ERROR) << "cannot open " << filename;
-    return NULL;
+    return nullptr;
   }
   return storage.release();
 }
 
-StorageInterface *TinyStorage::New() {
-  return new TinyStorageImpl;
-}
+StorageInterface *TinyStorage::New() { return new TinyStorageImpl; }
 
 }  // namespace storage
 }  // namespace mozc
