@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -58,7 +58,7 @@ class GtkCandidateWindowHandler : public CandidateWindowHandlerInterface {
   virtual void Show(IBusEngine *engine);
 
   virtual void OnIBusCustomFontDescriptionChanged(
-      const string &custom_font_description);
+      const std::string &custom_font_description);
 
   virtual void OnIBusUseCustomFontDescriptionChanged(
       bool use_custom_font_description);
@@ -66,16 +66,15 @@ class GtkCandidateWindowHandler : public CandidateWindowHandlerInterface {
   void RegisterGSettingsObserver();
 
  protected:
-  bool SendUpdateCommand(IBusEngine *engine,
-                         const commands::Output &output,
+  bool SendUpdateCommand(IBusEngine *engine, const commands::Output &output,
                          bool visibility) const;
 
   std::unique_ptr<renderer::RendererInterface> renderer_;
   std::unique_ptr<commands::Output> last_update_output_;
 
  private:
-  string GetFontDescription() const;
-  string custom_font_description_;
+  std::string GetFontDescription() const;
+  std::string custom_font_description_;
   bool use_custom_font_description_;
   std::unique_ptr<GSettingsObserver> settings_observer_;
 
