@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -90,8 +90,8 @@ const bool kActivatedOnLaunch = true;
 PropertyHandler::PropertyHandler(MessageTranslatorInterface *translator,
                                  client::ClientInterface *client)
     : prop_root_(ibus_prop_list_new()),
-      prop_composition_mode_(NULL),
-      prop_mozc_tool_(NULL),
+      prop_composition_mode_(nullptr),
+      prop_mozc_tool_(nullptr),
       client_(client),
       translator_(translator),
       original_composition_mode_(kMozcEngineInitialCompositionMode),
@@ -121,19 +121,19 @@ PropertyHandler::~PropertyHandler() {
   if (prop_composition_mode_) {
     // The ref counter will drop to one.
     g_object_unref(prop_composition_mode_);
-    prop_composition_mode_ = NULL;
+    prop_composition_mode_ = nullptr;
   }
 
   if (prop_mozc_tool_) {
     // The ref counter will drop to one.
     g_object_unref(prop_mozc_tool_);
-    prop_mozc_tool_ = NULL;
+    prop_mozc_tool_ = nullptr;
   }
 
   if (prop_root_) {
     // Destroy all objects under the root.
     g_object_unref(prop_root_);
-    prop_root_ = NULL;
+    prop_root_ = nullptr;
   }
 }
 
@@ -144,7 +144,7 @@ void PropertyHandler::Register(IBusEngine *engine) {
 
 // TODO(nona): do not use kMozcEngine*** directory.
 void PropertyHandler::AppendCompositionPropertyToPanel() {
-  if (kMozcEngineProperties == NULL || kMozcEnginePropertiesSize == 0) {
+  if (kMozcEngineProperties == nullptr || kMozcEnginePropertiesSize == 0) {
     return;
   }
 
@@ -153,12 +153,12 @@ void PropertyHandler::AppendCompositionPropertyToPanel() {
   IBusPropList *sub_prop_list = ibus_prop_list_new();
 
   // Create items for the radio menu.
-  const commands::CompositionMode initial_mode = is_activated_ ?
-      original_composition_mode_ :
-      kMozcEnginePropertyIMEOffState->composition_mode;
+  const commands::CompositionMode initial_mode =
+      is_activated_ ? original_composition_mode_
+                    : kMozcEnginePropertyIMEOffState->composition_mode;
 
-  string icon_path_for_panel;
-  const char *mode_symbol = NULL;
+  std::string icon_path_for_panel;
+  const char *mode_symbol = nullptr;
   for (size_t i = 0; i < kMozcEnginePropertiesSize; ++i) {
     const MozcEngineProperty &entry = kMozcEngineProperties[i];
     IBusText *label = ibus_text_new_from_string(
@@ -169,23 +169,18 @@ void PropertyHandler::AppendCompositionPropertyToPanel() {
       icon_path_for_panel = GetIconPath(entry.icon);
       mode_symbol = entry.label_for_panel;
     }
-    IBusProperty *item = ibus_property_new(entry.key,
-                                           PROP_TYPE_RADIO,
-                                           label,
-                                           NULL /* icon */,
-                                           NULL /* tooltip */,
-                                           TRUE /* sensitive */,
-                                           TRUE /* visible */,
-                                           state,
-                                           NULL /* sub props */);
+    IBusProperty *item = ibus_property_new(
+        entry.key, PROP_TYPE_RADIO, label, nullptr /* icon */,
+        nullptr /* tooltip */, TRUE /* sensitive */, TRUE /* visible */, state,
+        nullptr /* sub props */);
     g_object_set_data(G_OBJECT(item), kGObjectDataKey, (gpointer)&entry);
     ibus_prop_list_append(sub_prop_list, item);
     // |sub_prop_list| owns |item| by calling g_object_ref_sink for the |item|.
   }
   DCHECK(!icon_path_for_panel.empty());
-  DCHECK(mode_symbol != NULL);
+  DCHECK(mode_symbol != nullptr);
 
-  const string &mode_label =
+  const std::string &mode_label =
       translator_->MaybeTranslate("Input Mode") + " (" + mode_symbol + ")";
   IBusText *label = ibus_text_new_from_string(mode_label.c_str());
 
@@ -194,15 +189,10 @@ void PropertyHandler::AppendCompositionPropertyToPanel() {
   // Do not change the name. Othewise the Gnome shell fails to recognize that
   // this property indicates Mozc's input mode.
   // See /usr/share/gnome-shell/js/ui/status/keyboard.js for details.
-  prop_composition_mode_ = ibus_property_new("InputMode",
-                                             PROP_TYPE_MENU,
-                                             label,
-                                             icon_path_for_panel.c_str(),
-                                             NULL /* tooltip */,
-                                             TRUE /* sensitive */,
-                                             TRUE /* visible */,
-                                             PROP_STATE_UNCHECKED,
-                                             sub_prop_list);
+  prop_composition_mode_ = ibus_property_new(
+      "InputMode", PROP_TYPE_MENU, label, icon_path_for_panel.c_str(),
+      nullptr /* tooltip */, TRUE /* sensitive */, TRUE /* visible */,
+      PROP_STATE_UNCHECKED, sub_prop_list);
 
   // Gnome shell uses symbol property for the mode indicator text icon iff the
   // property name is "InputMode".
@@ -219,16 +209,16 @@ void PropertyHandler::AppendCompositionPropertyToPanel() {
   ibus_prop_list_append(prop_root_, prop_composition_mode_);
 }
 
-void PropertyHandler::UpdateContentTypeImpl(IBusEngine *engine,
-                                            bool disabled) {
+void PropertyHandler::UpdateContentTypeImpl(IBusEngine *engine, bool disabled) {
   const bool prev_is_disabled = is_disabled_;
   is_disabled_ = disabled;
   if (prev_is_disabled == is_disabled_) {
     return;
   }
-  const auto visible_mode = (prev_is_disabled && !is_disabled_ && IsActivated())
-      ? original_composition_mode_ :
-        kMozcEnginePropertyIMEOffState->composition_mode;
+  const auto visible_mode =
+      (prev_is_disabled && !is_disabled_ && IsActivated())
+          ? original_composition_mode_
+          : kMozcEnginePropertyIMEOffState->composition_mode;
   UpdateCompositionModeIcon(engine, visible_mode);
 }
 
@@ -242,7 +232,8 @@ void PropertyHandler::UpdateContentType(IBusEngine *engine) {
 
 // TODO(nona): do not use kMozcEngine*** directory.
 void PropertyHandler::AppendToolPropertyToPanel() {
-  if (kMozcEngineToolProperties == NULL || kMozcEngineToolPropertiesSize == 0 ||
+  if (kMozcEngineToolProperties == nullptr ||
+      kMozcEngineToolPropertiesSize == 0 ||
       !IsMozcToolAvailable()) {
     return;
   }
@@ -256,31 +247,20 @@ void PropertyHandler::AppendToolPropertyToPanel() {
     IBusText *label = ibus_text_new_from_string(
         translator_->MaybeTranslate(entry.label).c_str());
     // TODO(yusukes): It would be better to use entry.icon here?
-    IBusProperty *item = ibus_property_new(entry.mode,
-                                           PROP_TYPE_NORMAL,
-                                           label,
-                                           NULL /* icon */,
-                                           NULL /* tooltip */,
-                                           TRUE,
-                                           TRUE,
-                                           PROP_STATE_UNCHECKED,
-                                           NULL);
+    IBusProperty *item = ibus_property_new(
+        entry.mode, PROP_TYPE_NORMAL, label, nullptr /* icon */,
+        nullptr /* tooltip */, TRUE, TRUE, PROP_STATE_UNCHECKED, nullptr);
     g_object_set_data(G_OBJECT(item), kGObjectDataKey, (gpointer)&entry);
     ibus_prop_list_append(sub_prop_list, item);
   }
 
-  IBusText *tool_label = ibus_text_new_from_string(
-      translator_->MaybeTranslate("Tools").c_str());
-  const string icon_path = GetIconPath(kMozcToolIconPath);
-  prop_mozc_tool_ = ibus_property_new("MozcTool",
-                                      PROP_TYPE_MENU,
-                                      tool_label,
-                                      icon_path.c_str(),
-                                      NULL /* tooltip */,
-                                      TRUE /* sensitive */,
-                                      TRUE /* visible */,
-                                      PROP_STATE_UNCHECKED,
-                                      sub_prop_list);
+  IBusText *tool_label =
+      ibus_text_new_from_string(translator_->MaybeTranslate("Tools").c_str());
+  const std::string icon_path = GetIconPath(kMozcToolIconPath);
+  prop_mozc_tool_ = ibus_property_new("MozcTool", PROP_TYPE_MENU, tool_label,
+                                      icon_path.c_str(), nullptr /* tooltip */,
+                                      TRUE /* sensitive */, TRUE /* visible */,
+                                      PROP_STATE_UNCHECKED, sub_prop_list);
 
   // Likewise, |prop_mozc_tool_| owns |sub_prop_list|. We have to sink
   // |prop_mozc_tool_| here so ibus_engine_update_property() call in
@@ -313,24 +293,23 @@ void PropertyHandler::Update(IBusEngine *engine,
 
 void PropertyHandler::UpdateCompositionModeIcon(
     IBusEngine *engine, const commands::CompositionMode new_composition_mode) {
-  if (prop_composition_mode_ == NULL) {
+  if (prop_composition_mode_ == nullptr) {
     return;
   }
 
-  const MozcEngineProperty *entry = NULL;
+  const MozcEngineProperty *entry = nullptr;
   for (size_t i = 0; i < kMozcEnginePropertiesSize; ++i) {
-    if (kMozcEngineProperties[i].composition_mode ==
-        new_composition_mode) {
+    if (kMozcEngineProperties[i].composition_mode == new_composition_mode) {
       entry = &(kMozcEngineProperties[i]);
       break;
     }
   }
   DCHECK(entry);
 
-  for (guint prop_index = 0; ; ++prop_index) {
+  for (guint prop_index = 0;; ++prop_index) {
     IBusProperty *prop = ibus_prop_list_get(
         ibus_property_get_sub_props(prop_composition_mode_), prop_index);
-    if (prop == NULL) {
+    if (prop == nullptr) {
       break;
     }
     if (!g_strcmp0(entry->key, ibus_property_get_key(prop))) {
@@ -352,7 +331,7 @@ void PropertyHandler::UpdateCompositionModeIcon(
   ibus_property_set_symbol(prop_composition_mode_, symbol);
 #endif  // MOZC_IBUS_HAS_SYMBOL
 
-  const string &mode_label =
+  const std::string &mode_label =
       translator_->MaybeTranslate("Input Mode") + " (" + mode_symbol + ")";
   IBusText *label = ibus_text_new_from_string(mode_label.c_str());
   ibus_property_set_label(prop_composition_mode_, label);
@@ -369,11 +348,10 @@ void PropertyHandler::SetCompositionMode(
   // composition_mode. However in IBus we can only control composition mode, not
   // IMEOn/IMEOff. So we use one composition state as IMEOff and the others as
   // IMEOn. This setting can be configured with setting
-  // kMozcEnginePropertyIMEOffState. If kMozcEnginePropertyIMEOffState is NULL,
-  // it means current IME should not be off.
-  if (kMozcEnginePropertyIMEOffState
-      && is_activated_
-      && composition_mode == kMozcEnginePropertyIMEOffState->composition_mode) {
+  // kMozcEnginePropertyIMEOffState. If kMozcEnginePropertyIMEOffState is
+  // nullptr, it means current IME should not be off.
+  if (kMozcEnginePropertyIMEOffState && is_activated_ &&
+      composition_mode == kMozcEnginePropertyIMEOffState->composition_mode) {
     command.set_type(commands::SessionCommand::TURN_OFF_IME);
     command.set_composition_mode(original_composition_mode_);
     client_->SendCommand(command, &output);
@@ -395,15 +373,15 @@ void PropertyHandler::ProcessPropertyActivate(IBusEngine *engine,
   }
 
   if (prop_mozc_tool_) {
-    for (guint prop_index = 0; ; ++prop_index) {
+    for (guint prop_index = 0;; ++prop_index) {
       IBusProperty *prop = ibus_prop_list_get(
           ibus_property_get_sub_props(prop_mozc_tool_), prop_index);
-      if (prop == NULL) {
+      if (prop == nullptr) {
         break;
       }
       if (!g_strcmp0(property_name, ibus_property_get_key(prop))) {
         const MozcEngineToolProperty *entry =
-            reinterpret_cast<const MozcEngineToolProperty*>(
+            reinterpret_cast<const MozcEngineToolProperty *>(
                 g_object_get_data(G_OBJECT(prop), kGObjectDataKey));
         DCHECK(entry->mode);
         if (!client_->LaunchTool(entry->mode, "")) {
@@ -419,32 +397,27 @@ void PropertyHandler::ProcessPropertyActivate(IBusEngine *engine,
   }
 
   if (prop_composition_mode_) {
-    for (guint prop_index = 0; ; ++prop_index) {
+    for (guint prop_index = 0;; ++prop_index) {
       IBusProperty *prop = ibus_prop_list_get(
           ibus_property_get_sub_props(prop_composition_mode_), prop_index);
-      if (prop == NULL) {
+      if (prop == nullptr) {
         break;
       }
       if (!g_strcmp0(property_name, ibus_property_get_key(prop))) {
         const MozcEngineProperty *entry =
-            reinterpret_cast<const MozcEngineProperty*>(
+            reinterpret_cast<const MozcEngineProperty *>(
                 g_object_get_data(G_OBJECT(prop), kGObjectDataKey));
         SetCompositionMode(engine, entry->composition_mode);
-        UpdateCompositionModeIcon(
-            engine, entry->composition_mode);
+        UpdateCompositionModeIcon(engine, entry->composition_mode);
         break;
       }
     }
   }
 }
 
-bool PropertyHandler::IsActivated() const {
-  return is_activated_;
-}
+bool PropertyHandler::IsActivated() const { return is_activated_; }
 
-bool PropertyHandler::IsDisabled() const {
-  return is_disabled_;
-}
+bool PropertyHandler::IsDisabled() const { return is_disabled_; }
 
 commands::CompositionMode PropertyHandler::GetOriginalCompositionMode() const {
   return original_composition_mode_;
