@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,8 +38,8 @@
 
 #include "base/logging.h"
 #include "base/mutex.h"
-#include "base/thread.h"
 #include "base/port.h"
+#include "base/thread.h"
 #include "base/util.h"
 
 namespace mozc {
@@ -51,19 +51,13 @@ using std::unique_ptr;
 
 class ScopedXcbGenericError {
  public:
-  ScopedXcbGenericError()
-      : error_(NULL) {
-  }
+  ScopedXcbGenericError() : error_(nullptr) {}
   ~ScopedXcbGenericError() {
     free(error_);
-    error_ = NULL;
-  }
-  const xcb_generic_error_t *get() const {
-    return error_;
-  }
-  xcb_generic_error_t **mutable_get() {
-    return &error_;
+    error_ = nullptr;
   }
+  const xcb_generic_error_t *get() const { return error_; }
+  xcb_generic_error_t **mutable_get() { return &error_; }
 
  private:
   xcb_generic_error_t *error_;
@@ -71,9 +65,7 @@ class ScopedXcbGenericError {
 
 template <typename T>
 struct FreeDeleter {
-  void operator()(T *ptr) const {
-    free(ptr);
-  }
+  void operator()(T *ptr) const { free(ptr); }
 };
 
 // TODO(yukawa): Use template aliases when GCC 4.6 is retired.
@@ -101,27 +93,23 @@ struct XcbAtoms {
         net_wm_name(XCB_NONE),
         net_wm_pid(XCB_NONE),
         utf8_string(XCB_NONE),
-        wm_client_machine(XCB_NONE) {
-  }
+        wm_client_machine(XCB_NONE) {}
 };
 
 class SelectionMonitorServer {
  public:
   SelectionMonitorServer()
-      : connection_(NULL),
+      : connection_(nullptr),
         requestor_window_(0),
         root_window_(0),
         xfixes_first_event_(0),
-        xcb_maximum_request_len_(0) {
-  }
+        xcb_maximum_request_len_(0) {}
 
-  ~SelectionMonitorServer() {
-    Release();
-  }
+  ~SelectionMonitorServer() { Release(); }
 
   bool Init() {
-    connection_ = ::xcb_connect(NULL, NULL);
-    if (connection_ == NULL) {
+    connection_ = ::xcb_connect(nullptr, nullptr);
+    if (connection_ == nullptr) {
       return false;
     }
 
@@ -140,18 +128,18 @@ class SelectionMonitorServer {
 
     requestor_window_ = ::xcb_generate_id(connection_);
     const uint32 mask = XCB_CW_EVENT_MASK;
-    const uint32 values[] = { XCB_EVENT_MASK_PROPERTY_CHANGE };
+    const uint32 values[] = {XCB_EVENT_MASK_PROPERTY_CHANGE};
     root_window_ = screen->root;
-    ::xcb_create_window(connection_, screen->root_depth,
-                        requestor_window_, root_window_,
-                        0, 0, 1, 1, 0, XCB_WINDOW_CLASS_INPUT_OUTPUT,
-                        screen->root_visual, mask, values);
+    ::xcb_create_window(connection_, screen->root_depth, requestor_window_,
+                        root_window_, 0, 0, 1, 1, 0,
+                        XCB_WINDOW_CLASS_INPUT_OUTPUT, screen->root_visual,
+                        mask, values);
     const uint32 xfixes_mask =
         XCB_XFIXES_SELECTION_EVENT_MASK_SET_SELECTION_OWNER |
         XCB_XFIXES_SELECTION_EVENT_MASK_SELECTION_WINDOW_DESTROY |
         XCB_XFIXES_SELECTION_EVENT_MASK_SELECTION_CLIENT_CLOSE;
-    ::xcb_xfixes_select_selection_input_checked(
-        connection_, requestor_window_, XCB_ATOM_PRIMARY, xfixes_mask);
+    ::xcb_xfixes_select_selection_input_checked(connection_, requestor_window_,
+                                                XCB_ATOM_PRIMARY, xfixes_mask);
     ::xcb_flush(connection_);
     return true;
   }
@@ -162,7 +150,7 @@ class SelectionMonitorServer {
     }
     if (::xcb_connection_has_error(connection_)) {
       LOG(ERROR) << "XCB connection has error.";
-      connection_ = NULL;
+      connection_ = nullptr;
       return false;
     }
     return true;
@@ -175,18 +163,17 @@ class SelectionMonitorServer {
     }
 
     ::xcb_flush(connection_);
-    unique_ptr<xcb_generic_event_t, void (*)(void*)> event(
+    unique_ptr<xcb_generic_event_t, void (*)(void *)> event(
         ::xcb_wait_for_event(connection_), &std::free);
 
-    if (event.get() == NULL) {
-      LOG(ERROR) << "NULL event returned.";
+    if (event.get() == nullptr) {
+      LOG(ERROR) << "nullptr event returned.";
       return false;
     }
 
     const uint32_t response_type = (event->response_type & ~0x80);
 
-    if (response_type ==
-        (xfixes_first_event_ + XCB_XFIXES_SELECTION_NOTIFY)) {
+    if (response_type == (xfixes_first_event_ + XCB_XFIXES_SELECTION_NOTIFY)) {
       return OnXFixesSelectionNotify(event.get(), max_bytes, next_info);
     }
 
@@ -211,7 +198,7 @@ class SelectionMonitorServer {
     event.response_type = XCB_CLIENT_MESSAGE;
     event.window = requestor_window_;
     event.format = 32;
-    event.type  = XCB_NONE;
+    event.type = XCB_NONE;
     ::xcb_send_event(connection_, false, requestor_window_,
                      XCB_EVENT_MASK_NO_EVENT,
                      reinterpret_cast<const char *>(&event));
@@ -222,19 +209,19 @@ class SelectionMonitorServer {
   void Release() {
     if (connection_) {
       ::xcb_disconnect(connection_);
-      connection_ = NULL;
+      connection_ = nullptr;
     }
   }
 
-  bool CreateAtom(const string name, xcb_atom_t *atom) const {
+  bool CreateAtom(const std::string name, xcb_atom_t *atom) const {
     DCHECK(atom);
     *atom = XCB_NONE;
     xcb_intern_atom_cookie_t cookie =
         ::xcb_intern_atom(connection_, false, name.size(), name.c_str());
     ScopedXcbInternAtomReply reply(
         ::xcb_intern_atom_reply(connection_, cookie, 0));
-    if (reply.get() == NULL) {
-      LOG(ERROR) << "xcb_intern_atom_reply returned NULL reply.";
+    if (reply.get() == nullptr) {
+      LOG(ERROR) << "xcb_intern_atom_reply returned nullptr reply.";
       return false;
     }
     if (reply->atom == XCB_NONE) {
@@ -245,43 +232,40 @@ class SelectionMonitorServer {
   }
 
   bool InitAtoms() {
-    return
-        CreateAtom("MOZC_SEL_MON", &atoms_.mozc_selection_monitor) &&
-        CreateAtom("UTF8_STRING", &atoms_.utf8_string) &&
-        CreateAtom("_NET_WM_NAME", &atoms_.net_wm_name) &&
-        CreateAtom("_NET_WM_PID", &atoms_.net_wm_pid) &&
-        CreateAtom("WM_CLIENT_MACHINE", &atoms_.wm_client_machine);
+    return CreateAtom("MOZC_SEL_MON", &atoms_.mozc_selection_monitor) &&
+           CreateAtom("UTF8_STRING", &atoms_.utf8_string) &&
+           CreateAtom("_NET_WM_NAME", &atoms_.net_wm_name) &&
+           CreateAtom("_NET_WM_PID", &atoms_.net_wm_pid) &&
+           CreateAtom("WM_CLIENT_MACHINE", &atoms_.wm_client_machine);
   }
 
   bool InitXFixes() {
-    const xcb_query_extension_reply_t
-        *ext_reply = ::xcb_get_extension_data(connection_, &xcb_xfixes_id);
-    if (ext_reply == NULL) {
-      LOG(ERROR) << "xcb_get_extension_data returns NULL.";
+    const xcb_query_extension_reply_t *ext_reply =
+        ::xcb_get_extension_data(connection_, &xcb_xfixes_id);
+    if (ext_reply == nullptr) {
+      LOG(ERROR) << "xcb_get_extension_data returns nullptr.";
       return false;
     }
 
     const xcb_xfixes_query_version_cookie_t xfixes_query_cookie =
-        xcb_xfixes_query_version(
-            connection_,
-            XCB_XFIXES_MAJOR_VERSION,
-            XCB_XFIXES_MINOR_VERSION);
+        xcb_xfixes_query_version(connection_, XCB_XFIXES_MAJOR_VERSION,
+                                 XCB_XFIXES_MINOR_VERSION);
     ScopedXcbGenericError xcb_error;
     ScopedXcbXFixesQueqyVersionReply xfixes_query(
-        ::xcb_xfixes_query_version_reply(
-            connection_, xfixes_query_cookie, xcb_error.mutable_get()));
-    if (xcb_error.get() != NULL) {
+        ::xcb_xfixes_query_version_reply(connection_, xfixes_query_cookie,
+                                         xcb_error.mutable_get()));
+    if (xcb_error.get() != nullptr) {
       LOG(ERROR) << "xcb_xfixes_query_version_reply failed. error_code: "
                  << static_cast<uint32>(xcb_error.get()->error_code);
       return false;
     }
-    if (xfixes_query.get() == NULL) {
+    if (xfixes_query.get() == nullptr) {
       return false;
     }
 
     xfixes_first_event_ = ext_reply->first_event;
-    LOG(INFO) << "XFixes ver: " << xfixes_query->major_version
-              << "." << xfixes_query->major_version
+    LOG(INFO) << "XFixes ver: " << xfixes_query->major_version << "."
+              << xfixes_query->major_version
               << ", first_event: " << xfixes_first_event_;
 
     xcb_maximum_request_len_ = ::xcb_get_maximum_request_length(connection_);
@@ -294,47 +278,41 @@ class SelectionMonitorServer {
     return true;
   }
 
-  string GetAtomName(xcb_atom_t atom) const {
-    const xcb_get_atom_name_cookie_t cookie = ::xcb_get_atom_name(
-        connection_, atom);
+  std::string GetAtomName(xcb_atom_t atom) const {
+    const xcb_get_atom_name_cookie_t cookie =
+        ::xcb_get_atom_name(connection_, atom);
     ScopedXcbGenericError xcb_error;
-    ScopedXcbGetAtomNameReply reply(
-        ::xcb_get_atom_name_reply(
-            connection_, cookie, xcb_error.mutable_get()));
-    if (xcb_error.get() != NULL) {
+    ScopedXcbGetAtomNameReply reply(::xcb_get_atom_name_reply(
+        connection_, cookie, xcb_error.mutable_get()));
+    if (xcb_error.get() != nullptr) {
       LOG(ERROR) << "xcb_get_atom_name_reply failed. error_code: "
                  << static_cast<uint32>(xcb_error.get()->error_code);
       return "";
     }
-    if (reply.get() == NULL) {
-      VLOG(2) << "reply is NULL";
+    if (reply.get() == nullptr) {
+      VLOG(2) << "reply is nullptr";
       return "";
     }
 
     const char *ptr = ::xcb_get_atom_name_name(reply.get());
     const size_t len = ::xcb_get_atom_name_name_length(reply.get());
-    return string(ptr, len);
+    return std::string(ptr, len);
   }
 
   bool GetByteArrayProperty(xcb_window_t window, xcb_atom_t property_atom,
-                            xcb_atom_t property_type_atom,
-                            size_t max_bytes,
-                            string *retval) const {
+                            xcb_atom_t property_type_atom, size_t max_bytes,
+                            std::string *retval) const {
     DCHECK(retval);
     retval->clear();
     size_t bytes_after = 0;
     int element_bit_size = 0;
     {
-      const xcb_get_property_cookie_t cookie =
-          ::xcb_get_property(connection_, false,
-                             window,
-                             property_atom,
-                             property_type_atom,
-                             0, 0);
+      const xcb_get_property_cookie_t cookie = ::xcb_get_property(
+          connection_, false, window, property_atom, property_type_atom, 0, 0);
       ScopedXcbGetPropertyReply reply(
           ::xcb_get_property_reply(connection_, cookie, 0));
-      if (reply.get() == NULL) {
-        VLOG(2) << "reply is NULL";
+      if (reply.get() == nullptr) {
+        VLOG(2) << "reply is nullptr";
         return false;
       }
       if (reply->type == XCB_NONE) {
@@ -371,17 +349,12 @@ class SelectionMonitorServer {
 
     while (bytes_after > 0) {
       const xcb_get_property_cookie_t cookie =
-          ::xcb_get_property(connection_,
-                             false,
-                             window,
-                             property_atom,
-                             property_type_atom,
-                             byte_offset,
-                             max_bytes);
+          ::xcb_get_property(connection_, false, window, property_atom,
+                             property_type_atom, byte_offset, max_bytes);
       ScopedXcbGetPropertyReply reply(
           ::xcb_get_property_reply(connection_, cookie, 0));
-      if (reply.get() == NULL) {
-        VLOG(2) << "reply is NULL";
+      if (reply.get() == nullptr) {
+        VLOG(2) << "reply is nullptr";
         return false;
       }
       if (reply->format != element_bit_size) {
@@ -389,10 +362,10 @@ class SelectionMonitorServer {
         return false;
       }
       bytes_after = reply->bytes_after;
-      const char *data = reinterpret_cast<const char *>(
-          ::xcb_get_property_value(reply.get()));
+      const char *data =
+          reinterpret_cast<const char *>(::xcb_get_property_value(reply.get()));
       const int length = ::xcb_get_property_value_length(reply.get());
-      *retval += string(data, length);
+      *retval += std::string(data, length);
       byte_offset += length;
     }
     return true;
@@ -403,15 +376,12 @@ class SelectionMonitorServer {
                            T *retval) const {
     *retval = 0;
     const xcb_get_property_cookie_t cookie =
-        ::xcb_get_property(connection_, false,
-                           window,
-                           property_atom,
-                           XCB_ATOM_CARDINAL,
-                           0, sizeof(T) * 8);
+        ::xcb_get_property(connection_, false, window, property_atom,
+                           XCB_ATOM_CARDINAL, 0, sizeof(T) * 8);
     ScopedXcbGetPropertyReply reply(
         ::xcb_get_property_reply(connection_, cookie, 0));
-    if (reply.get() == NULL) {
-      VLOG(2) << "reply is NULL";
+    if (reply.get() == nullptr) {
+      VLOG(2) << "reply is nullptr";
       return false;
     }
 
@@ -431,51 +401,42 @@ class SelectionMonitorServer {
       return false;
     }
 
-    *retval = *reinterpret_cast<const T *>(
-        ::xcb_get_property_value(reply.get()));
+    *retval =
+        *reinterpret_cast<const T *>(::xcb_get_property_value(reply.get()));
     return true;
   }
 
   bool OnXFixesSelectionNotify(const xcb_generic_event_t *event,
                                size_t max_bytes, SelectionInfo *next_info) {
     const xcb_xfixes_selection_notify_event_t *event_notify =
-        reinterpret_cast<const xcb_xfixes_selection_notify_event_t *>(
-            event);
+        reinterpret_cast<const xcb_xfixes_selection_notify_event_t *>(event);
     if (event_notify->selection != XCB_ATOM_PRIMARY) {
       VLOG(2) << "Ignored :" << GetAtomName(event_notify->selection);
       return false;
     }
 
     // Send request message for selection info.
-    ::xcb_convert_selection(connection_, requestor_window_,
-                            XCB_ATOM_PRIMARY, atoms_.utf8_string,
-                            atoms_.mozc_selection_monitor,
+    ::xcb_convert_selection(connection_, requestor_window_, XCB_ATOM_PRIMARY,
+                            atoms_.utf8_string, atoms_.mozc_selection_monitor,
                             XCB_CURRENT_TIME);
 
     last_request_info_.timestamp = event_notify->selection_timestamp;
 
     uint32_t net_wm_pid = 0;
-    if (GetCardinalProperty(event_notify->owner,
-                            atoms_.net_wm_pid,
+    if (GetCardinalProperty(event_notify->owner, atoms_.net_wm_pid,
                             &net_wm_pid)) {
       last_request_info_.process_id = net_wm_pid;
     }
 
-    string net_wm_name;
-    if (GetByteArrayProperty(event_notify->owner,
-                             atoms_.net_wm_name,
-                             atoms_.utf8_string,
-                             max_bytes,
-                             &net_wm_name)) {
+    std::string net_wm_name;
+    if (GetByteArrayProperty(event_notify->owner, atoms_.net_wm_name,
+                             atoms_.utf8_string, max_bytes, &net_wm_name)) {
       last_request_info_.window_title = net_wm_name;
     }
 
-    string wm_client_machine;
-    if (GetByteArrayProperty(event_notify->owner,
-                             atoms_.wm_client_machine,
-                             XCB_ATOM_STRING,
-                             max_bytes,
-                             &wm_client_machine)) {
+    std::string wm_client_machine;
+    if (GetByteArrayProperty(event_notify->owner, atoms_.wm_client_machine,
+                             XCB_ATOM_STRING, max_bytes, &wm_client_machine)) {
       last_request_info_.machine_name = wm_client_machine;
     }
 
@@ -498,12 +459,9 @@ class SelectionMonitorServer {
       return false;
     }
 
-    string selected_text;
-    if (!GetByteArrayProperty(event_notify->requestor,
-                              event_notify->property,
-                              atoms_.utf8_string,
-                              max_bytes,
-                              &selected_text)) {
+    std::string selected_text;
+    if (!GetByteArrayProperty(event_notify->requestor, event_notify->property,
+                              atoms_.utf8_string, max_bytes, &selected_text)) {
       LOG(ERROR) << "Failed to retrieve selection text.";
       return false;
     }
@@ -525,14 +483,10 @@ class SelectionMonitorServer {
   DISALLOW_COPY_AND_ASSIGN(SelectionMonitorServer);
 };
 
-class SelectionMonitorImpl : public SelectionMonitorInterface,
-                             public Thread {
+class SelectionMonitorImpl : public SelectionMonitorInterface, public Thread {
  public:
   SelectionMonitorImpl(SelectionMonitorServer *server, size_t max_text_bytes)
-    : server_(server),
-      max_text_bytes_(max_text_bytes),
-      quit_(false) {
-  }
+      : server_(server), max_text_bytes_(max_text_bytes), quit_(false) {}
 
   virtual ~SelectionMonitorImpl() {
     // Currently mozc::Thread cannot safely detach the attached thread since
@@ -547,9 +501,7 @@ class SelectionMonitorImpl : public SelectionMonitorInterface,
   }
 
   // Implements SelectionMonitorInterface::StartMonitoring.
-  virtual void StartMonitoring() {
-    Thread::Start("SelectionMonitor");
-  }
+  virtual void StartMonitoring() { Thread::Start("SelectionMonitor"); }
 
   // Implements SelectionMonitorInterface::QueryQuit.
   virtual void QueryQuit() {
@@ -606,15 +558,13 @@ class SelectionMonitorImpl : public SelectionMonitorInterface,
 
 SelectionMonitorInterface::~SelectionMonitorInterface() {}
 
-SelectionInfo::SelectionInfo()
-    : timestamp(0), process_id(0) {
-}
+SelectionInfo::SelectionInfo() : timestamp(0), process_id(0) {}
 
 SelectionMonitorInterface *SelectionMonitorFactory::Create(
     size_t max_text_bytes) {
   unique_ptr<SelectionMonitorServer> server(new SelectionMonitorServer());
   if (!server->Init()) {
-    return NULL;
+    return nullptr;
   }
   return new SelectionMonitorImpl(server.release(), max_text_bytes);
 }
