@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -58,11 +58,9 @@ class SurroundingTextUtil {
   // When both 1) and 2) are satisfied, this function calculates
   // |*anchor_pos| for case 1).
   // Otherwise returns false.
-  static bool GetAnchorPosFromSelection(
-      const string &surrounding_text,
-      const string &selected_text,
-      guint cursor_pos,
-      guint *anchor_pos);
+  static bool GetAnchorPosFromSelection(const std::string &surrounding_text,
+                                        const std::string &selected_text,
+                                        guint cursor_pos, guint *anchor_pos);
 
  private:
   DISALLOW_IMPLICIT_CONSTRUCTORS(SurroundingTextUtil);
