@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -51,17 +51,15 @@ class ConversionModeUtil {
   // |kana_lock_enabled_in_hiragana_mode| is false.  Note that
   // InputModeConversionFlagToCompositionMode ignores TF_CONVERSIONMODE_ROMAN
   // flag.
-  static bool ToNativeMode(
-      mozc::commands::CompositionMode mode,
-      bool kana_lock_enabled_in_hiragana_mode,
-      uint32 *flag);
+  static bool ToNativeMode(mozc::commands::CompositionMode mode,
+                           bool kana_lock_enabled_in_hiragana_mode,
+                           uint32 *flag);
 
   // Converts combination of TF_CONVERSIONMODE_* to corresponding |mode|.
   // This function ignores TF_CONVERSIONMODE_ROMAN flag.
   // This his behavior is the same to that of MS-IME 98 or later.
   // http://support.microsoft.com/kb/419357
-  static bool ToMozcMode(
-      uint32 flag, mozc::commands::CompositionMode *mode);
+  static bool ToMozcMode(uint32 flag, mozc::commands::CompositionMode *mode);
 
   // A variant of ToNativeMode but takes mozc::commands::Status.
   // |logical_imm32_mode| is the conversion mode that should be reported to
@@ -70,15 +68,12 @@ class ConversionModeUtil {
   // the user.
   static bool ConvertStatusFromMozcToNative(
       const mozc::commands::Status &status,
-      bool kana_lock_enabled_in_hiragana_mode,
-      bool *is_open,
-      DWORD *logical_imm32_mode,
-      DWORD *visible_imm32_mode);
+      bool kana_lock_enabled_in_hiragana_mode, bool *is_open,
+      DWORD *logical_imm32_mode, DWORD *visible_imm32_mode);
 
   // A variant of ToMozcMode but returns mozc::commands::CompositionMode.
   static bool GetMozcModeFromNativeMode(
-      DWORD imm32_mode,
-      mozc::commands::CompositionMode *mozc_mode);
+      DWORD imm32_mode, mozc::commands::CompositionMode *mozc_mode);
 };
 }  // namespace win32
 }  // namespace mozc
