@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,13 +38,11 @@ namespace win32 {
 namespace {
 struct FixedReconvertString : public RECONVERTSTRING {
   BYTE buffer[4096];
-  void Initialize(const std::wstring &entire_string,
-                  size_t padding_bytes) {
+  void Initialize(const std::wstring &entire_string, size_t padding_bytes) {
     dwSize = sizeof(FixedReconvertString);
     dwVersion = 0;
 
-    dwStrOffset =
-        FIELD_OFFSET(FixedReconvertString, buffer) + padding_bytes;
+    dwStrOffset = FIELD_OFFSET(FixedReconvertString, buffer) + padding_bytes;
     wchar_t *dest = reinterpret_cast<wchar_t *>(&buffer[padding_bytes]);
     for (size_t i = 0; i < entire_string.size(); ++i) {
       dest[i] = entire_string[i];
@@ -156,49 +154,38 @@ TEST(ReconvertStringTest, dwCompAndTargetStrOffset_IsOnEnd) {
   EXPECT_TRUE(ReconvertString::Validate(&reconvert_string));
 }
 
-#define EXPECT_DECOMPOSE_SUCCESS(                                        \
-    expected_precedeing_text,                                            \
-    expected_preceding_composition,                                      \
-    expected_target,                                                     \
-    expected_following_composition,                                      \
-    expected_following_text,                                             \
-    actual_reconvert_string)                                             \
-  do {                                                                   \
-    std::wstring actual_precedeing_text;                                      \
-    std::wstring actual_preceding_composition;                                \
-    std::wstring actual_target;                                               \
-    std::wstring actual_following_composition;                                \
-    std::wstring actual_following_text;                                       \
-    EXPECT_TRUE(ReconvertString::Decompose(                              \
-        &(actual_reconvert_string),                                      \
-        &actual_precedeing_text,                                         \
-        &actual_preceding_composition,                                   \
-        &actual_target,                                                  \
-        &actual_following_composition,                                   \
-        &actual_following_text));                                        \
-    EXPECT_EQ((expected_precedeing_text), actual_precedeing_text);       \
-    EXPECT_EQ((expected_preceding_composition),                          \
-                 actual_preceding_composition);                          \
-    EXPECT_EQ((expected_target), actual_target);                         \
-    EXPECT_EQ((expected_following_composition),                          \
-                 actual_following_composition);                          \
-    EXPECT_EQ((expected_following_text), actual_following_text);         \
+#define EXPECT_DECOMPOSE_SUCCESS(                                              \
+    expected_precedeing_text, expected_preceding_composition, expected_target, \
+    expected_following_composition, expected_following_text,                   \
+    actual_reconvert_string)                                                   \
+  do {                                                                         \
+    std::wstring actual_precedeing_text;                                       \
+    std::wstring actual_preceding_composition;                                 \
+    std::wstring actual_target;                                                \
+    std::wstring actual_following_composition;                                 \
+    std::wstring actual_following_text;                                        \
+    EXPECT_TRUE(ReconvertString::Decompose(                                    \
+        &(actual_reconvert_string), &actual_precedeing_text,                   \
+        &actual_preceding_composition, &actual_target,                         \
+        &actual_following_composition, &actual_following_text));               \
+    EXPECT_EQ((expected_precedeing_text), actual_precedeing_text);             \
+    EXPECT_EQ((expected_preceding_composition), actual_preceding_composition); \
+    EXPECT_EQ((expected_target), actual_target);                               \
+    EXPECT_EQ((expected_following_composition), actual_following_composition); \
+    EXPECT_EQ((expected_following_text), actual_following_text);               \
   } while (false)
 
-#define EXPECT_DECOMPOSE_FAIL(actual_reconvert_string)                   \
-  do {                                                                   \
-    std::wstring actual_precedeing_text;                                      \
-    std::wstring actual_preceding_composition;                                \
-    std::wstring actual_target;                                               \
-    std::wstring actual_following_composition;                                \
-    std::wstring actual_following_text;                                       \
-    EXPECT_FALSE(ReconvertString::Decompose(                             \
-        &(actual_reconvert_string),                                      \
-        &actual_precedeing_text,                                         \
-        &actual_preceding_composition,                                   \
-        &actual_target,                                                  \
-        &actual_following_composition,                                   \
-        &actual_following_text));                                        \
+#define EXPECT_DECOMPOSE_FAIL(actual_reconvert_string)           \
+  do {                                                           \
+    std::wstring actual_precedeing_text;                         \
+    std::wstring actual_preceding_composition;                   \
+    std::wstring actual_target;                                  \
+    std::wstring actual_following_composition;                   \
+    std::wstring actual_following_text;                          \
+    EXPECT_FALSE(ReconvertString::Decompose(                     \
+        &(actual_reconvert_string), &actual_precedeing_text,     \
+        &actual_preceding_composition, &actual_target,           \
+        &actual_following_composition, &actual_following_text)); \
   } while (false)
 
 TEST(ReconvertStringTest, Decompose) {
@@ -266,8 +253,8 @@ TEST(ReconvertStringTest, Compose) {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
 
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"H", L"e", L"l", L"l", L"o", &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"H", L"e", L"l", L"l", L"o",
+                                         &reconvert_string));
     EXPECT_EQ(5, reconvert_string.dwStrLen);
     EXPECT_DECOMPOSE_SUCCESS(L"H", L"e", L"l", L"l", L"o", reconvert_string);
   }
@@ -275,8 +262,8 @@ TEST(ReconvertStringTest, Compose) {
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"H", L"", L"", L"", L"", &reconvert_string));
+    EXPECT_TRUE(
+        ReconvertString::Compose(L"H", L"", L"", L"", L"", &reconvert_string));
     EXPECT_EQ(1, reconvert_string.dwStrLen);
     EXPECT_DECOMPOSE_SUCCESS(L"H", L"", L"", L"", L"", reconvert_string);
   }
@@ -284,8 +271,8 @@ TEST(ReconvertStringTest, Compose) {
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"", L"e", L"", L"", L"", &reconvert_string));
+    EXPECT_TRUE(
+        ReconvertString::Compose(L"", L"e", L"", L"", L"", &reconvert_string));
     EXPECT_EQ(1, reconvert_string.dwStrLen);
     EXPECT_DECOMPOSE_SUCCESS(L"", L"e", L"", L"", L"", reconvert_string);
   }
@@ -293,8 +280,8 @@ TEST(ReconvertStringTest, Compose) {
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"", L"", L"l", L"", L"", &reconvert_string));
+    EXPECT_TRUE(
+        ReconvertString::Compose(L"", L"", L"l", L"", L"", &reconvert_string));
     EXPECT_EQ(1, reconvert_string.dwStrLen);
     EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"l", L"", L"", reconvert_string);
   }
@@ -302,8 +289,8 @@ TEST(ReconvertStringTest, Compose) {
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"", L"", L"", L"l", L"", &reconvert_string));
+    EXPECT_TRUE(
+        ReconvertString::Compose(L"", L"", L"", L"l", L"", &reconvert_string));
     EXPECT_EQ(1, reconvert_string.dwStrLen);
     EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"", L"l", L"", reconvert_string);
   }
@@ -311,8 +298,8 @@ TEST(ReconvertStringTest, Compose) {
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"", L"", L"", L"", L"o", &reconvert_string));
+    EXPECT_TRUE(
+        ReconvertString::Compose(L"", L"", L"", L"", L"o", &reconvert_string));
     EXPECT_EQ(1, reconvert_string.dwStrLen);
     EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"", L"", L"o", reconvert_string);
   }
@@ -323,8 +310,8 @@ TEST(ReconvertStringTest, Compose) {
     // Emulate the buffer size is too short.
     reconvert_string.dwSize = sizeof(RECONVERTSTRING);
 
-    EXPECT_FALSE(ReconvertString::Compose(
-        L"H", L"", L"", L"", L"o", &reconvert_string));
+    EXPECT_FALSE(
+        ReconvertString::Compose(L"H", L"", L"", L"", L"o", &reconvert_string));
   }
 }
 
@@ -334,19 +321,14 @@ TEST(ReconvertStringTest, EnsureCompositionIsNotEmpty) {
     reconvert_string.Initialize(L"", 10);
 
     // L"東京", L"", L"", L"", L"都に住む"
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"\u6771\u4EAC",
-        L"", L"", L"",
-        L"\u90FD\u306B\u4F4F\u3080",
-        &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"\u6771\u4EAC", L"", L"", L"",
+                                         L"\u90FD\u306B\u4F4F\u3080",
+                                         &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
     // L"", L"", L"東京都", L"", L"に住む"
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"", L"",
-        L"\u6771\u4EAC\u90FD",
-        L"",
-        L"\u306B\u4F4F\u3080", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"\u6771\u4EAC\u90FD", L"",
+                             L"\u306B\u4F4F\u3080", reconvert_string);
   }
 
   {
@@ -354,18 +336,13 @@ TEST(ReconvertStringTest, EnsureCompositionIsNotEmpty) {
     reconvert_string.Initialize(L"", 10);
 
     // L"はい", L"", L"", L"", L"。"
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"\u306F\u3044",
-        L"", L"", L"",
-        L"\u3002",
-        &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"\u306F\u3044", L"", L"", L"",
+                                         L"\u3002", &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
     // L"はい", L"", L"。", L"", L""
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"\u306F\u3044", L"",
-        L"\u3002",
-        L"", L"", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"\u306F\u3044", L"", L"\u3002", L"", L"",
+                             reconvert_string);
   }
 
   {
@@ -374,17 +351,14 @@ TEST(ReconvertStringTest, EnsureCompositionIsNotEmpty) {
 
     // L"", L"", L"", L"", L"南アメリカ大陸"
     EXPECT_TRUE(ReconvertString::Compose(
-        L"",
-        L"", L"", L"",
-        L"\u5357\u30A2\u30E1\u30EA\u30AB\u5927\u9678",
+        L"", L"", L"", L"", L"\u5357\u30A2\u30E1\u30EA\u30AB\u5927\u9678",
         &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
     // L"", L"", L"はい", L"", L"。"
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"", L"",
-        L"\u5357",
-        L"", L"\u30A2\u30E1\u30EA\u30AB\u5927\u9678", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"\u5357", L"",
+                             L"\u30A2\u30E1\u30EA\u30AB\u5927\u9678",
+                             reconvert_string);
   }
 
   {
@@ -392,18 +366,13 @@ TEST(ReconvertStringTest, EnsureCompositionIsNotEmpty) {
     reconvert_string.Initialize(L"", 10);
 
     // L"て\nき", L"", L"", L"", L"と\nう"
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"\u3066\n\u304D",
-        L"", L"", L"",
-        L"\u3068\n\u3046",
-        &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"\u3066\n\u304D", L"", L"", L"",
+                                         L"\u3068\n\u3046", &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
     // L"て\n", L"", L"きと", L"", L"\nう"
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"\u3066\n", L"",
-        L"\u304D\u3068",
-        L"", L"\n\u3046", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"\u3066\n", L"", L"\u304D\u3068", L"",
+                             L"\n\u3046", reconvert_string);
   }
 }
 
@@ -412,36 +381,34 @@ TEST(ReconvertStringTest, CompositionIsNotEmptyAgainstScriptTypeUnknown) {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
 
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"Hello", L"", L"", L"", L", world!", &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"Hello", L"", L"", L"", L", world!",
+                                         &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"Hello", L"", L",", L"", L" world!", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"Hello", L"", L",", L"", L" world!",
+                             reconvert_string);
   }
 
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
 
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"@@@", L"", L"", L"", L"", &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"@@@", L"", L"", L"", L"",
+                                         &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"@@", L"", L"@", L"", L"", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"@@", L"", L"@", L"", L"", reconvert_string);
   }
 
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
 
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"", L"", L"", L"", L"@@@", &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"", L"", L"", L"", L"@@@",
+                                         &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"", L"", L"@", L"", L"@@", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"@", L"", L"@@", reconvert_string);
   }
 }
 
@@ -452,11 +419,8 @@ TEST(ReconvertStringTest,
     reconvert_string.Initialize(L"", 10);
 
     // L"パ", L"", L"", L"", L"パ"
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"\u30CF\u309A",
-        L"", L"", L"",
-        L"\u30D1",
-        &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"\u30CF\u309A", L"", L"", L"",
+                                         L"\u30D1", &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
 
@@ -468,10 +432,8 @@ TEST(ReconvertStringTest,
     //     L"", L"", reconvert_string);
 
     // L"パ", L"", L"パ", L"", L"" (non-composite-character-aware)
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"\u30CF\u309A", L"",
-        L"\u30D1",
-        L"", L"", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"\u30CF\u309A", L"", L"\u30D1", L"", L"",
+                             reconvert_string);
   }
 
   {
@@ -479,11 +441,8 @@ TEST(ReconvertStringTest,
     reconvert_string.Initialize(L"", 10);
 
     // L"パ", L"", L"", L"", L"パ"
-    EXPECT_TRUE(ReconvertString::Compose(
-        L"\u30D1",
-        L"", L"", L"",
-        L"\u30CF\u309A",
-        &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(L"\u30D1", L"", L"", L"",
+                                         L"\u30CF\u309A", &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
 
@@ -495,10 +454,8 @@ TEST(ReconvertStringTest,
     //     L"", L"", reconvert_string);
 
     // L"", L"", L"パハ", L"", L"\u309A" (non-composite-character-aware)
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"", L"",
-        L"\u30D1\u30CF",
-        L"", L"\u309A", reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"\u30D1\u30CF", L"", L"\u309A",
+                             reconvert_string);
   }
 }
 
@@ -506,8 +463,8 @@ TEST(ReconvertStringTest, EnsureCompositionIsNotEmptyAgainstSurrogatePair) {
   // Visual C++ 2008 does not support embedding surrogate pair in string
   // literals like L"\uD842\uDF9F".  This is why we use wchar_t array instead.
   // L"今𠮟る"
-  const wchar_t kSurrogatePairText0_4[] =
-      {0x4ECA, 0xD842, 0xDF9F, 0x308B, 0x0000};
+  const wchar_t kSurrogatePairText0_4[] = {0x4ECA, 0xD842, 0xDF9F, 0x308B,
+                                           0x0000};
   // L"今𠮟"
   const wchar_t kSurrogatePairText0_3[] = {0x4ECA, 0xD842, 0xDF9F, 0x0000};
   // Invalid
@@ -532,56 +489,42 @@ TEST(ReconvertStringTest, EnsureCompositionIsNotEmptyAgainstSurrogatePair) {
 
     // L"", L"", L"", L"", L"今𠮟る"
     EXPECT_TRUE(ReconvertString::Compose(
-        L"",
-        L"", L"", L"",
-        kSurrogatePairText0_4,
-        &reconvert_string));
+        L"", L"", L"", L"", kSurrogatePairText0_4, &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
 
     // L"", L"", L"今𠮟", L"", L"る" (surrogate-pairs-aware)
-    EXPECT_DECOMPOSE_SUCCESS(
-        L"", L"",
-        kSurrogatePairText0_3,
-        L"", kSurrogatePairText3_1, reconvert_string);
+    EXPECT_DECOMPOSE_SUCCESS(L"", L"", kSurrogatePairText0_3, L"",
+                             kSurrogatePairText3_1, reconvert_string);
   }
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
 
     // L"今𠮟[High]", L"", L"", L"", L"𠮟[Low]る"
-    EXPECT_TRUE(ReconvertString::Compose(
-        kSurrogatePairText0_2,
-        L"", L"", L"",
-        kSurrogatePairText2_2,
-        &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(kSurrogatePairText0_2, L"", L"", L"",
+                                         kSurrogatePairText2_2,
+                                         &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
 
-     // L"", L"", L"今𠮟", L"", L"る" (surrogate-pairs-aware)
-     EXPECT_DECOMPOSE_SUCCESS(
-         L"", L"",
-         kSurrogatePairText0_3,
-         L"", kSurrogatePairText3_1, reconvert_string);
+    // L"", L"", L"今𠮟", L"", L"る" (surrogate-pairs-aware)
+    EXPECT_DECOMPOSE_SUCCESS(L"", L"", kSurrogatePairText0_3, L"",
+                             kSurrogatePairText3_1, reconvert_string);
   }
   {
     FixedReconvertString reconvert_string;
     reconvert_string.Initialize(L"", 10);
 
     // L"今𠮟", L"", L"", L"", L""
-    EXPECT_TRUE(ReconvertString::Compose(
-        kSurrogatePairText0_3,
-        L"", L"", L"",
-        L"",
-        &reconvert_string));
+    EXPECT_TRUE(ReconvertString::Compose(kSurrogatePairText0_3, L"", L"", L"",
+                                         L"", &reconvert_string));
     EXPECT_TRUE(
         ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
 
-     // L"", L"", L"今𠮟", L"", L"" (surrogate-pairs-aware)
-     EXPECT_DECOMPOSE_SUCCESS(
-         L"", L"",
-         kSurrogatePairText0_3,
-         L"", L"", reconvert_string);
+    // L"", L"", L"今𠮟", L"", L"" (surrogate-pairs-aware)
+    EXPECT_DECOMPOSE_SUCCESS(L"", L"", kSurrogatePairText0_3, L"", L"",
+                             reconvert_string);
   }
 }
 
@@ -595,19 +538,12 @@ TEST(ReconvertStringTest, ExcludeControlCode) {
   following_text += L"\u3064\u3065\u304F";
 
   // L"テスト", L"", L"", L"", L"\0つづく"
-  EXPECT_TRUE(ReconvertString::Compose(
-      L"\u30C6\u30B9\u30C8",
-      L"", L"", L"",
-      following_text,
-      &reconvert_string));
-  EXPECT_TRUE(
-      ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
+  EXPECT_TRUE(ReconvertString::Compose(L"\u30C6\u30B9\u30C8", L"", L"", L"",
+                                       following_text, &reconvert_string));
+  EXPECT_TRUE(ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
   // L"", L"", L"テスト", L"", L"\0つづく"
-  EXPECT_DECOMPOSE_SUCCESS(
-      L"", L"",
-      L"\u30C6\u30B9\u30C8",
-      L"", following_text,
-      reconvert_string);
+  EXPECT_DECOMPOSE_SUCCESS(L"", L"", L"\u30C6\u30B9\u30C8", L"", following_text,
+                           reconvert_string);
 }
 
 TEST(ReconvertStringTest, ExcludeCRLF_Issue4196242) {
@@ -615,19 +551,13 @@ TEST(ReconvertStringTest, ExcludeCRLF_Issue4196242) {
   reconvert_string.Initialize(L"", 10);
 
   // L"テスト", L"", L"", L"", L"@\r\n\r\n\r\nおわり"
-  EXPECT_TRUE(ReconvertString::Compose(
-      L"\u30C6\u30B9\u30C8",
-      L"", L"", L"",
-      L"@\r\n\r\n\r\n\u304A\u308F\u308A",
-      &reconvert_string));
-  EXPECT_TRUE(
-      ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
+  EXPECT_TRUE(ReconvertString::Compose(L"\u30C6\u30B9\u30C8", L"", L"", L"",
+                                       L"@\r\n\r\n\r\n\u304A\u308F\u308A",
+                                       &reconvert_string));
+  EXPECT_TRUE(ReconvertString::EnsureCompositionIsNotEmpty(&reconvert_string));
   // L"テスト", L"", L"@", L"", L"\r\n\r\n\r\nおわり"
-  EXPECT_DECOMPOSE_SUCCESS(
-      L"\u30C6\u30B9\u30C8", L"",
-      L"@",
-      L"", L"\r\n\r\n\r\n\u304A\u308F\u308A",
-      reconvert_string);
+  EXPECT_DECOMPOSE_SUCCESS(L"\u30C6\u30B9\u30C8", L"", L"@", L"",
+                           L"\r\n\r\n\r\n\u304A\u308F\u308A", reconvert_string);
 }
 }  // namespace win32
 }  // namespace mozc
