@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -67,59 +67,41 @@ class KeyEventHandler {
   // status.  Currently, key down event of VK_DBE_ROMAN or VK_DBE_NOROMAN
   // flips the input style when both |state.open| and
   // |behavior->use_romaji_key_to_toggle_input_style| is true.
-  static void UpdateBehaviorInImeProcessKey(
-      const VirtualKey &virtual_key,
-      bool is_key_down,
-      const InputState &state,
-      InputBehavior *behavior);
+  static void UpdateBehaviorInImeProcessKey(const VirtualKey &virtual_key,
+                                            bool is_key_down,
+                                            const InputState &state,
+                                            InputBehavior *behavior);
 
   static KeyEventHandlerResult ImeProcessKey(
-      const VirtualKey &virtual_key,
-      BYTE scan_code,
-      bool is_key_down,
-      const KeyboardStatus &keyboard_status,
-      const InputBehavior &behavior,
-      const InputState &initial_state,
-      const commands::Context &context,
-      client::ClientInterface *client,
-      Win32KeyboardInterface *keyboard,
-      InputState *next_state,
-      commands::Output *output);
+      const VirtualKey &virtual_key, BYTE scan_code, bool is_key_down,
+      const KeyboardStatus &keyboard_status, const InputBehavior &behavior,
+      const InputState &initial_state, const commands::Context &context,
+      client::ClientInterface *client, Win32KeyboardInterface *keyboard,
+      InputState *next_state, commands::Output *output);
 
   static KeyEventHandlerResult ImeToAsciiEx(
-      const VirtualKey &virtual_key,
-      BYTE scan_code,
-      bool is_key_down,
-      const KeyboardStatus &keyboard_status,
-      const InputBehavior &behavior,
-      const InputState &initial_state,
-      const commands::Context &context,
-      client::ClientInterface *client,
-      Win32KeyboardInterface *keyboard,
-      InputState *next_state,
-      commands::Output *output);
+      const VirtualKey &virtual_key, BYTE scan_code, bool is_key_down,
+      const KeyboardStatus &keyboard_status, const InputBehavior &behavior,
+      const InputState &initial_state, const commands::Context &context,
+      client::ClientInterface *client, Win32KeyboardInterface *keyboard,
+      InputState *next_state, commands::Output *output);
 
  protected:
-  static KeyEventHandlerResult HandleKey(
-      const VirtualKey &virtual_key,
-      BYTE scan_code,
-      bool is_key_down,
-      const KeyboardStatus &keyboard_status,
-      const InputBehavior &behavior,
-      const InputState &initial_state,
-      Win32KeyboardInterface *keyboard,
-      commands::KeyEvent *key);
+  static KeyEventHandlerResult HandleKey(const VirtualKey &virtual_key,
+                                         BYTE scan_code, bool is_key_down,
+                                         const KeyboardStatus &keyboard_status,
+                                         const InputBehavior &behavior,
+                                         const InputState &initial_state,
+                                         Win32KeyboardInterface *keyboard,
+                                         commands::KeyEvent *key);
 
-  static bool ConvertToKeyEvent(
-      const VirtualKey &virtual_key,
-      BYTE scan_code,
-      bool is_key_down,
-      bool is_menu_active,
-      const InputBehavior &behavior,
-      const InputState &ime_state,
-      const KeyboardStatus &keyboard_status,
-      Win32KeyboardInterface *keyboard,
-      commands::KeyEvent *key);
+  static bool ConvertToKeyEvent(const VirtualKey &virtual_key, BYTE scan_code,
+                                bool is_key_down, bool is_menu_active,
+                                const InputBehavior &behavior,
+                                const InputState &ime_state,
+                                const KeyboardStatus &keyboard_status,
+                                Win32KeyboardInterface *keyboard,
+                                commands::KeyEvent *key);
 
   // This function updates the current keyboard status so that a user will not
   // be bothered with unexpected Kana-lock.  See b/2601927, b/2521571,
@@ -132,10 +114,9 @@ class KeyEventHandler {
   // cases.  In such a case, you can use the returned |new_keyboard_status|
   // for subsequent key handlers so that they can behave as if the Kana-Lock
   // was unlocked when the key event occurred.
-  static void UnlockKanaLock(
-      const KeyboardStatus &keyboard_status,
-      Win32KeyboardInterface *keyboard,
-      KeyboardStatus *new_keyboard_status);
+  static void UnlockKanaLock(const KeyboardStatus &keyboard_status,
+                             Win32KeyboardInterface *keyboard,
+                             KeyboardStatus *new_keyboard_status);
 
   // Span Tool if launch_tool_mode is set in |output|.
   static void MaybeSpawnTool(client::ClientInterface *client,
