@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,16 +38,13 @@ namespace {
 
 // TODO(yukawa): Move this to util.cc.
 char32 SurrogatePairToUCS4(wchar_t high, wchar_t low) {
-  return (((high - 0xD800) & 0x3FF) << 10) +
-         ((low - 0xDC00) & 0x3FF) + 0x10000;
+  return (((high - 0xD800) & 0x3FF) << 10) + ((low - 0xDC00) & 0x3FF) + 0x10000;
 }
 
 }  // namespace
 
 SurrogatePairObserver::SurrogatePairObserver()
-    : state_(INITIAL_STATE),
-      surrogate_high_(L'\0'),
-      surrogate_low_(L'\0') {}
+    : state_(INITIAL_STATE), surrogate_high_(L'\0'), surrogate_low_(L'\0') {}
 
 SurrogatePairObserver::ClientAction SurrogatePairObserver::OnTestKeyEvent(
     const VirtualKey &virtual_key, bool is_keydown) {
@@ -108,8 +105,7 @@ SurrogatePairObserver::ClientAction SurrogatePairObserver::OnKeyEvent(
       }
       if (IS_LOW_SURROGATE(ucs2)) {
         if (is_keydown) {
-          const char32 ucs4 = SurrogatePairToUCS4(surrogate_high_,
-                                                  ucs2);
+          const char32 ucs4 = SurrogatePairToUCS4(surrogate_high_, ucs2);
           if (!is_test_key) {
             surrogate_low_ = ucs2;
             state_ = WAIT_FOR_SURROGATE_LOW_UP;
@@ -139,8 +135,7 @@ SurrogatePairObserver::ClientAction SurrogatePairObserver::OnKeyEvent(
       }
       if (IS_LOW_SURROGATE(ucs2)) {
         if (is_keydown) {
-          const char32 ucs4 = SurrogatePairToUCS4(surrogate_high_,
-                                                  ucs2);
+          const char32 ucs4 = SurrogatePairToUCS4(surrogate_high_, ucs2);
           if (!is_test_key) {
             surrogate_low_ = ucs2;
             state_ = WAIT_FOR_SURROGATE_LOW_UP;
@@ -182,8 +177,8 @@ SurrogatePairObserver::ClientAction SurrogatePairObserver::OnKeyEvent(
           // Ignore orhpaned key-up of low surrogate.
           return ClientAction(CONSUME_KEY_BUT_NEVER_SEND_TO_SERVER, 0);
         }
-        const char32 ucs4 = SurrogatePairToUCS4(surrogate_high_,
-                                                surrogate_low_);
+        const char32 ucs4 =
+            SurrogatePairToUCS4(surrogate_high_, surrogate_low_);
         if (!is_test_key) {
           state_ = INITIAL_STATE;
           surrogate_high_ = L'\0';
