@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,10 +31,12 @@
 
 #define _ATL_NO_AUTOMATIC_NAMESPACE
 #define _WTL_NO_AUTOMATIC_NAMESPACE
+// clang-format off
 #include <atlbase.h>
 #include <atlapp.h>
 #include <atlmisc.h>
 #include <atlgdi.h>
+// clang-format on
 
 #include <safeint.h>
 
@@ -43,6 +45,7 @@
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/util.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace win32 {
@@ -55,31 +58,24 @@ using ::WTL::CBitmapHandle;
 using ::WTL::CDC;
 using ::WTL::CFont;
 using ::WTL::CFontHandle;
+using ::WTL::CIconHandle;
 using ::WTL::CLogFont;
 using ::WTL::CRect;
 using ::WTL::CSize;
-using ::WTL::CIconHandle;
 
 RGBQUAD ToRGBQuad(DWORD color_ref) {
-  const RGBQUAD rgbquad = {
-    GetBValue(color_ref),
-    GetGValue(color_ref),
-    GetRValue(color_ref),
-    0xff
-  };
+  const RGBQUAD rgbquad = {GetBValue(color_ref), GetGValue(color_ref),
+                           GetRValue(color_ref), 0xff};
   return rgbquad;
 }
 
-CIconHandle CreateMonochromeIconInternal(
-    int bitmap_width,
-    int bitmap_height,
-    StringPiece text,
-    StringPiece fontname,
-    COLORREF text_color) {
-
+CIconHandle CreateMonochromeIconInternal(int bitmap_width, int bitmap_height,
+                                         absl::string_view text,
+                                         absl::string_view fontname,
+                                         COLORREF text_color) {
   struct MonochromeBitmapInfo {
     BITMAPINFOHEADER header;
-    RGBQUAD          color_palette[2];
+    RGBQUAD color_palette[2];
   };
 
   uint8 *src_dib_buffer = nullptr;
@@ -109,9 +105,8 @@ CIconHandle CreateMonochromeIconInternal(
     info.color_palette[1] = ToRGBQuad(kBackgroundColor);
 
     src_dib.CreateDIBSection(
-        nullptr, reinterpret_cast<const BITMAPINFO *>(&info),
-        DIB_RGB_COLORS, reinterpret_cast<void **>(&src_dib_buffer),
-        nullptr, 0);
+        nullptr, reinterpret_cast<const BITMAPINFO *>(&info), DIB_RGB_COLORS,
+        reinterpret_cast<void **>(&src_dib_buffer), nullptr, 0);
     if (src_dib.IsNull()) {
       return nullptr;
     }
@@ -187,8 +182,8 @@ CIconHandle CreateMonochromeIconInternal(
 
     uint8 *xor_dib_buffer = nullptr;
     xor_dib.CreateDIBSection(
-        nullptr, reinterpret_cast<const BITMAPINFO *>(&info),
-        DIB_RGB_COLORS, reinterpret_cast<void **>(&xor_dib_buffer), nullptr, 0);
+        nullptr, reinterpret_cast<const BITMAPINFO *>(&info), DIB_RGB_COLORS,
+        reinterpret_cast<void **>(&xor_dib_buffer), nullptr, 0);
     if (xor_dib.IsNull()) {
       return nullptr;
     }
@@ -247,25 +242,22 @@ CIconHandle CreateMonochromeIconInternal(
 }  // namespace
 
 // static
-HICON TextIcon::CreateMonochromeIcon(size_t width,
-                                     size_t height,
-                                     StringPiece text,
-                                     StringPiece fontname,
+HICON TextIcon::CreateMonochromeIcon(size_t width, size_t height,
+                                     absl::string_view text,
+                                     absl::string_view fontname,
                                      COLORREF text_color) {
   int safe_width = 0;
   int safe_height = 0;
   int safe_num_pixels = 0;
-  if (!SafeCast(width, safe_width) ||
-      !SafeCast(height, safe_height) ||
+  if (!SafeCast(width, safe_width) || !SafeCast(height, safe_height) ||
       !SafeMultiply(safe_width, safe_height, safe_num_pixels)) {
     LOG(ERROR) << "Requested size is too large."
-               << " width: " << width
-               << " height: " << height;
+               << " width: " << width << " height: " << height;
     return nullptr;
   }
 
-  return CreateMonochromeIconInternal(
-      safe_width, safe_height, text, fontname, text_color);
+  return CreateMonochromeIconInternal(safe_width, safe_height, text, fontname,
+                                      text_color);
 }
 
 }  // namespace win32
