@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,30 +30,29 @@
 #ifndef MOZC_WIN32_BASE_TEXT_ICON_H_
 #define MOZC_WIN32_BASE_TEXT_ICON_H_
 
+#include <stddef.h>
 #include <windows.h>
 
-#include "base/port.h"
-#include "base/string_piece.h"
+#include "absl/strings/string_view.h"
 
 namespace mozc {
 namespace win32 {
 
 class TextIcon {
  public:
+  TextIcon() = delete;
+  ~TextIcon() = delete;
+
   // Returns a monochrome icon with rendering |text| by using given |fontname|
   // and |text_color|.
   // The returned icon consists of color bitmap (a.k.a. XOR bitmap) and mask
   // bitmap (a.k.a. AND bitmap). This is mainly because ITfLangBarMgr causes
   // GDI handle leak when ITfLangBarItemButton::GetIcon returns an icon which
   // consists only of mask bitmap (AND bitmap).
-  static HICON CreateMonochromeIcon(size_t width,
-                                    size_t height,
-                                    StringPiece text,
-                                    StringPiece fontname,
+  static HICON CreateMonochromeIcon(size_t width, size_t height,
+                                    absl::string_view text,
+                                    absl::string_view fontname,
                                     COLORREF text_color);
-
- private:
-  DISALLOW_IMPLICIT_CONSTRUCTORS(TextIcon);
 };
 
 }  // namespace win32
