@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,8 +29,10 @@
 
 #include "win32/ime/ime_core.h"
 
-#include <ime.h>
+// clang-format off
 #include <windows.h>
+#include <ime.h>
+// clang-format on
 
 #include <memory>
 
@@ -42,9 +44,9 @@
 #include "session/output_util.h"
 #include "win32/base/conversion_mode_util.h"
 #include "win32/base/deleter.h"
+#include "win32/base/imm_reconvert_string.h"
 #include "win32/base/input_state.h"
 #include "win32/base/keyboard.h"
-#include "win32/base/imm_reconvert_string.h"
 #include "win32/ime/ime_candidate_info.h"
 #include "win32/ime/ime_composition_string.h"
 #include "win32/ime/ime_private_context.h"
@@ -62,7 +64,7 @@ using std::unique_ptr;
 
 namespace {
 
-const size_t kReconvertStringSizeLimit = 1024*64;
+const size_t kReconvertStringSizeLimit = 1024 * 64;
 // An embedded object in the RichEdit will be replaced with this character.
 // See b/3406434 for details.
 const wchar_t kObjectReplacementCharacter = L'\uFFFC';
@@ -83,8 +85,8 @@ bool GetNextState(HIMC himc, const commands::Output &output,
     }
     next_visible_mode = next_logical_mode;
   } else if (!mozc::win32::ConversionModeUtil::ConvertStatusFromMozcToNative(
-      output.status(), context.IsKanaInputPreferred(),
-      &next_open_status, &next_logical_mode, &next_visible_mode)) {
+                 output.status(), context.IsKanaInputPreferred(),
+                 &next_open_status, &next_logical_mode, &next_visible_mode)) {
     return false;
   }
 
@@ -94,8 +96,8 @@ bool GetNextState(HIMC himc, const commands::Output &output,
   return true;
 }
 
-bool UpdateInputContext(
-    HIMC himc, const commands::Output &output, bool generate_message) {
+bool UpdateInputContext(HIMC himc, const commands::Output &output,
+                        bool generate_message) {
   InputState next_state;
   if (!GetNextState(himc, output, &next_state)) {
     return false;
@@ -124,8 +126,7 @@ HIMCC EnsureHIMCCSize(HIMCC himcc, DWORD size) {
   return ::ImmReSizeIMCC(himcc, size);
 }
 
-bool UpdateCompositionString(HIMC himc,
-                             const commands::Output &output,
+bool UpdateCompositionString(HIMC himc, const commands::Output &output,
                              std::vector<UIMessage> *messages) {
   ScopedHIMC<InputContext> context(himc);
 
@@ -133,8 +134,8 @@ bool UpdateCompositionString(HIMC himc,
   // CompositionString buffer that we allocated in ImeSelect(). Thus we need
   // to resize the buffer when necessary. b/6841008
   // TODO(yukawa): Move this logic into more appropriate place.
-  const HIMCC composition_string_handle = EnsureHIMCCSize(
-      context->hCompStr, sizeof(CompositionString));
+  const HIMCC composition_string_handle =
+      EnsureHIMCCSize(context->hCompStr, sizeof(CompositionString));
   if (composition_string_handle == nullptr) {
     return false;
   }
@@ -145,10 +146,9 @@ bool UpdateCompositionString(HIMC himc,
   return true;
 }
 
-bool UpdateCompositionStringAndPushMessages(
-    HIMC himc,
-    const commands::Output &output,
-    MessageQueue *message_queue) {
+bool UpdateCompositionStringAndPushMessages(HIMC himc,
+                                            const commands::Output &output,
+                                            MessageQueue *message_queue) {
   ScopedHIMC<InputContext> context(himc);
   ScopedHIMCC<PrivateContext> private_context(context->hPrivate);
   std::vector<UIMessage> messages;
@@ -165,9 +165,9 @@ bool UpdateCompositionStringAndPushMessages(
   for (std::vector<UIMessage>::const_iterator it = messages.begin();
        it != messages.end(); ++it) {
     if (UIVisibilityTracker::IsVisibilityTestMessageForComposiwionWindow(
-           it->message(), it->wparam(), it->lparam())) {
-      private_context->ui_visibility_tracker->
-        BeginVisibilityTestForCompositionWindow();
+            it->message(), it->wparam(), it->lparam())) {
+      private_context->ui_visibility_tracker
+          ->BeginVisibilityTestForCompositionWindow();
     }
     message_queue->AddMessage(it->message(), it->wparam(), it->lparam());
   }
@@ -187,9 +187,9 @@ bool GetReconvertString(const RECONVERTSTRING *reconvert_string,
   std::wstring preceding_composition;
   std::wstring target_text;
   std::wstring following_composition;
-  if (!ReconvertString::Decompose(
-          reconvert_string, nullptr, &preceding_composition,
-          &target_text, &following_composition, nullptr)) {
+  if (!ReconvertString::Decompose(reconvert_string, nullptr,
+                                  &preceding_composition, &target_text,
+                                  &following_composition, nullptr)) {
     DLOG(INFO) << "ReconvertString::Decompose failed.";
     return false;
   }
@@ -215,8 +215,7 @@ bool GetReconvertString(const RECONVERTSTRING *reconvert_string,
   return true;
 }
 
-bool QueryDocumentFeed(HIMC himc,
-                       std::wstring *preceding_text,
+bool QueryDocumentFeed(HIMC himc, std::wstring *preceding_text,
                        std::wstring *following_text) {
   LRESULT result = ::ImmRequestMessageW(himc, IMR_DOCUMENTFEED, 0);
   if (result == 0) {
@@ -243,9 +242,8 @@ bool QueryDocumentFeed(HIMC himc,
     return false;
   }
 
-  return ReconvertString::Decompose(
-      reconvert_string, preceding_text, nullptr, nullptr, nullptr,
-      following_text);
+  return ReconvertString::Decompose(reconvert_string, preceding_text, nullptr,
+                                    nullptr, nullptr, following_text);
 }
 
 }  // namespace
@@ -267,17 +265,13 @@ void ImeCore::UpdateContextWithSurroundingText(HIMC himc,
 }
 
 KeyEventHandlerResult ImeCore::ImeProcessKey(
-    mozc::client::ClientInterface *client,
-    const VirtualKey &virtual_key,
-    const LParamKeyInfo &lparam,
-    const KeyboardStatus &keyboard_status,
-    const InputBehavior &behavior,
-    const InputState &initial_state,
-    const mozc::commands::Context &context,
-    InputState *next_state,
+    mozc::client::ClientInterface *client, const VirtualKey &virtual_key,
+    const LParamKeyInfo &lparam, const KeyboardStatus &keyboard_status,
+    const InputBehavior &behavior, const InputState &initial_state,
+    const mozc::commands::Context &context, InputState *next_state,
     commands::Output *output) {
-  unique_ptr<Win32KeyboardInterface>
-      keyboard(Win32KeyboardInterface::CreateDefault());
+  unique_ptr<Win32KeyboardInterface> keyboard(
+      Win32KeyboardInterface::CreateDefault());
   return KeyEventHandler::ImeProcessKey(
       virtual_key, lparam.GetScanCode(), lparam.IsKeyDownInImeProcessKey(),
       keyboard_status, behavior, initial_state, context, client, keyboard.get(),
@@ -285,18 +279,13 @@ KeyEventHandlerResult ImeCore::ImeProcessKey(
 }
 
 KeyEventHandlerResult ImeCore::ImeToAsciiEx(
-    mozc::client::ClientInterface *client,
-    const VirtualKey &virtual_key,
-    BYTE scan_code,
-    bool is_key_down,
-    const KeyboardStatus &keyboard_status,
-    const InputBehavior &behavior,
-    const InputState &initial_state,
-    const commands::Context &context,
-    InputState *next_state,
+    mozc::client::ClientInterface *client, const VirtualKey &virtual_key,
+    BYTE scan_code, bool is_key_down, const KeyboardStatus &keyboard_status,
+    const InputBehavior &behavior, const InputState &initial_state,
+    const commands::Context &context, InputState *next_state,
     commands::Output *output) {
-  unique_ptr<Win32KeyboardInterface>
-      keyboard(Win32KeyboardInterface::CreateDefault());
+  unique_ptr<Win32KeyboardInterface> keyboard(
+      Win32KeyboardInterface::CreateDefault());
   return KeyEventHandler::ImeToAsciiEx(
       virtual_key, scan_code, is_key_down, keyboard_status, behavior,
       initial_state, context, client, keyboard.get(), next_state, output);
@@ -321,8 +310,8 @@ bool ImeCore::OpenIME(mozc::client::ClientInterface *client, DWORD next_mode) {
   return true;
 }
 
-bool ImeCore::CloseIME(mozc::client::ClientInterface *client,
-                       DWORD next_mode, commands::Output *output) {
+bool ImeCore::CloseIME(mozc::client::ClientInterface *client, DWORD next_mode,
+                       commands::Output *output) {
   commands::CompositionMode mode = commands::DIRECT;
   if (!ConversionModeUtil::GetMozcModeFromNativeMode(next_mode, &mode)) {
     return false;
@@ -360,8 +349,8 @@ bool ImeCore::CancelComposition(HIMC himc, bool generate_message) {
   return UpdateInputContext(himc, output, generate_message);
 }
 
-bool ImeCore::SwitchInputMode(
-    HIMC himc, DWORD native_mode, bool generate_message) {
+bool ImeCore::SwitchInputMode(HIMC himc, DWORD native_mode,
+                              bool generate_message) {
   UIContext context(himc);
 
   const bool open = context.GetOpenStatus();
@@ -389,8 +378,8 @@ DWORD ImeCore::GetSupportableConversionMode(DWORD raw_conversion_mode) {
   // we have to update it and then send the IMN_SETCONVERSIONMODE message.
   // See b/2914115 for details.
   const DWORD kHiragana = IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE;
-  const DWORD kFullKatakana = IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE |
-                              IME_CMODE_KATAKANA;
+  const DWORD kFullKatakana =
+      IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE | IME_CMODE_KATAKANA;
   const DWORD kHalfKatakana = IME_CMODE_NATIVE | IME_CMODE_KATAKANA;
   const DWORD kFullAlpha = IME_CMODE_ALPHANUMERIC | IME_CMODE_FULLSHAPE;
   const DWORD kHalfAlpha = IME_CMODE_ALPHANUMERIC;
@@ -456,17 +445,13 @@ bool ImeCore::IsInputContextInitialized(HIMC himc) {
 
 void ImeCore::SortIMEMessages(
     const std::vector<UIMessage> &composition_messages,
-    const std::vector<UIMessage> &candidate_messages,
-    bool previous_open_status,
-    DWORD previous_conversion_mode,
-    bool next_open_status,
-    DWORD next_conversion_mode,
-    std::vector<UIMessage> *sorted_messages) {
+    const std::vector<UIMessage> &candidate_messages, bool previous_open_status,
+    DWORD previous_conversion_mode, bool next_open_status,
+    DWORD next_conversion_mode, std::vector<UIMessage> *sorted_messages) {
   DCHECK(sorted_messages);
   sorted_messages->clear();
 
-  const bool open_status_changed =
-      (previous_open_status != next_open_status);
+  const bool open_status_changed = (previous_open_status != next_open_status);
   const bool conversion_mode_changed =
       (previous_conversion_mode != next_conversion_mode);
 
@@ -477,8 +462,8 @@ void ImeCore::SortIMEMessages(
 
   // Notify IMN_SETCONVERSIONMODE.
   if (conversion_mode_changed) {
-    sorted_messages->push_back(UIMessage(
-        WM_IME_NOTIFY, IMN_SETCONVERSIONMODE, 0));
+    sorted_messages->push_back(
+        UIMessage(WM_IME_NOTIFY, IMN_SETCONVERSIONMODE, 0));
   }
 
   // Notify IMN_CLOSECANDIDATE.
@@ -509,7 +494,7 @@ void ImeCore::SortIMEMessages(
   // Notify all other candidate UI messages.
   // Typically IMN_OPENCANDIDATE and IMN_CHANGECANDIDATE will be handled.
   for (std::vector<UIMessage>::const_iterator it =
-       other_candidate_messages.begin();
+           other_candidate_messages.begin();
        it != other_candidate_messages.end(); ++it) {
     DCHECK(!((it->message() == WM_IME_NOTIFY) &&
              (it->wparam() == IMN_CLOSECANDIDATE)));
@@ -518,7 +503,7 @@ void ImeCore::SortIMEMessages(
 
   // Notify WM_IME_ENDCOMPOSITION
   for (std::vector<UIMessage>::const_iterator it =
-       end_composition_messages.begin();
+           end_composition_messages.begin();
        it != end_composition_messages.end(); ++it) {
     DCHECK_EQ(WM_IME_ENDCOMPOSITION, it->message());
     sorted_messages->push_back(*it);
@@ -533,8 +518,7 @@ void ImeCore::SortIMEMessages(
       UIMessage(WM_IME_NOTIFY, IMN_PRIVATE, kNotifyUpdateUI));
 }
 
-bool ImeCore::UpdateContext(HIMC himc,
-                            const InputState &next_state,
+bool ImeCore::UpdateContext(HIMC himc, const InputState &next_state,
                             const commands::Output &new_output,
                             MessageQueue *message_queue) {
   if (!IsInputContextInitialized(himc)) {
@@ -574,12 +558,11 @@ bool ImeCore::UpdateContext(HIMC himc,
   if (!GetNextState(himc, callback_output, &callback_state)) {
     return false;
   }
-  return UpdateContextMain(himc, callback_state,
-                           callback_output, message_queue);
+  return UpdateContextMain(himc, callback_state, callback_output,
+                           message_queue);
 }
 
-bool ImeCore::UpdateContextMain(HIMC himc,
-                                const InputState &next_state,
+bool ImeCore::UpdateContextMain(HIMC himc, const InputState &next_state,
                                 const commands::Output &new_output,
                                 MessageQueue *message_queue) {
   DCHECK(IsInputContextInitialized(himc));
@@ -589,8 +572,8 @@ bool ImeCore::UpdateContextMain(HIMC himc,
 
   // If the deletion range matches commands::Capability::DELETE_PRECEDING_TEXT,
   // initialize the deleter.
-  if (generate_message &&
-      new_output.has_consumed() && new_output.has_deletion_range() &&
+  if (generate_message && new_output.has_consumed() &&
+      new_output.has_deletion_range() &&
       new_output.deletion_range().has_length() &&
       new_output.deletion_range().has_offset() &&
       (new_output.deletion_range().length() ==
@@ -600,8 +583,8 @@ bool ImeCore::UpdateContextMain(HIMC himc,
     UIContext uicontext(himc);
     if (!uicontext.IsCompositionStringEmpty()) {
       commands::Output empty_output;
-      if (!UpdateCompositionStringAndPushMessages(
-              himc, empty_output, message_queue)) {
+      if (!UpdateCompositionStringAndPushMessages(himc, empty_output,
+                                                  message_queue)) {
         return false;
       }
     }
@@ -623,8 +606,7 @@ bool ImeCore::UpdateContextMain(HIMC himc,
   *private_context->ime_state = next_state;
   const bool previous_open = (context->fOpen != FALSE);
   const DWORD previous_conversion = context->fdwConversion;
-  const commands::Output &output =
-      *private_context->last_output;
+  const commands::Output &output = *private_context->last_output;
 
   // Update context.
   context->fOpen = next_state.open ? TRUE : FALSE;
@@ -636,9 +618,8 @@ bool ImeCore::UpdateContextMain(HIMC himc,
   }
 
   std::vector<UIMessage> candidate_messages;
-  context->hCandInfo =
-      mozc::win32::CandidateInfoUtil::Update(context->hCandInfo,
-                                             output, &candidate_messages);
+  context->hCandInfo = mozc::win32::CandidateInfoUtil::Update(
+      context->hCandInfo, output, &candidate_messages);
   if (context->hCandInfo == nullptr) {
     return false;
   }
@@ -648,13 +629,9 @@ bool ImeCore::UpdateContextMain(HIMC himc,
     // we might want to send these messages in the the same order to MS-IME.
     // See b/3488848 for details.
     std::vector<UIMessage> sorted_messages;
-    SortIMEMessages(composition_messages,
-                    candidate_messages,
-                    previous_open,
-                    previous_conversion,
-                    next_state.open,
-                    next_state.logical_conversion_mode,
-                    &sorted_messages);
+    SortIMEMessages(composition_messages, candidate_messages, previous_open,
+                    previous_conversion, next_state.open,
+                    next_state.logical_conversion_mode, &sorted_messages);
 
     // Allow visibility trackers to track if each UI message will be
     UIVisibilityTracker *ui_visibility_tracker =
@@ -662,11 +639,11 @@ bool ImeCore::UpdateContextMain(HIMC himc,
     for (std::vector<UIMessage>::const_iterator it = sorted_messages.begin();
          it != sorted_messages.end(); ++it) {
       if (UIVisibilityTracker::IsVisibilityTestMessageForCandidateWindow(
-             it->message(), it->wparam(), it->lparam())) {
-       ui_visibility_tracker->BeginVisibilityTestForCandidateWindow();
+              it->message(), it->wparam(), it->lparam())) {
+        ui_visibility_tracker->BeginVisibilityTestForCandidateWindow();
       }
       if (UIVisibilityTracker::IsVisibilityTestMessageForComposiwionWindow(
-             it->message(), it->wparam(), it->lparam())) {
+              it->message(), it->wparam(), it->lparam())) {
         ui_visibility_tracker->BeginVisibilityTestForCompositionWindow();
       }
       message_queue->AddMessage(it->message(), it->wparam(), it->lparam());
@@ -689,8 +666,7 @@ BOOL ImeCore::IMEOff(HIMC himc, bool generate_message) {
   }
 
   commands::Output output;
-  if (!ImeCore::CloseIME(context.client(), logical_conversion_mode,
-                         &output)) {
+  if (!ImeCore::CloseIME(context.client(), logical_conversion_mode, &output)) {
     return FALSE;
   }
   bool next_open_status = false;
@@ -702,10 +678,9 @@ BOOL ImeCore::IMEOff(HIMC himc, bool generate_message) {
       return FALSE;
     }
     next_visible_mode = next_logical_mode;
-  } else if (!mozc::win32::ConversionModeUtil::
-                  ConvertStatusFromMozcToNative(
-      output.status(), context.IsKanaInputPreferred(),
-      &next_open_status, &next_logical_mode, &next_visible_mode)) {
+  } else if (!mozc::win32::ConversionModeUtil::ConvertStatusFromMozcToNative(
+                 output.status(), context.IsKanaInputPreferred(),
+                 &next_open_status, &next_logical_mode, &next_visible_mode)) {
     return FALSE;
   }
   InputState next_state;
@@ -726,8 +701,8 @@ BOOL ImeCore::IMEOff(HIMC himc, bool generate_message) {
   return (message_queue.Send() ? TRUE : FALSE);
 }
 
-BOOL ImeCore::HighlightCandidate(
-    HIMC himc, int32 candidate_index, bool generate_message) {
+BOOL ImeCore::HighlightCandidate(HIMC himc, int32 candidate_index,
+                                 bool generate_message) {
   if (!IsInputContextInitialized(himc)) {
     return FALSE;
   }
@@ -744,8 +719,8 @@ BOOL ImeCore::HighlightCandidate(
       return FALSE;
     }
 
-    if (!OutputUtil::GetCandidateIdByIndex(
-             last_output, candidate_index, &next_candidate_id)) {
+    if (!OutputUtil::GetCandidateIdByIndex(last_output, candidate_index,
+                                           &next_candidate_id)) {
       return FALSE;
     }
 
@@ -753,8 +728,7 @@ BOOL ImeCore::HighlightCandidate(
     // selected.  If the |last_output| does not have focused candidate,
     // HIGHLIGHT_CANDIDATE is always be sent.
     int32 focused_candidate_id = 0;
-    if (OutputUtil::GetFocusedCandidateId(
-            last_output, &focused_candidate_id) &&
+    if (OutputUtil::GetFocusedCandidateId(last_output, &focused_candidate_id) &&
         (next_candidate_id == focused_candidate_id)) {
       // Already highlighted.
       return TRUE;
@@ -801,8 +775,8 @@ BOOL ImeCore::CloseCandidate(HIMC himc, bool generate_message) {
     // displayed, currently we need this path to support mouse clicking for
     // suggest window.
 
-    if (!OutputUtil::GetFocusedCandidateId(
-             last_output, &focused_candidate_id)) {
+    if (!OutputUtil::GetFocusedCandidateId(last_output,
+                                           &focused_candidate_id)) {
       return FALSE;
     }
   }
@@ -824,8 +798,7 @@ BOOL ImeCore::CloseCandidate(HIMC himc, bool generate_message) {
 bool ImeCore::IsActiveContext(HIMC himc) {
   bool is_active = false;
   const HWND focus_window = ::GetFocus();
-  if (focus_window != nullptr &&
-      ::IsWindow(focus_window) != FALSE) {
+  if (focus_window != nullptr && ::IsWindow(focus_window) != FALSE) {
     const HIMC active_himc = ::ImmGetContext(focus_window);
     is_active = (himc == active_himc);
     ::ImmReleaseContext(focus_window, active_himc);
@@ -924,9 +897,9 @@ string ImeCore::GetTextForReconversionFromIME(HIMC himc) {
           expanded_reconvert_string)) {
     return "";
   }
-  result = ::ImmRequestMessageW(
-      himc, IMR_CONFIRMRECONVERTSTRING,
-      reinterpret_cast<LPARAM>(expanded_reconvert_string));
+  result =
+      ::ImmRequestMessageW(himc, IMR_CONFIRMRECONVERTSTRING,
+                           reinterpret_cast<LPARAM>(expanded_reconvert_string));
   if (result != FALSE) {
     // The application accepted |expanded_reconvert_string|.
     reconvert_string = expanded_reconvert_string;
