@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,53 +31,51 @@
 // Microsoft Visual C++ generated include file.
 // Used by TextService_template.rc
 //
-#define IDS_INPUTMODE                   104
-#define IDS_DIRECT                      106
-#define IDS_HIRAGANA                    107
-#define IDS_TOOL                        108
-#define IDS_PROPERTY                    109
-#define IDS_DICTIONARY                  110
-#define IDS_WORD_REGISTER               111
-#define IDS_HELP                        112
-#define IDS_CANCEL                      114
-#define IDS_HAND_WRITING                113
-#define IDS_CHARACTER_PALETTE           115
-#define IDS_ABOUT                       116
-#define IDS_FULL_KATAKANA               117
-#define IDS_HALF_ALPHANUMERIC           118
-#define IDS_FULL_ALPHANUMERIC           119
-#define IDS_HALF_KATAKANA               120
-#define IDS_RECONVERSION                121
+#define IDS_INPUTMODE 104
+#define IDS_DIRECT 106
+#define IDS_HIRAGANA 107
+#define IDS_TOOL 108
+#define IDS_PROPERTY 109
+#define IDS_DICTIONARY 110
+#define IDS_WORD_REGISTER 111
+#define IDS_HELP 112
+#define IDS_CANCEL 114
+#define IDS_ABOUT 116
+#define IDS_FULL_KATAKANA 117
+#define IDS_HALF_ALPHANUMERIC 118
+#define IDS_FULL_ALPHANUMERIC 119
+#define IDS_HALF_KATAKANA 120
+#define IDS_RECONVERSION 121
 
 // Historically, the TSF version of Mozc used the resource ID 102 for showing
 // IMM32 icon.  For this reason, we keep this ID for the product icon.
-#define IDI_IMM32                       102
-#define IDI_DIRECT                      112
-#define IDI_DIRECT_NT                   103
-#define IDI_HIRAGANA                    104
-#define IDI_HIRAGANA_NT                 105
-#define IDI_TOOL                        106
-#define IDI_TOOL_NT                     107
-#define IDI_PROPERTY                    108
-#define IDI_PROPERTY_NT                 109
-#define IDI_DICTIONARY                  110
-#define IDI_DICTIONARY_NT               111
-#define IDI_FULL_KATAKANA               114
-#define IDI_FULL_KATAKANA_NT            115
-#define IDI_HALF_ALPHANUMERIC           116
-#define IDI_HALF_ALPHANUMERIC_NT        117
-#define IDI_FULL_ALPHANUMERIC           118
-#define IDI_FULL_ALPHANUMERIC_NT        119
-#define IDI_HALF_KATAKANA               120
-#define IDI_HALF_KATAKANA_NT            121
+#define IDI_IMM32 102
+#define IDI_DIRECT 112
+#define IDI_DIRECT_NT 103
+#define IDI_HIRAGANA 104
+#define IDI_HIRAGANA_NT 105
+#define IDI_TOOL 106
+#define IDI_TOOL_NT 107
+#define IDI_PROPERTY 108
+#define IDI_PROPERTY_NT 109
+#define IDI_DICTIONARY 110
+#define IDI_DICTIONARY_NT 111
+#define IDI_FULL_KATAKANA 114
+#define IDI_FULL_KATAKANA_NT 115
+#define IDI_HALF_ALPHANUMERIC 116
+#define IDI_HALF_ALPHANUMERIC_NT 117
+#define IDI_FULL_ALPHANUMERIC 118
+#define IDI_FULL_ALPHANUMERIC_NT 119
+#define IDI_HALF_KATAKANA 120
+#define IDI_HALF_KATAKANA_NT 121
 
 // Next default values for new objects
 //
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
-#define _APS_NEXT_RESOURCE_VALUE        118
-#define _APS_NEXT_COMMAND_VALUE         40002
-#define _APS_NEXT_CONTROL_VALUE         1000
-#define _APS_NEXT_SYMED_VALUE           101
+#define _APS_NEXT_RESOURCE_VALUE 118
+#define _APS_NEXT_COMMAND_VALUE 40002
+#define _APS_NEXT_CONTROL_VALUE 1000
+#define _APS_NEXT_SYMED_VALUE 101
 #endif
 #endif
