@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -54,9 +54,7 @@ namespace {
 class CandidateStringImpl : public ITfCandidateString {
  public:
   CandidateStringImpl(ULONG index, const std::wstring &value)
-      : index_(index),
-        value_(value) {
-  }
+      : index_(index), value_(value) {}
 
   // The IUnknown interface methods.
   virtual HRESULT STDMETHODCALLTYPE QueryInterface(const IID &interface_id,
@@ -80,9 +78,7 @@ class CandidateStringImpl : public ITfCandidateString {
     return S_OK;
   }
 
-  virtual ULONG STDMETHODCALLTYPE AddRef() {
-    return ref_count_.AddRefImpl();
-  }
+  virtual ULONG STDMETHODCALLTYPE AddRef() { return ref_count_.AddRefImpl(); }
 
   virtual ULONG STDMETHODCALLTYPE Release() {
     const ULONG count = ref_count_.ReleaseImpl();
@@ -120,9 +116,7 @@ class CandidateStringImpl : public ITfCandidateString {
 class EnumTfCandidatesImpl : public IEnumTfCandidates {
  public:
   explicit EnumTfCandidatesImpl(const std::vector<std::wstring> &candidates)
-      : candidates_(candidates),
-        current_(0) {
-  }
+      : candidates_(candidates), current_(0) {}
 
   // The IUnknown interface methods.
   virtual HRESULT STDMETHODCALLTYPE QueryInterface(const IID &interface_id,
@@ -146,9 +140,7 @@ class EnumTfCandidatesImpl : public IEnumTfCandidates {
     return S_OK;
   }
 
-  virtual ULONG STDMETHODCALLTYPE AddRef() {
-    return ref_count_.AddRefImpl();
-  }
+  virtual ULONG STDMETHODCALLTYPE AddRef() { return ref_count_.AddRefImpl(); }
 
   virtual ULONG STDMETHODCALLTYPE Release() {
     const ULONG count = ref_count_.ReleaseImpl();
@@ -185,8 +177,8 @@ class EnumTfCandidatesImpl : public IEnumTfCandidates {
         *fetched_count = i;
         return S_FALSE;
       }
-      candidate_string[i] = new CandidateStringImpl(current_,
-                                                    candidates_[current_]);
+      candidate_string[i] =
+          new CandidateStringImpl(current_, candidates_[current_]);
       candidate_string[i]->AddRef();
       ++current_;
     }
@@ -220,9 +212,7 @@ class CandidateListImpl : public ITfCandidateList {
  public:
   CandidateListImpl(const std::vector<std::wstring> &candidates,
                     TipCandidateListCallback *callback)
-      : candidates_(candidates),
-        callback_(callback) {
-  }
+      : candidates_(candidates), callback_(callback) {}
 
   // The IUnknown interface methods.
   virtual HRESULT STDMETHODCALLTYPE QueryInterface(const IID &interface_id,
@@ -246,9 +236,7 @@ class CandidateListImpl : public ITfCandidateList {
     return S_OK;
   }
 
-  virtual ULONG STDMETHODCALLTYPE AddRef() {
-    return ref_count_.AddRefImpl();
-  }
+  virtual ULONG STDMETHODCALLTYPE AddRef() { return ref_count_.AddRefImpl(); }
 
   virtual ULONG STDMETHODCALLTYPE Release() {
     const ULONG count = ref_count_.ReleaseImpl();
@@ -260,8 +248,8 @@ class CandidateListImpl : public ITfCandidateList {
 
  private:
   // The ITfCandidateList interface methods.
-  virtual HRESULT STDMETHODCALLTYPE EnumCandidates(
-      IEnumTfCandidates **enum_candidate) {
+  virtual HRESULT STDMETHODCALLTYPE
+  EnumCandidates(IEnumTfCandidates **enum_candidate) {
     if (enum_candidate == nullptr) {
       return E_INVALIDARG;
     }
@@ -270,9 +258,8 @@ class CandidateListImpl : public ITfCandidateList {
     return S_OK;
   }
 
-  virtual HRESULT STDMETHODCALLTYPE GetCandidate(
-      ULONG index,
-      ITfCandidateString **candidate_string) {
+  virtual HRESULT STDMETHODCALLTYPE
+  GetCandidate(ULONG index, ITfCandidateString **candidate_string) {
     if (candidate_string == nullptr) {
       return E_INVALIDARG;
     }
@@ -292,9 +279,8 @@ class CandidateListImpl : public ITfCandidateList {
     return S_OK;
   }
 
-  virtual HRESULT STDMETHODCALLTYPE SetResult(
-      ULONG index,
-      TfCandidateResult candidate_result) {
+  virtual HRESULT STDMETHODCALLTYPE
+  SetResult(ULONG index, TfCandidateResult candidate_result) {
     if (candidates_.size() <= index) {
       return E_INVALIDARG;
     }
@@ -314,8 +300,7 @@ class CandidateListImpl : public ITfCandidateList {
 
 }  // namespace
 
-TipCandidateListCallback::~TipCandidateListCallback() {
-}
+TipCandidateListCallback::~TipCandidateListCallback() {}
 
 // static
 ITfCandidateList *TipCandidateList::New(
