@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,9 +30,9 @@
 #ifndef MOZC_WIN32_TIP_TIP_ENUM_DISPLAY_ATTRIBUTES_H_
 #define MOZC_WIN32_TIP_TIP_ENUM_DISPLAY_ATTRIBUTES_H_
 
-#include <windows.h>
-#include <rpcsal.h>
 #include <msctf.h>
+#include <rpcsal.h>
+#include <windows.h>
 
 #include "base/port.h"
 #include "win32/tip/tip_ref_count.h"
@@ -42,23 +42,22 @@ namespace win32 {
 namespace tsf {
 
 // Represents the list of the display attributes used in this module.
-class TipEnumDisplayAttributes
-    : public IEnumTfDisplayAttributeInfo {
+class TipEnumDisplayAttributes : public IEnumTfDisplayAttributeInfo {
  public:
   TipEnumDisplayAttributes();
   virtual ~TipEnumDisplayAttributes();
 
   // IUnknown
-  virtual HRESULT STDMETHODCALLTYPE QueryInterface(
-      REFIID interface_id, void **object);
+  virtual HRESULT STDMETHODCALLTYPE QueryInterface(REFIID interface_id,
+                                                   void **object);
   virtual ULONG STDMETHODCALLTYPE AddRef();
   virtual ULONG STDMETHODCALLTYPE Release();
 
   // IEnumTfDisplayAttributeInfo
-  virtual HRESULT STDMETHODCALLTYPE Clone(
-      IEnumTfDisplayAttributeInfo **enum_attributes);
-  virtual HRESULT STDMETHODCALLTYPE Next(
-      ULONG count, ITfDisplayAttributeInfo **attribute_array, ULONG *fetched);
+  virtual HRESULT STDMETHODCALLTYPE
+  Clone(IEnumTfDisplayAttributeInfo **enum_attributes);
+  virtual HRESULT STDMETHODCALLTYPE
+  Next(ULONG count, ITfDisplayAttributeInfo **attribute_array, ULONG *fetched);
   virtual HRESULT STDMETHODCALLTYPE Reset();
   virtual HRESULT STDMETHODCALLTYPE Skip(ULONG count);
 
