@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,8 +41,8 @@ using ::mozc::client::ClientFactory;
 using ::mozc::client::ClientInterface;
 using ::mozc::commands::Input;
 using ::mozc::commands::KeyEvent;
-using ::mozc::commands::SessionCommand;
 using ::mozc::commands::Output;
+using ::mozc::commands::SessionCommand;
 using ::std::unique_ptr;
 
 namespace mozc {
@@ -53,14 +53,11 @@ namespace {
 
 class TipQueryProviderImpl : public TipQueryProvider {
  public:
-  explicit TipQueryProviderImpl(ClientInterface *client)
-      : client_(client) {
-  }
+  explicit TipQueryProviderImpl(ClientInterface *client) : client_(client) {}
 
  private:
   // The TipQueryProvider interface methods.
-  virtual bool Query(const std::wstring &query,
-                     QueryType type,
+  virtual bool Query(const std::wstring &query, QueryType type,
                      std::vector<std::wstring> *result) {
     if (type == kReconversion) {
       return ReconvertQuery(query, result);
@@ -141,8 +138,7 @@ class TipQueryProviderImpl : public TipQueryProvider {
 
 }  // namespace
 
-TipQueryProvider::~TipQueryProvider() {
-}
+TipQueryProvider::~TipQueryProvider() {}
 
 // static
 TipQueryProvider *TipQueryProvider::Create() {
