@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -52,8 +52,7 @@ class TipQueryProvider {
     kDefault,
     kReconversion,
   };
-  virtual bool Query(const std::wstring &query,
-                     QueryType type,
+  virtual bool Query(const std::wstring &query, QueryType type,
                      std::vector<std::wstring> *result) = 0;
 };
 
