@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,9 +32,9 @@
 #include <Windows.h>
 #define _ATL_NO_AUTOMATIC_NAMESPACE
 #define _WTL_NO_AUTOMATIC_NAMESPACE
+#include <Ctffunc.h>
 #include <atlbase.h>
 #include <atlcom.h>
-#include <Ctffunc.h>
 
 #include <memory>
 #include <vector>
@@ -53,8 +53,7 @@ namespace tsf {
 namespace {
 
 #ifdef GOOGLE_JAPANESE_INPUT_BUILD
-const wchar_t kSearchCandidateProviderName[] =
-    L"Google Japanese Input";
+const wchar_t kSearchCandidateProviderName[] = L"Google Japanese Input";
 #else
 const wchar_t kSearchCandidateProviderName[] = L"Mozc";
 #endif
@@ -62,8 +61,7 @@ const wchar_t kSearchCandidateProviderName[] = L"Mozc";
 class SearchCandidateProviderImpl : public ITfFnSearchCandidateProvider {
  public:
   explicit SearchCandidateProviderImpl(TipQueryProvider *provider)
-      : provider_(provider) {
-  }
+      : provider_(provider) {}
 
  private:
   // The IUnknown interface methods.
@@ -90,9 +88,7 @@ class SearchCandidateProviderImpl : public ITfFnSearchCandidateProvider {
     return S_OK;
   }
 
-  virtual ULONG STDMETHODCALLTYPE AddRef() {
-    return ref_count_.AddRefImpl();
-  }
+  virtual ULONG STDMETHODCALLTYPE AddRef() { return ref_count_.AddRefImpl(); }
 
   virtual ULONG STDMETHODCALLTYPE Release() {
     const ULONG count = ref_count_.ReleaseImpl();
@@ -113,9 +109,7 @@ class SearchCandidateProviderImpl : public ITfFnSearchCandidateProvider {
 
   // The ITfFnSearchCandidateProvider interface method.
   virtual HRESULT STDMETHODCALLTYPE GetSearchCandidates(
-      BSTR query,
-      BSTR application_id,
-      ITfCandidateList **candidate_list) {
+      BSTR query, BSTR application_id, ITfCandidateList **candidate_list) {
     if (candidate_list == nullptr) {
       return E_INVALIDARG;
     }
@@ -128,8 +122,7 @@ class SearchCandidateProviderImpl : public ITfFnSearchCandidateProvider {
     return S_OK;
   }
 
-  virtual HRESULT STDMETHODCALLTYPE SetResult(BSTR query,
-                                              BSTR application_id,
+  virtual HRESULT STDMETHODCALLTYPE SetResult(BSTR query, BSTR application_id,
                                               BSTR result) {
     // Not implemented.
     return S_OK;
