@@ -1,4 +1,4 @@
-// Copyright 2010-2018, Google Inc.
+// Copyright 2010-2020, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -49,8 +49,7 @@ class TipUiHandler {
     kIndicatorWindow,
   };
 
-  static ITfUIElement *CreateUI(UiType type,
-                                TipTextService *text_service,
+  static ITfUIElement *CreateUI(UiType type, TipTextService *text_service,
                                 ITfContext *context);
   static void OnDestroyElement(TipTextService *text_service,
                                ITfUIElement *element);
@@ -61,8 +60,7 @@ class TipUiHandler {
                                    ITfDocumentMgr *document_manager);
   static void OnFocusChange(TipTextService *text_service,
                             ITfDocumentMgr *focused_document_manager);
-  static bool Update(TipTextService *text_service,
-                     ITfContext *context,
+  static bool Update(TipTextService *text_service, ITfContext *context,
                      TfEditCookie readable_cookie);
   static bool OnDllProcessAttach(HINSTANCE module_handle, bool static_loading);
   static void OnDllProcessDetach(HINSTANCE module_handle,
